@@ -18,12 +18,9 @@
  */
 package org.apache.accumulo.core.classloader;
 
-import java.io.IOException;
-
 import org.apache.accumulo.core.conf.AccumuloConfiguration;
 import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.spi.common.ContextClassLoaderFactory;
-import org.apache.accumulo.core.spi.common.ContextClassLoaderFactory.ContextClassLoaderException;
 import org.apache.accumulo.core.util.ConfigurationImpl;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -48,7 +45,7 @@ public class ClassLoaderUtil {
         // load the default implementation
         LOG.info("Using default {}, which is subject to change in a future release",
             ContextClassLoaderFactory.class.getName());
-        FACTORY = new DefaultContextClassLoaderFactory(conf);
+        FACTORY = new URLContextClassLoaderFactory();
       } else {
         // load user's selected implementation and provide it with the service environment
         try {
@@ -72,20 +69,19 @@ public class ClassLoaderUtil {
   }
 
   // for testing
-  public static synchronized void resetContextFactoryForTests() {
+  static synchronized void resetContextFactoryForTests() {
     FACTORY = null;
   }
 
-  @SuppressWarnings("deprecation")
-  public static ClassLoader getClassLoader(String context) throws ContextClassLoaderException {
+  public static ClassLoader getClassLoader() {
+    return getClassLoader(null);
+  }
+
+  public static ClassLoader getClassLoader(String context) {
     if (context != null && !context.isEmpty()) {
       return FACTORY.getClassLoader(context);
     } else {
-      try {
-        return org.apache.accumulo.start.classloader.vfs.AccumuloVFSClassLoader.getClassLoader();
-      } catch (IOException e) {
-        throw new ContextClassLoaderException(context, e);
-      }
+      return ClassLoader.getSystemClassLoader();
     }
   }
 
@@ -99,7 +95,7 @@ public class ClassLoaderUtil {
           return false;
         }
         return true;
-      } catch (ContextClassLoaderException e) {
+      } catch (RuntimeException e) {
         LOG.debug("Context {} is not valid.", context, e);
         return false;
       }
@@ -110,11 +106,7 @@ public class ClassLoaderUtil {
 
   public static <U> Class<? extends U> loadClass(String context, String className,
       Class<U> extension) throws ClassNotFoundException {
-    try {
-      return getClassLoader(context).loadClass(className).asSubclass(extension);
-    } catch (ContextClassLoaderException e) {
-      throw new ClassNotFoundException("Error loading class from context: " + context, e);
-    }
+    return getClassLoader(context).loadClass(className).asSubclass(extension);
   }
 
   public static <U> Class<? extends U> loadClass(String className, Class<U> extension)
@@ -125,9 +117,8 @@ public class ClassLoaderUtil {
   /**
    * Retrieve the classloader context from a table's configuration.
    */
-  @SuppressWarnings("removal")
   public static String tableContext(AccumuloConfiguration conf) {
-    return conf.get(conf.resolve(Property.TABLE_CLASSLOADER_CONTEXT, Property.TABLE_CLASSPATH));
+    return conf.get(Property.TABLE_CLASSLOADER_CONTEXT);
   }
 
 }
