@@ -33,8 +33,8 @@ public interface ConditionalWriter extends AutoCloseable {
   class Result {
 
     private Status status;
-    private final ConditionalMutation mutation;
-    private final String server;
+    private ConditionalMutation mutation;
+    private String server;
     private Exception exception;
 
     public Result(Status s, ConditionalMutation m, String server) {
@@ -107,7 +107,7 @@ public interface ConditionalWriter extends AutoCloseable {
      */
     VIOLATED,
     /**
-     * Error occurred after mutation was sent to server, its unknown if the mutation was written.
+     * error occurred after mutation was sent to server, its unknown if the mutation was written.
      * Although the status of the mutation is unknown, Accumulo guarantees the mutation will not be
      * written at a later point in time.
      */
