@@ -18,8 +18,8 @@
  */
 package org.apache.accumulo.core.client;
 
+import static com.google.common.util.concurrent.Uninterruptibles.sleepUninterruptibly;
 import static java.util.concurrent.TimeUnit.MILLISECONDS;
-import static org.apache.accumulo.core.util.UtilWaitThread.sleepUninterruptibly;
 
 import java.util.ArrayList;
 import java.util.Iterator;
@@ -45,17 +45,17 @@ public class IsolatedScanner extends ScannerOptions implements Scanner {
   private static class RowBufferingIterator implements Iterator<Entry<Key,Value>> {
 
     private Iterator<Entry<Key,Value>> source;
-    private final RowBuffer buffer;
+    private RowBuffer buffer;
     private Entry<Key,Value> nextRowStart;
     private Iterator<Entry<Key,Value>> rowIter;
     private ByteSequence lastRow = null;
-    private final long timeout;
+    private long timeout;
 
     private final Scanner scanner;
-    private final ScannerOptions opts;
-    private final Range range;
-    private final int batchSize;
-    private final long readaheadThreshold;
+    private ScannerOptions opts;
+    private Range range;
+    private int batchSize;
+    private long readaheadThreshold;
 
     private void readRow() {
 
@@ -195,7 +195,7 @@ public class IsolatedScanner extends ScannerOptions implements Scanner {
 
   public static class MemoryRowBuffer implements RowBuffer {
 
-    private final ArrayList<Entry<Key,Value>> buffer = new ArrayList<>();
+    private ArrayList<Entry<Key,Value>> buffer = new ArrayList<>();
 
     @Override
     public void add(Entry<Key,Value> entry) {
@@ -214,11 +214,11 @@ public class IsolatedScanner extends ScannerOptions implements Scanner {
 
   }
 
-  private final Scanner scanner;
+  private Scanner scanner;
   private Range range;
   private int batchSize;
   private long readaheadThreshold;
-  private final RowBufferFactory bufferFactory;
+  private RowBufferFactory bufferFactory;
 
   public IsolatedScanner(Scanner scanner) {
     this(scanner, new MemoryRowBufferFactory());
