@@ -27,7 +27,7 @@ public class NamespaceNotEmptyException extends Exception {
 
   private static final long serialVersionUID = 1L;
 
-  private final String namespace;
+  private String namespace;
 
   /**
    * @param namespaceId the internal id of the namespace
