@@ -29,7 +29,7 @@ public class NamespaceNotFoundException extends Exception {
    */
   private static final long serialVersionUID = 1L;
 
-  private final String namespace;
+  private String namespace;
 
   /**
    * @param namespaceId the internal id of the namespace that was sought
