@@ -140,7 +140,17 @@ public interface InstanceOperations {
   void removeProperty(final String property) throws AccumuloException, AccumuloSecurityException;
 
   /**
-   * Retrieve the system-wide configuration.
+   * Retrieve the system-wide, merged view of the system configuration. Accumulo has multiple layers
+   * of properties, in order of precedence (highest - lowest):
+   * <ul>
+   * <li>the properties set in Zookeeper</li>
+   * <li>the properties set in the site configuration file</li>
+   * <li>the default properties</li>
+   * </ul>
+   * The properties returned is the merged view of these properties. The properties that are stored
+   * in ZooKeeper can be modified with {@link #modifyProperties modifyProperties},
+   * {@link #setProperty setProperty} and {@link #removeProperty removeProperty}. Properties can be
+   * further refined by namesapce {@link NamespaceOperations} and by table {@link TableOperations}.
    *
    * @return A map of system properties set in zookeeper. If a property is not set in zookeeper,
    *         then it will return the value set in accumulo.properties on some server. If nothing is
@@ -164,19 +174,10 @@ public interface InstanceOperations {
    */
   List<String> getManagerLocations();
 
-  /**
-   * Returns the locations of the active compactors
-   *
-   * @return A set of currently active compactors.
-   * @since 2.1.4
-   */
-  Set<String> getCompactors();
-
   /**
    * Returns the locations of the active scan servers
    *
    * @return A set of currently active scan servers.
-   * @since 2.1.0
    */
   Set<String> getScanServers();
 
@@ -198,12 +199,13 @@ public interface InstanceOperations {
       throws AccumuloException, AccumuloSecurityException;
 
   /**
-   * List the active compaction running on a TabletServer or Compactor. The server address can be
-   * retrieved using {@link #getCompactors()} or {@link #getTabletServers()}. Use
-   * {@link #getActiveCompactions()} to get a list of all compactions running on tservers and
-   * compactors. Implementation updated in 2.1.4 to accept a compactor address.
+   * List the active compaction running on a tablet server. Using this method with
+   * {@link #getTabletServers()} will only show compactions running on tservers, leaving out any
+   * external compactions running on compactors. Use {@link #getActiveCompactions()} to get a list
+   * of all compactions running on tservers and compactors.
    *
-   * @param tserver The server address. This should be of the form {@code <ip address>:<port>}
+   * @param tserver The tablet server address. This should be of the form
+   *        {@code <ip address>:<port>}
    * @return the list of active compactions
    * @since 1.5.0
    */
@@ -244,17 +246,6 @@ public interface InstanceOperations {
    */
   void waitForBalance() throws AccumuloException;
 
-  /**
-   * Returns a unique string that identifies this instance of accumulo.
-   *
-   * @return a String
-   * @since 2.0.0
-   *
-   * @deprecated in 2.1.0 Use {@link #getInstanceId()}
-   */
-  @Deprecated(since = "2.1.0")
-  String getInstanceID();
-
   /**
    * Returns a unique ID object that identifies this instance of accumulo.
    *
