@@ -19,20 +19,5 @@
 package org.apache.accumulo.core.client.admin;
 
 public enum ScanState {
-  /**
-   * Indicates no work is currently queued or running to fetch the next batch of key/values for a
-   * scan. This could be because the server is waiting for a client to retrieve a batch of
-   * key/values its has already fetched and is buffering.
-   */
-  IDLE,
-  /**
-   * Indicates a task is running in a server side thread pool to fetch the next batch of key/values
-   * for a scan.
-   */
-  RUNNING,
-  /**
-   * Indicates a task is queued in a server side thread pool to fetch the next bach of key/values
-   * for a scan.
-   */
-  QUEUED
+  IDLE, RUNNING, QUEUED
 }
