@@ -87,47 +87,6 @@ public interface TableOperations {
   void create(String tableName)
       throws AccumuloException, AccumuloSecurityException, TableExistsException;
 
-  /**
-   * @param tableName the name of the table
-   * @param limitVersion Enables/disables the versioning iterator, which will limit the number of
-   *        Key versions kept.
-   * @throws AccumuloException if a general error occurs
-   * @throws AccumuloSecurityException if the user does not have permission
-   * @throws TableExistsException if the table already exists
-   * @deprecated since 1.7.0; use {@link #create(String, NewTableConfiguration)} instead.
-   */
-  @Deprecated(since = "1.7.0")
-  default void create(String tableName, boolean limitVersion)
-      throws AccumuloException, AccumuloSecurityException, TableExistsException {
-    if (limitVersion) {
-      create(tableName);
-    } else {
-      create(tableName, new NewTableConfiguration().withoutDefaultIterators());
-    }
-  }
-
-  /**
-   * @param tableName the name of the table
-   * @param versioningIter Enables/disables the versioning iterator, which will limit the number of
-   *        Key versions kept.
-   * @param timeType specifies logical or real-time based time recording for entries in the table
-   * @throws AccumuloException if a general error occurs
-   * @throws AccumuloSecurityException if the user does not have permission
-   * @throws TableExistsException if the table already exists
-   * @deprecated since 1.7.0; use {@link #create(String, NewTableConfiguration)} instead.
-   */
-  @Deprecated(since = "1.7.0")
-  default void create(String tableName, boolean versioningIter, TimeType timeType)
-      throws AccumuloException, AccumuloSecurityException, TableExistsException {
-    NewTableConfiguration ntc = new NewTableConfiguration().setTimeType(timeType);
-
-    if (versioningIter) {
-      create(tableName, ntc);
-    } else {
-      create(tableName, ntc.withoutDefaultIterators());
-    }
-  }
-
   /**
    * Create a table with specified configuration. A safe way to ignore tables that do exist would be
    * to do something like the following:
@@ -224,21 +183,6 @@ public interface TableOperations {
   void addSplits(String tableName, SortedSet<Text> partitionKeys)
       throws TableNotFoundException, AccumuloException, AccumuloSecurityException;
 
-  /**
-   * @param tableName the name of the table
-   * @return the split points (end-row names) for the table's current split profile
-   * @throws TableNotFoundException if the table does not exist
-   * @deprecated since 1.5.0; use {@link #listSplits(String)} instead.
-   */
-  @Deprecated(since = "1.5.0")
-  default Collection<Text> getSplits(String tableName) throws TableNotFoundException {
-    try {
-      return listSplits(tableName);
-    } catch (AccumuloSecurityException | AccumuloException e) {
-      throw new RuntimeException(e);
-    }
-  }
-
   /**
    * @param tableName the name of the table
    * @return the split points (end-row names) for the table's current split profile
@@ -250,23 +194,6 @@ public interface TableOperations {
   Collection<Text> listSplits(String tableName)
       throws TableNotFoundException, AccumuloSecurityException, AccumuloException;
 
-  /**
-   * @param tableName the name of the table
-   * @param maxSplits specifies the maximum number of splits to return
-   * @return the split points (end-row names) for the table's current split profile, grouped into
-   *         fewer splits so as not to exceed maxSplits
-   * @deprecated since 1.5.0; use {@link #listSplits(String, int)} instead.
-   */
-  @Deprecated(since = "1.5.0")
-  default Collection<Text> getSplits(String tableName, int maxSplits)
-      throws TableNotFoundException {
-    try {
-      return listSplits(tableName, maxSplits);
-    } catch (AccumuloSecurityException | AccumuloException e) {
-      throw new RuntimeException(e);
-    }
-  }
-
   /**
    * @param tableName the name of the table
    * @param maxSplits specifies the maximum number of splits to return
@@ -363,8 +290,8 @@ public interface TableOperations {
 
   /**
    * Starts a full major compaction of the tablets in the range (start, end]. If the config does not
-   * specify a compaction selector (or a deprecated strategy), then all files in a tablet are
-   * compacted. The compaction is performed even for tablets that have only one file.
+   * specify a compaction selector, then all files in a tablet are compacted. The compaction is
+   * performed even for tablets that have only one file.
    *
    * <p>
    * The following optional settings can only be set by one compact call per table at the same time.
@@ -374,8 +301,6 @@ public interface TableOperations {
    * <li>Selector : {@link CompactionConfig#setSelector(PluginConfig)}</li>
    * <li>Configurer : {@link CompactionConfig#setConfigurer(PluginConfig)}</li>
    * <li>Iterators : {@link CompactionConfig#setIterators(List)}</li>
-   * <li>Compaction strategy (deprecated) :
-   * {@code CompactionConfig.setCompactionStrategy(CompactionStrategyConfig)}</li>
    * </ul>
    *
    * <p>
@@ -528,8 +453,7 @@ public interface TableOperations {
    * @return The map that became Accumulo's new properties for this table. This map is immutable and
    *         contains the snapshot passed to mapMutator and the changes made by mapMutator.
    *
-   * @throws AccumuloException if a general error occurs. Wrapped TableNotFoundException if table
-   *         does not exist.
+   * @throws AccumuloException if a general error occurs
    * @throws AccumuloSecurityException if the user does not have permission
    * @throws IllegalArgumentException if the Consumer alters the map by adding properties that
    *         cannot be stored
@@ -554,11 +478,11 @@ public interface TableOperations {
       throws AccumuloException, AccumuloSecurityException;
 
   /**
-   * Gets a merged view of the properties of a table with its parent configuration. This operation
-   * is asynchronous and eventually consistent. It is not guaranteed that all tablets in a table
-   * will return the same values. Within a few seconds without another change, all tablets in a
-   * table should be consistent. The clone table feature can be used if consistency is required.
-   * Method calls {@link #getConfiguration(String)} and then calls .entrySet() on the map.
+   * Gets properties of a table. This operation is asynchronous and eventually consistent. It is not
+   * guaranteed that all tablets in a table will return the same values. Within a few seconds
+   * without another change, all tablets in a table should be consistent. The clone table feature
+   * can be used if consistency is required. Method calls {@link #getConfiguration(String)} and then
+   * calls .entrySet() on the map.
    *
    * @param tableName the name of the table
    * @return all properties visible by this table (system and per-table properties). Note that
@@ -572,11 +496,10 @@ public interface TableOperations {
   }
 
   /**
-   * Gets a merged view of the properties of a table with its parent configuration. This operation
-   * is asynchronous and eventually consistent. It is not guaranteed that all tablets in a table
-   * will return the same values. Within a few seconds without another change, all tablets in a
-   * table should be consistent. The clone table feature can be used if consistency is required.
-   * This method returns a Map instead of an Iterable.
+   * Gets properties of a table. This operation is asynchronous and eventually consistent. It is not
+   * guaranteed that all tablets in a table will return the same values. Within a few seconds
+   * without another change, all tablets in a table should be consistent. The clone table feature
+   * can be used if consistency is required. This new method returns a Map instead of an Iterable.
    *
    * @param tableName the name of the table
    * @return all properties visible by this table (system and per-table properties). Note that
@@ -588,11 +511,10 @@ public interface TableOperations {
       throws AccumuloException, TableNotFoundException;
 
   /**
-   * Gets per-table properties of a table. Note that this does not return a merged view of the
-   * properties with its parent configuration. This operation is asynchronous and eventually
-   * consistent. It is not guaranteed that all tablets in a table will return the same values.
-   * Within a few seconds without another change, all tablets in a table should be consistent. The
-   * clone table feature can be used if consistency is required.
+   * Gets per-table properties of a table. This operation is asynchronous and eventually consistent.
+   * It is not guaranteed that all tablets in a table will return the same values. Within a few
+   * seconds without another change, all tablets in a table should be consistent. The clone table
+   * feature can be used if consistency is required.
    *
    * @param tableName the name of the table
    * @return per-table properties visible by this table. Note that recently changed properties may
@@ -640,27 +562,6 @@ public interface TableOperations {
   Set<Range> splitRangeByTablets(String tableName, Range range, int maxSplits)
       throws AccumuloException, AccumuloSecurityException, TableNotFoundException;
 
-  /**
-   * Bulk import all the files in a directory into a table. Files can be created using
-   * {@link RFile#newWriter()}
-   *
-   * @param tableName the name of the table
-   * @param dir the HDFS directory to find files for importing
-   * @param failureDir the HDFS directory to place files that failed to be imported, must exist and
-   *        be empty
-   * @param setTime override the time values in the input files, and use the current time for all
-   *        mutations
-   * @throws IOException when there is an error reading/writing to HDFS
-   * @throws AccumuloException when there is a general accumulo error
-   * @throws AccumuloSecurityException when the user does not have the proper permissions
-   * @throws TableNotFoundException when the table no longer exists
-   *
-   * @deprecated since 2.0.0 use {@link #importDirectory(String)} instead.
-   */
-  @Deprecated(since = "2.0.0")
-  void importDirectory(String tableName, String dir, String failureDir, boolean setTime)
-      throws TableNotFoundException, IOException, AccumuloException, AccumuloSecurityException;
-
   /**
    * @since 2.0.0
    */
@@ -750,11 +651,9 @@ public interface TableOperations {
    * Bulk import the files in a directory into a table. Files can be created using
    * {@link RFile#newWriter()}.
    * <p>
-   * This new method of bulk import examines files in the current process outside of holding a table
-   * lock. The old bulk import method ({@link #importDirectory(String, String, String, boolean)})
-   * examines files on the server side while holding a table read lock.
-   * <p>
-   * This API supports adding files to online and offline tables.
+   * This API supports adding files to online and offline tables. The files are examined on the
+   * client side to determine destination tablets. This examination will use memory and cpu within
+   * the process calling this API.
    * <p>
    * For example, to bulk import files from the directory 'dir1' into the table 'table1' use the
    * following code.
@@ -932,8 +831,6 @@ public interface TableOperations {
    *
    * @param tableName the name of the table
    * @param number the unique number assigned to the constraint
-   * @throws AccumuloException if a general error occurs. Wrapped TableNotFoundException if table
-   *         does not exist.
    * @throws AccumuloSecurityException thrown if the user doesn't have permission to remove the
    *         constraint
    * @since 1.5.0
