@@ -18,7 +18,6 @@
  */
 package org.apache.accumulo.core.client.admin.compaction;
 
-import java.net.URI;
 import java.util.Collection;
 import java.util.Map;
 
@@ -36,7 +35,7 @@ public interface CompactionConfigurer {
   /**
    * @since 2.1.0
    */
-  interface InitParameters {
+  public interface InitParameters {
     TableId getTableId();
 
     Map<String,String> getOptions();
@@ -49,25 +48,16 @@ public interface CompactionConfigurer {
   /**
    * @since 2.1.0
    */
-  interface InputParameters {
+  public interface InputParameters {
     TableId getTableId();
 
-    Collection<CompactableFile> getInputFiles();
-
     /**
-     * Returns the tablet that is compacting.
-     *
-     * @since 2.1.4
+     * @return the id of the tablet being compacted
+     * @since 3.0.0
      */
     TabletId getTabletId();
 
-    /**
-     * Returns the path that the compaction will write to, one use of this is to know the output
-     * volume.
-     *
-     * @since 2.1.4
-     */
-    URI getOutputFile();
+    public Collection<CompactableFile> getInputFiles();
 
     PluginEnvironment getEnvironment();
   }
@@ -77,7 +67,7 @@ public interface CompactionConfigurer {
    *
    * @since 2.1.0
    */
-  class Overrides {
+  public class Overrides {
     private final Map<String,String> tablePropertyOverrides;
 
     public Overrides(Map<String,String> tablePropertyOverrides) {
