@@ -19,7 +19,6 @@
 package org.apache.accumulo.core.client.rfile;
 
 import static com.google.common.base.Preconditions.checkArgument;
-import static java.util.Objects.requireNonNull;
 
 import java.io.IOException;
 import java.io.OutputStream;
@@ -27,6 +26,7 @@ import java.util.Collections;
 import java.util.HashMap;
 import java.util.Map;
 import java.util.Map.Entry;
+import java.util.Objects;
 import java.util.stream.Stream;
 
 import org.apache.accumulo.core.client.rfile.RFile.WriterFSOptions;
@@ -37,8 +37,8 @@ import org.apache.accumulo.core.conf.AccumuloConfiguration;
 import org.apache.accumulo.core.conf.ConfigurationCopy;
 import org.apache.accumulo.core.conf.DefaultConfiguration;
 import org.apache.accumulo.core.crypto.CryptoFactoryLoader;
-import org.apache.accumulo.core.data.LoadPlan;
 import org.apache.accumulo.core.file.FileOperations;
+import org.apache.accumulo.core.metadata.UnreferencedTabletFile;
 import org.apache.accumulo.core.metadata.ValidationUtil;
 import org.apache.accumulo.core.sample.impl.SamplerConfigurationImpl;
 import org.apache.accumulo.core.spi.crypto.CryptoEnvironment;
@@ -73,7 +73,6 @@ class RFileWriterBuilder implements RFile.OutputArguments, RFile.WriterFSOptions
   private int visCacheSize = 1000;
   private Map<String,String> samplerProps = Collections.emptyMap();
   private Map<String,String> summarizerProps = Collections.emptyMap();
-  private LoadPlan.SplitResolver splitResolver;
 
   private void checkDisjoint(Map<String,String> props, Map<String,String> derivedProps,
       String kind) {
@@ -83,7 +82,7 @@ class RFileWriterBuilder implements RFile.OutputArguments, RFile.WriterFSOptions
 
   @Override
   public WriterOptions withSampler(SamplerConfiguration samplerConf) {
-    requireNonNull(samplerConf);
+    Objects.requireNonNull(samplerConf);
     Map<String,String> tmp = new SamplerConfigurationImpl(samplerConf).toTablePropertiesMap();
     checkDisjoint(tableConfig, tmp, "sampler");
     this.samplerProps = tmp;
@@ -108,9 +107,6 @@ class RFileWriterBuilder implements RFile.OutputArguments, RFile.WriterFSOptions
     CryptoService cs =
         CryptoFactoryLoader.getServiceForClient(CryptoEnvironment.Scope.TABLE, tableConfig);
 
-    var loadPlanCollector =
-        splitResolver == null ? new LoadPlanCollector() : new LoadPlanCollector(splitResolver);
-
     if (out.getOutputStream() != null) {
       FSDataOutputStream fsdo;
       if (out.getOutputStream() instanceof FSDataOutputStream) {
@@ -121,19 +117,18 @@ class RFileWriterBuilder implements RFile.OutputArguments, RFile.WriterFSOptions
       return new RFileWriter(
           fileops.newWriterBuilder().forOutputStream(".rf", fsdo, out.getConf(), cs)
               .withTableConfiguration(acuconf).withStartDisabled().build(),
-          visCacheSize, loadPlanCollector);
+          visCacheSize);
     } else {
-      return new RFileWriter(
-          fileops.newWriterBuilder()
-              .forFile(out.path.toString(), out.getFileSystem(out.path), out.getConf(), cs)
-              .withTableConfiguration(acuconf).withStartDisabled().build(),
-          visCacheSize, loadPlanCollector);
+      return new RFileWriter(fileops.newWriterBuilder()
+          .forFile(UnreferencedTabletFile.of(out.getFileSystem(), out.path), out.getFileSystem(),
+              out.getConf(), cs)
+          .withTableConfiguration(acuconf).withStartDisabled().build(), visCacheSize);
     }
   }
 
   @Override
   public WriterOptions withFileSystem(FileSystem fs) {
-    requireNonNull(fs);
+    Objects.requireNonNull(fs);
     out.fs = fs;
     return this;
   }
@@ -147,14 +142,14 @@ class RFileWriterBuilder implements RFile.OutputArguments, RFile.WriterFSOptions
 
   @Override
   public WriterOptions to(OutputStream out) {
-    requireNonNull(out);
+    Objects.requireNonNull(out);
     this.out = new OutputArgs(out);
     return this;
   }
 
   @Override
   public WriterOptions withTableProperties(Iterable<Entry<String,String>> tableConfig) {
-    requireNonNull(tableConfig);
+    Objects.requireNonNull(tableConfig);
     HashMap<String,String> cfg = new HashMap<>();
     for (Entry<String,String> entry : tableConfig) {
       cfg.put(entry.getKey(), entry.getValue());
@@ -168,7 +163,7 @@ class RFileWriterBuilder implements RFile.OutputArguments, RFile.WriterFSOptions
 
   @Override
   public WriterOptions withTableProperties(Map<String,String> tableConfig) {
-    requireNonNull(tableConfig);
+    Objects.requireNonNull(tableConfig);
     return withTableProperties(tableConfig.entrySet());
   }
 
@@ -179,15 +174,9 @@ class RFileWriterBuilder implements RFile.OutputArguments, RFile.WriterFSOptions
     return this;
   }
 
-  @Override
-  public WriterOptions withSplitResolver(LoadPlan.SplitResolver splitResolver) {
-    this.splitResolver = requireNonNull(splitResolver);
-    return this;
-  }
-
   @Override
   public WriterOptions withSummarizers(SummarizerConfiguration... summarizerConf) {
-    requireNonNull(summarizerConf);
+    Objects.requireNonNull(summarizerConf);
     Map<String,String> tmp = SummarizerConfiguration.toTableProperties(summarizerConf);
     checkDisjoint(tableConfig, tmp, "summarizer");
     this.summarizerProps = tmp;
