@@ -23,6 +23,7 @@ import static java.util.Objects.requireNonNull;
 
 import java.io.DataOutput;
 import java.io.IOException;
+import java.io.UncheckedIOException;
 import java.util.Map;
 import java.util.Set;
 
@@ -84,17 +85,6 @@ public abstract class AbstractHashSampler implements Sampler {
     }
   }
 
-  /**
-   * Subclasses with options should override this method and return true if the option is valid for
-   * the subclass or if {@code super.isValidOption(opt)} returns true.
-   *
-   * @deprecated since 2.1.0, replaced by {@link #validateOptions(Map)}
-   */
-  @Deprecated(since = "2.1.0")
-  protected boolean isValidOption(String option) {
-    return REQUIRED_SAMPLER_OPTIONS.contains(option);
-  }
-
   /**
    * Subclasses with options should override this method and call {@code super.init(config)}.
    */
@@ -142,7 +132,7 @@ public abstract class AbstractHashSampler implements Sampler {
     try {
       hash(new DataoutputHasher(hasher), k);
     } catch (IOException e) {
-      throw new RuntimeException(e);
+      throw new UncheckedIOException(e);
     }
     return hasher.hash().asInt() % modulus == 0;
   }
