@@ -30,17 +30,18 @@ import org.apache.accumulo.core.data.TabletId;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.dataImpl.TabletIdImpl;
 import org.apache.accumulo.core.dataImpl.thrift.IterInfo;
-import org.apache.accumulo.core.util.HostAndPort;
+
+import com.google.common.net.HostAndPort;
 
 /**
  * @since 1.6.0
  */
 public class ActiveCompactionImpl extends ActiveCompaction {
 
-  private final org.apache.accumulo.core.tabletserver.thrift.ActiveCompaction tac;
-  private final ClientContext context;
-  private final HostAndPort hostport;
-  private final Type type;
+  private org.apache.accumulo.core.tabletserver.thrift.ActiveCompaction tac;
+  private ClientContext context;
+  private HostAndPort hostport;
+  private Type type;
 
   ActiveCompactionImpl(ClientContext context,
       org.apache.accumulo.core.tabletserver.thrift.ActiveCompaction tac, HostAndPort hostport,
@@ -101,6 +102,11 @@ public class ActiveCompactionImpl extends ActiveCompaction {
     return tac.getEntriesWritten();
   }
 
+  @Override
+  public long getPausedCount() {
+    return tac.getTimesPaused();
+  }
+
   @Override
   public List<IteratorSetting> getIterators() {
     ArrayList<IteratorSetting> ret = new ArrayList<>();
