@@ -31,7 +31,7 @@ import org.apache.accumulo.core.util.UnsynchronizedBuffer;
 
 public class CompressedIterators {
   private Map<String,Integer> symbolMap;
-  private final List<String> symbolTable;
+  private List<String> symbolTable;
 
   public static class IterConfig {
     public List<IterInfo> ssiList = new ArrayList<>();
