@@ -62,14 +62,14 @@ import org.apache.accumulo.core.rpc.clients.ThriftClientTypes;
 import org.apache.accumulo.core.trace.TraceUtil;
 import org.apache.accumulo.core.util.LocalityGroupUtil;
 import org.apache.accumulo.core.util.LocalityGroupUtil.LocalityGroupConfigurationError;
+import org.apache.accumulo.core.util.OpTimer;
 import org.apache.accumulo.core.util.Retry;
-import org.apache.accumulo.core.util.Timer;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 public class NamespaceOperationsImpl extends NamespaceOperationsHelper {
   private final ClientContext context;
-  private final TableOperationsImpl tableOps;
+  private TableOperationsImpl tableOps;
 
   private static final Logger log = LoggerFactory.getLogger(TableOperations.class);
 
@@ -82,18 +82,19 @@ public class NamespaceOperationsImpl extends NamespaceOperationsHelper {
   @Override
   public SortedSet<String> list() {
 
-    Timer timer = null;
+    OpTimer timer = null;
 
     if (log.isTraceEnabled()) {
       log.trace("tid={} Fetching list of namespaces...", Thread.currentThread().getId());
-      timer = Timer.startNew();
+      timer = new OpTimer().start();
     }
 
     TreeSet<String> namespaces = new TreeSet<>(Namespaces.getNameToIdMap(context).keySet());
 
     if (timer != null) {
+      timer.stop();
       log.trace("tid={} Fetched {} namespaces in {}", Thread.currentThread().getId(),
-          namespaces.size(), String.format("%.3f secs", timer.elapsed(MILLISECONDS) / 1000.0));
+          namespaces.size(), String.format("%.3f secs", timer.scale(SECONDS)));
     }
 
     return namespaces;
@@ -103,19 +104,20 @@ public class NamespaceOperationsImpl extends NamespaceOperationsHelper {
   public boolean exists(String namespace) {
     EXISTING_NAMESPACE_NAME.validate(namespace);
 
-    Timer timer = null;
+    OpTimer timer = null;
 
     if (log.isTraceEnabled()) {
       log.trace("tid={} Checking if namespace {} exists", Thread.currentThread().getId(),
           namespace);
-      timer = Timer.startNew();
+      timer = new OpTimer().start();
     }
 
     boolean exists = Namespaces.namespaceNameExists(context, namespace);
 
     if (timer != null) {
+      timer.stop();
       log.trace("tid={} Checked existence of {} in {}", Thread.currentThread().getId(), exists,
-          String.format("%.3f secs", timer.elapsed(MILLISECONDS) / 1000.0));
+          String.format("%.3f secs", timer.scale(SECONDS)));
     }
 
     return exists;
@@ -336,7 +338,8 @@ public class NamespaceOperationsImpl extends NamespaceOperationsHelper {
   public Map<String,String> namespaceIdMap() {
     return Namespaces.getNameToIdMap(context).entrySet().stream()
         .collect(Collectors.toMap(Map.Entry::getKey, e -> e.getValue().canonical(), (v1, v2) -> {
-          throw new RuntimeException(String.format("Duplicate key for values %s and %s", v1, v2));
+          throw new IllegalStateException(
+              String.format("Duplicate key for values %s and %s", v1, v2));
         }, TreeMap::new));
   }
 
