@@ -18,7 +18,6 @@
  */
 package org.apache.accumulo.core.clientImpl;
 
-import java.time.Duration;
 import java.util.Collections;
 import java.util.Iterator;
 import java.util.List;
@@ -28,11 +27,15 @@ import java.util.concurrent.ExecutionException;
 import java.util.concurrent.Future;
 import java.util.concurrent.atomic.AtomicBoolean;
 
+import org.apache.accumulo.core.client.AccumuloException;
+import org.apache.accumulo.core.client.AccumuloSecurityException;
 import org.apache.accumulo.core.client.SampleNotPresentException;
 import org.apache.accumulo.core.client.ScannerBase.ConsistencyLevel;
 import org.apache.accumulo.core.client.TableDeletedException;
+import org.apache.accumulo.core.client.TableNotFoundException;
 import org.apache.accumulo.core.client.TableOfflineException;
 import org.apache.accumulo.core.clientImpl.ThriftScanner.ScanState;
+import org.apache.accumulo.core.clientImpl.ThriftScanner.ScanTimedOutException;
 import org.apache.accumulo.core.data.Key;
 import org.apache.accumulo.core.data.KeyValue;
 import org.apache.accumulo.core.data.Range;
@@ -46,29 +49,29 @@ import com.google.common.base.Preconditions;
 public class ScannerIterator implements Iterator<Entry<Key,Value>> {
 
   // scanner options
-  private final Duration timeOut;
+  private long timeOut;
 
   // scanner state
   private Iterator<KeyValue> iter;
   private final ScanState scanState;
 
-  private final ScannerOptions options;
+  private ScannerOptions options;
 
   private Future<List<KeyValue>> readAheadOperation;
 
   private boolean finished = false;
 
   private long batchCount = 0;
-  private final long readaheadThreshold;
+  private long readaheadThreshold;
 
-  private final ScannerImpl.Reporter reporter;
+  private ScannerImpl.Reporter reporter;
 
   private final ClientContext context;
 
-  private final AtomicBoolean closed = new AtomicBoolean(false);
+  private AtomicBoolean closed = new AtomicBoolean(false);
 
   ScannerIterator(ClientContext context, TableId tableId, Authorizations authorizations,
-      Range range, int size, Duration timeOut, ScannerOptions options, boolean isolated,
+      Range range, int size, long timeOut, ScannerOptions options, boolean isolated,
       long readaheadThreshold, ScannerImpl.Reporter reporter) {
     this.context = context;
     this.timeOut = timeOut;
@@ -124,8 +127,6 @@ public class ScannerIterator implements Iterator<Entry<Key,Value>> {
   }
 
   void close() {
-    // setting this so that some errors can be ignored
-    scanState.closeInitiated = true;
     // run actual close operation in the background so this does not block.
     context.executeCleanupTask(() -> {
       synchronized (scanState) {
@@ -146,7 +147,8 @@ public class ScannerIterator implements Iterator<Entry<Key,Value>> {
     readAheadOperation = context.submitScannerReadAheadTask(this::readBatch);
   }
 
-  private List<KeyValue> readBatch() throws Exception {
+  private List<KeyValue> readBatch() throws ScanTimedOutException, AccumuloException,
+      AccumuloSecurityException, TableNotFoundException {
 
     List<KeyValue> batch;
 
@@ -179,11 +181,10 @@ public class ScannerIterator implements Iterator<Entry<Key,Value>> {
       }
     } catch (ExecutionException ee) {
       wrapExecutionException(ee);
-      throw new RuntimeException(ee);
-    } catch (RuntimeException e) {
-      throw e;
-    } catch (Exception e) {
-      throw new RuntimeException(e);
+      throw new IllegalStateException(ee);
+    } catch (AccumuloException | AccumuloSecurityException | TableNotFoundException
+        | ScanTimedOutException | InterruptedException e) {
+      throw new IllegalStateException(e);
     }
 
     if (!nextBatch.isEmpty()) {
