@@ -19,7 +19,6 @@
 package org.apache.accumulo.core.clientImpl;
 
 import static com.google.common.base.Preconditions.checkArgument;
-import static org.apache.accumulo.core.util.threads.ThreadPoolNames.ACCUMULO_POOL_PREFIX;
 
 import java.lang.ref.Cleaner.Cleanable;
 import java.util.ArrayList;
@@ -72,10 +71,8 @@ public class TabletServerBatchReader extends ScannerOptions implements BatchScan
     this.tableName = tableName;
     this.numThreads = numQueryThreads;
 
-    queryThreadPool = context.threadPools()
-        .getPoolBuilder(
-            ACCUMULO_POOL_PREFIX.poolName + ".client.batch.scanner." + batchReaderInstance)
-        .numCoreThreads(numQueryThreads).build();
+    queryThreadPool = context.threadPools().createFixedThreadPool(numQueryThreads,
+        "batch scanner " + batchReaderInstance + "-", false);
     // Call shutdown on this thread pool in case the caller does not call close().
     cleanable = CleanerUtil.shutdownThreadPoolExecutor(queryThreadPool, closed, log);
   }
