@@ -18,12 +18,10 @@
  */
 package org.apache.accumulo.core.clientImpl;
 
-import static java.util.concurrent.TimeUnit.MILLISECONDS;
 import static java.util.concurrent.TimeUnit.SECONDS;
+import static org.apache.accumulo.core.util.LazySingletons.RANDOM;
 
 import java.io.IOException;
-import java.io.InterruptedIOException;
-import java.security.SecureRandom;
 import java.time.Duration;
 import java.util.ArrayList;
 import java.util.Collection;
@@ -32,12 +30,9 @@ import java.util.EnumMap;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
-import java.util.Optional;
 import java.util.Set;
 import java.util.SortedMap;
 import java.util.SortedSet;
-import java.util.concurrent.TimeUnit;
-import java.util.function.Supplier;
 import java.util.stream.Collectors;
 
 import org.apache.accumulo.core.Constants;
@@ -45,9 +40,9 @@ import org.apache.accumulo.core.client.AccumuloException;
 import org.apache.accumulo.core.client.AccumuloSecurityException;
 import org.apache.accumulo.core.client.SampleNotPresentException;
 import org.apache.accumulo.core.client.TableNotFoundException;
-import org.apache.accumulo.core.client.TimedOutException;
 import org.apache.accumulo.core.client.sample.SamplerConfiguration;
 import org.apache.accumulo.core.clientImpl.TabletLocator.TabletLocation;
+import org.apache.accumulo.core.clientImpl.thrift.TInfo;
 import org.apache.accumulo.core.clientImpl.thrift.ThriftSecurityException;
 import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.data.Column;
@@ -71,23 +66,22 @@ import org.apache.accumulo.core.security.Authorizations;
 import org.apache.accumulo.core.spi.scan.ScanServerAttempt;
 import org.apache.accumulo.core.spi.scan.ScanServerSelections;
 import org.apache.accumulo.core.spi.scan.ScanServerSelector;
+import org.apache.accumulo.core.tabletscan.thrift.ScanServerBusyException;
+import org.apache.accumulo.core.tabletscan.thrift.TSampleNotPresentException;
+import org.apache.accumulo.core.tabletscan.thrift.TabletScanClientService;
+import org.apache.accumulo.core.tabletscan.thrift.TooManyFilesException;
 import org.apache.accumulo.core.tabletserver.thrift.NoSuchScanIDException;
 import org.apache.accumulo.core.tabletserver.thrift.NotServingTabletException;
-import org.apache.accumulo.core.tabletserver.thrift.ScanServerBusyException;
-import org.apache.accumulo.core.tabletserver.thrift.TSampleNotPresentException;
-import org.apache.accumulo.core.tabletserver.thrift.TabletScanClientService;
-import org.apache.accumulo.core.tabletserver.thrift.TooManyFilesException;
 import org.apache.accumulo.core.trace.TraceUtil;
-import org.apache.accumulo.core.trace.thrift.TInfo;
-import org.apache.accumulo.core.util.HostAndPort;
-import org.apache.accumulo.core.util.Retry;
-import org.apache.accumulo.core.util.Timer;
+import org.apache.accumulo.core.util.OpTimer;
 import org.apache.hadoop.io.Text;
 import org.apache.thrift.TApplicationException;
 import org.apache.thrift.TException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import com.google.common.net.HostAndPort;
+
 import io.opentelemetry.api.trace.Span;
 import io.opentelemetry.context.Scope;
 
@@ -107,7 +101,6 @@ public class ThriftScanner {
   // metadata
   public static final Map<TabletType,Set<String>> serversWaitedForWrites =
       new EnumMap<>(TabletType.class);
-  private static final SecureRandom random = new SecureRandom();
 
   static {
     for (TabletType ttype : TabletType.values()) {
@@ -213,8 +206,6 @@ public class ThriftScanner {
 
     Duration busyTimeout;
 
-    volatile boolean closeInitiated = false;
-
     TabletLocation getErrorLocation() {
       return prevLoc;
     }
@@ -271,42 +262,6 @@ public class ThriftScanner {
     }
   }
 
-  static <T> Optional<T> waitUntil(Supplier<Optional<T>> condition, Duration maxWaitTime,
-      String description, Duration timeoutLeft, ClientContext context, TableId tableId,
-      Logger log) {
-    Retry retry = Retry.builder().infiniteRetries().retryAfter(100, MILLISECONDS)
-        .incrementBy(100, MILLISECONDS).maxWait(1, SECONDS).backOffFactor(1.5)
-        .logInterval(3, TimeUnit.MINUTES).createRetry();
-
-    Timer waitTimer = Timer.startNew();
-    Optional<T> optional = condition.get();
-    while (optional.isEmpty()) {
-      log.trace("For tableId {} scan server selector is waiting for '{}'", tableId, description);
-
-      if (waitTimer.hasElapsed(timeoutLeft)) {
-        throw new TimedOutException("While waiting for '" + description
-            + "' in order to select a scan server, the scan timed out. ");
-      }
-
-      if (waitTimer.hasElapsed(maxWaitTime)) {
-        return Optional.empty();
-      }
-
-      context.requireNotDeleted(tableId);
-
-      try {
-        retry.waitForNextAttempt(log, String.format(
-            "For tableId %s scan server selector is waiting for '%s'", tableId, description));
-      } catch (InterruptedException e) {
-        throw new RuntimeException(e);
-      }
-
-      optional = condition.get();
-    }
-
-    return optional;
-  }
-
   public static class ScanTimedOutException extends IOException {
 
     private static final long serialVersionUID = 1L;
@@ -321,14 +276,14 @@ public class ThriftScanner {
       Thread.sleep(millis);
     }
     // wait 2 * last time, with +-10% random jitter
-    return (long) (Math.min(millis * 2, maxSleep) * (.9 + random.nextDouble() / 5));
+    return (long) (Math.min(millis * 2, maxSleep) * (.9 + RANDOM.get().nextDouble() / 5));
   }
 
-  public static List<KeyValue> scan(ClientContext context, ScanState scanState, Duration timeOut)
+  public static List<KeyValue> scan(ClientContext context, ScanState scanState, long timeOut)
       throws ScanTimedOutException, AccumuloException, AccumuloSecurityException,
       TableNotFoundException {
     TabletLocation loc = null;
-    Timer scanTimer = Timer.startNew();
+    long startTime = System.currentTimeMillis();
     String lastError = null;
     String error = null;
     int tooManyFilesCount = 0;
@@ -344,12 +299,14 @@ public class ThriftScanner {
         if (Thread.currentThread().isInterrupted()) {
           throw new AccumuloException("Thread interrupted");
         }
-        if (scanTimer.hasElapsed(timeOut)) {
+
+        if ((System.currentTimeMillis() - startTime) / 1000.0 > timeOut) {
           throw new ScanTimedOutException();
         }
 
         while (loc == null) {
-          if (scanTimer.hasElapsed(timeOut)) {
+          long currentTime = System.currentTimeMillis();
+          if ((currentTime - startTime) / 1000.0 > timeOut) {
             throw new ScanTimedOutException();
           }
 
@@ -374,18 +331,18 @@ public class ThriftScanner {
             } else {
               // when a tablet splits we do want to continue scanning the low child
               // of the split if we are already passed it
-              Range dataRange = loc.tablet_extent.toDataRange();
+              Range dataRange = loc.getExtent().toDataRange();
 
               if (scanState.range.getStartKey() != null
                   && dataRange.afterEndKey(scanState.range.getStartKey())) {
                 // go to the next tablet
-                scanState.startRow = loc.tablet_extent.endRow();
+                scanState.startRow = loc.getExtent().endRow();
                 scanState.skipStartRow = true;
                 loc = null;
               } else if (scanState.range.getEndKey() != null
                   && dataRange.beforeStartKey(scanState.range.getEndKey())) {
                 // should not happen
-                throw new RuntimeException("Unexpected tablet, extent : " + loc.tablet_extent
+                throw new IllegalStateException("Unexpected tablet, extent : " + loc.getExtent()
                     + "  range : " + scanState.range + " startRow : " + scanState.startRow);
               }
             }
@@ -411,9 +368,9 @@ public class ThriftScanner {
         }
 
         Span child2 = TraceUtil.startSpan(ThriftScanner.class, "scan::location",
-            Map.of("tserver", loc.tablet_location));
+            Map.of("tserver", loc.getTserverLocation()));
         try (Scope scanLocation = child2.makeCurrent()) {
-          results = scan(loc, scanState, context, timeOut, scanTimer);
+          results = scan(loc, scanState, context);
         } catch (AccumuloSecurityException e) {
           context.clearTableListCache();
           context.requireNotDeleted(scanState.tableId);
@@ -422,7 +379,7 @@ public class ThriftScanner {
           throw e;
         } catch (TApplicationException tae) {
           TraceUtil.setException(child2, tae, true);
-          throw new AccumuloServerException(scanState.getErrorLocation().tablet_location, tae);
+          throw new AccumuloServerException(scanState.getErrorLocation().getTserverLocation(), tae);
         } catch (TSampleNotPresentException tsnpe) {
           String message = "Table " + context.getPrintableTableInfoFromId(scanState.tableId)
               + " does not have sampling configured or built";
@@ -437,7 +394,7 @@ public class ThriftScanner {
           }
           lastError = error;
 
-          TabletLocator.getLocator(context, scanState.tableId).invalidateCache(loc.tablet_extent);
+          TabletLocator.getLocator(context, scanState.tableId).invalidateCache(loc.getExtent());
           loc = null;
 
           // no need to try the current scan id somewhere else
@@ -511,13 +468,8 @@ public class ThriftScanner {
           TraceUtil.setException(child2, e, false);
           sleepMillis = pause(sleepMillis, maxSleepTime, scanState.runOnScanServer);
         } catch (TException e) {
-          boolean wasInterruptedAfterClose =
-              e.getCause() != null && e.getCause().getClass().equals(InterruptedIOException.class)
-                  && scanState.closeInitiated;
-          if (!wasInterruptedAfterClose) {
-            TabletLocator.getLocator(context, scanState.tableId).invalidateCache(context,
-                loc.tablet_location);
-          }
+          TabletLocator.getLocator(context, scanState.tableId).invalidateCache(context,
+              loc.getTserverLocation());
           error = "Scan failed, thrift error " + e.getClass().getName() + "  " + e.getMessage()
               + " " + scanState.getErrorLocation();
           if (!error.equals(lastError)) {
@@ -558,8 +510,7 @@ public class ThriftScanner {
     }
   }
 
-  private static List<KeyValue> scan(TabletLocation loc, ScanState scanState, ClientContext context,
-      Duration timeOut, Timer startTime)
+  private static List<KeyValue> scan(TabletLocation loc, ScanState scanState, ClientContext context)
       throws AccumuloSecurityException, NotServingTabletException, TException,
       NoSuchScanIDException, TooManyFilesException, TSampleNotPresentException {
     if (scanState.finished) {
@@ -570,23 +521,21 @@ public class ThriftScanner {
 
       TabletLocation newLoc;
 
-      var tabletId = new TabletIdImpl(loc.tablet_extent);
+      var tabletId = new TabletIdImpl(loc.getExtent());
 
       if (scanState.scanID != null && scanState.prevLoc != null
-          && scanState.prevLoc.tablet_session.equals("scan_server")
-          && scanState.prevLoc.tablet_extent.equals(loc.tablet_extent)) {
+          && scanState.prevLoc.getTserverSession().equals("scan_server")
+          && scanState.prevLoc.getExtent().equals(loc.getExtent())) {
         // this is the case of continuing a scan on a scan server for the same tablet, so lets not
         // call the scan server selector and just go back to the previous scan server
         newLoc = scanState.prevLoc;
         log.trace(
             "For tablet {} continuing scan on scan server {} without consulting scan server selector, using busyTimeout {}",
-            loc.tablet_extent, newLoc.tablet_location, scanState.busyTimeout);
+            loc.getExtent(), newLoc.getTserverLocation(), scanState.busyTimeout);
       } else {
         // obtain a snapshot once and only expose this snapshot to the plugin for consistency
         var attempts = scanState.scanAttempts.snapshot();
 
-        Duration timeoutLeft = timeOut.minus(startTime.elapsed());
-
         var params = new ScanServerSelector.SelectorParameters() {
 
           @Override
@@ -606,13 +555,6 @@ public class ThriftScanner {
             }
             return scanState.executionHints;
           }
-
-          @Override
-          public <T> Optional<T> waitUntil(Supplier<Optional<T>> condition, Duration maxWaitTime,
-              String description) {
-            return ThriftScanner.waitUntil(condition, maxWaitTime, description, timeoutLeft,
-                context, loc.tablet_extent.tableId(), log);
-          }
         };
 
         ScanServerSelections actions = context.getScanServerSelector().selectServers(params);
@@ -621,19 +563,17 @@ public class ThriftScanner {
 
         String scanServer = actions.getScanServer(tabletId);
         if (scanServer != null) {
-          newLoc = new TabletLocation(loc.tablet_extent, scanServer, "scan_server");
+          newLoc = new TabletLocation(loc.getExtent(), scanServer, "scan_server");
           delay = actions.getDelay();
           scanState.busyTimeout = actions.getBusyTimeout();
           log.trace(
-              "For tablet {} using hints {} scan server selector chose scan_server:{} delay:{} busyTimeout:{}",
-              loc.tablet_extent, scanState.executionHints, scanServer, delay,
-              scanState.busyTimeout);
+              "For tablet {} scan server selector chose scan_server:{} delay:{} busyTimeout:{}",
+              loc.getExtent(), scanServer, delay, scanState.busyTimeout);
         } else {
           newLoc = loc;
           delay = actions.getDelay();
           scanState.busyTimeout = Duration.ZERO;
-          log.trace("For tablet {} using hints {} scan server selector chose tablet_server",
-              loc.tablet_extent, scanState.executionHints);
+          log.trace("For tablet {} scan server selector chose tablet_server", loc.getExtent());
         }
 
         if (!delay.isZero()) {
@@ -646,7 +586,7 @@ public class ThriftScanner {
         }
       }
 
-      var reporter = scanState.scanAttempts.createReporter(newLoc.tablet_location, tabletId);
+      var reporter = scanState.scanAttempts.createReporter(newLoc.getTserverLocation(), tabletId);
 
       try {
         return scanRpc(newLoc, scanState, context, scanState.busyTimeout.toMillis());
@@ -667,11 +607,11 @@ public class ThriftScanner {
       NotServingTabletException, TException, NoSuchScanIDException, TooManyFilesException,
       TSampleNotPresentException, ScanServerBusyException {
 
-    Timer timer = null;
+    OpTimer timer = null;
 
     final TInfo tinfo = TraceUtil.traceInfo();
 
-    final HostAndPort parsedLocation = HostAndPort.fromString(loc.tablet_location);
+    final HostAndPort parsedLocation = HostAndPort.fromString(loc.getTserverLocation());
     TabletScanClientService.Client client =
         ThriftUtil.getClient(ThriftClientTypes.TABLET_SCAN, parsedLocation, context);
 
@@ -686,23 +626,24 @@ public class ThriftScanner {
       scanState.prevLoc = loc;
 
       if (scanState.scanID == null) {
-        Thread.currentThread().setName("Starting scan tserver=" + loc.tablet_location + " tableId="
-            + loc.tablet_extent.tableId());
+        Thread.currentThread().setName("Starting scan tserver=" + loc.getTserverLocation()
+            + " tableId=" + loc.getExtent().tableId());
 
         if (log.isTraceEnabled()) {
-          String msg = "Starting scan tserver=" + loc.tablet_location + " tablet="
-              + loc.tablet_extent + " range=" + scanState.range + " ssil="
+          String msg = "Starting scan tserver=" + loc.getTserverLocation() + " tablet="
+              + loc.getExtent() + " range=" + scanState.range + " ssil="
               + scanState.serverSideIteratorList + " ssio=" + scanState.serverSideIteratorOptions
               + " context=" + scanState.classLoaderContext;
           log.trace("tid={} {}", Thread.currentThread().getId(), msg);
-          timer = Timer.startNew();
+          timer = new OpTimer().start();
         }
 
-        TabletType ttype = TabletType.type(loc.tablet_extent);
-        boolean waitForWrites = !serversWaitedForWrites.get(ttype).contains(loc.tablet_location);
+        TabletType ttype = TabletType.type(loc.getExtent());
+        boolean waitForWrites =
+            !serversWaitedForWrites.get(ttype).contains(loc.getTserverLocation());
 
         InitialScan is = client.startScan(tinfo, scanState.context.rpcCreds(),
-            loc.tablet_extent.toThrift(), scanState.range.toThrift(),
+            loc.getExtent().toThrift(), scanState.range.toThrift(),
             scanState.columns.stream().map(Column::toThrift).collect(Collectors.toList()),
             scanState.size, scanState.serverSideIteratorList, scanState.serverSideIteratorOptions,
             scanState.authorizations.getAuthorizationsBB(), waitForWrites, scanState.isolated,
@@ -710,7 +651,7 @@ public class ThriftScanner {
             SamplerConfigurationImpl.toThrift(scanState.samplerConfig), scanState.batchTimeOut,
             scanState.classLoaderContext, scanState.executionHints, busyTimeout);
         if (waitForWrites) {
-          serversWaitedForWrites.get(ttype).add(loc.tablet_location);
+          serversWaitedForWrites.get(ttype).add(loc.getTserverLocation());
         }
 
         sr = is.result;
@@ -724,12 +665,12 @@ public class ThriftScanner {
       } else {
         // log.debug("Calling continue scan : "+scanState.range+" loc = "+loc);
         String msg =
-            "Continuing scan tserver=" + loc.tablet_location + " scanid=" + scanState.scanID;
+            "Continuing scan tserver=" + loc.getTserverLocation() + " scanid=" + scanState.scanID;
         Thread.currentThread().setName(msg);
 
         if (log.isTraceEnabled()) {
           log.trace("tid={} {}", Thread.currentThread().getId(), msg);
-          timer = Timer.startNew();
+          timer = new OpTimer().start();
         }
 
         sr = client.continueScan(tinfo, scanState.scanID, busyTimeout);
@@ -741,41 +682,41 @@ public class ThriftScanner {
 
       if (sr.more) {
         if (timer != null) {
+          timer.stop();
           log.trace("tid={} Finished scan in {} #results={} scanid={}",
-              Thread.currentThread().getId(),
-              String.format("%.3f secs", timer.elapsed(MILLISECONDS) / 1000.0), sr.results.size(),
-              scanState.scanID);
+              Thread.currentThread().getId(), String.format("%.3f secs", timer.scale(SECONDS)),
+              sr.results.size(), scanState.scanID);
         }
       } else {
         // log.debug("No more : tab end row = "+loc.tablet_extent.getEndRow()+" range =
         // "+scanState.range);
-        if (loc.tablet_extent.endRow() == null) {
+        if (loc.getExtent().endRow() == null) {
           scanState.finished = true;
 
           if (timer != null) {
+            timer.stop();
             log.trace("tid={} Completely finished scan in {} #results={}",
-                Thread.currentThread().getId(),
-                String.format("%.3f secs", timer.elapsed(MILLISECONDS) / 1000.0),
+                Thread.currentThread().getId(), String.format("%.3f secs", timer.scale(SECONDS)),
                 sr.results.size());
           }
 
         } else if (scanState.range.getEndKey() == null || !scanState.range
-            .afterEndKey(new Key(loc.tablet_extent.endRow()).followingKey(PartialKey.ROW))) {
-          scanState.startRow = loc.tablet_extent.endRow();
+            .afterEndKey(new Key(loc.getExtent().endRow()).followingKey(PartialKey.ROW))) {
+          scanState.startRow = loc.getExtent().endRow();
           scanState.skipStartRow = true;
 
           if (timer != null) {
+            timer.stop();
             log.trace("tid={} Finished scanning tablet in {} #results={}",
-                Thread.currentThread().getId(),
-                String.format("%.3f secs", timer.elapsed(MILLISECONDS) / 1000.0),
+                Thread.currentThread().getId(), String.format("%.3f secs", timer.scale(SECONDS)),
                 sr.results.size());
           }
         } else {
           scanState.finished = true;
           if (timer != null) {
+            timer.stop();
             log.trace("tid={} Completely finished in {} #results={}",
-                Thread.currentThread().getId(),
-                String.format("%.3f secs", timer.elapsed(MILLISECONDS) / 1000.0),
+                Thread.currentThread().getId(), String.format("%.3f secs", timer.scale(SECONDS)),
                 sr.results.size());
           }
         }
@@ -808,7 +749,7 @@ public class ThriftScanner {
       TInfo tinfo = TraceUtil.traceInfo();
 
       log.debug("Closing active scan {} {}", scanState.prevLoc, scanState.scanID);
-      HostAndPort parsedLocation = HostAndPort.fromString(scanState.prevLoc.tablet_location);
+      HostAndPort parsedLocation = HostAndPort.fromString(scanState.prevLoc.getTserverLocation());
       TabletScanClientService.Client client = null;
       try {
         client =
