@@ -20,8 +20,8 @@ package org.apache.accumulo.core.clientImpl;
 
 import static java.util.concurrent.TimeUnit.MILLISECONDS;
 import static java.util.concurrent.TimeUnit.MINUTES;
+import static org.apache.accumulo.core.util.LazySingletons.RANDOM;
 
-import java.security.SecureRandom;
 import java.util.ArrayDeque;
 import java.util.ArrayList;
 import java.util.Collections;
@@ -34,7 +34,6 @@ import java.util.Map;
 import java.util.Map.Entry;
 import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
-import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.locks.Lock;
 import java.util.concurrent.locks.ReentrantLock;
 import java.util.function.Consumer;
@@ -42,8 +41,6 @@ import java.util.function.LongSupplier;
 import java.util.function.Supplier;
 
 import org.apache.accumulo.core.rpc.ThriftUtil;
-import org.apache.accumulo.core.rpc.clients.ThriftClientTypes;
-import org.apache.accumulo.core.util.HostAndPort;
 import org.apache.accumulo.core.util.Pair;
 import org.apache.accumulo.core.util.threads.Threads;
 import org.apache.thrift.TConfiguration;
@@ -52,14 +49,15 @@ import org.apache.thrift.transport.TTransportException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import com.google.common.annotations.VisibleForTesting;
 import com.google.common.base.Preconditions;
+import com.google.common.net.HostAndPort;
 
 import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
 
 public class ThriftTransportPool {
 
   private static final Logger log = LoggerFactory.getLogger(ThriftTransportPool.class);
-  private static final SecureRandom random = new SecureRandom();
   private static final long ERROR_THRESHOLD = 20L;
   private static final long STUCK_THRESHOLD = MINUTES.toMillis(2);
 
@@ -71,25 +69,14 @@ public class ThriftTransportPool {
 
   private final LongSupplier maxAgeMillis;
 
-  private ThriftTransportPool(LongSupplier maxAgeMillis, boolean shouldHalt) {
+  private ThriftTransportPool(LongSupplier maxAgeMillis) {
     this.maxAgeMillis = maxAgeMillis;
-    final String threadName = "Thrift Connection Pool Checker";
-    final Runnable checkRunner = thriftConnectionPoolChecker();
-    if (shouldHalt) {
-      this.checkThread = Threads.createCriticalThread(threadName, checkRunner);
-    } else {
-      this.checkThread = Threads.createNonCriticalThread(threadName, checkRunner);
-    }
-  }
-
-  private Runnable thriftConnectionPoolChecker() {
-    return () -> {
+    this.checkThread = Threads.createThread("Thrift Connection Pool Checker", () -> {
       try {
         final long minNanos = MILLISECONDS.toNanos(250);
         final long maxNanos = MINUTES.toNanos(1);
         long lastRun = System.nanoTime();
-        // loop often, to detect shutdowns quickly
-        while (!connectionPool.awaitShutdown(250)) {
+        while (!connectionPool.shutdown) {
           // don't close on every loop; instead, check based on configured max age, within bounds
           var threshold = Math.min(maxNanos,
               Math.max(minNanos, MILLISECONDS.toNanos(maxAgeMillis.getAsLong()) / 2));
@@ -98,66 +85,95 @@ public class ThriftTransportPool {
             closeExpiredConnections();
             lastRun = currentNanos;
           }
+          // loop often, to detect shutdowns quickly
+          Thread.sleep(250);
         }
       } catch (InterruptedException e) {
-        log.warn("Thread " + Thread.currentThread().getName() + " was interrupted. Exiting.");
         Thread.currentThread().interrupt();
       } catch (TransportPoolShutdownException e) {
         log.debug("Error closing expired connections", e);
       }
-    };
+    });
   }
 
   /**
    * Create a new instance and start its checker thread, returning the instance.
    *
    * @param maxAgeMillis the supplier for the max age of idle transports before they are cleaned up
-   * @param shouldHalt true if the death of the checker thread via a RuntimeException should halt
-   *        the JVM; false otherwise. This should be true if the thread is running within a server
-   *        and false if the thread is running within a client
    * @return a new instance with its checker thread started to clean up idle transports
    */
-  static ThriftTransportPool startNew(LongSupplier maxAgeMillis, boolean shouldHalt) {
-    var pool = new ThriftTransportPool(maxAgeMillis, shouldHalt);
+  static ThriftTransportPool startNew(LongSupplier maxAgeMillis) {
+    var pool = new ThriftTransportPool(maxAgeMillis);
     log.debug("Set thrift transport pool idle time to {}ms", maxAgeMillis.getAsLong());
     pool.checkThread.start();
     return pool;
   }
 
-  public TTransport getTransport(ThriftClientTypes<?> type, HostAndPort location, long milliseconds,
-      ClientContext context, boolean preferCached) throws TTransportException {
+  public TTransport getTransport(HostAndPort location, long milliseconds, ClientContext context)
+      throws TTransportException {
+    ThriftTransportKey cacheKey = new ThriftTransportKey(location, milliseconds, context);
 
-    ThriftTransportKey cacheKey = new ThriftTransportKey(type, location, milliseconds, context);
-    if (preferCached) {
-      CachedConnection connection = connectionPool.reserveAny(cacheKey);
-      if (connection != null) {
-        log.trace("Using existing connection to {}", cacheKey.getServer());
-        return connection.transport;
-      }
+    CachedConnection connection = connectionPool.reserveAny(cacheKey);
+
+    if (connection != null) {
+      log.trace("Using existing connection to {}", cacheKey.getServer());
+      return connection.transport;
+    } else {
+      return createNewTransport(cacheKey);
     }
-    return createNewTransport(cacheKey);
   }
 
-  public Pair<String,TTransport> getAnyCachedTransport(ThriftClientTypes<?> type) {
-    final List<ThriftTransportKey> serversSet = new ArrayList<>();
-    for (ThriftTransportKey ttk : connectionPool.getThriftTransportKeys()) {
-      if (ttk.getType().equals(type)) {
-        serversSet.add(ttk);
+  @VisibleForTesting
+  public Pair<String,TTransport> getAnyTransport(List<ThriftTransportKey> servers,
+      boolean preferCachedConnection) throws TTransportException {
+
+    servers = new ArrayList<>(servers);
+
+    if (preferCachedConnection) {
+      HashSet<ThriftTransportKey> serversSet = new HashSet<>(servers);
+
+      // randomly pick a server from the connection cache
+      serversSet.retainAll(connectionPool.getThriftTransportKeys());
+
+      if (!serversSet.isEmpty()) {
+        ArrayList<ThriftTransportKey> cachedServers = new ArrayList<>(serversSet);
+        Collections.shuffle(cachedServers, RANDOM.get());
+
+        for (ThriftTransportKey ttk : cachedServers) {
+          CachedConnection connection = connectionPool.reserveAny(ttk);
+          if (connection != null) {
+            final String serverAddr = ttk.getServer().toString();
+            log.trace("Using existing connection to {}", serverAddr);
+            return new Pair<>(serverAddr, connection.transport);
+          }
+
+        }
       }
     }
-    if (serversSet.isEmpty()) {
-      return null;
-    }
-    Collections.shuffle(serversSet, random);
-    for (ThriftTransportKey ttk : serversSet) {
-      CachedConnection connection = connectionPool.reserveAny(ttk);
-      if (connection != null) {
-        final String serverAddr = ttk.getServer().toString();
-        log.trace("Using existing connection to {}", serverAddr);
-        return new Pair<>(serverAddr, connection.transport);
+
+    int retryCount = 0;
+    while (!servers.isEmpty() && retryCount < 10) {
+
+      int index = RANDOM.get().nextInt(servers.size());
+      ThriftTransportKey ttk = servers.get(index);
+
+      if (preferCachedConnection) {
+        CachedConnection connection = connectionPool.reserveAnyIfPresent(ttk);
+        if (connection != null) {
+          return new Pair<>(ttk.getServer().toString(), connection.transport);
+        }
+      }
+
+      try {
+        return new Pair<>(ttk.getServer().toString(), createNewTransport(ttk));
+      } catch (TTransportException tte) {
+        log.debug("Failed to connect to {}", servers.get(index), tte);
+        servers.remove(index);
+        retryCount++;
       }
     }
-    return null;
+
+    throw new TTransportException("Failed to connect to a server");
   }
 
   private TTransport createNewTransport(ThriftTransportKey cacheKey) throws TTransportException {
@@ -258,7 +274,7 @@ public class ThriftTransportPool {
     try {
       checkThread.join();
     } catch (InterruptedException e) {
-      throw new RuntimeException(e);
+      throw new IllegalStateException(e);
     }
   }
 
@@ -338,7 +354,7 @@ public class ThriftTransportPool {
     final Lock[] locks;
     final ConcurrentHashMap<ThriftTransportKey,CachedConnections> connections =
         new ConcurrentHashMap<>();
-    private final CountDownLatch shutdownLatch = new CountDownLatch(1);
+    private volatile boolean shutdown = false;
 
     ConnectionPool() {
       // intentionally using a prime number, don't use 31
@@ -373,6 +389,27 @@ public class ThriftTransportPool {
       return executeWithinLock(key, connections::reserveAny);
     }
 
+    /**
+     * Reserve and return a new {@link CachedConnection} from the {@link CachedConnections} mapped
+     * to the specified transport key. If a {@link CachedConnections} is not found, null will be
+     * returned.
+     *
+     * <p>
+     *
+     * This operation locks access to the mapping for the key in {@link ConnectionPool#connections}
+     * until the operation completes.
+     *
+     * @param key the transport key
+     * @return the reserved {@link CachedConnection}, or null if none were available.
+     */
+    CachedConnection reserveAnyIfPresent(final ThriftTransportKey key) {
+      // It's possible that multiple locks from executeWithinLock will overlap with a single lock
+      // inside the ConcurrentHashMap which can unnecessarily block threads. Access the
+      // ConcurrentHashMap outside of executeWithinLock to prevent this.
+      var connections = getCachedConnections(key);
+      return connections == null ? null : executeWithinLock(key, connections::reserveAny);
+    }
+
     /**
      * Puts the specified connection into the reserved map of the {@link CachedConnections} for the
      * specified transport key. If a {@link CachedConnections} is not found, one will be created.
@@ -433,10 +470,10 @@ public class ThriftTransportPool {
       // All locks are now acquired, so nothing else should be able to run concurrently...
       try {
         // Check if an shutdown has already been initiated.
-        if (isShutdown()) {
+        if (shutdown) {
           return;
         }
-        shutdownLatch.countDown();
+        shutdown = true;
         connections.values().forEach(CachedConnections::closeAllTransports);
       } finally {
         for (Lock lock : locks) {
@@ -445,20 +482,6 @@ public class ThriftTransportPool {
       }
     }
 
-    boolean isShutdown() {
-      return shutdownLatch.getCount() == 0;
-    }
-
-    /**
-     * Waits for shutdown for at most the specified number of milliseconds and returns whether
-     * shutdown happened.
-     *
-     * @return true if shutdown happened, false if the timeout was reached
-     */
-    boolean awaitShutdown(long timeoutMillis) throws InterruptedException {
-      return shutdownLatch.await(timeoutMillis, MILLISECONDS);
-    }
-
     <T> T executeWithinLock(final ThriftTransportKey key, Supplier<T> function) {
       Lock lock = getLock(key);
       try {
@@ -482,7 +505,7 @@ public class ThriftTransportPool {
 
       lock.lock();
 
-      if (isShutdown()) {
+      if (shutdown) {
         lock.unlock();
         throw new TransportPoolShutdownException(
             "The Accumulo singleton for connection pooling is disabled.  This is likely caused by "
@@ -492,6 +515,10 @@ public class ThriftTransportPool {
       return lock;
     }
 
+    CachedConnections getCachedConnections(final ThriftTransportKey key) {
+      return connections.get(key);
+    }
+
     CachedConnections getOrCreateCachedConnections(final ThriftTransportKey key) {
       return connections.computeIfAbsent(key, k -> new CachedConnections());
     }
