@@ -19,7 +19,6 @@
 package org.apache.accumulo.core.clientImpl.bulk;
 
 import static java.nio.charset.StandardCharsets.UTF_8;
-import static org.apache.accumulo.core.clientImpl.bulk.BulkSerialize.createGson;
 
 import java.io.BufferedReader;
 import java.io.IOException;
@@ -32,9 +31,9 @@ import java.util.Map;
 
 import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
+import org.apache.accumulo.core.util.json.ByteArrayToBase64TypeAdapter;
 
 import com.google.gson.Gson;
-import com.google.gson.JsonParseException;
 import com.google.gson.stream.JsonReader;
 
 /**
@@ -42,15 +41,14 @@ import com.google.gson.stream.JsonReader;
  */
 public class LoadMappingIterator
     implements Iterator<Map.Entry<KeyExtent,Bulk.Files>>, AutoCloseable {
-  private TableId tableId;
-  private JsonReader reader;
-  private Gson gson = createGson();
+  private final TableId tableId;
+  private final JsonReader reader;
+  private static final Gson gson = ByteArrayToBase64TypeAdapter.createBase64Gson();
   private Map<String,String> renameMap;
-  private KeyExtent lastKeyExtent = null;
 
-  LoadMappingIterator(TableId tableId, InputStream loadMapFile) throws IOException {
+  LoadMappingIterator(TableId tableId, InputStream loadMappingFile) throws IOException {
     this.tableId = tableId;
-    this.reader = new JsonReader(new BufferedReader(new InputStreamReader(loadMapFile, UTF_8)));
+    this.reader = new JsonReader(new BufferedReader(new InputStreamReader(loadMappingFile, UTF_8)));
     this.reader.beginArray();
   }
 
@@ -74,27 +72,12 @@ public class LoadMappingIterator
 
   @Override
   public Map.Entry<KeyExtent,Bulk.Files> next() {
-    Bulk.Mapping bm;
-    try {
-      bm = gson.fromJson(reader, Bulk.Mapping.class);
-    } catch (JsonParseException e) {
-      throw new IllegalStateException("Failed to read next mapping", e);
-    }
-
-    KeyExtent currentKeyExtent = bm.getKeyExtent(tableId);
-
-    if (lastKeyExtent != null && currentKeyExtent.compareTo(lastKeyExtent) < 0) {
-      throw new IllegalStateException(
-          String.format("KeyExtents are not in sorted order: %s was seen before %s", lastKeyExtent,
-              currentKeyExtent));
-    }
-
-    lastKeyExtent = currentKeyExtent;
-
+    Bulk.Mapping bm = gson.fromJson(reader, Bulk.Mapping.class);
     if (renameMap != null) {
-      return new AbstractMap.SimpleEntry<>(currentKeyExtent, bm.getFiles().mapNames(renameMap));
+      return new AbstractMap.SimpleEntry<>(bm.getKeyExtent(tableId),
+          bm.getFiles().mapNames(renameMap));
     } else {
-      return new AbstractMap.SimpleEntry<>(currentKeyExtent, bm.getFiles());
+      return new AbstractMap.SimpleEntry<>(bm.getKeyExtent(tableId), bm.getFiles());
     }
   }
 
