@@ -28,7 +28,6 @@ import java.util.Map;
 import java.util.Objects;
 import java.util.Properties;
 
-import org.apache.accumulo.core.Constants;
 import org.apache.accumulo.core.client.admin.TableOperations.ImportMappingOptions;
 import org.apache.accumulo.core.client.security.tokens.AuthenticationToken;
 import org.apache.accumulo.core.client.security.tokens.CredentialProviderToken;
@@ -135,16 +134,7 @@ public enum ClientProperty {
       "The maximum duration to leave idle transports open in the client's transport pool", "2.1.0",
       false),
 
-  // Trace
-  @Deprecated(since = "2.1.0", forRemoval = true)
-  TRACE_SPAN_RECEIVERS("trace.span.receivers", "org.apache.accumulo.tracer.ZooTraceClient",
-      "A list of span receiver classes to send trace spans"),
-  @Deprecated(since = "2.1.0", forRemoval = true)
-  TRACE_ZOOKEEPER_PATH("trace.zookeeper.path", Constants.ZTRACERS, PropertyType.PATH,
-      "The zookeeper node where tracers are registered", "2.0.0", false);
-
-  @Deprecated(since = "2.1.0", forRemoval = true)
-  public static final String TRACE_SPAN_RECEIVER_PREFIX = "trace.span.receiver";
+  ;
 
   private final String key;
   private final String defaultValue;
