@@ -20,7 +20,6 @@ package org.apache.accumulo.core.conf;
 
 import static java.util.Objects.requireNonNull;
 
-import java.io.IOException;
 import java.util.Arrays;
 import java.util.Objects;
 import java.util.function.Function;
@@ -31,16 +30,9 @@ import java.util.stream.IntStream;
 import java.util.stream.Stream;
 
 import org.apache.accumulo.core.file.rfile.RFile;
-import org.apache.accumulo.core.file.rfile.bcfile.Compression;
-import org.apache.accumulo.core.file.rfile.bcfile.CompressionAlgorithm;
 import org.apache.commons.lang3.Range;
 import org.apache.hadoop.fs.Path;
-import org.apache.hadoop.io.compress.Compressor;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
 
-import com.fasterxml.jackson.databind.DeserializationFeature;
-import com.fasterxml.jackson.databind.ObjectMapper;
 import com.google.common.base.Preconditions;
 
 /**
@@ -115,14 +107,8 @@ public enum PropertyType {
           + "Substitutions of the ACCUMULO_HOME environment variable can be done in the system "
           + "config file using '${env:ACCUMULO_HOME}' or similar."),
 
-  DROP_CACHE_SELECTION("drop cache option", in(false, "NONE", "ALL", "NON-IMPORT"),
-      "One of 'ALL', 'NONE', or 'NON-IMPORT'"),
-
-  // VFS_CLASSLOADER_CACHE_DIR's default value is a special case, for documentation purposes
-  @SuppressWarnings("removal")
   ABSOLUTEPATH("absolute path",
-      x -> x == null || x.trim().isEmpty() || new Path(x.trim()).isAbsolute()
-          || x.equals(Property.VFS_CLASSLOADER_CACHE_DIR.getDefaultValue()),
+      x -> x == null || x.trim().isEmpty() || new Path(x.trim()).isAbsolute(),
       "An absolute filesystem path. The filesystem depends on the property."
           + " This is the same as path, but enforces that its root is explicitly specified."),
 
@@ -134,9 +120,6 @@ public enum PropertyType {
       "A list of fully qualified java class names representing classes on the classpath.\n"
           + "An example is 'java.lang.String', rather than 'String'"),
 
-  COMPRESSION_TYPE("compression type name", new ValidCompressionType(),
-      "One of the configured compression types."),
-
   DURABILITY("durability", in(false, null, "default", "none", "log", "flush", "sync"),
       "One of 'none', 'log', 'flush' or 'sync'."),
 
@@ -150,9 +133,6 @@ public enum PropertyType {
       "An arbitrary string of characters whose format is unspecified and"
           + " interpreted based on the context of the property to which it applies."),
 
-  JSON("json", new ValidJson(),
-      "An arbitrary string that is represents a valid, parsable generic json object."
-          + "The validity of the json object in the context of the property usage is not checked by this type."),
   BOOLEAN("boolean", in(false, null, "true", "false"),
       "Has a value of either 'true' or 'false' (case-insensitive)"),
 
@@ -160,20 +140,16 @@ public enum PropertyType {
 
   FILENAME_EXT("file name extension", in(true, RFile.EXTENSION),
       "One of the currently supported filename extensions for storing table data files. "
-          + "Currently, only " + RFile.EXTENSION + " is supported."),
+          + "Currently, only " + RFile.EXTENSION + " is supported.");
 
-  EC("erasurecode", in(false, "enable", "disable", "inherit"),
-      "One of 'enable','disable','inherit'.");
-
-  private final String shortname;
-  private final String format;
+  private String shortname, format;
   // Field is transient because enums are Serializable, but Predicates aren't necessarily,
   // and our lambdas certainly aren't; This shouldn't matter because enum serialization doesn't
   // store fields, so this is a false positive in our spotbugs version
   // see https://github.com/spotbugs/spotbugs/issues/740
-  private transient final Predicate<String> predicate;
+  private transient Predicate<String> predicate;
 
-  PropertyType(String shortname, Predicate<String> predicate, String formatDescription) {
+  private PropertyType(String shortname, Predicate<String> predicate, String formatDescription) {
     this.shortname = shortname;
     this.predicate = Objects.requireNonNull(predicate);
     this.format = formatDescription;
@@ -207,41 +183,6 @@ public enum PropertyType {
     return predicate.test(value);
   }
 
-  /**
-   * Validate that the provided string can be parsed into a json object. This implementation uses
-   * jackson databind because it is less permissive that GSON for what is considered valid. This
-   * implementation cannot guarantee that the json is valid for the target usage. That would require
-   * something like a json schema or a check specific to the use-case. This is only trying to
-   * provide a generic, minimal check that at least the json is valid.
-   */
-  private static class ValidJson implements Predicate<String> {
-    private static final Logger log = LoggerFactory.getLogger(ValidJson.class);
-
-    // ObjectMapper is thread-safe, but uses synchronization. If this causes contention, ThreadLocal
-    // may be an option.
-    private final ObjectMapper jsonMapper =
-        new ObjectMapper().enable(DeserializationFeature.FAIL_ON_READING_DUP_TREE_KEY)
-            .enable(DeserializationFeature.FAIL_ON_TRAILING_TOKENS);
-
-    // set a limit of 1 million characters on the string as rough guard on invalid input
-    private static final int ONE_MILLION = 1024 * 1024;
-
-    @Override
-    public boolean test(String value) {
-      try {
-        if (value.length() > ONE_MILLION) {
-          log.info("provided json string length {} is greater than limit of {} for parsing",
-              value.length(), ONE_MILLION);
-          return false;
-        }
-        jsonMapper.readTree(value);
-        return true;
-      } catch (IOException ex) {
-        return false;
-      }
-    }
-  }
-
   private static Predicate<String> in(final boolean caseSensitive, final String... allowedSet) {
     if (caseSensitive) {
       return x -> Arrays.stream(allowedSet)
@@ -260,32 +201,6 @@ public enum PropertyType {
         || (suffixCheck.test(x) && new Bounds(lowerBound, upperBound).test(stripUnits.apply(x)));
   }
 
-  private static class ValidCompressionType implements Predicate<String> {
-
-    private static final Logger LOG = LoggerFactory.getLogger(ValidCompressionType.class);
-
-    @Override
-    public boolean test(String type) {
-      if (!Compression.getSupportedAlgorithms().contains(type)) {
-        return false;
-      }
-      CompressionAlgorithm ca = Compression.getCompressionAlgorithmByName(type);
-      Compressor c = null;
-      try {
-        c = ca.getCompressor();
-        return true;
-      } catch (RuntimeException e) {
-        LOG.error("Error creating compressor for type {}", type, e);
-        return false;
-      } finally {
-        if (c != null) {
-          ca.returnCompressor(c);
-        }
-      }
-    }
-
-  }
-
   private static final Pattern SUFFIX_REGEX = Pattern.compile("[^\\d]*$");
   private static final Function<String,String> stripUnits =
       x -> x == null ? null : SUFFIX_REGEX.matcher(x.trim()).replaceAll("");
@@ -400,7 +315,7 @@ public enum PropertyType {
 
   public static class PortRange extends Matches {
 
-    public static final Range<Integer> VALID_RANGE = Range.of(1024, 65535);
+    public static final Range<Integer> VALID_RANGE = Range.between(1024, 65535);
 
     public PortRange(final String pattern) {
       super(pattern);
