@@ -30,7 +30,6 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.function.Predicate;
-import java.util.regex.Pattern;
 import java.util.stream.Collectors;
 
 import org.yaml.snakeyaml.Yaml;
@@ -39,25 +38,14 @@ import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
 
 public class ClusterConfigParser {
 
-  private static final Pattern GROUP_NAME_PATTERN =
-      Pattern.compile("^[a-zA-Z_]{1,}[a-zA-Z0-9_]{0,}$");
-
-  public static void validateGroupNames(Set<String> names) {
-    for (String name : names) {
-      if (!GROUP_NAME_PATTERN.matcher(name).matches()) {
-        throw new RuntimeException("Group name: " + name + " contains invalid characters");
-      }
-    }
-  }
-
   private static final String PROPERTY_FORMAT = "%s=\"%s\"%n";
   private static final String[] SECTIONS = new String[] {"manager", "monitor", "gc", "tserver"};
 
-  private static final Set<String> VALID_CONFIG_KEYS =
-      Set.of("manager", "monitor", "gc", "tserver", "tservers_per_host", "compaction.coordinator");
+  private static final Set<String> VALID_CONFIG_KEYS = Set.of("manager", "monitor", "gc", "tserver",
+      "tservers_per_host", "sservers_per_host", "compaction.coordinator");
 
   private static final Set<String> VALID_CONFIG_PREFIXES =
-      Set.of("compaction.compactor.", "sserver.", "compactors_per_host.", "sservers_per_host.");
+      Set.of("compaction.compactor.", "sserver.");
 
   private static final Predicate<String> VALID_CONFIG_SECTIONS =
       section -> VALID_CONFIG_KEYS.contains(section)
@@ -132,7 +120,6 @@ public class ClusterConfigParser {
     Set<String> compactorQueues =
         config.keySet().stream().filter(k -> k.startsWith(compactorPrefix))
             .map(k -> k.substring(compactorPrefix.length())).collect(Collectors.toSet());
-    validateGroupNames(compactorQueues);
 
     if (!compactorQueues.isEmpty()) {
       out.printf(PROPERTY_FORMAT, "COMPACTION_QUEUES",
@@ -140,28 +127,26 @@ public class ClusterConfigParser {
       for (String queue : compactorQueues) {
         out.printf(PROPERTY_FORMAT, "COMPACTOR_HOSTS_" + queue,
             config.get("compaction.compactor." + queue));
-        String numCompactors = config.getOrDefault("compactors_per_host." + queue, "1");
-        out.printf(PROPERTY_FORMAT, "NUM_COMPACTORS_" + queue, numCompactors);
       }
     }
 
     String sserverPrefix = "sserver.";
     Set<String> sserverGroups = config.keySet().stream().filter(k -> k.startsWith(sserverPrefix))
         .map(k -> k.substring(sserverPrefix.length())).collect(Collectors.toSet());
-    validateGroupNames(sserverGroups);
 
     if (!sserverGroups.isEmpty()) {
       out.printf(PROPERTY_FORMAT, "SSERVER_GROUPS",
           sserverGroups.stream().collect(Collectors.joining(" ")));
       sserverGroups.forEach(ssg -> out.printf(PROPERTY_FORMAT, "SSERVER_HOSTS_" + ssg,
           config.get(sserverPrefix + ssg)));
-      sserverGroups.forEach(ssg -> out.printf(PROPERTY_FORMAT, "NUM_SSERVERS_" + ssg,
-          config.getOrDefault("sservers_per_host." + ssg, "1")));
     }
 
     String numTservers = config.getOrDefault("tservers_per_host", "1");
     out.print("NUM_TSERVERS=\"${NUM_TSERVERS:=" + numTservers + "}\"\n");
 
+    String numSservers = config.getOrDefault("sservers_per_host", "1");
+    out.print("NUM_SSERVERS=\"${NUM_SSERVERS:=" + numSservers + "}\"\n");
+
     out.flush();
   }
 
@@ -173,19 +158,14 @@ public class ClusterConfigParser {
       System.exit(1);
     }
 
-    try {
-      if (args.length == 2) {
-        // Write to a file instead of System.out if provided as an argument
-        try (OutputStream os = Files.newOutputStream(Paths.get(args[1]), StandardOpenOption.CREATE);
-            PrintStream out = new PrintStream(os)) {
-          outputShellVariables(parseConfiguration(args[0]), new PrintStream(out));
-        }
-      } else {
-        outputShellVariables(parseConfiguration(args[0]), System.out);
+    if (args.length == 2) {
+      // Write to a file instead of System.out if provided as an argument
+      try (OutputStream os = Files.newOutputStream(Paths.get(args[1]), StandardOpenOption.CREATE);
+          PrintStream out = new PrintStream(os)) {
+        outputShellVariables(parseConfiguration(args[0]), new PrintStream(out));
       }
-    } catch (Exception e) {
-      System.err.println("Processing error: " + e.getMessage());
-      System.exit(1);
+    } else {
+      outputShellVariables(parseConfiguration(args[0]), System.out);
     }
   }
 
