@@ -38,7 +38,7 @@ public class BlockedInputStream extends InputStream {
 
   public BlockedInputStream(InputStream in, int blockSize, int maxSize) {
     if (blockSize == 0) {
-      throw new RuntimeException("Invalid block size");
+      throw new IllegalArgumentException("Invalid block size");
     }
     if (in instanceof DataInputStream) {
       this.in = (DataInputStream) in;
@@ -67,7 +67,7 @@ public class BlockedInputStream extends InputStream {
     if (readPos == array.length) {
       readPos = 0;
     } else if (readPos > array.length) {
-      throw new RuntimeException(
+      throw new IllegalStateException(
           "Unexpected state, this should only ever increase or cycle on the boundary!");
     }
     return toRet;
@@ -121,7 +121,7 @@ public class BlockedInputStream extends InputStream {
       finished = true;
       return false;
     } else if (size == 0) {
-      throw new RuntimeException(
+      throw new IllegalStateException(
           "Empty block written, this shouldn't happen with this BlockedOutputStream.");
     }
 
