@@ -36,8 +36,8 @@ import org.apache.hadoop.io.Text;
  */
 public class Condition {
 
-  private final ByteSequence cf;
-  private final ByteSequence cq;
+  private ByteSequence cf;
+  private ByteSequence cq;
   private ByteSequence cv;
   private ByteSequence val;
   private Long ts;
