@@ -1162,10 +1162,17 @@ public class Key implements WritableComparable<Key>, Cloneable {
     last--;
 
     if (a1[last] == a2[last]) {
-      return Arrays.equals(a1, a2);
+      for (int i = 0; i < last; i++) {
+        if (a1[i] != a2[i]) {
+          return false;
+        }
+      }
     } else {
       return false;
     }
+
+    return true;
+
   }
 
   /**
