@@ -32,16 +32,15 @@ import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
 import java.util.Set;
-import java.util.concurrent.TimeUnit;
 
 import org.apache.accumulo.core.fate.ReadOnlyTStore.TStatus;
 import org.apache.accumulo.core.fate.zookeeper.FateLock;
 import org.apache.accumulo.core.fate.zookeeper.FateLock.FateLockPath;
-import org.apache.accumulo.core.fate.zookeeper.ServiceLock;
-import org.apache.accumulo.core.fate.zookeeper.ServiceLock.ServiceLockPath;
 import org.apache.accumulo.core.fate.zookeeper.ZooReader;
 import org.apache.accumulo.core.fate.zookeeper.ZooReaderWriter;
 import org.apache.accumulo.core.fate.zookeeper.ZooUtil.NodeMissingPolicy;
+import org.apache.accumulo.core.lock.ServiceLock;
+import org.apache.accumulo.core.lock.ServiceLock.ServiceLockPath;
 import org.apache.accumulo.core.util.FastFormat;
 import org.apache.zookeeper.KeeperException;
 import org.slf4j.Logger;
@@ -333,7 +332,7 @@ public class AdminUtil<T> {
    * @param waitingLocks populated list of locks held by transaction - or an empty map if none.
    * @return current fate and lock status
    */
-  public static <T> FateStatus getTransactionStatus(ReadOnlyTStore<T> zs, Set<Long> filterTxid,
+  private FateStatus getTransactionStatus(ReadOnlyTStore<T> zs, Set<Long> filterTxid,
       EnumSet<TStatus> filterStatus, Map<Long,List<String>> heldLocks,
       Map<Long,List<String>> waitingLocks) {
 
@@ -341,57 +340,37 @@ public class AdminUtil<T> {
     List<TransactionStatus> statuses = new ArrayList<>(transactions.size());
 
     for (Long tid : transactions) {
-      try {
-        zs.reserve(tid);
 
-        String txName = (String) zs.getTransactionInfo(tid, Fate.TxInfo.TX_NAME);
+      zs.reserve(tid);
 
-        List<String> hlocks = heldLocks.remove(tid);
+      String txName = (String) zs.getTransactionInfo(tid, Fate.TxInfo.TX_NAME);
 
-        if (hlocks == null) {
-          hlocks = Collections.emptyList();
-        }
+      List<String> hlocks = heldLocks.remove(tid);
 
-        List<String> wlocks = waitingLocks.remove(tid);
+      if (hlocks == null) {
+        hlocks = Collections.emptyList();
+      }
 
-        if (wlocks == null) {
-          wlocks = Collections.emptyList();
-        }
+      List<String> wlocks = waitingLocks.remove(tid);
 
-        String top = null;
-        ReadOnlyRepo<T> repo = zs.top(tid);
-        if (repo != null) {
-          top = repo.getName();
-        }
+      if (wlocks == null) {
+        wlocks = Collections.emptyList();
+      }
 
-        TStatus status = zs.getStatus(tid);
+      String top = null;
+      ReadOnlyRepo<T> repo = zs.top(tid);
+      if (repo != null) {
+        top = repo.getName();
+      }
 
-        long timeCreated = zs.timeCreated(tid);
+      TStatus status = zs.getStatus(tid);
 
-        zs.unreserve(tid, 0, TimeUnit.MILLISECONDS);
+      long timeCreated = zs.timeCreated(tid);
 
-        if (includeByStatus(status, filterStatus) && includeByTxid(tid, filterTxid)) {
-          statuses
-              .add(new TransactionStatus(tid, status, txName, hlocks, wlocks, top, timeCreated));
-        }
-      } catch (Exception e) {
-        // If the cause of the Exception is a NoNodeException, it should be ignored as this
-        // indicates the transaction has completed between the time the list of transactions was
-        // acquired and the time the transaction was probed for info.
-        boolean nne = false;
-        Throwable cause = e;
-        while (cause != null) {
-          if (cause instanceof KeeperException.NoNodeException) {
-            nne = true;
-            break;
-          }
-          cause = cause.getCause();
-        }
-        if (!nne) {
-          throw e;
-        }
-        log.debug("Tried to get info on a since completed transaction - ignoring "
-            + FateTxId.formatTid(tid));
+      zs.unreserve(tid, 0);
+
+      if (includeByStatus(status, filterStatus) && includeByTxid(tid, filterTxid)) {
+        statuses.add(new TransactionStatus(tid, status, txName, hlocks, wlocks, top, timeCreated));
       }
     }
 
@@ -399,11 +378,11 @@ public class AdminUtil<T> {
 
   }
 
-  private static boolean includeByStatus(TStatus status, EnumSet<TStatus> filterStatus) {
+  private boolean includeByStatus(TStatus status, EnumSet<TStatus> filterStatus) {
     return (filterStatus == null) || filterStatus.contains(status);
   }
 
-  private static boolean includeByTxid(Long tid, Set<Long> filterTxid) {
+  private boolean includeByTxid(Long tid, Set<Long> filterTxid) {
     return (filterTxid == null) || filterTxid.isEmpty() || filterTxid.contains(tid);
   }
 
@@ -471,7 +450,7 @@ public class AdminUtil<T> {
         break;
     }
 
-    zs.unreserve(txid, 0, TimeUnit.MILLISECONDS);
+    zs.unreserve(txid, 0);
     return state;
   }
 
@@ -515,7 +494,7 @@ public class AdminUtil<T> {
         break;
     }
 
-    zs.unreserve(txid, 0, TimeUnit.MILLISECONDS);
+    zs.unreserve(txid, 0);
     return state;
   }
 
