@@ -18,7 +18,7 @@
  */
 package org.apache.accumulo.core.fate;
 
-import static java.util.concurrent.TimeUnit.MILLISECONDS;
+import static com.google.common.util.concurrent.Uninterruptibles.sleepUninterruptibly;
 import static java.util.concurrent.TimeUnit.MINUTES;
 import static java.util.concurrent.TimeUnit.SECONDS;
 import static org.apache.accumulo.core.fate.ReadOnlyTStore.TStatus.FAILED;
@@ -35,7 +35,6 @@ import java.util.concurrent.ExecutorService;
 import java.util.concurrent.RejectedExecutionException;
 import java.util.concurrent.ScheduledThreadPoolExecutor;
 import java.util.concurrent.ThreadPoolExecutor;
-import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.function.Function;
 
@@ -45,7 +44,6 @@ import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.fate.ReadOnlyTStore.TStatus;
 import org.apache.accumulo.core.logging.FateLogger;
 import org.apache.accumulo.core.util.ShutdownUtil;
-import org.apache.accumulo.core.util.Timer;
 import org.apache.accumulo.core.util.UtilWaitThread;
 import org.apache.accumulo.core.util.threads.ThreadPools;
 import org.apache.thrift.TApplicationException;
@@ -62,7 +60,8 @@ public class Fate<T> {
 
   private final TStore<T> store;
   private final T environment;
-  private ExecutorService executor;
+  private final ScheduledThreadPoolExecutor fatePoolWatcher;
+  private final ExecutorService executor;
 
   private static final EnumSet<TStatus> FINISHED_STATES = EnumSet.of(FAILED, SUCCESSFUL, UNKNOWN);
 
@@ -88,7 +87,7 @@ public class Fate<T> {
           } else {
             Repo<T> prevOp = null;
             try {
-              deferTime = executeIsReady(tid, op);
+              deferTime = op.isReady(tid, environment);
 
               // Here, deferTime is only used to determine success (zero) or failure (non-zero),
               // proceeding on success and returning to the while loop on failure.
@@ -98,7 +97,7 @@ public class Fate<T> {
                 if (status == SUBMITTED) {
                   store.setStatus(tid, IN_PROGRESS);
                 }
-                op = executeCall(tid, op);
+                op = op.call(tid, environment);
               } else {
                 continue;
               }
@@ -133,7 +132,7 @@ public class Fate<T> {
           runnerLog.error("Uncaught exception in FATE runner thread.", e);
         } finally {
           if (tid != null) {
-            store.unreserve(tid, deferTime, TimeUnit.MILLISECONDS);
+            store.unreserve(tid, deferTime);
           }
         }
       }
@@ -162,7 +161,7 @@ public class Fate<T> {
         while (true) {
           // Nothing is going to work well at this point, so why even try. Just wait for the end,
           // preventing this FATE thread from processing further work and likely failing.
-          UtilWaitThread.sleepUninterruptibly(1, MINUTES);
+          sleepUninterruptibly(1, MINUTES);
         }
       }
     }
@@ -216,75 +215,46 @@ public class Fate<T> {
         log.warn("Failed to undo Repo, " + FateTxId.formatTid(tid), e);
       }
     }
-  }
 
-  protected long executeIsReady(Long tid, Repo<T> op) throws Exception {
-    var startTime = Timer.startNew();
-    var deferTime = op.isReady(tid, environment);
-    if (log.isTraceEnabled()) {
-      log.trace("Running {}.isReady() {} took {} ms and returned {}", op.getName(),
-          FateTxId.formatTid(tid), startTime.elapsed(MILLISECONDS), deferTime);
-    }
-    return deferTime;
-  }
-
-  protected Repo<T> executeCall(Long tid, Repo<T> op) throws Exception {
-    var startTime = Timer.startNew();
-    var next = op.call(tid, environment);
-    if (log.isTraceEnabled()) {
-      log.trace("Running {}.call() {} took {} ms and returned {}", op.getName(),
-          FateTxId.formatTid(tid), startTime.elapsed(MILLISECONDS),
-          next == null ? "null" : next.getName());
-    }
-    return next;
   }
 
   /**
    * Creates a Fault-tolerant executor.
-   * <p>
-   * Note: Users of this class should call
-   * {@link #startTransactionRunners(AccumuloConfiguration, ScheduledThreadPoolExecutor)} to launch
-   * the worker threads after creating a Fate object.
    *
    * @param toLogStrFunc A function that converts Repo to Strings that are suitable for logging
    */
-  public Fate(T environment, TStore<T> store, Function<Repo<T>,String> toLogStrFunc) {
+  public Fate(T environment, TStore<T> store, Function<Repo<T>,String> toLogStrFunc,
+      AccumuloConfiguration conf) {
     this.store = FateLogger.wrap(store, toLogStrFunc);
     this.environment = environment;
-  }
-
-  /**
-   * Launches the specified number of worker threads.
-   */
-  public void startTransactionRunners(AccumuloConfiguration conf,
-      ScheduledThreadPoolExecutor serverGeneralScheduledThreadPool) {
     final ThreadPoolExecutor pool = ThreadPools.getServerThreadPools().createExecutorService(conf,
         Property.MANAGER_FATE_THREADPOOL_SIZE, true);
-    ThreadPools
-        .watchCriticalScheduledTask(serverGeneralScheduledThreadPool.scheduleWithFixedDelay(() -> {
-          // resize the pool if the property changed
-          ThreadPools.resizePool(pool, conf, Property.MANAGER_FATE_THREADPOOL_SIZE);
-          // If the pool grew, then ensure that there is a TransactionRunner for each thread
-          int needed = conf.getCount(Property.MANAGER_FATE_THREADPOOL_SIZE) - pool.getActiveCount();
-          if (needed > 0) {
-            for (int i = 0; i < needed; i++) {
-              try {
-                pool.execute(new TransactionRunner());
-              } catch (RejectedExecutionException e) {
-                // RejectedExecutionException could be shutting down
-                if (pool.isShutdown()) {
-                  // The exception is expected in this case, no need to spam the logs.
-                  log.trace("Error adding transaction runner to FaTE executor pool.", e);
-                } else {
-                  // This is bad, FaTE may no longer work!
-                  log.error("Error adding transaction runner to FaTE executor pool.", e);
-                }
-                break;
-              }
+    this.fatePoolWatcher =
+        ThreadPools.getServerThreadPools().createGeneralScheduledExecutorService(conf);
+    ThreadPools.watchCriticalScheduledTask(fatePoolWatcher.schedule(() -> {
+      // resize the pool if the property changed
+      ThreadPools.resizePool(pool, conf, Property.MANAGER_FATE_THREADPOOL_SIZE);
+      // If the pool grew, then ensure that there is a TransactionRunner for each thread
+      int needed = conf.getCount(Property.MANAGER_FATE_THREADPOOL_SIZE) - pool.getQueue().size();
+      if (needed > 0) {
+        for (int i = 0; i < needed; i++) {
+          try {
+            pool.execute(new TransactionRunner());
+          } catch (RejectedExecutionException e) {
+            // RejectedExecutionException could be shutting down
+            if (pool.isShutdown()) {
+              // The exception is expected in this case, no need to spam the logs.
+              log.trace("Error adding transaction runner to FaTE executor pool.", e);
+            } else {
+              // This is bad, FaTE may no longer work!
+              log.error("Error adding transaction runner to FaTE executor pool.", e);
             }
+            break;
           }
-        }, 3, 30, SECONDS));
-    executor = pool;
+        }
+      }
+    }, 3, SECONDS));
+    this.executor = pool;
   }
 
   // get a transaction id back to the requester before doing any work
@@ -305,7 +275,7 @@ public class Fate<T> {
             store.push(tid, repo);
           } catch (StackOverflowException e) {
             // this should not happen
-            throw new RuntimeException(e);
+            throw new IllegalStateException(e);
           }
         }
 
@@ -318,7 +288,7 @@ public class Fate<T> {
         store.setStatus(tid, SUBMITTED);
       }
     } finally {
-      store.unreserve(tid, 0, TimeUnit.MILLISECONDS);
+      store.unreserve(tid, 0);
     }
 
   }
@@ -354,7 +324,7 @@ public class Fate<T> {
             return false;
           }
         } finally {
-          store.unreserve(tid, 0, TimeUnit.MILLISECONDS);
+          store.unreserve(tid, 0);
         }
       } else {
         // reserved, lets retry.
@@ -385,7 +355,7 @@ public class Fate<T> {
           break;
       }
     } finally {
-      store.unreserve(tid, 0, TimeUnit.MILLISECONDS);
+      store.unreserve(tid, 0);
     }
   }
 
@@ -398,7 +368,7 @@ public class Fate<T> {
       }
       return (String) store.getTransactionInfo(tid, TxInfo.RETURN_VALUE);
     } finally {
-      store.unreserve(tid, 0, TimeUnit.MILLISECONDS);
+      store.unreserve(tid, 0);
     }
   }
 
@@ -412,27 +382,19 @@ public class Fate<T> {
       }
       return (Exception) store.getTransactionInfo(tid, TxInfo.EXCEPTION);
     } finally {
-      store.unreserve(tid, 0, TimeUnit.MILLISECONDS);
+      store.unreserve(tid, 0);
     }
   }
 
   /**
    * Flags that FATE threadpool to clear out and end. Does not actively stop running FATE processes.
    */
-  public void shutdown(boolean wait) {
+  public void shutdown() {
     keepRunning.set(false);
-    if (executor == null) {
-      return;
-    }
-    executor.shutdownNow();
-    if (wait) {
-      while (!executor.isTerminated()) {
-        try {
-          executor.awaitTermination(1, SECONDS);
-        } catch (InterruptedException e) {
-          throw new IllegalStateException(e);
-        }
-      }
+    fatePoolWatcher.shutdown();
+    if (executor != null) {
+      executor.shutdown();
     }
   }
+
 }
