@@ -18,9 +18,10 @@
  */
 package org.apache.accumulo.core.fate;
 
+import static com.google.common.util.concurrent.Uninterruptibles.sleepUninterruptibly;
 import static java.nio.charset.StandardCharsets.UTF_8;
 import static java.util.concurrent.TimeUnit.MILLISECONDS;
-import static org.apache.accumulo.core.util.UtilWaitThread.sleepUninterruptibly;
+import static org.apache.accumulo.core.util.LazySingletons.RANDOM;
 
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
@@ -28,7 +29,7 @@ import java.io.IOException;
 import java.io.ObjectInputStream;
 import java.io.ObjectOutputStream;
 import java.io.Serializable;
-import java.security.SecureRandom;
+import java.io.UncheckedIOException;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.EnumSet;
@@ -36,14 +37,8 @@ import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
-import java.util.Queue;
 import java.util.Set;
-import java.util.concurrent.ConcurrentLinkedQueue;
-import java.util.concurrent.TimeUnit;
-import java.util.concurrent.locks.Lock;
-import java.util.concurrent.locks.ReentrantLock;
 
-import org.apache.accumulo.core.fate.zookeeper.ZooCache;
 import org.apache.accumulo.core.fate.zookeeper.ZooReaderWriter;
 import org.apache.accumulo.core.fate.zookeeper.ZooUtil.NodeExistsPolicy;
 import org.apache.accumulo.core.fate.zookeeper.ZooUtil.NodeMissingPolicy;
@@ -57,28 +52,31 @@ import org.slf4j.LoggerFactory;
 
 import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
 
+//TODO use zoocache? - ACCUMULO-1297
 //TODO handle zookeeper being down gracefully - ACCUMULO-1297
 
 public class ZooStore<T> implements TStore<T> {
 
   private static final Logger log = LoggerFactory.getLogger(ZooStore.class);
-  private ZooCache zc;
   private String path;
   private ZooReaderWriter zk;
+  private String lastReserved = "";
   private Set<Long> reserved;
-  private Map<Long,Long> deferred;
-  private static final SecureRandom random = new SecureRandom();
+  private Map<Long,Long> defered;
   private long statusChangeEvents = 0;
   private int reservationsWaiting = 0;
 
   private byte[] serialize(Object o) {
 
-    try (ByteArrayOutputStream baos = new ByteArrayOutputStream();
-        ObjectOutputStream oos = new ObjectOutputStream(baos)) {
+    try {
+      ByteArrayOutputStream baos = new ByteArrayOutputStream();
+      ObjectOutputStream oos = new ObjectOutputStream(baos);
       oos.writeObject(o);
+      oos.close();
+
       return baos.toByteArray();
     } catch (IOException e) {
-      throw new RuntimeException(e);
+      throw new UncheckedIOException(e);
     }
   }
 
@@ -86,11 +84,14 @@ public class ZooStore<T> implements TStore<T> {
       justification = "unsafe to store arbitrary serialized objects like this, but needed for now"
           + " for backwards compatibility")
   private Object deserialize(byte[] ser) {
-    try (ByteArrayInputStream bais = new ByteArrayInputStream(ser);
-        ObjectInputStream ois = new ObjectInputStream(bais)) {
+    try {
+      ByteArrayInputStream bais = new ByteArrayInputStream(ser);
+      ObjectInputStream ois = new ObjectInputStream(bais);
       return ois.readObject();
-    } catch (Exception e) {
-      throw new RuntimeException(e);
+    } catch (IOException e) {
+      throw new UncheckedIOException(e);
+    } catch (ReflectiveOperationException e) {
+      throw new IllegalStateException(e);
     }
   }
 
@@ -102,14 +103,12 @@ public class ZooStore<T> implements TStore<T> {
     return Long.parseLong(txdir.split("_")[1], 16);
   }
 
-  public ZooStore(String path, ZooReaderWriter zk, ZooCache zc)
-      throws KeeperException, InterruptedException {
+  public ZooStore(String path, ZooReaderWriter zk) throws KeeperException, InterruptedException {
 
     this.path = path;
     this.zk = zk;
-    this.zc = zc;
     this.reserved = new HashSet<>();
-    this.deferred = new HashMap<>();
+    this.defered = new HashMap<>();
 
     zk.putPersistentData(path, new byte[0], NodeExistsPolicy.SKIP);
   }
@@ -124,49 +123,18 @@ public class ZooStore<T> implements TStore<T> {
     while (true) {
       try {
         // looking at the code for SecureRandom, it appears to be thread safe
-        long tid = random.nextLong() & 0x7fffffffffffffffL;
+        long tid = RANDOM.get().nextLong() & 0x7fffffffffffffffL;
         zk.putPersistentData(getTXPath(tid), TStatus.NEW.name().getBytes(UTF_8),
             NodeExistsPolicy.FAIL);
         return tid;
       } catch (NodeExistsException nee) {
         // exist, so just try another random #
-      } catch (Exception e) {
-        throw new RuntimeException(e);
+      } catch (KeeperException | InterruptedException e) {
+        throw new IllegalStateException(e);
       }
     }
   }
 
-  /*
-   * Holds a copy of all of the fate transaction in zookeeper. Used for finding the next one to
-   * reserve. When empty a single thread will refill. All fate threads can pull off of the queue as
-   * they look for something to reserve. This is used so that each thread does not have to read all
-   * children from zookeeper when looking for any fate tx to reserve.
-   */
-  private final Queue<String> reservationCandidates = new ConcurrentLinkedQueue<>();
-  /*
-   * The purpose of this lock is to ensure only one thread reads the list of all fate operations
-   * from zookeeper at a time. The reason this lock was used instead of synchronizing on the
-   * ZooStore object is because all places that do sync on ZooStore only read/write in memory data
-   * structs. Therefore, did not want to read from zookeeper while synchronizing on ZooStore here.
-   */
-  private final Lock reservationCandidateLock = new ReentrantLock();
-
-  private Queue<String> getTxDirs() throws InterruptedException, KeeperException {
-    if (reservationCandidates.isEmpty()) {
-      reservationCandidateLock.lock();
-      try {
-        if (reservationCandidates.isEmpty()) {
-          List<String> txdirs = new ArrayList<>(zc.getChildren(path));
-          Collections.sort(txdirs);
-          reservationCandidates.addAll(txdirs);
-        }
-      } finally {
-        reservationCandidateLock.unlock();
-      }
-    }
-    return reservationCandidates;
-  }
-
   @Override
   public long reserve() {
     try {
@@ -177,19 +145,29 @@ public class ZooStore<T> implements TStore<T> {
           events = statusChangeEvents;
         }
 
-        Queue<String> txdirs = getTxDirs();
+        List<String> txdirs = new ArrayList<>(zk.getChildren(path));
+        Collections.sort(txdirs);
 
-        while (true) {
-          String txdir = txdirs.poll();
-          if (txdir == null) {
-            break;
+        synchronized (this) {
+          if (!txdirs.isEmpty() && txdirs.get(txdirs.size() - 1).compareTo(lastReserved) <= 0) {
+            lastReserved = "";
           }
+        }
+
+        for (String txdir : txdirs) {
           long tid = parseTid(txdir);
 
           synchronized (this) {
-            if (deferred.containsKey(tid)) {
-              if ((deferred.get(tid) - System.nanoTime()) < 0) {
-                deferred.remove(tid);
+            // this check makes reserve pick up where it left off, so that it cycles through all as
+            // it is repeatedly called.... failing to do so can lead to
+            // starvation where fate ops that sort higher and hold a lock are never reserved.
+            if (txdir.compareTo(lastReserved) <= 0) {
+              continue;
+            }
+
+            if (defered.containsKey(tid)) {
+              if (defered.get(tid) < System.currentTimeMillis()) {
+                defered.remove(tid);
               } else {
                 continue;
               }
@@ -198,6 +176,7 @@ public class ZooStore<T> implements TStore<T> {
               continue;
             } else {
               reserved.add(tid);
+              lastReserved = txdir;
             }
           }
 
@@ -214,7 +193,7 @@ public class ZooStore<T> implements TStore<T> {
           } catch (NoNodeException nne) {
             // node deleted after we got the list of children, its ok
             unreserve(tid);
-          } catch (Exception e) {
+          } catch (KeeperException | InterruptedException | RuntimeException e) {
             unreserve(tid);
             throw e;
           }
@@ -223,13 +202,11 @@ public class ZooStore<T> implements TStore<T> {
         synchronized (this) {
           // suppress lgtm alert - synchronized variable is not always true
           if (events == statusChangeEvents) { // lgtm [java/constant-comparison]
-            if (deferred.isEmpty()) {
+            if (defered.isEmpty()) {
               this.wait(5000);
             } else {
-              long currTime = System.nanoTime();
-              long minWait =
-                  deferred.values().stream().mapToLong(l -> l - currTime).min().getAsLong();
-              long waitTime = TimeUnit.MILLISECONDS.convert(minWait, TimeUnit.NANOSECONDS);
+              Long minTime = Collections.min(defered.values());
+              long waitTime = minTime - System.currentTimeMillis();
               if (waitTime > 0) {
                 this.wait(Math.min(waitTime, 5000));
               }
@@ -237,8 +214,8 @@ public class ZooStore<T> implements TStore<T> {
           }
         }
       }
-    } catch (InterruptedException | KeeperException e) {
-      throw new RuntimeException(e);
+    } catch (KeeperException | InterruptedException e) {
+      throw new IllegalStateException(e);
     }
   }
 
@@ -251,7 +228,7 @@ public class ZooStore<T> implements TStore<T> {
           try {
             this.wait(1000);
           } catch (InterruptedException e) {
-            throw new RuntimeException(e);
+            throw new IllegalStateException(e);
           }
         }
 
@@ -296,8 +273,7 @@ public class ZooStore<T> implements TStore<T> {
   }
 
   @Override
-  public void unreserve(long tid, long deferTime, TimeUnit deferTimeUnit) {
-    deferTime = TimeUnit.NANOSECONDS.convert(deferTime, deferTimeUnit);
+  public void unreserve(long tid, long deferTime) {
 
     if (deferTime < 0) {
       throw new IllegalArgumentException("deferTime < 0 : " + deferTime);
@@ -310,7 +286,7 @@ public class ZooStore<T> implements TStore<T> {
       }
 
       if (deferTime > 0) {
-        deferred.put(tid, System.nanoTime() + deferTime);
+        defered.put(tid, System.currentTimeMillis() + deferTime);
       }
 
       this.notifyAll();
@@ -343,7 +319,7 @@ public class ZooStore<T> implements TStore<T> {
             return null;
           }
         } catch (KeeperException.NoNodeException ex) {
-          throw new RuntimeException(ex);
+          throw new IllegalStateException(ex);
         }
 
         byte[] ser = zk.getData(txpath + "/" + top);
@@ -354,8 +330,8 @@ public class ZooStore<T> implements TStore<T> {
         log.debug("zookeeper error reading " + txpath + ": " + ex, ex);
         sleepUninterruptibly(100, MILLISECONDS);
         continue;
-      } catch (Exception e) {
-        throw new RuntimeException(e);
+      } catch (KeeperException | InterruptedException e) {
+        throw new IllegalStateException(e);
       }
     }
     return null;
@@ -395,8 +371,8 @@ public class ZooStore<T> implements TStore<T> {
       zk.putPersistentSequential(txpath + "/repo_", serialize(repo));
     } catch (StackOverflowException soe) {
       throw soe;
-    } catch (Exception e) {
-      throw new RuntimeException(e);
+    } catch (KeeperException | InterruptedException e) {
+      throw new IllegalStateException(e);
     }
   }
 
@@ -411,8 +387,8 @@ public class ZooStore<T> implements TStore<T> {
         throw new IllegalStateException("Tried to pop when empty " + FateTxId.formatTid(tid));
       }
       zk.recursiveDelete(txpath + "/" + top, NodeMissingPolicy.SKIP);
-    } catch (Exception e) {
-      throw new RuntimeException(e);
+    } catch (KeeperException | InterruptedException e) {
+      throw new IllegalStateException(e);
     }
   }
 
@@ -421,8 +397,8 @@ public class ZooStore<T> implements TStore<T> {
       return TStatus.valueOf(new String(zk.getData(getTXPath(tid)), UTF_8));
     } catch (NoNodeException nne) {
       return TStatus.UNKNOWN;
-    } catch (Exception e) {
-      throw new RuntimeException(e);
+    } catch (KeeperException | InterruptedException e) {
+      throw new IllegalStateException(e);
     }
   }
 
@@ -451,7 +427,7 @@ public class ZooStore<T> implements TStore<T> {
           try {
             this.wait(5000);
           } catch (InterruptedException e) {
-            throw new RuntimeException(e);
+            throw new IllegalStateException(e);
           }
         }
       }
@@ -465,8 +441,8 @@ public class ZooStore<T> implements TStore<T> {
     try {
       zk.putPersistentData(getTXPath(tid), status.name().getBytes(UTF_8),
           NodeExistsPolicy.OVERWRITE);
-    } catch (Exception e) {
-      throw new RuntimeException(e);
+    } catch (KeeperException | InterruptedException e) {
+      throw new IllegalStateException(e);
     }
 
     synchronized (this) {
@@ -481,8 +457,8 @@ public class ZooStore<T> implements TStore<T> {
 
     try {
       zk.recursiveDelete(getTXPath(tid), NodeMissingPolicy.SKIP);
-    } catch (Exception e) {
-      throw new RuntimeException(e);
+    } catch (KeeperException | InterruptedException e) {
+      throw new IllegalStateException(e);
     }
   }
 
@@ -502,8 +478,8 @@ public class ZooStore<T> implements TStore<T> {
         data[1] = ' ';
         zk.putPersistentData(getTXPath(tid) + "/" + txInfo, data, NodeExistsPolicy.OVERWRITE);
       }
-    } catch (Exception e2) {
-      throw new RuntimeException(e2);
+    } catch (KeeperException | InterruptedException e2) {
+      throw new IllegalStateException(e2);
     }
   }
 
@@ -525,22 +501,22 @@ public class ZooStore<T> implements TStore<T> {
       }
     } catch (NoNodeException nne) {
       return null;
-    } catch (Exception e) {
-      throw new RuntimeException(e);
+    } catch (KeeperException | InterruptedException e) {
+      throw new IllegalStateException(e);
     }
   }
 
   @Override
   public List<Long> list() {
     try {
-      List<String> transactions = zc.getChildren(path);
-      ArrayList<Long> l = new ArrayList<>(transactions.size());
+      ArrayList<Long> l = new ArrayList<>();
+      List<String> transactions = zk.getChildren(path);
       for (String txid : transactions) {
         l.add(parseTid(txid));
       }
       return l;
-    } catch (Exception e) {
-      throw new RuntimeException(e);
+    } catch (KeeperException | InterruptedException e) {
+      throw new IllegalStateException(e);
     }
   }
 
@@ -567,7 +543,7 @@ public class ZooStore<T> implements TStore<T> {
       } catch (KeeperException.NoNodeException e) {
         return Collections.emptyList();
       } catch (KeeperException | InterruptedException e1) {
-        throw new RuntimeException(e1);
+        throw new IllegalStateException(e1);
       }
 
       ops = new ArrayList<>(ops);
@@ -587,7 +563,7 @@ public class ZooStore<T> implements TStore<T> {
             // children changed so start over
             continue outer;
           } catch (KeeperException | InterruptedException e) {
-            throw new RuntimeException(e);
+            throw new IllegalStateException(e);
           }
         }
       }
