@@ -89,8 +89,8 @@ public class DistributedReadWriteLock implements java.util.concurrent.locks.Read
       return result;
     }
 
-    private final LockType type;
-    private final byte[] userData;
+    private LockType type;
+    private byte[] userData;
   }
 
   // This kind of lock can be easily implemented by ZooKeeper
@@ -137,8 +137,7 @@ public class DistributedReadWriteLock implements java.util.concurrent.locks.Read
             return;
           }
         } catch (InterruptedException ex) {
-          Thread.currentThread().interrupt();
-          log.warn("Interrupted while waiting to acquire lock", ex);
+          // ignored
         }
       }
     }
@@ -237,8 +236,8 @@ public class DistributedReadWriteLock implements java.util.concurrent.locks.Read
     }
   }
 
-  private final QueueLock qlock;
-  private final byte[] data;
+  private QueueLock qlock;
+  private byte[] data;
 
   public DistributedReadWriteLock(QueueLock qlock, byte[] data) {
     this.qlock = qlock;
