@@ -19,20 +19,22 @@
 package org.apache.accumulo.core.fate.zookeeper;
 
 import static java.nio.charset.StandardCharsets.UTF_8;
+import static org.apache.accumulo.core.util.LazySingletons.RANDOM;
 
-import java.security.SecureRandom;
 import java.util.Collections;
 import java.util.ConcurrentModificationException;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.Optional;
 import java.util.concurrent.locks.Lock;
 import java.util.concurrent.locks.LockSupport;
 import java.util.concurrent.locks.ReadWriteLock;
 import java.util.concurrent.locks.ReentrantReadWriteLock;
-import java.util.function.Predicate;
 
-import org.apache.accumulo.core.fate.zookeeper.ServiceLock.ServiceLockPath;
+import org.apache.accumulo.core.lock.ServiceLock;
+import org.apache.accumulo.core.lock.ServiceLock.ServiceLockPath;
+import org.apache.accumulo.core.lock.ServiceLockData;
 import org.apache.zookeeper.KeeperException;
 import org.apache.zookeeper.KeeperException.Code;
 import org.apache.zookeeper.WatchedEvent;
@@ -63,7 +65,6 @@ public class ZooCache {
   private final HashMap<String,List<String>> childrenCache;
 
   private final ZooReader zReader;
-  private static final SecureRandom random = new SecureRandom();
 
   private volatile boolean closed = false;
 
@@ -271,7 +272,7 @@ public class ZooCache {
         }
         LockSupport.parkNanos(sleepTime);
         if (sleepTime < 10_000) {
-          sleepTime = (int) (sleepTime + sleepTime * random.nextDouble());
+          sleepTime = (int) (sleepTime + sleepTime * RANDOM.get().nextDouble());
         }
       }
     }
@@ -526,40 +527,21 @@ public class ZooCache {
     }
   }
 
-  /**
-   * Removes all paths in the cache match the predicate.
-   */
-  public void clear(Predicate<String> pathPredicate) {
-    Preconditions.checkState(!closed);
-    Predicate<String> pathPredicateToUse;
-    if (log.isTraceEnabled()) {
-      pathPredicateToUse = pathPredicate.and(path -> {
-        log.trace("removing {} from cache", path);
-        return true;
-      });
-    } else {
-      pathPredicateToUse = pathPredicate;
-    }
-    cacheWriteLock.lock();
-    try {
-      cache.keySet().removeIf(pathPredicateToUse);
-      childrenCache.keySet().removeIf(pathPredicateToUse);
-      statCache.keySet().removeIf(pathPredicateToUse);
-
-      immutableCache = new ImmutableCacheCopies(++updateCount, cache, statCache, childrenCache);
-
-    } finally {
-      cacheWriteLock.unlock();
-    }
-  }
-
-  public byte[] getLockData(ServiceLockPath path) {
+  public Optional<ServiceLockData> getLockData(ServiceLockPath path) {
     List<String> children = ServiceLock.validateAndSort(path, getChildren(path.toString()));
     if (children == null || children.isEmpty()) {
-      return null;
+      return Optional.empty();
     }
     String lockNode = children.get(0);
-    return get(path + "/" + lockNode);
+
+    byte[] lockData = get(path + "/" + lockNode);
+    if (log.isTraceEnabled()) {
+      log.trace("Data from lockNode {} is {}", lockNode, new String(lockData, UTF_8));
+    }
+    if (lockData == null) {
+      lockData = new byte[0];
+    }
+    return ServiceLockData.parse(lockData);
   }
 
 }
