@@ -102,8 +102,8 @@ public class LruBlockCache extends SynchronousLoadingBlockCache implements Block
   private final EvictionThread evictionThread;
 
   /** Statistics thread schedule pool (for heavy debugging, could remove) */
-  private final ScheduledExecutorService scheduleThreadPool =
-      ThreadPools.getServerThreadPools().createScheduledExecutorService(1, "LRUBlockCacheStats");
+  private final ScheduledExecutorService scheduleThreadPool = ThreadPools.getServerThreadPools()
+      .createScheduledExecutorService(1, "LRUBlockCacheStats", true);
 
   /** Current size of cache */
   private final AtomicLong size;
@@ -154,7 +154,7 @@ public class LruBlockCache extends SynchronousLoadingBlockCache implements Block
         try {
           Thread.sleep(10);
         } catch (InterruptedException ex) {
-          throw new RuntimeException(ex);
+          throw new IllegalStateException(ex);
         }
       }
     } else {
@@ -391,9 +391,9 @@ public class LruBlockCache extends SynchronousLoadingBlockCache implements Block
    */
   private class BlockBucket implements Comparable<BlockBucket> {
 
-    private final CachedBlockQueue queue;
-    private long totalSize;
-    private final long bucketSize;
+    private CachedBlockQueue queue;
+    private long totalSize = 0;
+    private long bucketSize;
 
     public BlockBucket(long bytesToFree, long blockSize, long bucketSize) {
       this.bucketSize = bucketSize;
@@ -512,7 +512,7 @@ public class LruBlockCache extends SynchronousLoadingBlockCache implements Block
    * Thread is triggered into action by {@link LruBlockCache#runEviction()}
    */
   private static class EvictionThread extends AccumuloDaemonThread {
-    private final WeakReference<LruBlockCache> cache;
+    private WeakReference<LruBlockCache> cache;
     private boolean running = false;
 
     public EvictionThread(LruBlockCache cache) {
@@ -532,9 +532,7 @@ public class LruBlockCache extends SynchronousLoadingBlockCache implements Block
           running = true;
           try {
             this.wait();
-          } catch (InterruptedException e) {
-            // empty
-          }
+          } catch (InterruptedException e) {}
         }
         LruBlockCache cache = this.cache.get();
         if (cache == null) {
@@ -577,14 +575,14 @@ public class LruBlockCache extends SynchronousLoadingBlockCache implements Block
     float freeMB = ((float) freeSize) / ((float) (1024 * 1024));
     float maxMB = ((float) this.conf.getMaxSize()) / ((float) (1024 * 1024));
     log.debug(
-        "Cache Stats: {} Sizes: Total={}MB ({}), Free={}MB ({}), Max={}MB"
+        "Cache Stats: Sizes: Total={}MB ({}), Free={}MB ({}), Max={}MB"
             + " ({}), Counts: Blocks={}, Access={}, Hit={}, Miss={}, Evictions={},"
             + " Evicted={},Ratios: Hit Ratio={}%, Miss Ratio={}%, Evicted/Run={},"
             + " Duplicate Reads={}",
-        conf.getCacheType(), sizeMB, totalSize, freeMB, freeSize, maxMB, this.conf.getMaxSize(),
-        size(), stats.requestCount(), stats.hitCount(), stats.getMissCount(),
-        stats.getEvictionCount(), stats.getEvictedCount(), stats.getHitRatio() * 100,
-        stats.getMissRatio() * 100, stats.evictedPerEviction(), stats.getDuplicateReads());
+        sizeMB, totalSize, freeMB, freeSize, maxMB, this.conf.getMaxSize(), size(),
+        stats.requestCount(), stats.hitCount(), stats.getMissCount(), stats.getEvictionCount(),
+        stats.getEvictedCount(), stats.getHitRatio() * 100, stats.getMissRatio() * 100,
+        stats.evictedPerEviction(), stats.getDuplicateReads());
   }
 
   /**
