@@ -26,7 +26,6 @@ import java.io.UncheckedIOException;
 import java.util.Collections;
 import java.util.Map;
 import java.util.Objects;
-import java.util.concurrent.ExecutionException;
 import java.util.concurrent.atomic.AtomicReference;
 import java.util.function.Supplier;
 
@@ -48,7 +47,7 @@ import org.apache.hadoop.fs.Seekable;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.cache.Cache;
+import com.github.benmanes.caffeine.cache.Cache;
 
 /**
  * This is a wrapper class for BCFile that includes a cache for independent caches for datablocks
@@ -170,8 +169,14 @@ public class CachableBlockFile {
 
     private long getCachedFileLen() throws IOException {
       try {
-        return fileLenCache.get(cacheId, lengthSupplier::get);
-      } catch (ExecutionException e) {
+        return fileLenCache.get(cacheId, k -> {
+          try {
+            return lengthSupplier.get();
+          } catch (IOException e) {
+            throw new UncheckedIOException(e);
+          }
+        });
+      } catch (UncheckedIOException e) {
         throw new IOException("Failed to get " + cacheId + " len from cache ", e);
       }
     }
@@ -247,9 +252,9 @@ public class CachableBlockFile {
     }
 
     private class RawBlockLoader extends BaseBlockLoader {
-      private final long offset;
-      private final long compressedSize;
-      private final long rawSize;
+      private long offset;
+      private long compressedSize;
+      private long rawSize;
 
       private RawBlockLoader(long offset, long compressedSize, long rawSize, boolean loadingMeta) {
         super(loadingMeta);
@@ -273,7 +278,7 @@ public class CachableBlockFile {
     }
 
     private class OffsetBlockLoader extends BaseBlockLoader {
-      private final int blockIndex;
+      private int blockIndex;
 
       private OffsetBlockLoader(int blockIndex, boolean loadingMeta) {
         super(loadingMeta);
@@ -322,7 +327,7 @@ public class CachableBlockFile {
 
       abstract String getBlockId();
 
-      private final boolean loadingMetaBlock;
+      private boolean loadingMetaBlock;
 
       public BaseBlockLoader(boolean loadingMetaBlock) {
         this.loadingMetaBlock = loadingMetaBlock;
@@ -351,18 +356,23 @@ public class CachableBlockFile {
             }
           }
 
-          try (BlockReader _currBlock = getBlockReader(maxSize, reader)) {
-            if (_currBlock == null) {
-              return null;
-            }
+          BlockReader _currBlock = getBlockReader(maxSize, reader);
+          if (_currBlock == null) {
+            return null;
+          }
 
-            byte[] b = new byte[(int) _currBlock.getRawSize()];
+          byte[] b = null;
+          try {
+            b = new byte[(int) _currBlock.getRawSize()];
             _currBlock.readFully(b);
-            return b;
           } catch (IOException e) {
             log.debug("Error full blockRead for file " + cacheId + " for block " + getBlockId(), e);
             throw new UncheckedIOException(e);
+          } finally {
+            _currBlock.close();
           }
+
+          return b;
         } catch (IOException e) {
           throw new UncheckedIOException(e);
         }
@@ -491,7 +501,7 @@ public class CachableBlockFile {
   }
 
   public static class CachedBlockRead extends DataInputStream {
-    private final SeekableByteArrayInputStream seekableInput;
+    private SeekableByteArrayInputStream seekableInput;
     private final CacheEntry cb;
     boolean indexable;
 
