@@ -50,7 +50,6 @@ import org.apache.accumulo.core.data.ByteSequence;
 import org.apache.accumulo.core.data.Key;
 import org.apache.accumulo.core.data.Range;
 import org.apache.accumulo.core.data.Value;
-import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.file.FileSKVIterator;
 import org.apache.accumulo.core.file.FileSKVWriter;
 import org.apache.accumulo.core.file.NoSuchMetaStoreException;
@@ -381,15 +380,15 @@ public class RFile {
 
   private static class SampleLocalityGroupWriter {
 
-    private final Sampler sampler;
+    private Sampler sampler;
 
-    private final List<SampleEntry> entries = new ArrayList<>();
+    private List<SampleEntry> entries = new ArrayList<>();
     private long dataSize = 0;
 
-    private final LocalityGroupWriter lgw;
+    private LocalityGroupWriter lgr;
 
-    public SampleLocalityGroupWriter(LocalityGroupWriter lgw, Sampler sampler) {
-      this.lgw = lgw;
+    public SampleLocalityGroupWriter(LocalityGroupWriter lgr, Sampler sampler) {
+      this.lgr = lgr;
       this.sampler = sampler;
     }
 
@@ -402,10 +401,10 @@ public class RFile {
 
     public void close() throws IOException {
       for (SampleEntry se : entries) {
-        lgw.append(se.key, se.val);
+        lgr.append(se.key, se.val);
       }
 
-      lgw.close();
+      lgr.close();
     }
 
     public void flushIfNeeded() throws IOException {
@@ -416,10 +415,10 @@ public class RFile {
 
         if (!subList.isEmpty()) {
           for (SampleEntry se : subList) {
-            lgw.append(se.key, se.val);
+            lgr.append(se.key, se.val);
           }
 
-          lgw.closeBlock(subList.get(subList.size() - 1).key, false);
+          lgr.closeBlock(subList.get(subList.size() - 1).key, false);
 
           subList.clear();
           dataSize = 0;
@@ -430,7 +429,7 @@ public class RFile {
 
   private static class LocalityGroupWriter {
 
-    private final BCFile.Writer fileWriter;
+    private BCFile.Writer fileWriter;
     private BlockAppender blockWriter;
 
     private final long blockSize;
@@ -443,10 +442,10 @@ public class RFile {
 
     private Key prevKey = new Key();
 
-    private final SampleLocalityGroupWriter sample;
+    private SampleLocalityGroupWriter sample;
 
     // Use windowed stats to fix ACCUMULO-4669
-    private final RollingStats keyLenStats = new RollingStats(2017);
+    private RollingStats keyLenStats = new RollingStats(2017);
     private double averageKeySize = 0;
 
     LocalityGroupWriter(BCFile.Writer fileWriter, long blockSize, long maxBlockSize,
@@ -562,14 +561,14 @@ public class RFile {
     public static final int MAX_CF_IN_DLG = 1000;
     private static final double MAX_BLOCK_MULTIPLIER = 1.1;
 
-    private final BCFile.Writer fileWriter;
+    private BCFile.Writer fileWriter;
 
     private final long blockSize;
     private final long maxBlockSize;
     private final int indexBlockSize;
 
-    private final ArrayList<LocalityGroupMetadata> localityGroups = new ArrayList<>();
-    private final ArrayList<LocalityGroupMetadata> sampleGroups = new ArrayList<>();
+    private ArrayList<LocalityGroupMetadata> localityGroups = new ArrayList<>();
+    private ArrayList<LocalityGroupMetadata> sampleGroups = new ArrayList<>();
     private LocalityGroupMetadata currentLocalityGroup = null;
     private LocalityGroupMetadata sampleLocalityGroup = null;
 
@@ -577,13 +576,13 @@ public class RFile {
     private boolean closed = false;
     private boolean startedDefaultLocalityGroup = false;
 
-    private final HashSet<ByteSequence> previousColumnFamilies;
+    private HashSet<ByteSequence> previousColumnFamilies;
     private long length = -1;
 
     private LocalityGroupWriter lgWriter;
 
-    private final SamplerConfigurationImpl samplerConfig;
-    private final Sampler sampler;
+    private SamplerConfigurationImpl samplerConfig;
+    private Sampler sampler;
 
     public Writer(BCFile.Writer bfw, int blockSize) throws IOException {
       this(bfw, blockSize, (int) DefaultConfiguration.getInstance()
@@ -756,13 +755,13 @@ public class RFile {
 
   private static class LocalityGroupReader extends LocalityGroup implements FileSKVIterator {
 
-    private final CachableBlockFile.Reader reader;
-    private final MultiLevelIndex.Reader index;
-    private final int blockCount;
-    private final Key firstKey;
-    private final int startBlock;
+    private CachableBlockFile.Reader reader;
+    private MultiLevelIndex.Reader index;
+    private int blockCount;
+    private Key firstKey;
+    private int startBlock;
     private boolean closed = false;
-    private final int version;
+    private int version;
     private boolean checkRange = true;
 
     private LocalityGroupReader(CachableBlockFile.Reader reader, LocalityGroupMetadata lgm,
@@ -1034,8 +1033,8 @@ public class RFile {
 
           if (iiter.hasPrevious()) {
             prevKey = new Key(iiter.peekPrevious().getKey()); // initially prevKey is the last key
+                                                              // of the prev block
           } else {
-            // of the prev block
             prevKey = new Key(); // first block in the file, so set prev key to minimal key
           }
 
@@ -1159,11 +1158,6 @@ public class RFile {
     public void setCacheProvider(CacheProvider cacheProvider) {
       throw new UnsupportedOperationException();
     }
-
-    @Override
-    public long estimateOverlappingEntries(KeyExtent extent) throws IOException {
-      throw new UnsupportedOperationException();
-    }
   }
 
   public static class Reader extends HeapIterator implements FileSKVIterator {
@@ -1179,14 +1173,14 @@ public class RFile {
     private final LocalityGroupContext lgContext;
     private LocalityGroupSeekCache lgCache;
 
-    private final List<Reader> deepCopies;
+    private List<Reader> deepCopies;
     private boolean deepCopy = false;
 
     private AtomicBoolean interruptFlag;
 
     private SamplerConfigurationImpl samplerConfig = null;
 
-    private final int rfileVersion;
+    private int rfileVersion;
 
     public Reader(CachableBlockFile.Reader rdr) throws IOException {
       this.reader = rdr;
@@ -1288,32 +1282,24 @@ public class RFile {
       this(new CachableBlockFile.Reader(b));
     }
 
-    private void closeLocalityGroupReaders(boolean ignoreIOExceptions) throws IOException {
+    private void closeLocalityGroupReaders() {
       for (LocalityGroupReader lgr : currentReaders) {
         try {
           lgr.close();
         } catch (IOException e) {
-          if (ignoreIOExceptions) {
-            log.warn("Errored out attempting to close LocalityGroupReader.", e);
-          } else {
-            throw e;
-          }
+          log.warn("Errored out attempting to close LocalityGroupReader.", e);
         }
       }
     }
 
     @Override
-    public void closeDeepCopies() throws IOException {
-      closeDeepCopies(false);
-    }
-
-    private void closeDeepCopies(boolean ignoreIOExceptions) throws IOException {
+    public void closeDeepCopies() {
       if (deepCopy) {
-        throw new RuntimeException("Calling closeDeepCopies on a deep copy is not supported");
+        throw new IllegalStateException("Calling closeDeepCopies on a deep copy is not supported");
       }
 
       for (Reader deepCopy : deepCopies) {
-        deepCopy.closeLocalityGroupReaders(ignoreIOExceptions);
+        deepCopy.closeLocalityGroupReaders();
       }
 
       deepCopies.clear();
@@ -1322,12 +1308,11 @@ public class RFile {
     @Override
     public void close() throws IOException {
       if (deepCopy) {
-        throw new RuntimeException("Calling close on a deep copy is not supported");
+        throw new IllegalStateException("Calling close on a deep copy is not supported");
       }
 
-      // Closes as much as possible igoring and logging exceptions along the way
-      closeDeepCopies(true);
-      closeLocalityGroupReaders(true);
+      closeDeepCopies();
+      closeLocalityGroupReaders();
 
       if (sampleReaders != null) {
         for (LocalityGroupReader lgr : sampleReaders) {
@@ -1549,11 +1534,12 @@ public class RFile {
     @Override
     public void setInterruptFlag(AtomicBoolean flag) {
       if (deepCopy) {
-        throw new RuntimeException("Calling setInterruptFlag on a deep copy is not supported");
+        throw new IllegalStateException("Calling setInterruptFlag on a deep copy is not supported");
       }
 
       if (!deepCopies.isEmpty()) {
-        throw new RuntimeException("Setting interrupt flag after calling deep copy not supported");
+        throw new IllegalStateException(
+            "Setting interrupt flag after calling deep copy not supported");
       }
 
       setInterruptFlagInternal(flag);
@@ -1570,35 +1556,5 @@ public class RFile {
     public void setCacheProvider(CacheProvider cacheProvider) {
       reader.setCacheProvider(cacheProvider);
     }
-
-    @Override
-    public long estimateOverlappingEntries(KeyExtent extent) throws IOException {
-      long totalEntries = 0;
-      Key startKey = extent.toDataRange().getStartKey();
-      IndexEntry indexEntry;
-
-      for (LocalityGroupReader lgr : currentReaders) {
-        boolean prevEntryOverlapped = false;
-        var indexIter = startKey == null ? lgr.getIndex() : lgr.index.lookup(startKey);
-
-        while (indexIter.hasNext()) {
-          indexEntry = indexIter.next();
-          if (extent.contains(indexEntry.getKey().getRow())) {
-            totalEntries += indexEntry.getNumEntries();
-            prevEntryOverlapped = true;
-          } else if (prevEntryOverlapped) {
-            // The last index entry included in the count is the one after the last contained by the
-            // extent. This is because it is possible for the extent to overlap this index entry
-            // but there is no way to check whether it does or not. The index entry only contains
-            // info about the last key, but the extent may overlap but not with the last key.
-            totalEntries += indexEntry.getNumEntries();
-            prevEntryOverlapped = false;
-            break;
-          }
-        }
-      }
-
-      return totalEntries;
-    }
   }
 }
