@@ -34,15 +34,14 @@ import org.apache.accumulo.core.file.FileSKVIterator;
 import org.apache.accumulo.core.file.FileSKVWriter;
 import org.apache.accumulo.core.file.blockfile.impl.CachableBlockFile.CachableBuilder;
 import org.apache.accumulo.core.file.rfile.bcfile.BCFile;
+import org.apache.accumulo.core.metadata.TabletFile;
 import org.apache.accumulo.core.sample.impl.SamplerConfigurationImpl;
 import org.apache.accumulo.core.sample.impl.SamplerFactory;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.CreateFlag;
 import org.apache.hadoop.fs.FSDataOutputStream;
 import org.apache.hadoop.fs.FileSystem;
-import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.fs.permission.FsPermission;
-import org.apache.hadoop.hdfs.DistributedFileSystem;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -56,7 +55,7 @@ public class RFileOperations extends FileOperations {
 
   private static RFile.Reader getReader(FileOptions options) throws IOException {
     CachableBuilder cb = new CachableBuilder()
-        .fsPath(options.getFileSystem(), new Path(options.getFilename()), options.dropCacheBehind)
+        .fsPath(options.getFileSystem(), options.getFile().getPath(), options.dropCacheBehind)
         .conf(options.getConfiguration()).fileLen(options.getFileLenCache())
         .cacheProvider(options.cacheProvider).readLimiter(options.getRateLimiter())
         .cryptoService(options.getCryptoService());
@@ -65,7 +64,7 @@ public class RFileOperations extends FileOperations {
 
   @Override
   protected long getFileSize(FileOptions options) throws IOException {
-    return options.getFileSystem().getFileStatus(new Path(options.getFilename())).getLen();
+    return options.getFileSystem().getFileStatus(options.getFile().getPath()).getLen();
   }
 
   @Override
@@ -134,65 +133,25 @@ public class RFileOperations extends FileOperations {
       }
       int bufferSize = conf.getInt("io.file.buffer.size", 4096);
 
-      String file = options.getFilename();
+      TabletFile file = options.getFile();
       FileSystem fs = options.getFileSystem();
 
-      var ecEnable = EcEnabled.valueOf(
-          options.getTableConfiguration().get(Property.TABLE_ENABLE_ERASURE_CODES).toUpperCase());
-
-      if (fs instanceof DistributedFileSystem) {
-        var builder = ((DistributedFileSystem) fs).createFile(new Path(file)).bufferSize(bufferSize)
-            .blockSize(block).overwrite(false);
-
-        if (options.dropCacheBehind) {
-          builder = builder.syncBlock();
-        }
-
-        // create parent directories if they do not exist
-        builder = builder.recursive();
-
-        switch (ecEnable) {
-          case ENABLE:
-            String ecPolicyName =
-                options.getTableConfiguration().get(Property.TABLE_ERASURE_CODE_POLICY);
-            // The default value of this property is empty string. If empty string is given to this
-            // builder it will disable erasure coding. So adding an explicit check for that.
-            Preconditions.checkArgument(!ecPolicyName.isBlank(), "Blank or empty value set for %s",
-                Property.TABLE_ERASURE_CODE_POLICY.getKey());
-            builder = builder.ecPolicyName(ecPolicyName);
-            break;
-          case DISABLE:
-            // force replication
-            builder = builder.replication((short) rep).replicate();
-            break;
-          case INHERIT:
-            // use the directory settings for replication or EC
-            builder = builder.replication((short) rep);
-            break;
-          default:
-            throw new IllegalStateException(ecEnable.name());
-        }
-
-        outputStream = builder.build();
-      } else if (options.dropCacheBehind) {
-        EnumSet<CreateFlag> set = EnumSet.of(CreateFlag.SYNC_BLOCK, CreateFlag.CREATE);
-        outputStream = fs.create(new Path(file), FsPermission.getDefault(), set, bufferSize,
-            (short) rep, block, null);
-      } else {
-        outputStream = fs.create(new Path(file), false, bufferSize, (short) rep, block);
-      }
-
       if (options.dropCacheBehind) {
+        EnumSet<CreateFlag> set = EnumSet.of(CreateFlag.SYNC_BLOCK, CreateFlag.CREATE);
+        outputStream = fs.create(file.getPath(), FsPermission.getDefault(), set, bufferSize,
+            (short) rep, block, null);
         try {
           // Tell the DataNode that the file does not need to be cached in the OS page cache
           outputStream.setDropBehind(Boolean.TRUE);
-          LOG.trace("Called setDropBehind(TRUE) for stream writing file {}", options.filename);
+          LOG.trace("Called setDropBehind(TRUE) for stream writing file {}", options.file);
         } catch (UnsupportedOperationException e) {
-          LOG.debug("setDropBehind not enabled for file: {}", options.filename);
+          LOG.debug("setDropBehind not enabled for file: {}", options.file);
         } catch (IOException e) {
-          LOG.debug("IOException setting drop behind for file: {}, msg: {}", options.filename,
+          LOG.debug("IOException setting drop behind for file: {}, msg: {}", options.file,
               e.getMessage());
         }
+      } else {
+        outputStream = fs.create(file.getPath(), false, bufferSize, (short) rep, block);
       }
     }
 
