@@ -26,11 +26,9 @@ package org.apache.accumulo.core.file.rfile;
  */
 public class VisibilityMetric {
 
-  private final long visLG;
-  private final long visBlock;
-  private final double visLGPer;
-  private final double visBlockPer;
-  private final String visibility;
+  private long visLG, visBlock;
+  private double visLGPer, visBlockPer;
+  private String visibility;
 
   public VisibilityMetric(String visibility, long visLG, double visLGPer, long visBlock,
       double visBlockPer) {
