@@ -60,7 +60,6 @@ public abstract class RowFilter extends WrappingIterator {
   private boolean inclusive;
   private Range range;
   private boolean hasTop;
-  private Map<String,String> options;
 
   private static class RowIterator extends WrappingIterator {
     private Range rowRange;
@@ -149,7 +148,6 @@ public abstract class RowFilter extends WrappingIterator {
       IteratorEnvironment env) throws IOException {
     super.init(source, options, env);
     this.decisionIterator = new RowIterator(source.deepCopy(env));
-    this.options = Map.copyOf(options);
   }
 
   @Override
@@ -157,10 +155,10 @@ public abstract class RowFilter extends WrappingIterator {
     RowFilter newInstance;
     try {
       newInstance = getClass().getDeclaredConstructor().newInstance();
-      newInstance.init(getSource().deepCopy(env), options, env);
-    } catch (Exception e) {
-      throw new RuntimeException(e);
+    } catch (ReflectiveOperationException e) {
+      throw new IllegalStateException(e);
     }
+    newInstance.setSource(getSource().deepCopy(env));
     newInstance.decisionIterator = new RowIterator(getSource().deepCopy(env));
     return newInstance;
   }
