@@ -94,7 +94,7 @@ public abstract class TransformingIterator extends WrappingIterator implements O
   public static final String MAX_BUFFER_SIZE_OPT = "maxBufferSize";
   private static final long DEFAULT_MAX_BUFFER_SIZE = 10000000;
 
-  private final Logger log = LoggerFactory.getLogger(getClass());
+  private Logger log = LoggerFactory.getLogger(getClass());
 
   protected ArrayList<Pair<Key,Value>> keys = new ArrayList<>();
   protected int keyPos = -1;
@@ -108,8 +108,7 @@ public abstract class TransformingIterator extends WrappingIterator implements O
   private LRUMap<ByteSequence,Boolean> parsedVisibilitiesCache = null;
   private long maxBufferSize;
 
-  private static final Comparator<Pair<Key,Value>> keyComparator =
-      Comparator.comparing(Pair::getFirst);
+  private static Comparator<Pair<Key,Value>> keyComparator = Comparator.comparing(Pair::getFirst);
 
   @Override
   public void init(SortedKeyValueIterator<Key,Value> source, Map<String,String> options,
@@ -177,8 +176,8 @@ public abstract class TransformingIterator extends WrappingIterator implements O
 
     try {
       copy = getClass().getDeclaredConstructor().newInstance();
-    } catch (Exception e) {
-      throw new RuntimeException(e);
+    } catch (ReflectiveOperationException e) {
+      throw new IllegalStateException(e);
     }
 
     copy.setSource(getSource().deepCopy(env));
@@ -267,9 +266,9 @@ public abstract class TransformingIterator extends WrappingIterator implements O
 
   private static class RangeIterator implements SortedKeyValueIterator<Key,Value> {
 
-    private final SortedKeyValueIterator<Key,Value> source;
-    private final Key prefixKey;
-    private final PartialKey keyPrefix;
+    private SortedKeyValueIterator<Key,Value> source;
+    private Key prefixKey;
+    private PartialKey keyPrefix;
     private boolean hasTop = false;
 
     RangeIterator(SortedKeyValueIterator<Key,Value> source, Key prefixKey, PartialKey keyPrefix) {
