@@ -174,8 +174,7 @@ public class IteratorConfigUtil {
    */
   public static SortedKeyValueIterator<Key,Value> convertItersAndLoad(IteratorScope scope,
       SortedKeyValueIterator<Key,Value> source, AccumuloConfiguration conf,
-      List<IteratorSetting> iterators, IteratorEnvironment env)
-      throws IOException, ReflectiveOperationException {
+      List<IteratorSetting> iterators, IteratorEnvironment env) throws IOException {
 
     List<IterInfo> ssiList = new ArrayList<>();
     Map<String,Map<String,String>> ssio = new HashMap<>();
@@ -195,13 +194,14 @@ public class IteratorConfigUtil {
    */
   public static SortedKeyValueIterator<Key,Value>
       loadIterators(SortedKeyValueIterator<Key,Value> source, IteratorBuilder iteratorBuilder)
-          throws IOException, ReflectiveOperationException {
+          throws IOException {
     SortedKeyValueIterator<Key,Value> prev = source;
     final boolean useClassLoader = iteratorBuilder.useAccumuloClassLoader;
     Map<String,Class<SortedKeyValueIterator<Key,Value>>> classCache = new HashMap<>();
 
-    for (IterInfo iterInfo : iteratorBuilder.iters) {
-      try {
+    try {
+      for (IterInfo iterInfo : iteratorBuilder.iters) {
+
         Class<SortedKeyValueIterator<Key,Value>> clazz = null;
         log.trace("Attempting to load iterator class {}", iterInfo.className);
         if (iteratorBuilder.useClassCache) {
@@ -225,13 +225,10 @@ public class IteratorConfigUtil {
 
         skvi.init(prev, options, iteratorBuilder.iteratorEnvironment);
         prev = skvi;
-
-      } catch (ReflectiveOperationException e) {
-        log.error("Failed to load iterator {}, for table {}, from context {}", iterInfo.className,
-            iteratorBuilder.iteratorEnvironment.getTableId(), iteratorBuilder.context, e);
-        // This has to be a RuntimeException to be handled properly to fail the scan
-        throw new RuntimeException(e);
       }
+    } catch (ReflectiveOperationException e) {
+      log.error(e.toString());
+      throw new IllegalStateException(e);
     }
     return prev;
   }
