@@ -26,12 +26,10 @@ import java.util.TreeSet;
 import java.util.concurrent.atomic.AtomicBoolean;
 
 import org.apache.accumulo.core.data.ByteSequence;
-import org.apache.accumulo.core.data.Column;
 import org.apache.accumulo.core.data.Key;
 import org.apache.accumulo.core.data.PartialKey;
 import org.apache.accumulo.core.data.Range;
 import org.apache.accumulo.core.data.Value;
-import org.apache.accumulo.core.dataImpl.RangeImpl;
 import org.apache.accumulo.core.iterators.IteratorEnvironment;
 import org.apache.accumulo.core.iterators.ServerSkippingIterator;
 import org.apache.accumulo.core.iterators.SortedKeyValueIterator;
@@ -123,20 +121,13 @@ public class ColumnFamilySkippingIterator extends ServerSkippingIterator
 
     if (inclusive) {
       sortedColFams = new TreeSet<>(colFamSet);
-      if (sortedColFams.isEmpty()) {
-        this.range = range;
-      } else {
-        // Limit the range based on the min and max column families
-        this.range = RangeImpl.bound(range, new Column(sortedColFams.first().toArray(), null, null),
-            new Column(sortedColFams.last().toArray(), null, null), true);
-      }
     } else {
       sortedColFams = null;
-      this.range = range;
     }
 
+    this.range = range;
     this.inclusive = inclusive;
-    super.seek(this.range, colFamSet, inclusive);
+    super.seek(range, colFamSet, inclusive);
   }
 
   @Override
