@@ -32,8 +32,8 @@ import org.apache.accumulo.core.iterators.ServerFilter;
 import org.apache.accumulo.core.iterators.SortedKeyValueIterator;
 
 public class ColumnQualifierFilter extends ServerFilter {
-  private final HashSet<ByteSequence> columnFamilies;
-  private final HashMap<ByteSequence,HashSet<ByteSequence>> columnsQualifiers;
+  private HashSet<ByteSequence> columnFamilies;
+  private HashMap<ByteSequence,HashSet<ByteSequence>> columnsQualifiers;
 
   private ColumnQualifierFilter(SortedKeyValueIterator<Key,Value> iterator, Set<Column> columns) {
     super(iterator);
@@ -41,13 +41,13 @@ public class ColumnQualifierFilter extends ServerFilter {
     this.columnsQualifiers = new HashMap<>();
 
     columns.forEach(col -> {
-      if (col.getColumnQualifier() != null) {
+      if (col.columnQualifier != null) {
         this.columnsQualifiers
-            .computeIfAbsent(new ArrayByteSequence(col.getColumnQualifier()), k -> new HashSet<>())
-            .add(new ArrayByteSequence(col.getColumnFamily()));
+            .computeIfAbsent(new ArrayByteSequence(col.columnQualifier), k -> new HashSet<>())
+            .add(new ArrayByteSequence(col.columnFamily));
       } else {
         // this whole column family should pass
-        columnFamilies.add(new ArrayByteSequence(col.getColumnFamily()));
+        columnFamilies.add(new ArrayByteSequence(col.columnFamily));
       }
     });
   }
