@@ -26,15 +26,14 @@ import java.util.stream.Stream;
 import org.apache.accumulo.core.data.Mutation;
 import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
-import org.apache.accumulo.core.fate.zookeeper.ServiceLock;
-import org.apache.accumulo.core.gc.GcCandidate;
 import org.apache.accumulo.core.gc.ReferenceFile;
+import org.apache.accumulo.core.lock.ServiceLock;
 import org.apache.accumulo.core.metadata.MetadataTable;
+import org.apache.accumulo.core.metadata.ReferencedTabletFile;
 import org.apache.accumulo.core.metadata.RootTable;
 import org.apache.accumulo.core.metadata.ScanServerRefTabletFile;
 import org.apache.accumulo.core.metadata.StoredTabletFile;
 import org.apache.accumulo.core.metadata.TServerInstance;
-import org.apache.accumulo.core.metadata.TabletFile;
 import org.apache.accumulo.core.metadata.schema.TabletMetadata.ColumnType;
 import org.apache.accumulo.core.metadata.schema.TabletMetadata.Location;
 import org.apache.accumulo.core.tabletserver.log.LogEntry;
@@ -98,7 +97,7 @@ public interface Ample {
     /**
      * @return The Id of the Accumulo table in which this data level stores its metadata.
      */
-    public TableId metaTableId() {
+    public TableId tableId() {
       if (id == null) {
         throw new UnsupportedOperationException();
       }
@@ -134,24 +133,6 @@ public interface Ample {
     EVENTUAL
   }
 
-  /**
-   * Enables status based processing of GcCandidates.
-   */
-  public enum GcCandidateType {
-    /**
-     * Candidates which have corresponding file references still present in tablet metadata.
-     */
-    INUSE,
-    /**
-     * Candidates that have no matching file references and can be removed from the system.
-     */
-    VALID,
-    /**
-     * Candidates that are malformed.
-     */
-    INVALID
-  }
-
   /**
    * Read a single tablets metadata. No checking is done for prev row, so it could differ. The
    * method will read the data using {@link ReadConsistency#IMMEDIATE}.
@@ -212,15 +193,16 @@ public interface Ample {
     throw new UnsupportedOperationException();
   }
 
-  /**
-   * Enum added to support unique candidate deletions in 2.1
-   */
-  default void deleteGcCandidates(DataLevel level, Collection<GcCandidate> candidates,
-      GcCandidateType type) {
+  default void deleteGcCandidates(DataLevel level, Collection<String> paths) {
     throw new UnsupportedOperationException();
   }
 
-  default Iterator<GcCandidate> getGcCandidates(DataLevel level) {
+  default Iterator<String> getGcCandidates(DataLevel level) {
+    throw new UnsupportedOperationException();
+  }
+
+  default void
+      putExternalCompactionFinalStates(Collection<ExternalCompactionFinalState> finalStates) {
     throw new UnsupportedOperationException();
   }
 
@@ -236,7 +218,7 @@ public interface Ample {
   /**
    * Return an encoded delete marker Mutation to delete the specified TabletFile path. A
    * ReferenceFile is used for the parameter because the Garbage Collector is optimized to store a
-   * directory for Tablet File. Otherwise, a {@link TabletFile} object could be used. The
+   * directory for Tablet File. Otherwise, a {@link ReferencedTabletFile} object could be used. The
    * tabletFilePathToRemove is validated and normalized before creating the mutation.
    *
    * @param tabletFilePathToRemove String full path of the TabletFile
@@ -263,13 +245,13 @@ public interface Ample {
   interface TabletMutator {
     TabletMutator putPrevEndRow(Text per);
 
-    TabletMutator putFile(TabletFile path, DataFileValue dfv);
+    TabletMutator putFile(ReferencedTabletFile path, DataFileValue dfv);
 
     TabletMutator putFile(StoredTabletFile path, DataFileValue dfv);
 
     TabletMutator deleteFile(StoredTabletFile path);
 
-    TabletMutator putScan(TabletFile path);
+    TabletMutator putScan(StoredTabletFile path);
 
     TabletMutator deleteScan(StoredTabletFile path);
 
@@ -293,9 +275,9 @@ public interface Ample {
 
     TabletMutator putTime(MetadataTime time);
 
-    TabletMutator putBulkFile(TabletFile bulkref, long tid);
+    TabletMutator putBulkFile(ReferencedTabletFile bulkref, long tid);
 
-    TabletMutator deleteBulkFile(TabletFile bulkref);
+    TabletMutator deleteBulkFile(StoredTabletFile bulkref);
 
     TabletMutator putChopped();
 
