@@ -67,14 +67,4 @@ public class ExternalCompactionId extends AbstractId<ExternalCompactionId> {
     return of(ecid);
   }
 
-  private static final int FIRST_UUID_CHAR_OFFSET = PREFIX.length();
-
-  /**
-   * @return first character of the UUID portion of the ExternalCompactionId.
-   */
-  public Character getFirstUUIDChar() {
-    // ExternalCompactionId string has a prefix of "ECID:", so
-    // we want the 6th character (index 5)
-    return canonical().charAt(FIRST_UUID_CHAR_OFFSET);
-  }
 }
