@@ -18,8 +18,8 @@
  */
 package org.apache.accumulo.core.metadata.schema;
 
+import static com.google.common.util.concurrent.Uninterruptibles.sleepUninterruptibly;
 import static java.util.concurrent.TimeUnit.MILLISECONDS;
-import static org.apache.accumulo.core.util.UtilWaitThread.sleepUninterruptibly;
 
 import java.util.Iterator;
 import java.util.function.Function;
@@ -51,8 +51,8 @@ public class LinkingIterator implements Iterator<TabletMetadata> {
 
   private static final Logger log = LoggerFactory.getLogger(LinkingIterator.class);
 
-  private final Range range;
-  private final Function<Range,Iterator<TabletMetadata>> iteratorFactory;
+  private Range range;
+  private Function<Range,Iterator<TabletMetadata>> iteratorFactory;
   private Iterator<TabletMetadata> source;
   private TabletMetadata prevTablet = null;
 
