@@ -34,13 +34,17 @@ import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.EnumSet;
+import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.NoSuchElementException;
 import java.util.Objects;
+import java.util.Optional;
 import java.util.Set;
+import java.util.function.Consumer;
 import java.util.function.Function;
+import java.util.stream.Collectors;
 import java.util.stream.Stream;
 import java.util.stream.StreamSupport;
 
@@ -94,6 +98,8 @@ public class TabletsMetadata implements Iterable<TabletMetadata>, AutoCloseable
     private final List<Text> families = new ArrayList<>();
     private final List<ColumnFQ> qualifiers = new ArrayList<>();
     private Set<KeyExtent> extentsToFetch = null;
+    private boolean fetchTablets = false;
+    private Optional<Consumer<KeyExtent>> notFoundHandler;
     private Ample.DataLevel level;
     private String table;
     private Range range;
@@ -104,7 +110,6 @@ public class TabletsMetadata implements Iterable<TabletMetadata>, AutoCloseable
     private TableId tableId;
     private ReadConsistency readConsistency = ReadConsistency.IMMEDIATE;
     private final AccumuloClient _client;
-    private Collection<KeyExtent> extents = null;
 
     Builder(AccumuloClient client) {
       this._client = client;
@@ -112,7 +117,7 @@ public class TabletsMetadata implements Iterable<TabletMetadata>, AutoCloseable
 
     @Override
     public TabletsMetadata build() {
-      if (extents != null) {
+      if (fetchTablets) {
         // setting multiple extents with forTablets(extents) is mutually exclusive with these
         // single-tablet options
         checkState(range == null && table == null && level == null && !checkConsistency);
@@ -120,7 +125,8 @@ public class TabletsMetadata implements Iterable<TabletMetadata>, AutoCloseable
       }
 
       checkState((level == null) != (table == null),
-          "scanTable() cannot be used in conjunction with forLevel(), forTable() or forTablet()");
+          "scanTable() cannot be used in conjunction with forLevel(), forTable() or forTablet() %s %s",
+          level, table);
       if (level == DataLevel.ROOT) {
         ClientContext ctx = ((ClientContext) _client);
         return new TabletsMetadata(getRootMetadata(ctx, readConsistency));
@@ -132,7 +138,7 @@ public class TabletsMetadata implements Iterable<TabletMetadata>, AutoCloseable
     private TabletsMetadata buildExtents(AccumuloClient client) {
 
       Map<DataLevel,List<KeyExtent>> groupedExtents =
-          extents.stream().collect(groupingBy(ke -> DataLevel.of(ke.tableId())));
+          extentsToFetch.stream().collect(groupingBy(ke -> DataLevel.of(ke.tableId())));
 
       List<Iterable<TabletMetadata>> iterables = new ArrayList<>();
 
@@ -175,19 +181,39 @@ public class TabletsMetadata implements Iterable<TabletMetadata>, AutoCloseable
             closables.add(scanner);
 
           } catch (TableNotFoundException e) {
-            throw new RuntimeException(e);
+            throw new IllegalStateException(e);
           }
 
         }
       }
 
-      return new TabletsMetadata(() -> {
+      if (notFoundHandler.isPresent()) {
+        HashSet<KeyExtent> extentsNotSeen = new HashSet<>(extentsToFetch);
+
+        var tablets = iterables.stream().flatMap(i -> StreamSupport.stream(i.spliterator(), false))
+            .filter(tabletMetadata -> extentsNotSeen.remove(tabletMetadata.getExtent()))
+            .collect(Collectors.toList());
+
+        extentsNotSeen.forEach(notFoundHandler.orElseThrow());
+
         for (AutoCloseable closable : closables) {
-          closable.close();
+          try {
+            closable.close();
+          } catch (Exception e) {
+            throw new RuntimeException(e);
+          }
         }
-      }, () -> iterables.stream().flatMap(i -> StreamSupport.stream(i.spliterator(), false))
-          .filter(tabletMetadata -> extentsToFetch.contains(tabletMetadata.getExtent()))
-          .iterator());
+
+        return new TabletsMetadata(() -> {}, tablets);
+      } else {
+        return new TabletsMetadata(() -> {
+          for (AutoCloseable closable : closables) {
+            closable.close();
+          }
+        }, () -> iterables.stream().flatMap(i -> StreamSupport.stream(i.spliterator(), false))
+            .filter(tabletMetadata -> extentsToFetch.contains(tabletMetadata.getExtent()))
+            .iterator());
+      }
 
     }
 
@@ -239,7 +265,7 @@ public class TabletsMetadata implements Iterable<TabletMetadata>, AutoCloseable
           return new TabletsMetadata(scanner, tmi);
         }
       } catch (TableNotFoundException e) {
-        throw new RuntimeException(e);
+        throw new IllegalStateException(e);
       }
     }
 
@@ -253,7 +279,7 @@ public class TabletsMetadata implements Iterable<TabletMetadata>, AutoCloseable
 
     @Override
     public Options checkConsistency() {
-      checkState(extents == null, "Unable to check consistency of non-contiguous tablets");
+      checkState(!fetchTablets, "Unable to check consistency of non-contiguous tablets");
       this.checkConsistency = true;
       return this;
     }
@@ -319,12 +345,6 @@ public class TabletsMetadata implements Iterable<TabletMetadata>, AutoCloseable
       return this;
     }
 
-    /**
-     * For a given data level, read all of its tablets metadata. For {@link DataLevel#USER} this
-     * will read tablet metadata from the accumulo.metadata table for all user tables. For
-     * {@link DataLevel#METADATA} this will read tablet metadata from the accumulo.root table. For
-     * {@link DataLevel#ROOT} this will read tablet metadata from Zookeeper.
-     */
     @Override
     public Options forLevel(DataLevel level) {
       this.level = level;
@@ -332,13 +352,6 @@ public class TabletsMetadata implements Iterable<TabletMetadata>, AutoCloseable
       return this;
     }
 
-    /**
-     * For a given table read all of its tablet metadata. If the table id is for a user table, then
-     * its metadata will be read from its section in the accumulo.metadata table. If the table id is
-     * for the accumulo.metadata table, then its metadata will be read from the accumulo.root table.
-     * If the table id is for the accumulo.root table, then its metadata will be read from
-     * zookeeper.
-     */
     @Override
     public TableRangeOptions forTable(TableId tableId) {
       this.level = DataLevel.of(tableId);
@@ -356,10 +369,12 @@ public class TabletsMetadata implements Iterable<TabletMetadata>, AutoCloseable
     }
 
     @Override
-    public Options forTablets(Collection<KeyExtent> extents) {
+    public Options forTablets(Collection<KeyExtent> extents,
+        Optional<Consumer<KeyExtent>> notFoundHandler) {
       this.level = null;
-      this.extents = extents;
       this.extentsToFetch = Set.copyOf(extents);
+      this.notFoundHandler = Objects.requireNonNull(notFoundHandler);
+      this.fetchTablets = true;
       return this;
     }
 
@@ -412,6 +427,8 @@ public class TabletsMetadata implements Iterable<TabletMetadata>, AutoCloseable
 
     /**
      * Checks that the metadata table forms a linked list and automatically backs up until it does.
+     * May cause {@link TabletDeletedException} to be thrown while reading tablets metadata in the
+     * case where a table is deleted or merge runs concurrently with scan.
      */
     Options checkConsistency();
 
@@ -449,8 +466,15 @@ public class TabletsMetadata implements Iterable<TabletMetadata>, AutoCloseable
     /**
      * Get the tablet metadata for the given extents. This will only return tablets where the end
      * row and prev end row exactly match the given extents.
+     *
+     * @param notFoundConsumer if a consumer is present, the extents that do not exists in the
+     *        metadata store are passed to the consumer. If the missing extents are not needed, then
+     *        pass Optional.empty() and it will be more efficient. Computing the missing extents
+     *        requires buffering all tablet metadata in memory before returning anything, when
+     *        Optional.empty() is passed this buffering is not done.
      */
-    Options forTablets(Collection<KeyExtent> extents);
+    Options forTablets(Collection<KeyExtent> extents,
+        Optional<Consumer<KeyExtent>> notFoundConsumer);
 
     /**
      * This method automatically determines where the metadata for the passed in table ID resides.
@@ -557,7 +581,7 @@ public class TabletsMetadata implements Iterable<TabletMetadata>, AutoCloseable
           byte[] bytes = zooReader.getData(path);
           return new RootTabletMetadata(new String(bytes, UTF_8)).toTabletMetadata();
         } catch (InterruptedException | KeeperException e) {
-          throw new RuntimeException(e);
+          throw new IllegalStateException(e);
         }
       default:
         throw new IllegalArgumentException("Unknown consistency level " + readConsistency);
@@ -578,8 +602,7 @@ public class TabletsMetadata implements Iterable<TabletMetadata>, AutoCloseable
     this.tablets = Collections.singleton(tm);
   }
 
-  // visible for testing
-  public TabletsMetadata(AutoCloseable closeable, Iterable<TabletMetadata> tmi) {
+  private TabletsMetadata(AutoCloseable closeable, Iterable<TabletMetadata> tmi) {
     this.closeable = closeable;
     this.tablets = tmi;
   }
@@ -593,7 +616,7 @@ public class TabletsMetadata implements Iterable<TabletMetadata>, AutoCloseable
         // avoid wrapping runtime w/ runtime
         throw e;
       } catch (Exception e) {
-        throw new RuntimeException(e);
+        throw new IllegalStateException(e);
       }
     }
   }
@@ -604,6 +627,6 @@ public class TabletsMetadata implements Iterable<TabletMetadata>, AutoCloseable
   }
 
   public Stream<TabletMetadata> stream() {
-    return StreamSupport.stream(tablets.spliterator(), false).onClose(this::close);
+    return StreamSupport.stream(tablets.spliterator(), false);
   }
 }
