@@ -18,18 +18,26 @@
  */
 package org.apache.accumulo.core.rpc;
 
+import static org.apache.accumulo.core.util.LazySingletons.RANDOM;
+
+import java.io.FileInputStream;
 import java.io.IOException;
 import java.io.UncheckedIOException;
 import java.net.InetAddress;
 import java.nio.channels.ClosedByInterruptException;
-import java.security.SecureRandom;
+import java.security.KeyStore;
 import java.util.HashMap;
 import java.util.Map;
 
+import javax.net.ssl.KeyManagerFactory;
+import javax.net.ssl.SSLContext;
+import javax.net.ssl.SSLSocket;
+import javax.net.ssl.SSLSocketFactory;
+import javax.net.ssl.TrustManagerFactory;
+
 import org.apache.accumulo.core.clientImpl.ClientContext;
 import org.apache.accumulo.core.rpc.SaslConnectionParams.SaslMechanism;
 import org.apache.accumulo.core.rpc.clients.ThriftClientTypes;
-import org.apache.accumulo.core.util.HostAndPort;
 import org.apache.hadoop.security.UserGroupInformation;
 import org.apache.hadoop.security.UserGroupInformation.AuthenticationMethod;
 import org.apache.thrift.TException;
@@ -41,9 +49,14 @@ import org.apache.thrift.transport.TSocket;
 import org.apache.thrift.transport.TTransport;
 import org.apache.thrift.transport.TTransportException;
 import org.apache.thrift.transport.TTransportFactory;
+import org.apache.thrift.transport.layered.TFramedTransport;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import com.google.common.net.HostAndPort;
+
+import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
+
 /**
  * Factory methods for creating Thrift client objects
  */
@@ -52,13 +65,12 @@ public class ThriftUtil {
   private static final Logger log = LoggerFactory.getLogger(ThriftUtil.class);
 
   private static final TraceProtocolFactory protocolFactory = new TraceProtocolFactory();
-  private static final AccumuloTFramedTransportFactory transportFactory =
-      new AccumuloTFramedTransportFactory(Integer.MAX_VALUE);
+  private static final TFramedTransport.Factory transportFactory =
+      new TFramedTransport.Factory(Integer.MAX_VALUE);
   private static final Map<Integer,TTransportFactory> factoryCache = new HashMap<>();
 
   public static final String GSSAPI = "GSSAPI", DIGEST_MD5 = "DIGEST-MD5";
 
-  private static final SecureRandom random = new SecureRandom();
   private static final int RELOGIN_MAX_BACKOFF = 5000;
 
   /**
@@ -110,8 +122,8 @@ public class ThriftUtil {
    */
   public static <T extends TServiceClient> T getClient(ThriftClientTypes<T> type,
       HostAndPort address, ClientContext context) throws TTransportException {
-    TTransport transport = context.getTransportPool().getTransport(type, address,
-        context.getClientTimeoutInMillis(), context, true);
+    TTransport transport = context.getTransportPool().getTransport(address,
+        context.getClientTimeoutInMillis(), context);
     return createClient(type, transport);
   }
 
@@ -126,8 +138,7 @@ public class ThriftUtil {
    */
   public static <T extends TServiceClient> T getClient(ThriftClientTypes<T> type,
       HostAndPort address, ClientContext context, long timeout) throws TTransportException {
-    TTransport transport =
-        context.getTransportPool().getTransport(type, address, timeout, context, true);
+    TTransport transport = context.getTransportPool().getTransport(address, timeout, context);
     return createClient(type, transport);
   }
 
@@ -176,7 +187,7 @@ public class ThriftUtil {
     int maxFrameSize1 = (int) maxFrameSize;
     TTransportFactory factory = factoryCache.get(maxFrameSize1);
     if (factory == null) {
-      factory = new AccumuloTFramedTransportFactory(maxFrameSize1);
+      factory = new TFramedTransport.Factory(maxFrameSize1);
       factoryCache.put(maxFrameSize1, factory);
     }
     return factory;
@@ -211,10 +222,26 @@ public class ThriftUtil {
           transport =
               TSSLTransportFactory.getClientSocket(address.getHost(), address.getPort(), timeout);
         } else {
-          transport = TSSLTransportFactory.getClientSocket(address.getHost(), address.getPort(),
-              timeout, sslParams.getTSSLTransportParameters());
+          // JDK6's factory doesn't appear to pass the protocol onto the Socket properly so we have
+          // to do some magic to make sure that happens. Not an issue in JDK7
+
+          // Taken from thrift-0.9.1 to make the SSLContext
+          SSLContext sslContext = createSSLContext(sslParams);
+
+          // Create the factory from it
+          SSLSocketFactory sslSockFactory = sslContext.getSocketFactory();
+
+          // Wrap the real factory with our own that will set the protocol on the Socket before
+          // returning it
+          ProtocolOverridingSSLSocketFactory wrappingSslSockFactory =
+              new ProtocolOverridingSSLSocketFactory(sslSockFactory,
+                  new String[] {sslParams.getClientProtocol()});
+
+          // Create the TSocket from that
+          transport =
+              createClient(wrappingSslSockFactory, address.getHost(), address.getPort(), timeout);
+          // TSSLTransportFactory leaves transports open, so no need to open here
         }
-        // TSSLTransportFactory leaves transports open, so no need to open here
 
         transport = ThriftUtil.transportFactory().getTransport(transport);
       } else if (saslParams != null) {
@@ -313,12 +340,12 @@ public class ThriftUtil {
         transport = ThriftUtil.transportFactory().getTransport(transport);
       }
       success = true;
-      return transport;
     } finally {
       if (!success && transport != null) {
         transport.close();
       }
     }
+    return transport;
   }
 
   /**
@@ -339,7 +366,7 @@ public class ThriftUtil {
       if (loginUser == null || !loginUser.hasKerberosCredentials()) {
         // We should have already checked that we're logged in and have credentials. A
         // precondition-like check.
-        throw new RuntimeException("Expected to find Kerberos UGI credentials, but did not");
+        throw new IllegalStateException("Expected to find Kerberos UGI credentials, but did not");
       }
       UserGroupInformation currentUser = UserGroupInformation.getCurrentUser();
       // A Proxy user is the "effective user" (in name only), riding on top of the "real user"'s Krb
@@ -358,7 +385,7 @@ public class ThriftUtil {
 
         // Avoid the replay attack protection, sleep 1 to 5000ms
         try {
-          Thread.sleep(random.nextInt(RELOGIN_MAX_BACKOFF) + 1);
+          Thread.sleep(RANDOM.get().nextInt(RELOGIN_MAX_BACKOFF) + 1);
         } catch (InterruptedException e) {
           Thread.currentThread().interrupt();
           return;
@@ -371,7 +398,81 @@ public class ThriftUtil {
       // The inability to check is worrisome and deserves a RuntimeException instead of a propagated
       // IO-like Exception.
       log.warn("Failed to check (and/or perform) Kerberos client re-login", e);
-      throw new RuntimeException(e);
+      throw new UncheckedIOException(e);
+    }
+  }
+
+  /**
+   * Lifted from TSSLTransportFactory in Thrift-0.9.1. The method to create a client socket with an
+   * SSLContextFactory object is not visible to us. Have to use SslConnectionParams instead of
+   * TSSLTransportParameters because no getters exist on TSSLTransportParameters.
+   *
+   * @param params Parameters to use to create the SSLContext
+   */
+  @SuppressFBWarnings(value = "PATH_TRAVERSAL_IN",
+      justification = "code runs in same security context as user who providing the keystore files")
+  private static SSLContext createSSLContext(SslConnectionParams params)
+      throws TTransportException {
+    try {
+      SSLContext ctx = SSLContext.getInstance(params.getClientProtocol());
+      TrustManagerFactory tmf = null;
+      KeyManagerFactory kmf = null;
+
+      if (params.isTrustStoreSet()) {
+        tmf = TrustManagerFactory.getInstance(TrustManagerFactory.getDefaultAlgorithm());
+        KeyStore ts = KeyStore.getInstance(params.getTrustStoreType());
+        try (FileInputStream fis = new FileInputStream(params.getTrustStorePath())) {
+          ts.load(fis, params.getTrustStorePass().toCharArray());
+        }
+        tmf.init(ts);
+      }
+
+      if (params.isKeyStoreSet()) {
+        kmf = KeyManagerFactory.getInstance(KeyManagerFactory.getDefaultAlgorithm());
+        KeyStore ks = KeyStore.getInstance(params.getKeyStoreType());
+        try (FileInputStream fis = new FileInputStream(params.getKeyStorePath())) {
+          ks.load(fis, params.getKeyStorePass().toCharArray());
+        }
+        kmf.init(ks, params.getKeyStorePass().toCharArray());
+      }
+
+      if (params.isKeyStoreSet() && params.isTrustStoreSet()) {
+        ctx.init(kmf.getKeyManagers(), tmf.getTrustManagers(), null);
+      } else if (params.isKeyStoreSet()) {
+        ctx.init(kmf.getKeyManagers(), null, null);
+      } else {
+        ctx.init(null, tmf.getTrustManagers(), null);
+      }
+      return ctx;
+    } catch (Exception e) {
+      throw new TTransportException("Error creating the transport", e);
+    }
+  }
+
+  /**
+   * Lifted from Thrift-0.9.1 because it was private. Create an SSLSocket with the given factory,
+   * host:port, and timeout.
+   *
+   * @param factory Factory to create the socket from
+   * @param host Destination host
+   * @param port Destination port
+   * @param timeout Socket timeout
+   */
+  private static TSocket createClient(SSLSocketFactory factory, String host, int port, int timeout)
+      throws TTransportException {
+    SSLSocket socket = null;
+    try {
+      socket = (SSLSocket) factory.createSocket(host, port);
+      socket.setSoTimeout(timeout);
+      return new TSocket(socket);
+    } catch (Exception e) {
+      try {
+        if (socket != null) {
+          socket.close();
+        }
+      } catch (IOException ioe) {}
+
+      throw new TTransportException("Could not connect to " + host + " on port " + port, e);
     }
   }
 
