@@ -18,8 +18,12 @@
  */
 package org.apache.accumulo.core.rpc.clients;
 
-import org.apache.accumulo.core.tabletserver.thrift.TabletScanClientService.Client;
+import org.apache.accumulo.core.tabletscan.thrift.TabletScanClientService.Client;
 
+/**
+ * Client side object that can be used to interact with services that support scan operations
+ * against tablets. See TabletScanClientService$Iface for a list of supported operations.
+ */
 public class TabletScanClientServiceThriftClient extends ThriftClientTypes<Client> {
 
   TabletScanClientServiceThriftClient(String serviceName) {
