@@ -27,7 +27,7 @@ import java.text.ParseException;
  */
 public class VisibilityParseException extends ParseException {
   private static final long serialVersionUID = 1L;
-  private final String visibility;
+  private String visibility;
 
   /**
    * Creates a new exception.
