@@ -25,7 +25,6 @@ import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
-import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
@@ -69,8 +68,7 @@ public abstract class GroupBalancer implements TabletBalancer {
 
   protected BalancerEnvironment environment;
   private final TableId tableId;
-
-  protected final Map<String,Long> lastRunTimes = new HashMap<>();
+  private long lastRun = 0;
 
   @Override
   public void init(BalancerEnvironment balancerEnvironment) {
@@ -213,8 +211,7 @@ public abstract class GroupBalancer implements TabletBalancer {
       return 5000;
     }
 
-    if (System.currentTimeMillis() - lastRunTimes.getOrDefault(params.partitionName(), 0L)
-        < getWaitTime()) {
+    if (System.currentTimeMillis() - lastRun < getWaitTime()) {
       return 5000;
     }
 
@@ -278,7 +275,7 @@ public abstract class GroupBalancer implements TabletBalancer {
 
     populateMigrations(tservers.keySet(), params.migrationsOut(), moves);
 
-    lastRunTimes.put(params.partitionName(), System.currentTimeMillis());
+    lastRun = System.currentTimeMillis();
 
     return 5000;
   }
@@ -488,7 +485,7 @@ public abstract class GroupBalancer implements TabletBalancer {
     }
 
     ArrayList<Pair<String,TabletServerId>> serversGroupsToRemove = new ArrayList<>();
-    HashSet<TabletServerId> serversToRemove = new HashSet<>();
+    ArrayList<TabletServerId> serversToRemove = new ArrayList<>();
 
     for (TserverGroupInfo destTgi : tservers.values()) {
       if (surplusExtra.isEmpty()) {
@@ -612,7 +609,7 @@ public abstract class GroupBalancer implements TabletBalancer {
       }
     }
 
-    HashSet<TabletServerId> emptyServers = new HashSet<>();
+    ArrayList<TabletServerId> emptyServers = new ArrayList<>();
     ArrayList<Pair<String,TabletServerId>> emptyServerGroups = new ArrayList<>();
     for (TserverGroupInfo destTgi : tservers.values()) {
       if (extraSurplus.isEmpty()) {
