@@ -19,11 +19,10 @@
 package org.apache.accumulo.core.spi.balancer;
 
 import static java.util.concurrent.TimeUnit.HOURS;
+import static org.apache.accumulo.core.util.LazySingletons.RANDOM;
 
 import java.net.InetAddress;
 import java.net.UnknownHostException;
-import java.security.SecureRandom;
-import java.time.Duration;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
@@ -35,7 +34,6 @@ import java.util.Map.Entry;
 import java.util.Set;
 import java.util.SortedMap;
 import java.util.TreeMap;
-import java.util.concurrent.TimeUnit;
 import java.util.function.Supplier;
 import java.util.regex.Pattern;
 import java.util.stream.Collectors;
@@ -47,7 +45,6 @@ import org.apache.accumulo.core.conf.ConfigurationTypeHelper;
 import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.data.TabletId;
-import org.apache.accumulo.core.logging.ConditionalLogger.EscalatingLogger;
 import org.apache.accumulo.core.manager.balancer.AssignmentParamsImpl;
 import org.apache.accumulo.core.manager.balancer.BalanceParamsImpl;
 import org.apache.accumulo.core.manager.balancer.TServerStatusImpl;
@@ -57,16 +54,13 @@ import org.apache.accumulo.core.spi.balancer.data.TableStatistics;
 import org.apache.accumulo.core.spi.balancer.data.TabletMigration;
 import org.apache.accumulo.core.spi.balancer.data.TabletServerId;
 import org.apache.accumulo.core.spi.balancer.data.TabletStatistics;
-import org.apache.accumulo.core.util.Timer;
 import org.apache.commons.lang3.builder.ToStringBuilder;
 import org.apache.commons.lang3.builder.ToStringStyle;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
-import org.slf4j.event.Level;
 
-import com.google.common.cache.CacheBuilder;
-import com.google.common.cache.CacheLoader;
-import com.google.common.cache.LoadingCache;
+import com.github.benmanes.caffeine.cache.Caffeine;
+import com.github.benmanes.caffeine.cache.LoadingCache;
 import com.google.common.collect.HashMultimap;
 import com.google.common.collect.Multimap;
 
@@ -98,12 +92,9 @@ import com.google.common.collect.Multimap;
  */
 public class HostRegexTableLoadBalancer extends TableLoadBalancer {
 
-  private static final SecureRandom random = new SecureRandom();
   private static final String PROP_PREFIX = Property.TABLE_ARBITRARY_PROP_PREFIX.getKey();
 
   private static final Logger LOG = LoggerFactory.getLogger(HostRegexTableLoadBalancer.class);
-  private static final Logger MIGRATIONS_LOGGER =
-      new EscalatingLogger(LOG, Duration.ofMinutes(5), 1000, Level.WARN);
   public static final String HOST_BALANCER_PREFIX = PROP_PREFIX + "balancer.host.regex.";
   public static final String HOST_BALANCER_OOB_CHECK_KEY =
       PROP_PREFIX + "balancer.host.regex.oob.period";
@@ -155,7 +146,7 @@ public class HostRegexTableLoadBalancer extends TableLoadBalancer {
     private final Map<String,Pattern> poolNameToRegexPattern;
 
     HrtlbConf(PluginEnvironment.Configuration conf) {
-      LOG.info("Building conf");
+      System.out.println("building hrtlb conf");
       String oobProperty = conf.get(HOST_BALANCER_OOB_CHECK_KEY);
       if (oobProperty != null) {
         oobCheckMillis = ConfigurationTypeHelper.getTimeInMillis(oobProperty);
@@ -183,7 +174,7 @@ public class HostRegexTableLoadBalancer extends TableLoadBalancer {
   }
 
   private static final Set<TabletId> EMPTY_MIGRATIONS = Collections.emptySet();
-  protected final Map<String,Long> lastOOBCheckTimes = new HashMap<>();
+  private volatile long lastOOBCheck = System.currentTimeMillis();
   private Map<String,SortedMap<TabletServerId,TServerStatus>> pools = new HashMap<>();
   private final Map<TabletId,TabletMigration> migrationsFromLastPass = new HashMap<>();
   private final Map<TableId,Long> tableToTimeSinceNoMigrations = new HashMap<>();
@@ -269,7 +260,7 @@ public class HostRegexTableLoadBalancer extends TableLoadBalancer {
   }
 
   private void checkTableConfig(TableId tableId) {
-    Map<String,String> tableRegexes = tablesRegExCache.getUnchecked(tableId).get();
+    Map<String,String> tableRegexes = tablesRegExCache.get(tableId).get();
 
     if (!hrtlbConf.get().regexes.equals(tableRegexes)) {
       LoggerFactory.getLogger(HostRegexTableLoadBalancer.class).warn(
@@ -329,13 +320,8 @@ public class HostRegexTableLoadBalancer extends TableLoadBalancer {
     this.hrtlbConf = balancerEnvironment.getConfiguration().getDerived(HrtlbConf::new);
 
     tablesRegExCache =
-        CacheBuilder.newBuilder().expireAfterAccess(1, HOURS).build(new CacheLoader<>() {
-          @Override
-          public Supplier<Map<String,String>> load(TableId key) {
-            return balancerEnvironment.getConfiguration(key)
-                .getDerived(HostRegexTableLoadBalancer::getRegexes);
-          }
-        });
+        Caffeine.newBuilder().expireAfterAccess(1, HOURS).build(key -> balancerEnvironment
+            .getConfiguration(key).getDerived(HostRegexTableLoadBalancer::getRegexes));
 
     LOG.info("{}", this);
   }
@@ -354,7 +340,6 @@ public class HostRegexTableLoadBalancer extends TableLoadBalancer {
         .collect(Collectors.toMap(Map.Entry::getValue, Map.Entry::getKey));
 
     // Send a view of the current servers to the tables tablet balancer
-    Timer assignmentTimer = Timer.startNew();
     for (Entry<TableId,Map<TabletId,TabletServerId>> e : groupedUnassigned.entrySet()) {
       Map<TabletId,TabletServerId> newAssignments = new HashMap<>();
       String tableName = tableIdToTableName.get(e.getKey());
@@ -370,14 +355,10 @@ public class HostRegexTableLoadBalancer extends TableLoadBalancer {
           continue;
         }
       }
-      LOG.debug("Sending {} tablets to balancer for table {} for assignment within {} tservers",
-          e.getValue().size(), tableName, currentView.keySet().size());
-      LOG.trace("table {} tserver assignment set {}", tableName, currentView.keySet());
-      assignmentTimer.restart();
+      LOG.debug("Sending {} tablets to balancer for table {} for assignment within tservers {}",
+          e.getValue().size(), tableName, currentView.keySet());
       getBalancerForTable(e.getKey())
           .getAssignments(new AssignmentParamsImpl(currentView, e.getValue(), newAssignments));
-      LOG.debug("assignment results table:{} assignments:{} time:{}ms", tableName,
-          newAssignments.size(), assignmentTimer.elapsed(TimeUnit.MILLISECONDS));
       newAssignments.forEach(params::addAssignment);
     }
   }
@@ -386,7 +367,7 @@ public class HostRegexTableLoadBalancer extends TableLoadBalancer {
   public long balance(BalanceParameters params) {
     long minBalanceTime = 20_000;
     // Iterate over the tables and balance each of them
-    Map<String,TableId> tableIdMap = params.getTablesToBalance();
+    Map<String,TableId> tableIdMap = environment.getTableIdMap();
     Map<TableId,String> tableIdToTableName = tableIdMap.entrySet().stream()
         .collect(Collectors.toMap(Map.Entry::getValue, Map.Entry::getKey));
     tableIdToTableName.keySet().forEach(this::checkTableConfig);
@@ -401,9 +382,7 @@ public class HostRegexTableLoadBalancer extends TableLoadBalancer {
 
     Map<String,SortedMap<TabletServerId,TServerStatus>> currentGrouped =
         splitCurrentByRegex(params.currentStatus());
-
-    if ((now - this.lastOOBCheckTimes.computeIfAbsent(params.partitionName(),
-        (p) -> System.currentTimeMillis())) > myConf.oobCheckMillis) {
+    if ((now - this.lastOOBCheck) > myConf.oobCheckMillis) {
       try {
         // Check to see if a tablet is assigned outside the bounds of the pool. If so, migrate it.
         for (String table : tableIdMap.keySet()) {
@@ -436,7 +415,7 @@ public class HostRegexTableLoadBalancer extends TableLoadBalancer {
                 String poolName = getPoolNameForTable(table);
                 SortedMap<TabletServerId,TServerStatus> currentView = currentGrouped.get(poolName);
                 if (currentView != null) {
-                  int skip = random.nextInt(currentView.size());
+                  int skip = RANDOM.get().nextInt(currentView.size());
                   Iterator<TabletServerId> iter = currentView.keySet().iterator();
                   for (int i = 0; i < skip; i++) {
                     iter.next();
@@ -463,7 +442,7 @@ public class HostRegexTableLoadBalancer extends TableLoadBalancer {
         }
       } finally {
         // this could have taken a while...get a new time
-        this.lastOOBCheckTimes.put(params.partitionName(), System.currentTimeMillis());
+        this.lastOOBCheck = System.currentTimeMillis();
       }
     }
 
@@ -507,7 +486,6 @@ public class HostRegexTableLoadBalancer extends TableLoadBalancer {
       migrationsFromLastPass.clear();
     }
 
-    Timer balanceTimer = Timer.startNew();
     for (TableId tableId : tableIdMap.values()) {
       String tableName = tableIdToTableName.get(tableId);
       String regexTableName = getPoolNameForTable(tableName);
@@ -517,13 +495,8 @@ public class HostRegexTableLoadBalancer extends TableLoadBalancer {
         continue;
       }
       ArrayList<TabletMigration> newMigrations = new ArrayList<>();
-      balanceTimer.restart();
-      TabletBalancer tableBalancer = getBalancerForTable(tableId);
-      tableBalancer.balance(new BalanceParamsImpl(currentView, migrations, newMigrations,
-          params.partitionName() + ":" + tableId, Map.of(tableName, tableId)));
-      LOG.debug("balance results class:{} tableId:{} migrations:{} time:{}ms",
-          tableBalancer.getClass().getSimpleName(), tableId, newMigrations.size(),
-          balanceTimer.elapsed(TimeUnit.MILLISECONDS));
+      getBalancerForTable(tableId)
+          .balance(new BalanceParamsImpl(currentView, migrations, newMigrations));
 
       if (newMigrations.isEmpty()) {
         tableToTimeSinceNoMigrations.remove(tableId);
@@ -538,8 +511,6 @@ public class HostRegexTableLoadBalancer extends TableLoadBalancer {
 
       migrationsOut.addAll(newMigrations);
       if (migrationsOut.size() >= myConf.maxTServerMigrations) {
-        MIGRATIONS_LOGGER.debug("Table {} migration size : {} is over tserver migration max: {}",
-            tableName, migrationsOut.size(), myConf.maxTServerMigrations);
         break;
       }
     }
@@ -548,8 +519,7 @@ public class HostRegexTableLoadBalancer extends TableLoadBalancer {
       migrationsFromLastPass.put(migration.getTablet(), migration);
     }
 
-    LOG.info("Migrating {} tablets for balance.", migrationsOut.size());
-    LOG.trace("Tablets currently migrating: {}", migrationsOut);
+    LOG.info("Migrating tablets for balance: {}", migrationsOut);
     return minBalanceTime;
   }
 
