@@ -66,17 +66,6 @@ public class TableLoadBalancer implements TabletBalancer {
     return null;
   }
 
-  private TabletBalancer constructAndInitializeBalancer(String clazzName, TableId tableId) {
-    try {
-      var balancer = constructNewBalancerForTable(clazzName, tableId);
-      balancer.init(environment);
-      return balancer;
-    } catch (Exception e) {
-      log.warn("Failed to load table balancer class {} for table {}", clazzName, tableId, e);
-      return null;
-    }
-  }
-
   protected TabletBalancer getBalancerForTable(TableId tableId) {
     TabletBalancer balancer = perTableBalancers.get(tableId);
 
@@ -85,16 +74,34 @@ public class TableLoadBalancer implements TabletBalancer {
     if (clazzName == null) {
       clazzName = SimpleLoadBalancer.class.getName();
     }
+    if (balancer != null) {
+      if (!clazzName.equals(balancer.getClass().getName())) {
+        // the balancer class for this table does not match the class specified in the configuration
+        try {
+          balancer = constructNewBalancerForTable(clazzName, tableId);
+          perTableBalancers.put(tableId, balancer);
+          balancer.init(environment);
 
-    if (balancer == null || !clazzName.equals(balancer.getClass().getName())) {
-      balancer = constructAndInitializeBalancer(clazzName, tableId);
+          log.info("Loaded new class {} for table {}", clazzName, tableId);
+        } catch (Exception e) {
+          log.warn("Failed to load table balancer class {} for table {}", clazzName, tableId, e);
+        }
+      }
+    }
+    if (balancer == null) {
+      try {
+        balancer = constructNewBalancerForTable(clazzName, tableId);
+        log.info("Loaded class {} for table {}", clazzName, tableId);
+      } catch (Exception e) {
+        log.warn("Failed to load table balancer class {} for table {}", clazzName, tableId, e);
+      }
+
       if (balancer == null) {
-        balancer = constructAndInitializeBalancer(DoNothingBalancer.class.getName(), tableId);
-        log.error("Fell back to balancer {} for table {}", DoNothingBalancer.class.getName(),
-            tableId);
+        log.info("Using balancer {} for table {}", SimpleLoadBalancer.class.getName(), tableId);
+        balancer = new SimpleLoadBalancer(tableId);
       }
-      log.info("Loaded class {} for table {}", balancer.getClass().getName(), tableId);
       perTableBalancers.put(tableId, balancer);
+      balancer.init(environment);
     }
     return balancer;
   }
@@ -116,13 +123,11 @@ public class TableLoadBalancer implements TabletBalancer {
   @Override
   public long balance(BalanceParameters params) {
     long minBalanceTime = 5_000;
-    for (Entry<String,TableId> entry : params.getTablesToBalance().entrySet()) {
-      String tableName = entry.getKey();
-      TableId tableId = entry.getValue();
+    // Iterate over the tables and balance each of them
+    for (TableId tableId : environment.getTableIdMap().values()) {
       ArrayList<TabletMigration> newMigrations = new ArrayList<>();
-      long tableBalanceTime = getBalancerForTable(tableId)
-          .balance(new BalanceParamsImpl(params.currentStatus(), params.currentMigrations(),
-              newMigrations, params.partitionName() + ":" + tableId, Map.of(tableName, tableId)));
+      long tableBalanceTime = getBalancerForTable(tableId).balance(
+          new BalanceParamsImpl(params.currentStatus(), params.currentMigrations(), newMigrations));
       if (tableBalanceTime < minBalanceTime) {
         minBalanceTime = tableBalanceTime;
       }
