@@ -20,11 +20,6 @@ package org.apache.accumulo.core.spi.cache;
 
 import java.util.HashMap;
 import java.util.Map;
-import java.util.function.Supplier;
-
-import org.apache.accumulo.core.conf.Property;
-import org.apache.accumulo.core.file.blockfile.cache.impl.BlockCacheConfiguration;
-import org.apache.accumulo.core.file.blockfile.cache.impl.NoopCache;
 
 /**
  * @since 2.0.0
@@ -113,13 +108,9 @@ public abstract class BlockCacheManager {
    * @param conf accumulo configuration
    */
   public void start(Configuration conf) {
-    Supplier<NoopCache> noop = () -> new NoopCache();
     for (CacheType type : CacheType.values()) {
-      if (conf.getMaxSize(type) > 0) {
-        this.caches.put(type, createCache(conf, type));
-      } else {
-        this.caches.put(type, noop.get());
-      }
+      BlockCache cache = this.createCache(conf, type);
+      this.caches.put(type, cache);
     }
   }
 
@@ -148,38 +139,4 @@ public abstract class BlockCacheManager {
    */
   protected abstract BlockCache createCache(Configuration conf, CacheType type);
 
-  /**
-   * A convenience method that returns a string of the from
-   * {@code tserver.cache.config.<prefix>.default.} this method is useful for configuring a cache
-   * manager.
-   *
-   * @param prefix A unique identifier that corresponds to a particular BlockCacheManager
-   *        implementation.
-   * @see Configuration#getProperties(String, CacheType)
-   * @deprecated since 2.1.0 because this method does not support scan servers, only tservers. Use
-   *             {@link Configuration#getProperties(String, CacheType)} instead.
-   */
-  @Deprecated(since = "2.1.0")
-  public static String getFullyQualifiedPropertyPrefix(String prefix) {
-    return BlockCacheConfiguration.getFullyQualifiedPropertyPrefix(Property.TSERV_PREFIX, prefix);
-  }
-
-  /**
-   * A convenience method that returns a string of the from
-   * {@code tserver.cache.config.<prefix>.<type>.} this method is useful for configuring a cache
-   * manager.
-   *
-   * @param prefix A unique identifier that corresponds to a particular BlockCacheManager
-   *        implementation.
-   * @see Configuration#getProperties(String, CacheType)
-   *
-   * @deprecated since 2.1.0 because this method does not support scan servers, only tservers. Use
-   *             {@link Configuration#getProperties(String, CacheType)} instead.
-   */
-  @Deprecated(since = "2.1.0")
-  public static String getFullyQualifiedPropertyPrefix(String prefix, CacheType type) {
-    return BlockCacheConfiguration.getFullyQualifiedPropertyPrefix(Property.TSERV_PREFIX, prefix,
-        type);
-  }
-
 }
