@@ -47,26 +47,6 @@ package org.apache.accumulo.core.spi.common;
  */
 public interface ContextClassLoaderFactory {
 
-  class ContextClassLoaderException extends Exception {
-
-    private static final long serialVersionUID = 1L;
-    private static final String msg = "Error getting classloader for context: ";
-
-    public ContextClassLoaderException(String context, Throwable cause, boolean enableSuppression,
-        boolean writableStackTrace) {
-      super(msg + context, cause, enableSuppression, writableStackTrace);
-    }
-
-    public ContextClassLoaderException(String context, Throwable cause) {
-      super(msg + context, cause);
-    }
-
-    public ContextClassLoaderException(String context) {
-      super(msg + context);
-    }
-
-  }
-
   /**
    * Pass the service environment to allow for additional class loader configuration
    *
@@ -75,16 +55,17 @@ public interface ContextClassLoaderFactory {
   default void init(ContextClassLoaderEnvironment env) {}
 
   /**
-   * Get the class loader for the given contextName. Callers should not cache the ClassLoader result
-   * as it may change if/when the ClassLoader reloads. Implementations should throw a
-   * ContextClassLoaderException if the provided contextName is not supported or fails to be
-   * constructed.
+   * Get the class loader for the given context. Callers should not cache the ClassLoader result as
+   * it may change if/when the ClassLoader reloads. Implementations should throw a RuntimeException
+   * of some type (such as IllegalArgumentException) if the provided context is not supported or
+   * fails to be constructed.
    *
-   * @param contextName the name of the context that represents a class loader that is managed by
-   *        this factory. Currently, Accumulo will only call this method for non-null and non-empty
+   * @param context the name of the context that represents a class loader that is managed by this
+   *        factory. Currently, Accumulo will only call this method for non-null and non-empty
    *        context. For empty or null context, Accumulo will use the system classloader without
    *        consulting this plugin.
-   * @return the class loader for the given contextName
+   * @return the class loader for the given context
    */
-  ClassLoader getClassLoader(String contextName) throws ContextClassLoaderException;
+  ClassLoader getClassLoader(String context);
+
 }
