@@ -31,16 +31,13 @@ import java.util.function.Predicate;
 
 import org.apache.accumulo.core.client.rfile.RFileSource;
 import org.apache.accumulo.core.client.summary.SummarizerConfiguration;
-import org.apache.accumulo.core.file.NoSuchMetaStoreException;
 import org.apache.accumulo.core.file.blockfile.impl.BasicCacheProvider;
 import org.apache.accumulo.core.file.blockfile.impl.CachableBlockFile;
 import org.apache.accumulo.core.file.blockfile.impl.CachableBlockFile.CachableBuilder;
 import org.apache.accumulo.core.file.rfile.RFile.Reader;
 import org.apache.accumulo.core.file.rfile.bcfile.MetaBlockDoesNotExist;
-import org.apache.accumulo.core.logging.LoggingBlockCache;
 import org.apache.accumulo.core.spi.cache.BlockCache;
 import org.apache.accumulo.core.spi.cache.CacheEntry;
-import org.apache.accumulo.core.spi.cache.CacheType;
 import org.apache.accumulo.core.spi.crypto.CryptoService;
 import org.apache.accumulo.core.summary.Gatherer.RowRange;
 import org.apache.hadoop.conf.Configuration;
@@ -48,7 +45,7 @@ import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.io.WritableUtils;
 
-import com.google.common.cache.Cache;
+import com.github.benmanes.caffeine.cache.Cache;
 
 public class SummaryReader {
 
@@ -58,8 +55,8 @@ public class SummaryReader {
 
   private static class CompositeCache implements BlockCache {
 
-    private final BlockCache summaryCache;
-    private final BlockCache indexCache;
+    private BlockCache summaryCache;
+    private BlockCache indexCache;
 
     CompositeCache(BlockCache summaryCache, BlockCache indexCache) {
       this.summaryCache = summaryCache;
@@ -193,9 +190,7 @@ public class SummaryReader {
     try {
       // the reason BCFile is used instead of RFile is to avoid reading in the RFile meta block when
       // only summary data is wanted.
-      CompositeCache compositeCache =
-          new CompositeCache(LoggingBlockCache.wrap(CacheType.SUMMARY, summaryCache),
-              LoggingBlockCache.wrap(CacheType.INDEX, indexCache));
+      CompositeCache compositeCache = new CompositeCache(summaryCache, indexCache);
       CachableBuilder cb = new CachableBuilder().fsPath(fs, file).conf(conf).fileLen(fileLenCache)
           .cacheProvider(new BasicCacheProvider(compositeCache, null)).cryptoService(cryptoService);
       bcReader = new CachableBlockFile.Reader(cb);
@@ -230,18 +225,10 @@ public class SummaryReader {
   }
 
   public static void print(Reader iter, PrintStream out) throws IOException {
-    List<SummarySerializer> stores = null;
-    try {
-      stores = load(iter::getMetaStore, conf -> true);
-    } catch (NoSuchMetaStoreException e) {
-      out.print("No summary data present in file\n");
-      // exit method early since rfile contains no summary data
-      return;
-    }
-
     String indent = "   ";
     out.print("Summary data : \n");
 
+    List<SummarySerializer> stores = load(iter::getMetaStore, conf -> true);
     int i = 1;
     for (SummarySerializer summaryStore : stores) {
       out.printf("%sSummary %d of %d generated by : %s\n", indent, i, stores.size(),
