@@ -25,17 +25,17 @@ import java.util.Map;
 import java.util.concurrent.Callable;
 
 import org.apache.accumulo.core.Constants;
-import org.apache.accumulo.core.trace.thrift.TInfo;
+import org.apache.accumulo.core.clientImpl.thrift.TInfo;
+import org.apache.accumulo.core.conf.AccumuloConfiguration;
+import org.apache.accumulo.core.conf.Property;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import io.opentelemetry.api.GlobalOpenTelemetry;
 import io.opentelemetry.api.OpenTelemetry;
-import io.opentelemetry.api.common.AttributeKey;
 import io.opentelemetry.api.common.Attributes;
 import io.opentelemetry.api.trace.Span;
 import io.opentelemetry.api.trace.SpanBuilder;
-import io.opentelemetry.api.trace.SpanContext;
 import io.opentelemetry.api.trace.SpanKind;
 import io.opentelemetry.api.trace.StatusCode;
 import io.opentelemetry.api.trace.Tracer;
@@ -43,6 +43,7 @@ import io.opentelemetry.api.trace.propagation.W3CTraceContextPropagator;
 import io.opentelemetry.context.Context;
 import io.opentelemetry.context.Scope;
 import io.opentelemetry.context.propagation.TextMapGetter;
+import io.opentelemetry.semconv.trace.attributes.SemanticAttributes;
 
 public class TraceUtil {
 
@@ -50,25 +51,25 @@ public class TraceUtil {
 
   private static final String SPAN_FORMAT = "%s::%s";
 
-  private static volatile boolean enabled = false;
+  private static volatile boolean enabled = true;
 
-  public static boolean getProcessTracing() {
-    return enabled;
-  }
-
-  public static void setProcessTracing(boolean shouldEnable) {
-    enabled = shouldEnable;
+  public static void initializeTracer(AccumuloConfiguration conf) {
+    enabled = conf.getBoolean(Property.GENERAL_OPENTELEMETRY_ENABLED);
     logTracingState();
   }
 
   private static void logTracingState() {
     var msg = "Trace enabled in Accumulo: {}, OpenTelemetry instance: {}, Tracer instance: {}";
     var enabledInAccumulo = enabled ? "yes" : "no";
-    var openTelemetry = enabled ? GlobalOpenTelemetry.get() : OpenTelemetry.noop();
+    var openTelemetry = getOpenTelemetry();
     var tracer = getTracer(openTelemetry);
     LOG.info(msg, enabledInAccumulo, openTelemetry.getClass(), tracer.getClass());
   }
 
+  private static OpenTelemetry getOpenTelemetry() {
+    return enabled ? GlobalOpenTelemetry.get() : OpenTelemetry.noop();
+  }
+
   private static Tracer getTracer(OpenTelemetry ot) {
     return ot.getTracer(Constants.APPNAME, Constants.VERSION);
   }
@@ -95,22 +96,19 @@ public class TraceUtil {
 
   private static Span startSpan(Class<?> caller, String spanName, SpanKind kind,
       Map<String,String> attributes, TInfo tinfo) {
-    Context context = tinfo == null ? null : getContext(tinfo);
-    SpanContext spanContext =
-        context == null ? SpanContext.getInvalid() : Span.fromContext(context).getSpanContext();
-    if (!enabled && !spanContext.isValid() && !Span.current().getSpanContext().isValid()) {
+    if (!enabled && !Span.current().getSpanContext().isValid()) {
       return Span.getInvalid();
     }
     final String name = String.format(SPAN_FORMAT, caller.getSimpleName(), spanName);
-    final SpanBuilder builder = getTracer(GlobalOpenTelemetry.get()).spanBuilder(name);
+    final SpanBuilder builder = getTracer(getOpenTelemetry()).spanBuilder(name);
     if (kind != null) {
       builder.setSpanKind(kind);
     }
     if (attributes != null) {
       attributes.forEach(builder::setAttribute);
     }
-    if (spanContext.isValid()) {
-      builder.setParent(context);
+    if (tinfo != null) {
+      builder.setParent(getContext(tinfo));
     }
     return builder.startSpan();
   }
@@ -126,15 +124,15 @@ public class TraceUtil {
     if (enabled) {
       span.setStatus(StatusCode.ERROR);
       span.recordException(e,
-          Attributes.builder().put(AttributeKey.stringKey("exception.type"), e.getClass().getName())
-              .put(AttributeKey.stringKey("exception.message"), e.getMessage())
-              .put(AttributeKey.booleanKey("exception.escaped"), rethrown).build());
+          Attributes.builder().put(SemanticAttributes.EXCEPTION_TYPE, e.getClass().getName())
+              .put(SemanticAttributes.EXCEPTION_MESSAGE, e.getMessage())
+              .put(SemanticAttributes.EXCEPTION_ESCAPED, rethrown).build());
     }
   }
 
   /**
-   * Obtain {@link org.apache.accumulo.core.trace.thrift.TInfo} for the current context. This is
-   * used to send the current trace information to a remote process
+   * Obtain {@link org.apache.accumulo.core.clientImpl.thrift.TInfo} for the current context. This
+   * is used to send the current trace information to a remote process
    */
   public static TInfo traceInfo() {
     TInfo tinfo = new TInfo();
