@@ -20,7 +20,6 @@ package org.apache.accumulo.core.util.compaction;
 
 import static java.util.Objects.requireNonNull;
 import static java.util.concurrent.TimeUnit.MILLISECONDS;
-import static java.util.concurrent.TimeUnit.NANOSECONDS;
 
 import java.util.TreeMap;
 
@@ -63,41 +62,45 @@ public class RunningCompactionInfo {
 
     // parse the updates map
     long nowMillis = System.currentTimeMillis();
+    long startedMillis = nowMillis;
     float percent = 0f;
     long updateMillis;
     TCompactionStatusUpdate last;
 
     // sort updates by key, which is a timestamp
     TreeMap<Long,TCompactionStatusUpdate> sorted = new TreeMap<>(updates);
+    var firstEntry = sorted.firstEntry();
     var lastEntry = sorted.lastEntry();
+    if (firstEntry != null) {
+      startedMillis = firstEntry.getKey();
+    }
+    duration = nowMillis - startedMillis;
+    long durationMinutes = MILLISECONDS.toMinutes(duration);
+    if (durationMinutes > 15) {
+      log.warn("Compaction {} has been running for {} minutes", ecid, durationMinutes);
+    }
 
     // last entry is all we care about so bail if null
     if (lastEntry != null) {
       last = lastEntry.getValue();
       updateMillis = lastEntry.getKey();
-      duration = NANOSECONDS.toMillis(last.getCompactionAgeNanos());
     } else {
-      log.trace("No updates found for {}", ecid);
+      log.debug("No updates found for {}", ecid);
       lastUpdate = 1;
       progress = percent;
       status = "na";
-      duration = 0;
       return;
     }
-    long durationMinutes = MILLISECONDS.toMinutes(duration);
-    if (durationMinutes > 15) {
-      log.trace("Compaction {} has been running for {} minutes", ecid, durationMinutes);
-    }
 
-    lastUpdate = nowMillis - updateMillis;
-    long sinceLastUpdateSeconds = MILLISECONDS.toSeconds(lastUpdate);
-    log.trace("Time since Last update {} - {} = {} seconds", nowMillis, updateMillis,
+    long sinceLastUpdateSeconds = MILLISECONDS.toSeconds(nowMillis - updateMillis);
+    log.debug("Time since Last update {} - {} = {} seconds", nowMillis, updateMillis,
         sinceLastUpdateSeconds);
 
     var total = last.getEntriesToBeCompacted();
     if (total > 0) {
       percent = (last.getEntriesRead() / (float) total) * 100;
     }
+    lastUpdate = nowMillis - updateMillis;
     progress = percent;
 
     if (updates.isEmpty()) {
@@ -105,9 +108,9 @@ public class RunningCompactionInfo {
     } else {
       status = last.state.name();
     }
-    log.trace("Parsed running compaction {} for {} with progress = {}%", status, ecid, progress);
+    log.debug("Parsed running compaction {} for {} with progress = {}%", status, ecid, progress);
     if (sinceLastUpdateSeconds > 30) {
-      log.trace("Compaction hasn't progressed from {} in {} seconds.", progress,
+      log.debug("Compaction hasn't progressed from {} in {} seconds.", progress,
           sinceLastUpdateSeconds);
     }
   }
