@@ -28,7 +28,6 @@ import java.util.Objects;
 import org.apache.accumulo.core.WithTestNames;
 import org.apache.accumulo.core.conf.ConfigurationCopy;
 import org.apache.accumulo.core.conf.Property;
-import org.apache.accumulo.core.spi.common.ContextClassLoaderFactory.ContextClassLoaderException;
 import org.apache.commons.io.FileUtils;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
@@ -65,11 +64,11 @@ public class ContextClassLoaderFactoryTest extends WithTestNames {
   }
 
   @Test
-  public void differentContexts() throws ContextClassLoaderException {
+  public void differentContexts() {
 
     ConfigurationCopy cc = new ConfigurationCopy();
     cc.set(Property.GENERAL_CONTEXT_CLASSLOADER_FACTORY.getKey(),
-        URLClassLoaderFactory.class.getName());
+        URLContextClassLoaderFactory.class.getName());
     ClassLoaderUtil.resetContextFactoryForTests();
     ClassLoaderUtil.initContextFactory(cc);
 
