@@ -19,12 +19,9 @@
 package org.apache.accumulo.core.cli;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import org.junit.jupiter.api.Test;
 
-import com.beust.jcommander.Parameter;
-
 public class TestHelp {
   protected class HelpStub extends Help {
     @Override
@@ -34,7 +31,7 @@ public class TestHelp {
 
     @Override
     public void exit(int status) {
-      throw new RuntimeException(Integer.toString(status));
+      throw new IllegalStateException(Integer.toString(status));
     }
   }
 
@@ -49,20 +46,4 @@ public class TestHelp {
     }
   }
 
-  @Test
-  public void testHelpCommand() {
-    class TestHelpOpt extends HelpStub {
-      @Parameter(names = {"--test"})
-      boolean test = false;
-    }
-
-    String[] args = {"--help", "--test"};
-    TestHelpOpt opts = new TestHelpOpt();
-    try {
-      opts.parseArgs("program", args);
-      assertTrue(opts.test);
-    } catch (RuntimeException e) {
-      assertEquals("0", e.getMessage());
-    }
-  }
 }
