@@ -18,8 +18,6 @@
  */
 package org.apache.accumulo.core.client.lexicoder;
 
-import static java.nio.charset.StandardCharsets.UTF_8;
-
 import org.apache.accumulo.core.clientImpl.lexicoder.AbstractLexicoderTest;
 import org.junit.jupiter.api.Test;
 
@@ -29,6 +27,6 @@ public class BytesLexicoderTest extends AbstractLexicoderTest {
   public void testDecodes() {
     BytesLexicoder lexicoder = new BytesLexicoder();
     assertDecodesB(lexicoder, new byte[0]);
-    assertDecodesB(lexicoder, "accumulo".getBytes(UTF_8));
+    assertDecodesB(lexicoder, "accumulo".getBytes());
   }
 }
