@@ -26,7 +26,6 @@ import static org.junit.jupiter.api.Assertions.assertSame;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.util.HashSet;
-import java.util.List;
 import java.util.Map.Entry;
 import java.util.TreeMap;
 import java.util.function.Predicate;
@@ -70,10 +69,6 @@ public class PropertyTest {
       assertFalse(prop.getDescription() == null || prop.getDescription().isEmpty(),
           "Description not set for " + prop);
 
-      // make sure property description ends with a period
-      assertTrue(prop.getDescription().endsWith("."),
-          "Property: " + prop.getKey() + " description does not end with period.");
-
       // make sure property starts with valid prefix
       boolean containsValidPrefix = false;
       for (String pre : validPrefixes) {
@@ -106,34 +101,6 @@ public class PropertyTest {
     }
   }
 
-  @Test
-  public void testJson() {
-    // using "real" example
-    String json1 =
-        "[{'name':'small','type':'internal','maxSize':'32M','numThreads':2},{'name':'huge','type':'internal','numThreads':2}]"
-            .replaceAll("'", "\"");
-    // use synthetic, but valid json
-    String json2 =
-        "[{'foo':'bar','type':'test','fooBar':'32'},{'foo':'bar','type':'test','fooBar':32}]"
-            .replaceAll("'", "\"");
-    String json3 = "{'foo':'bar','type':'test','fooBar':'32'}".replaceAll("'", "\"");
-
-    List<String> valids = List.of(json1, json2, json3);
-
-    List<String> invalids = List.of("notJson", "also not json", "{\"x}", "{\"y\"", "{name:value}",
-        "{ \"foo\" : \"bar\", \"foo\" : \"baz\" }", "{\"y\":123}extra");
-
-    for (Property prop : Property.values()) {
-      if (prop.getType().equals(PropertyType.JSON)) {
-        valids.forEach(j -> assertTrue(Property.isValidProperty(prop.getKey(), j)));
-        valids.forEach(j -> assertTrue(prop.getType().isValidFormat(j)));
-
-        invalids.forEach(j -> assertFalse(Property.isValidProperty(prop.getKey(), j)));
-        invalids.forEach(j -> assertFalse(prop.getType().isValidFormat(j)));
-      }
-    }
-  }
-
   @Test
   public void testPropertyValidation() {
 
@@ -191,9 +158,6 @@ public class PropertyTest {
         case BOOLEAN:
           invalidValue = "fooFalse";
           break;
-        case JSON:
-          invalidValue = "not json";
-          break;
         default:
           LOG.debug("Property type: {} has no defined test case", propertyType);
           invalidValue = "foo";
@@ -206,20 +170,19 @@ public class PropertyTest {
   // This test verifies all "sensitive" properties are properly marked as sensitive
   @Test
   public void testSensitiveKeys() {
-    // add trace token, because it's a sensitive property not in the default configuration
+    // add instance.crypto.opts, because it's a sensitive property not in the default configuration
     ConfigurationCopy conf = new ConfigurationCopy(DefaultConfiguration.getInstance());
-    conf.set("trace.token.property.blah", "something");
+    conf.set("instance.crypto.opts.sensitive.blah", "something");
 
     // ignores duplicates because ConfigurationCopy already de-duplicates
     Collector<Entry<String,String>,?,TreeMap<String,String>> treeMapCollector =
         Collectors.toMap(Entry::getKey, Entry::getValue, (a, b) -> a, TreeMap::new);
 
-    @SuppressWarnings("deprecation")
     Predicate<Entry<String,String>> sensitiveNames =
         e -> e.getKey().equals(Property.INSTANCE_SECRET.getKey())
             || e.getKey().toLowerCase().contains("password")
             || e.getKey().toLowerCase().endsWith("secret")
-            || e.getKey().startsWith(Property.TRACE_TOKEN_PROPERTY_PREFIX.getKey());
+            || e.getKey().startsWith(Property.INSTANCE_CRYPTO_SENSITIVE_PREFIX.getKey());
 
     Predicate<Entry<String,String>> isMarkedSensitive = e -> Property.isSensitive(e.getKey());
 
@@ -228,8 +191,8 @@ public class PropertyTest {
     TreeMap<String,String> actual = StreamSupport.stream(conf.spliterator(), false)
         .filter(isMarkedSensitive).collect(treeMapCollector);
 
-    // make sure trace token property wasn't excluded from both
-    assertEquals("something", expected.get("trace.token.property.blah"));
+    // make sure instance.crypto.opts property wasn't excluded from both
+    assertEquals("something", expected.get("instance.crypto.opts.sensitive.blah"));
     assertEquals(expected, actual);
   }
 
@@ -251,9 +214,6 @@ public class PropertyTest {
     assertTrue(Property.INSTANCE_SECRET.isSensitive());
     assertFalse(Property.INSTANCE_VOLUMES.isSensitive());
 
-    @SuppressWarnings("deprecation")
-    Property deprecatedProp = Property.GENERAL_CLASSPATHS;
-    assertTrue(deprecatedProp.isDeprecated());
     assertFalse(Property.INSTANCE_VOLUMES_REPLACEMENTS.isDeprecated());
   }
 
@@ -298,7 +258,7 @@ public class PropertyTest {
 
   @Test
   public void testFixedPropertiesNonNull() {
-    Property.FIXED_PROPERTIES.forEach(p -> {
+    Property.fixedProperties.forEach(p -> {
       assertNotNull(p.getDefaultValue());
       assertFalse(p.getDefaultValue().isBlank());
     });
