@@ -28,7 +28,6 @@ import java.io.DataInputStream;
 import java.io.IOException;
 import java.security.SecureRandom;
 import java.util.Arrays;
-import java.util.concurrent.atomic.AtomicBoolean;
 
 import org.apache.accumulo.core.crypto.streams.BlockedInputStream;
 import org.apache.accumulo.core.crypto.streams.BlockedOutputStream;
@@ -45,8 +44,7 @@ public class BlockedIOStreamTest {
 
   private void writeRead(int blockSize, int expectedSize) throws IOException {
     ByteArrayOutputStream baos = new ByteArrayOutputStream();
-    BlockedOutputStream blockOut =
-        new BlockedOutputStream(baos, blockSize, 1, new AtomicBoolean(true));
+    BlockedOutputStream blockOut = new BlockedOutputStream(baos, blockSize, 1);
 
     String contentString = "My Blocked Content String";
     byte[] content = contentString.getBytes(UTF_8);
@@ -88,7 +86,7 @@ public class BlockedIOStreamTest {
   public void testSpillingOverOutputStream() throws IOException {
     ByteArrayOutputStream baos = new ByteArrayOutputStream();
     // buffer will be size 12
-    BlockedOutputStream blockOut = new BlockedOutputStream(baos, 16, 16, new AtomicBoolean(true));
+    BlockedOutputStream blockOut = new BlockedOutputStream(baos, 16, 16);
 
     byte[] undersized = new byte[11];
     byte[] perfectSized = new byte[12];
@@ -131,8 +129,7 @@ public class BlockedIOStreamTest {
     ByteArrayOutputStream baos = new ByteArrayOutputStream();
     int blockSize = 16;
     // buffer will be size 12
-    BlockedOutputStream blockOut =
-        new BlockedOutputStream(baos, blockSize, blockSize, new AtomicBoolean(true));
+    BlockedOutputStream blockOut = new BlockedOutputStream(baos, blockSize, blockSize);
 
     int size = 1024 * 1024 * 128;
     byte[] giant = new byte[size];
