@@ -19,17 +19,16 @@
 package org.apache.accumulo.core.crypto;
 
 import static com.google.common.collect.MoreCollectors.onlyElement;
-import static java.nio.charset.StandardCharsets.UTF_8;
 import static org.apache.accumulo.core.conf.Property.INSTANCE_CRYPTO_FACTORY;
 import static org.apache.accumulo.core.crypto.CryptoUtils.getFileDecrypter;
 import static org.apache.accumulo.core.spi.crypto.CryptoEnvironment.Scope.TABLE;
 import static org.apache.accumulo.core.spi.crypto.CryptoEnvironment.Scope.WAL;
+import static org.apache.accumulo.core.util.LazySingletons.RANDOM;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertNotEquals;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
 import static org.junit.jupiter.api.Assertions.assertThrows;
-import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
@@ -46,10 +45,7 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.HashMap;
-import java.util.List;
 import java.util.Map;
-import java.util.concurrent.Executors;
-import java.util.concurrent.Future;
 
 import javax.crypto.Cipher;
 import javax.crypto.NoSuchPaddingException;
@@ -92,7 +88,6 @@ import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
 
 public class CryptoTest {
 
-  private static final SecureRandom random = new SecureRandom();
   private static final int MARKER_INT = 0xCADEFEDD;
   private static final String MARKER_STRING = "1 2 3 4 5 6 7 8 a b c d e f g h ";
   private static final Configuration hadoopConf = new Configuration();
@@ -295,7 +290,7 @@ public class CryptoTest {
 
     String stringifiedBytes = Arrays.toString(encryptedBytes);
     String stringifiedMarkerBytes =
-        getStringifiedBytes("U+1F47B".getBytes(UTF_8), MARKER_STRING, MARKER_INT);
+        getStringifiedBytes("U+1F47B".getBytes(), MARKER_STRING, MARKER_INT);
 
     assertEquals(stringifiedBytes, stringifiedMarkerBytes);
 
@@ -309,7 +304,7 @@ public class CryptoTest {
 
     String stringifiedBytes = Arrays.toString(encryptedBytes);
     String stringifiedMarkerBytes =
-        getStringifiedBytes("U+1F47B".getBytes(UTF_8), MARKER_STRING, MARKER_INT);
+        getStringifiedBytes("U+1F47B".getBytes(), MARKER_STRING, MARKER_INT);
 
     assertEquals(stringifiedBytes, stringifiedMarkerBytes);
 
@@ -414,11 +409,11 @@ public class CryptoTest {
       NoSuchProviderException, NoSuchPaddingException, InvalidKeyException {
     // verify valid key sizes (corresponds to 128, 192, and 256 bits)
     for (int i : new int[] {16, 24, 32}) {
-      verifyKeySizeForCBC(random, i);
+      verifyKeySizeForCBC(RANDOM.get(), i);
     }
     // verify invalid key sizes
     for (int i : new int[] {1, 2, 8, 11, 15, 64, 128}) {
-      assertThrows(InvalidKeyException.class, () -> verifyKeySizeForCBC(random, i));
+      assertThrows(InvalidKeyException.class, () -> verifyKeySizeForCBC(RANDOM.get(), i));
     }
   }
 
@@ -434,8 +429,8 @@ public class CryptoTest {
   @Test
   public void testAESKeyUtilsWrapAndUnwrap()
       throws NoSuchAlgorithmException, NoSuchProviderException {
-    java.security.Key kek = AESCryptoService.generateKey(random, 16);
-    java.security.Key fek = AESCryptoService.generateKey(random, 16);
+    java.security.Key kek = AESCryptoService.generateKey(RANDOM.get(), 16);
+    java.security.Key fek = AESCryptoService.generateKey(RANDOM.get(), 16);
     byte[] wrapped = AESCryptoService.wrapKey(fek, kek);
     assertFalse(Arrays.equals(fek.getEncoded(), wrapped));
     java.security.Key unwrapped = AESCryptoService.unwrapKey(wrapped, kek);
@@ -445,8 +440,8 @@ public class CryptoTest {
   @Test
   public void testAESKeyUtilsFailUnwrapWithWrongKEK()
       throws NoSuchAlgorithmException, NoSuchProviderException {
-    java.security.Key kek = AESCryptoService.generateKey(random, 16);
-    java.security.Key fek = AESCryptoService.generateKey(random, 16);
+    java.security.Key kek = AESCryptoService.generateKey(RANDOM.get(), 16);
+    java.security.Key fek = AESCryptoService.generateKey(RANDOM.get(), 16);
     byte[] wrongBytes = kek.getEncoded();
     wrongBytes[0]++;
     java.security.Key wrongKek = new SecretKeySpec(wrongBytes, "AES");
@@ -501,91 +496,6 @@ public class CryptoTest {
     assertEquals(2, factory.getCount());
   }
 
-  @Test
-  public void testMultipleThreads() throws Exception {
-    testMultipleThreads(WAL);
-    testMultipleThreads(TABLE);
-  }
-
-  private void testMultipleThreads(Scope scope) throws Exception {
-
-    byte[] plainText = new byte[1024 * 1024];
-    for (int i = 0; i < plainText.length; i++) {
-      plainText[i] = (byte) (i % 128);
-    }
-
-    AESCryptoService cs = new AESCryptoService();
-    cs.init(getAllCryptoProperties(ConfigMode.CRYPTO_TABLE_ON));
-    CryptoEnvironment encEnv = new CryptoEnvironmentImpl(scope, null, null);
-    FileEncrypter encrypter = cs.getFileEncrypter(encEnv);
-    byte[] params = encrypter.getDecryptionParameters();
-
-    assertNotNull(params);
-
-    ByteArrayOutputStream out = new ByteArrayOutputStream();
-    DataOutputStream dataOut = new DataOutputStream(out);
-    OutputStream encrypted = encrypter.encryptStream(dataOut);
-
-    assertNotNull(encrypted);
-    DataOutputStream cipherOut = new DataOutputStream(encrypted);
-
-    cipherOut.write(plainText);
-
-    cipherOut.close();
-    dataOut.close();
-    encrypted.close();
-    out.close();
-    byte[] cipherText = out.toByteArray();
-
-    var executor = Executors.newCachedThreadPool();
-
-    List<Future<Boolean>> verifyFutures = new ArrayList<>();
-
-    FileDecrypter decrypter = cs.getFileDecrypter(new CryptoEnvironmentImpl(scope, null, params));
-
-    // verify that each input stream returned by decrypter.decryptStream() is independent when used
-    // by multiple threads
-    for (int i = 0; i < 32; i++) {
-      var future = executor.submit(() -> {
-        try (ByteArrayInputStream in = new ByteArrayInputStream(cipherText);
-            DataInputStream decrypted = new DataInputStream(decrypter.decryptStream(in))) {
-          byte[] dataRead = new byte[plainText.length];
-          decrypted.readFully(dataRead);
-          return Arrays.equals(plainText, dataRead);
-        }
-      });
-      verifyFutures.add(future);
-    }
-
-    for (var future : verifyFutures) {
-      assertTrue(future.get());
-    }
-  }
-
-  @Test
-  public void testOverlappingWrites() throws Exception {
-    testOverlappingWrites(WAL);
-    testOverlappingWrites(TABLE);
-  }
-
-  private void testOverlappingWrites(Scope scope) throws Exception {
-    AESCryptoService cs = new AESCryptoService();
-    cs.init(getAllCryptoProperties(ConfigMode.CRYPTO_TABLE_ON));
-    CryptoEnvironment encEnv = new CryptoEnvironmentImpl(scope, null, null);
-    FileEncrypter encrypter = cs.getFileEncrypter(encEnv);
-
-    ByteArrayOutputStream out1 = new ByteArrayOutputStream();
-    var es1 = encrypter.encryptStream(out1);
-
-    // try to create a new encryption stream w/o closing the previous one
-    ByteArrayOutputStream out2 = new ByteArrayOutputStream();
-    var ce = assertThrows(CryptoException.class, () -> encrypter.encryptStream(out2));
-    assertTrue(ce.getMessage().contains("closing previous"));
-
-    es1.close();
-    assertNotNull(encrypter.encryptStream(out2));
-  }
-
   private ArrayList<Key> testData() {
     ArrayList<Key> keys = new ArrayList<>();
     keys.add(new Key("a", "cf", "cq"));
