@@ -50,13 +50,9 @@ public class TableIdTest extends WithTestNames {
   @Test
   public void testCacheNoDuplicates() {
 
-    @SuppressWarnings("deprecation")
-    TableId REPL_TABLE_ID = org.apache.accumulo.core.replication.ReplicationTable.ID;
-
-    // the next two lines just preloads the built-ins, since they now exist in a separate class from
+    // the next line just preloads the built-ins, since they now exist in a separate class from
     // TableId, and aren't preloaded when the TableId class is referenced
     assertNotSame(RootTable.ID, MetadataTable.ID);
-    assertNotSame(RootTable.ID, REPL_TABLE_ID);
 
     String tableString = "table-" + testName();
     long initialSize = cacheCount();
@@ -69,8 +65,6 @@ public class TableIdTest extends WithTestNames {
     assertSame(MetadataTable.ID, builtInTableId);
     builtInTableId = TableId.of("+r");
     assertSame(RootTable.ID, builtInTableId);
-    builtInTableId = TableId.of("+rep");
-    assertSame(REPL_TABLE_ID, builtInTableId);
     table1 = TableId.of(tableString);
     assertEquals(initialSize + 1, cacheCount());
     assertEquals(tableString, table1.canonical());
@@ -98,7 +92,7 @@ public class TableIdTest extends WithTestNames {
     long preGCSize = 0;
     int i = 0;
     while ((preGCSize = cacheCount()) < 100) {
-      TableId.of(new String("table" + i++));
+      TableId.of(("table" + i++));
     }
     LOG.info("Entries before System.gc(): {}", preGCSize);
     assertEquals(100, preGCSize);
