@@ -1,24 +1,25 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.core.file.rfile;
 
-import static org.junit.Assert.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
 
-import java.io.File;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.HashMap;
@@ -32,11 +33,9 @@ import org.apache.accumulo.core.data.Key;
 import org.apache.accumulo.core.data.Range;
 import org.apache.accumulo.core.data.Value;
 import org.apache.accumulo.core.util.LocalityGroupUtil;
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import com.google.common.util.concurrent.AtomicLongMap;
 
@@ -45,18 +44,14 @@ import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
 @SuppressFBWarnings(value = "PATH_TRAVERSAL_IN", justification = "paths not set by user input")
 public class RFileMetricsTest {
 
-  @Rule
-  public TemporaryFolder tempFolder =
-      new TemporaryFolder(new File(System.getProperty("user.dir") + "/target"));
-
   private TestRFile trf = null;
 
-  @Before
+  @BeforeEach
   public void makeTestRFile() {
     trf = new TestRFile();
   }
 
-  @After
+  @AfterEach
   public void cleanUpTestRFile() {
     // do our best to clean up first
     if (trf != null) {
@@ -519,8 +514,8 @@ public class RFileMetricsTest {
 
     for (int row = 0; row < 1100; row++) {
       String rs = String.format("%06x", row);
-      trf.writer.append(new Key(rs, fam1, "q4", "A", 42L), new Value("v".getBytes()));
-      trf.writer.append(new Key(rs, fam2, "q4", "A|B", 42L), new Value("v".getBytes()));
+      trf.writer.append(new Key(rs, fam1, "q4", "A", 42L), new Value("v"));
+      trf.writer.append(new Key(rs, fam2, "q4", "A|B", 42L), new Value("v"));
     }
 
     trf.writer.startDefaultLocalityGroup();
@@ -532,7 +527,7 @@ public class RFileMetricsTest {
       String rs = String.format("%06x", row);
       for (int v = 0; v < 5; v++) {
         String fs = String.format("%06x", fam++);
-        trf.writer.append(new Key(rs, fs, "q4", vis[v], 42L), new Value("v".getBytes()));
+        trf.writer.append(new Key(rs, fs, "q4", vis[v], 42L), new Value("v"));
       }
     }
 
