@@ -18,7 +18,6 @@
  */
 package org.apache.accumulo.core.iterators.user;
 
-import static java.nio.charset.StandardCharsets.UTF_8;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
@@ -40,9 +39,9 @@ import org.apache.accumulo.core.data.Column;
 import org.apache.accumulo.core.data.Key;
 import org.apache.accumulo.core.data.Range;
 import org.apache.accumulo.core.data.Value;
+import org.apache.accumulo.core.iterators.DefaultIteratorEnvironment;
 import org.apache.accumulo.core.iterators.Filter;
 import org.apache.accumulo.core.iterators.SortedKeyValueIterator;
-import org.apache.accumulo.core.iteratorsImpl.ClientIteratorEnvironment;
 import org.apache.accumulo.core.iteratorsImpl.system.ColumnQualifierFilter;
 import org.apache.accumulo.core.iteratorsImpl.system.SortedMapIterator;
 import org.apache.accumulo.core.iteratorsImpl.system.VisibilityFilter;
@@ -230,19 +229,19 @@ public class FilterTest {
 
     ColumnAgeOffFilter a = new ColumnAgeOffFilter();
     assertTrue(a.validateOptions(is.getOptions()));
-    a.init(new SortedMapIterator(tm), is.getOptions(), ClientIteratorEnvironment.DEFAULT);
+    a.init(new SortedMapIterator(tm), is.getOptions(), new DefaultIteratorEnvironment());
     a.overrideCurrentTime(ts);
     a.seek(new Range(), EMPTY_COL_FAMS, false);
     assertEquals(902, size(a));
 
     ColumnAgeOffFilter.addTTL(is, new IteratorSetting.Column("a", "b"), 101L);
-    a.init(new SortedMapIterator(tm), is.getOptions(), ClientIteratorEnvironment.DEFAULT);
+    a.init(new SortedMapIterator(tm), is.getOptions(), new DefaultIteratorEnvironment());
     a.overrideCurrentTime(ts);
     a.seek(new Range(), EMPTY_COL_FAMS, false);
     assertEquals(102, size(a));
 
     ColumnAgeOffFilter.removeTTL(is, new IteratorSetting.Column("a", "b"));
-    a.init(new SortedMapIterator(tm), is.getOptions(), ClientIteratorEnvironment.DEFAULT);
+    a.init(new SortedMapIterator(tm), is.getOptions(), new DefaultIteratorEnvironment());
     a = (ColumnAgeOffFilter) a.deepCopy(null);
     a.overrideCurrentTime(ts);
     a.seek(new Range(), EMPTY_COL_FAMS, false);
@@ -271,19 +270,19 @@ public class FilterTest {
 
     ColumnAgeOffFilter a = new ColumnAgeOffFilter();
     assertTrue(a.validateOptions(is.getOptions()));
-    a.init(new SortedMapIterator(tm), is.getOptions(), ClientIteratorEnvironment.DEFAULT);
+    a.init(new SortedMapIterator(tm), is.getOptions(), new DefaultIteratorEnvironment());
     a.overrideCurrentTime(ts);
     a.seek(new Range(), EMPTY_COL_FAMS, false);
     assertEquals(98, size(a));
 
     ColumnAgeOffFilter.addTTL(is, new IteratorSetting.Column("a", "b"), 101L);
-    a.init(new SortedMapIterator(tm), is.getOptions(), ClientIteratorEnvironment.DEFAULT);
+    a.init(new SortedMapIterator(tm), is.getOptions(), new DefaultIteratorEnvironment());
     a.overrideCurrentTime(ts);
     a.seek(new Range(), EMPTY_COL_FAMS, false);
     assertEquals(898, size(a));
 
     ColumnAgeOffFilter.removeTTL(is, new IteratorSetting.Column("a", "b"));
-    a.init(new SortedMapIterator(tm), is.getOptions(), ClientIteratorEnvironment.DEFAULT);
+    a.init(new SortedMapIterator(tm), is.getOptions(), new DefaultIteratorEnvironment());
     a = (ColumnAgeOffFilter) a.deepCopy(null);
     a.overrideCurrentTime(ts);
     a.seek(new Range(), EMPTY_COL_FAMS, false);
@@ -312,19 +311,19 @@ public class FilterTest {
 
     ColumnAgeOffFilter a = new ColumnAgeOffFilter();
     assertTrue(a.validateOptions(is.getOptions()));
-    a.init(new SortedMapIterator(tm), is.getOptions(), ClientIteratorEnvironment.DEFAULT);
+    a.init(new SortedMapIterator(tm), is.getOptions(), new DefaultIteratorEnvironment());
     a.overrideCurrentTime(ts);
     a.seek(new Range(), EMPTY_COL_FAMS, false);
     assertEquals(902, size(a));
 
     ColumnAgeOffFilter.addTTL(is, new IteratorSetting.Column("negate", "b"), 101L);
-    a.init(new SortedMapIterator(tm), is.getOptions(), ClientIteratorEnvironment.DEFAULT);
+    a.init(new SortedMapIterator(tm), is.getOptions(), new DefaultIteratorEnvironment());
     a.overrideCurrentTime(ts);
     a.seek(new Range(), EMPTY_COL_FAMS, false);
     assertEquals(102, size(a));
 
     ColumnAgeOffFilter.removeTTL(is, new IteratorSetting.Column("negate", "b"));
-    a.init(new SortedMapIterator(tm), is.getOptions(), ClientIteratorEnvironment.DEFAULT);
+    a.init(new SortedMapIterator(tm), is.getOptions(), new DefaultIteratorEnvironment());
     a = (ColumnAgeOffFilter) a.deepCopy(null);
     a.overrideCurrentTime(ts);
     a.seek(new Range(), EMPTY_COL_FAMS, false);
@@ -336,7 +335,7 @@ public class FilterTest {
     Value dv = new Value();
     TreeMap<Key,Value> tm = new TreeMap<>();
     HashSet<Column> hsc = new HashSet<>();
-    hsc.add(new Column("c".getBytes(UTF_8), null, null));
+    hsc.add(new Column("c".getBytes(), null, null));
 
     Text colf1 = new Text("a");
     Text colq1 = new Text("b");
@@ -364,7 +363,7 @@ public class FilterTest {
     assertEquals(1000, size(a));
 
     hsc = new HashSet<>();
-    hsc.add(new Column("a".getBytes(UTF_8), "b".getBytes(UTF_8), null));
+    hsc.add(new Column("a".getBytes(), "b".getBytes(), null));
     a = ColumnQualifierFilter.wrap(new SortedMapIterator(tm), hsc);
     a.seek(new Range(), EMPTY_COL_FAMS, false);
     int size = size(a);
@@ -428,25 +427,25 @@ public class FilterTest {
 
     assertEquals(5, tm.size());
 
-    int size = size(ncqf(tm, new Column("c".getBytes(UTF_8), null, null)));
+    int size = size(ncqf(tm, new Column("c".getBytes(), null, null)));
     assertEquals(5, size);
 
-    size = size(ncqf(tm, new Column("a".getBytes(UTF_8), null, null)));
+    size = size(ncqf(tm, new Column("a".getBytes(), null, null)));
     assertEquals(5, size);
 
-    size = size(ncqf(tm, new Column("a".getBytes(UTF_8), "x".getBytes(UTF_8), null)));
+    size = size(ncqf(tm, new Column("a".getBytes(), "x".getBytes(), null)));
     assertEquals(1, size);
 
-    size = size(ncqf(tm, new Column("a".getBytes(UTF_8), "x".getBytes(UTF_8), null),
-        new Column("b".getBytes(UTF_8), "x".getBytes(UTF_8), null)));
+    size = size(ncqf(tm, new Column("a".getBytes(), "x".getBytes(), null),
+        new Column("b".getBytes(), "x".getBytes(), null)));
     assertEquals(2, size);
 
-    size = size(ncqf(tm, new Column("a".getBytes(UTF_8), "x".getBytes(UTF_8), null),
-        new Column("b".getBytes(UTF_8), "y".getBytes(UTF_8), null)));
+    size = size(ncqf(tm, new Column("a".getBytes(), "x".getBytes(), null),
+        new Column("b".getBytes(), "y".getBytes(), null)));
     assertEquals(2, size);
 
-    size = size(ncqf(tm, new Column("a".getBytes(UTF_8), "x".getBytes(UTF_8), null),
-        new Column("b".getBytes(UTF_8), null, null)));
+    size = size(ncqf(tm, new Column("a".getBytes(), "x".getBytes(), null),
+        new Column("b".getBytes(), null, null)));
     assertEquals(3, size);
   }
 
