@@ -18,12 +18,11 @@
  */
 package org.apache.accumulo.core.iterators.user;
 
-import static java.nio.charset.StandardCharsets.UTF_8;
+import static org.apache.accumulo.core.util.LazySingletons.RANDOM;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.IOException;
-import java.security.SecureRandom;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.HashSet;
@@ -38,20 +37,19 @@ import org.apache.accumulo.core.data.Range;
 import org.apache.accumulo.core.data.Value;
 import org.apache.accumulo.core.file.rfile.RFileTest;
 import org.apache.accumulo.core.file.rfile.RFileTest.TestRFile;
+import org.apache.accumulo.core.iterators.DefaultIteratorEnvironment;
 import org.apache.accumulo.core.iterators.IteratorEnvironment;
 import org.apache.accumulo.core.iterators.SortedKeyValueIterator;
-import org.apache.accumulo.core.iteratorsImpl.ClientIteratorEnvironment;
 import org.apache.accumulo.core.iteratorsImpl.system.MultiIterator;
 import org.apache.hadoop.io.Text;
 import org.junit.jupiter.api.Test;
 
 public class IndexedDocIteratorTest {
 
-  private static final SecureRandom random = new SecureRandom();
   private static final Collection<ByteSequence> EMPTY_COL_FAMS = new ArrayList<>();
   private static final byte[] nullByte = {0};
 
-  private static IteratorEnvironment env = ClientIteratorEnvironment.DEFAULT;
+  private static IteratorEnvironment env = new DefaultIteratorEnvironment();
 
   Text[] columnFamilies;
   Text[] otherColumnFamilies;
@@ -63,7 +61,7 @@ public class IndexedDocIteratorTest {
 
   static {
     docColf.append(nullByte, 0, 1);
-    docColf.append("type".getBytes(UTF_8), 0, "type".getBytes(UTF_8).length);
+    docColf.append("type".getBytes(), 0, "type".getBytes().length);
   }
 
   private TreeMap<Key,Value> createSortedMap(float hitRatio, int numRows, int numDocsPerRow,
@@ -92,14 +90,14 @@ public class IndexedDocIteratorTest {
         boolean docHits = true;
         Text doc = new Text("type");
         doc.append(nullByte, 0, 1);
-        doc.append(String.format("%010d", docid).getBytes(UTF_8), 0, 10);
+        doc.append(String.format("%010d", docid).getBytes(), 0, 10);
         for (int j = 0; j < columnFamilies.length; j++) {
-          if (random.nextFloat() < hitRatio) {
+          if (RANDOM.get().nextFloat() < hitRatio) {
             Text colq = new Text(columnFamilies[j]);
             colq.append(nullByte, 0, 1);
             colq.append(doc.getBytes(), 0, doc.getLength());
             colq.append(nullByte, 0, 1);
-            colq.append("stuff".getBytes(UTF_8), 0, "stuff".length());
+            colq.append("stuff".getBytes(), 0, "stuff".length());
             Key k = new Key(row, indexColf, colq);
             map.put(k, v);
             sb.append(" ");
@@ -117,12 +115,12 @@ public class IndexedDocIteratorTest {
           docs.add(doc);
         }
         for (Text cf : otherColumnFamilies) {
-          if (random.nextFloat() < hitRatio) {
+          if (RANDOM.get().nextFloat() < hitRatio) {
             Text colq = new Text(cf);
             colq.append(nullByte, 0, 1);
             colq.append(doc.getBytes(), 0, doc.getLength());
             colq.append(nullByte, 0, 1);
-            colq.append("stuff".getBytes(UTF_8), 0, "stuff".length());
+            colq.append("stuff".getBytes(), 0, "stuff".length());
             Key k = new Key(row, indexColf, colq);
             map.put(k, v);
             sb.append(" ");
@@ -150,7 +148,7 @@ public class IndexedDocIteratorTest {
   private SortedKeyValueIterator<Key,Value> createIteratorStack(float hitRatio, int numRows,
       int numDocsPerRow, Text[] columnFamilies, Text[] otherColumnFamilies, HashSet<Text> docs,
       Text[] negatedColumns) throws IOException {
-    // write a map file
+    // write a data file
     trf.openWriter(false);
 
     TreeMap<Key,Value> inMemoryMap = createSortedMap(hitRatio, numRows, numDocsPerRow,
@@ -214,7 +212,7 @@ public class IndexedDocIteratorTest {
 
       Text d = IndexedDocIterator.parseDocID(k);
       assertTrue(docs.contains(d));
-      assertTrue(new String(v.get(), UTF_8).endsWith(" docID=" + d));
+      assertTrue(new String(v.get()).endsWith(" docID=" + d));
 
       iter.next();
     }
@@ -251,7 +249,7 @@ public class IndexedDocIteratorTest {
       Value v = iter.getTopValue();
       Text d = IndexedDocIterator.parseDocID(k);
       assertTrue(docs.contains(d));
-      assertTrue(new String(v.get(), UTF_8).endsWith(" docID=" + d));
+      assertTrue(new String(v.get()).endsWith(" docID=" + d));
       iter.next();
     }
     assertEquals(hitCount, docs.size());
@@ -296,7 +294,7 @@ public class IndexedDocIteratorTest {
       Value v = iter.getTopValue();
       Text d = IndexedDocIterator.parseDocID(k);
       assertTrue(docs.contains(d));
-      assertTrue(new String(v.get(), UTF_8).endsWith(" docID=" + d));
+      assertTrue(new String(v.get()).endsWith(" docID=" + d));
       iter.next();
     }
     assertEquals(hitCount, docs.size());
@@ -339,7 +337,7 @@ public class IndexedDocIteratorTest {
       Value v = iter.getTopValue();
       Text d = IndexedDocIterator.parseDocID(k);
       assertTrue(docs.contains(d));
-      assertTrue(new String(v.get(), UTF_8).endsWith(" docID=" + d));
+      assertTrue(new String(v.get()).endsWith(" docID=" + d));
       iter.next();
     }
     assertEquals(hitCount, docs.size());
