@@ -34,7 +34,6 @@ import org.apache.accumulo.core.data.PartialKey;
 import org.apache.accumulo.core.data.Range;
 import org.apache.accumulo.core.data.Value;
 import org.apache.accumulo.core.iterators.IteratorUtil.IteratorScope;
-import org.apache.accumulo.core.iteratorsImpl.ClientIteratorEnvironment;
 import org.apache.accumulo.core.iteratorsImpl.system.ColumnFamilySkippingIterator;
 import org.apache.accumulo.core.iteratorsImpl.system.SortedMapIterator;
 import org.junit.jupiter.api.Test;
@@ -68,7 +67,7 @@ public class LargeRowFilterTest {
     IteratorSetting is = new IteratorSetting(1, LargeRowFilter.class);
     LargeRowFilter.setMaxColumns(is, maxColumns);
     lrfi.init(new ColumnFamilySkippingIterator(smi), is.getOptions(),
-        new ClientIteratorEnvironment.Builder().withScope(scope).build());
+        new RowDeletingIteratorTest.TestIE(scope, false));
     return lrfi;
   }
 
