@@ -47,7 +47,6 @@ import org.apache.accumulo.core.iterators.IteratorEnvironment;
 import org.apache.accumulo.core.iterators.IteratorUtil.IteratorScope;
 import org.apache.accumulo.core.iterators.SortedKeyValueIterator;
 import org.apache.accumulo.core.iterators.WrappingIterator;
-import org.apache.accumulo.core.iteratorsImpl.ClientIteratorEnvironment;
 import org.apache.accumulo.core.iteratorsImpl.system.ColumnFamilySkippingIterator;
 import org.apache.accumulo.core.iteratorsImpl.system.SortedMapIterator;
 import org.apache.accumulo.core.iteratorsImpl.system.VisibilityFilter;
@@ -91,7 +90,7 @@ public class TransformingIteratorTest {
     try {
       titer = clazz.getDeclaredConstructor().newInstance();
     } catch (ReflectiveOperationException e) {
-      throw new RuntimeException(e);
+      throw new IllegalStateException(e);
     }
 
     IteratorEnvironment iterEnv = EasyMock.createMock(IteratorEnvironment.class);
@@ -620,7 +619,7 @@ public class TransformingIteratorTest {
     @Override
     public void init(SortedKeyValueIterator<Key,Value> source, Map<String,String> options,
         IteratorEnvironment env) throws IOException {
-      env = new ClientIteratorEnvironment.Builder().withScope(IteratorScope.majc).build();
+      env = new MajCIteratorEnvironmentAdapter();
       super.init(source, options, env);
     }
   }
@@ -666,7 +665,7 @@ public class TransformingIteratorTest {
     @Override
     public void init(SortedKeyValueIterator<Key,Value> source, Map<String,String> options,
         IteratorEnvironment env) throws IOException {
-      env = new ClientIteratorEnvironment.Builder().withScope(IteratorScope.majc).build();
+      env = new MajCIteratorEnvironmentAdapter();
       super.init(source, options, env);
     }
   }
@@ -696,7 +695,7 @@ public class TransformingIteratorTest {
     @Override
     public void init(SortedKeyValueIterator<Key,Value> source, Map<String,String> options,
         IteratorEnvironment env) throws IOException {
-      env = new ClientIteratorEnvironment.Builder().withScope(IteratorScope.majc).build();
+      env = new MajCIteratorEnvironmentAdapter();
       super.init(source, options, env);
     }
   }
@@ -743,4 +742,10 @@ public class TransformingIteratorTest {
     }
   }
 
+  private static class MajCIteratorEnvironmentAdapter implements IteratorEnvironment {
+    @Override
+    public IteratorScope getIteratorScope() {
+      return IteratorScope.majc;
+    }
+  }
 }
