@@ -18,10 +18,10 @@
  */
 package org.apache.accumulo.core.spi.balancer;
 
+import static org.apache.accumulo.core.util.LazySingletons.RANDOM;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 
-import java.security.SecureRandom;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.HashSet;
@@ -40,7 +40,6 @@ import org.apache.accumulo.core.dataImpl.TabletIdImpl;
 import org.apache.accumulo.core.manager.balancer.BalanceParamsImpl;
 import org.apache.accumulo.core.manager.balancer.TServerStatusImpl;
 import org.apache.accumulo.core.manager.balancer.TabletServerIdImpl;
-import org.apache.accumulo.core.metadata.schema.Ample.DataLevel;
 import org.apache.accumulo.core.spi.balancer.data.TServerStatus;
 import org.apache.accumulo.core.spi.balancer.data.TabletMigration;
 import org.apache.accumulo.core.spi.balancer.data.TabletServerId;
@@ -50,8 +49,6 @@ import org.junit.jupiter.api.Test;
 
 public class GroupBalancerTest {
 
-  private static final SecureRandom random = new SecureRandom();
-
   private static final Function<TabletId,String> partitioner =
       input -> (input == null || input.getEndRow() == null) ? null
           : input.getEndRow().toString().substring(0, 2);
@@ -84,8 +81,7 @@ public class GroupBalancerTest {
     }
 
     public void balance(final int maxMigrations) {
-      TableId tid = TableId.of("1");
-      GroupBalancer balancer = new GroupBalancer(tid) {
+      GroupBalancer balancer = new GroupBalancer(TableId.of("1")) {
 
         @Override
         protected Map<TabletId,TabletServerId> getLocationProvider() {
@@ -108,11 +104,10 @@ public class GroupBalancerTest {
         }
       };
 
-      balance(balancer, maxMigrations, Map.of("1", tid));
+      balance(balancer, maxMigrations);
     }
 
-    public void balance(TabletBalancer balancer, int maxMigrations,
-        Map<String,TableId> tablesToBalance) {
+    public void balance(TabletBalancer balancer, int maxMigrations) {
 
       while (true) {
         Set<TabletId> migrations = new HashSet<>();
@@ -121,11 +116,10 @@ public class GroupBalancerTest {
 
         for (TabletServerId tsi : tservers) {
           current.put(tsi, new TServerStatusImpl(
-              new org.apache.accumulo.core.master.thrift.TabletServerStatus()));
+              new org.apache.accumulo.core.manager.thrift.TabletServerStatus()));
         }
 
-        balancer.balance(new BalanceParamsImpl(current, migrations, migrationsOut,
-            DataLevel.USER.name(), tablesToBalance));
+        balancer.balance(new BalanceParamsImpl(current, migrations, migrationsOut));
 
         assertTrue(migrationsOut.size() <= (maxMigrations + 5),
             "Max Migration exceeded " + maxMigrations + " " + migrationsOut.size());
@@ -330,8 +324,8 @@ public class GroupBalancerTest {
 
     for (int g = 1; g <= 60; g++) {
       for (int t = 1; t <= 241; t++) {
-        tservers.addTablet(String.format("%02d:%d", g, t), "192.168.1." + (random.nextInt(249) + 1),
-            9997);
+        tservers.addTablet(String.format("%02d:%d", g, t),
+            "192.168.1." + (RANDOM.get().nextInt(249) + 1), 9997);
       }
     }
 
@@ -347,9 +341,9 @@ public class GroupBalancerTest {
     TabletServers tservers = new TabletServers();
 
     for (int g = 1; g <= 60; g++) {
-      for (int t = 1; t <= random.nextInt(1000); t++) {
-        tservers.addTablet(String.format("%02d:%d", g, t), "192.168.1." + (random.nextInt(249) + 1),
-            9997);
+      for (int t = 1; t <= RANDOM.get().nextInt(1000); t++) {
+        tservers.addTablet(String.format("%02d:%d", g, t),
+            "192.168.1." + (RANDOM.get().nextInt(249) + 1), 9997);
       }
     }
 
