@@ -48,13 +48,13 @@ import org.apache.accumulo.core.manager.balancer.AssignmentParamsImpl;
 import org.apache.accumulo.core.manager.balancer.BalanceParamsImpl;
 import org.apache.accumulo.core.manager.balancer.TabletServerIdImpl;
 import org.apache.accumulo.core.manager.balancer.TabletStatisticsImpl;
-import org.apache.accumulo.core.metadata.schema.Ample.DataLevel;
 import org.apache.accumulo.core.spi.balancer.data.TServerStatus;
 import org.apache.accumulo.core.spi.balancer.data.TabletMigration;
 import org.apache.accumulo.core.spi.balancer.data.TabletServerId;
 import org.apache.accumulo.core.spi.balancer.data.TabletStatistics;
 import org.apache.accumulo.core.tabletserver.thrift.TabletStats;
 import org.apache.accumulo.core.util.ConfigurationImpl;
+import org.apache.accumulo.core.util.UtilWaitThread;
 import org.junit.jupiter.api.Test;
 
 public class HostRegexTableLoadBalancerTest extends BaseHostRegexTableLoadBalancerTest {
@@ -98,7 +98,7 @@ public class HostRegexTableLoadBalancerTest extends BaseHostRegexTableLoadBalanc
     List<TabletMigration> migrationsOut = new ArrayList<>();
     long wait =
         this.balance(new BalanceParamsImpl(Collections.unmodifiableSortedMap(createCurrent(15)),
-            migrations, migrationsOut, DataLevel.USER.name(), environment.getTableIdMap()));
+            migrations, migrationsOut));
     assertEquals(20000, wait);
     // should balance four tablets in one of the tables before reaching max
     assertEquals(4, migrationsOut.size());
@@ -109,7 +109,7 @@ public class HostRegexTableLoadBalancerTest extends BaseHostRegexTableLoadBalanc
     }
     migrationsOut.clear();
     wait = this.balance(new BalanceParamsImpl(Collections.unmodifiableSortedMap(createCurrent(15)),
-        migrations, migrationsOut, DataLevel.USER.name(), environment.getTableIdMap()));
+        migrations, migrationsOut));
     assertEquals(20000, wait);
     // should balance four tablets in one of the other tables before reaching max
     assertEquals(4, migrationsOut.size());
@@ -120,7 +120,7 @@ public class HostRegexTableLoadBalancerTest extends BaseHostRegexTableLoadBalanc
     }
     migrationsOut.clear();
     wait = this.balance(new BalanceParamsImpl(Collections.unmodifiableSortedMap(createCurrent(15)),
-        migrations, migrationsOut, DataLevel.USER.name(), environment.getTableIdMap()));
+        migrations, migrationsOut));
     assertEquals(20000, wait);
     // should balance four tablets in one of the other tables before reaching max
     assertEquals(4, migrationsOut.size());
@@ -131,7 +131,7 @@ public class HostRegexTableLoadBalancerTest extends BaseHostRegexTableLoadBalanc
     }
     migrationsOut.clear();
     wait = this.balance(new BalanceParamsImpl(Collections.unmodifiableSortedMap(createCurrent(15)),
-        migrations, migrationsOut, DataLevel.USER.name(), environment.getTableIdMap()));
+        migrations, migrationsOut));
     assertEquals(20000, wait);
     // no more balancing to do
     assertEquals(0, migrationsOut.size());
@@ -148,7 +148,7 @@ public class HostRegexTableLoadBalancerTest extends BaseHostRegexTableLoadBalanc
     migrations.addAll(tableTablets.get(BAR.getTableName()));
     long wait =
         this.balance(new BalanceParamsImpl(Collections.unmodifiableSortedMap(createCurrent(15)),
-            migrations, migrationsOut, DataLevel.USER.name(), environment.getTableIdMap()));
+            migrations, migrationsOut));
     assertEquals(20000, wait);
     // no migrations should have occurred as 10 is the maxOutstandingMigrations
     assertEquals(0, migrationsOut.size());
@@ -186,7 +186,6 @@ public class HostRegexTableLoadBalancerTest extends BaseHostRegexTableLoadBalanc
         barHosts.containsKey(new TabletServerIdImpl("192.168.0.9", 9997, Integer.toHexString(1))));
     assertTrue(
         barHosts.containsKey(new TabletServerIdImpl("192.168.0.10", 9997, Integer.toHexString(1))));
-    // confirms that the default pool contains un-assigned tservers
     assertTrue(groups.containsKey(DEFAULT_POOL));
     SortedMap<TabletServerId,TServerStatus> defHosts = groups.get(DEFAULT_POOL);
     assertEquals(5, defHosts.size());
@@ -202,179 +201,6 @@ public class HostRegexTableLoadBalancerTest extends BaseHostRegexTableLoadBalanc
         defHosts.containsKey(new TabletServerIdImpl("192.168.0.15", 9997, Integer.toHexString(1))));
   }
 
-  @Test
-  public void testDefaultPoolAll() {
-    // If all tservers are included in regular expressions, the the default pool
-    // contains all tservers
-    HashMap<String,String> props = new HashMap<>(DEFAULT_TABLE_PROPERTIES);
-    props.put(HostRegexTableLoadBalancer.HOST_BALANCER_PREFIX + FOO.getTableName(), "r01.*");
-    props.put(HostRegexTableLoadBalancer.HOST_BALANCER_PREFIX + BAR.getTableName(), "r02.*");
-    props.put(HostRegexTableLoadBalancer.HOST_BALANCER_PREFIX + BAZ.getTableName(), "r03.*");
-    init(props);
-    Map<String,SortedMap<TabletServerId,TServerStatus>> groups =
-        this.splitCurrentByRegex(createCurrent(15));
-    assertEquals(4, groups.size());
-    assertTrue(groups.containsKey(FOO.getTableName()));
-    SortedMap<TabletServerId,TServerStatus> fooHosts = groups.get(FOO.getTableName());
-    assertEquals(5, fooHosts.size());
-    assertTrue(
-        fooHosts.containsKey(new TabletServerIdImpl("192.168.0.1", 9997, Integer.toHexString(1))));
-    assertTrue(
-        fooHosts.containsKey(new TabletServerIdImpl("192.168.0.2", 9997, Integer.toHexString(1))));
-    assertTrue(
-        fooHosts.containsKey(new TabletServerIdImpl("192.168.0.3", 9997, Integer.toHexString(1))));
-    assertTrue(
-        fooHosts.containsKey(new TabletServerIdImpl("192.168.0.4", 9997, Integer.toHexString(1))));
-    assertTrue(
-        fooHosts.containsKey(new TabletServerIdImpl("192.168.0.5", 9997, Integer.toHexString(1))));
-    assertTrue(groups.containsKey(BAR.getTableName()));
-    SortedMap<TabletServerId,TServerStatus> barHosts = groups.get(BAR.getTableName());
-    assertEquals(5, barHosts.size());
-    assertTrue(
-        barHosts.containsKey(new TabletServerIdImpl("192.168.0.6", 9997, Integer.toHexString(1))));
-    assertTrue(
-        barHosts.containsKey(new TabletServerIdImpl("192.168.0.7", 9997, Integer.toHexString(1))));
-    assertTrue(
-        barHosts.containsKey(new TabletServerIdImpl("192.168.0.8", 9997, Integer.toHexString(1))));
-    assertTrue(
-        barHosts.containsKey(new TabletServerIdImpl("192.168.0.9", 9997, Integer.toHexString(1))));
-    assertTrue(
-        barHosts.containsKey(new TabletServerIdImpl("192.168.0.10", 9997, Integer.toHexString(1))));
-    assertTrue(groups.containsKey(BAZ.getTableName()));
-    SortedMap<TabletServerId,TServerStatus> bazHosts = groups.get(BAZ.getTableName());
-    assertEquals(5, bazHosts.size());
-    assertTrue(
-        bazHosts.containsKey(new TabletServerIdImpl("192.168.0.11", 9997, Integer.toHexString(1))));
-    assertTrue(
-        bazHosts.containsKey(new TabletServerIdImpl("192.168.0.12", 9997, Integer.toHexString(1))));
-    assertTrue(
-        bazHosts.containsKey(new TabletServerIdImpl("192.168.0.13", 9997, Integer.toHexString(1))));
-    assertTrue(
-        bazHosts.containsKey(new TabletServerIdImpl("192.168.0.14", 9997, Integer.toHexString(1))));
-    assertTrue(
-        bazHosts.containsKey(new TabletServerIdImpl("192.168.0.15", 9997, Integer.toHexString(1))));
-    assertTrue(groups.containsKey(DEFAULT_POOL));
-    SortedMap<TabletServerId,TServerStatus> defHosts = groups.get(DEFAULT_POOL);
-    assertEquals(15, defHosts.size());
-  }
-
-  @Test
-  public void testSplitCurrentByRegexDefineDefaultPoolOverlapping() {
-    HashMap<String,String> props = new HashMap<>(DEFAULT_TABLE_PROPERTIES);
-    props.put(HostRegexTableLoadBalancer.HOST_BALANCER_PREFIX + FOO.getTableName(), "r01.*");
-    props.put(HostRegexTableLoadBalancer.HOST_BALANCER_PREFIX + BAR.getTableName(), "r02.*");
-    // Normally the DEFAULT pool would be comprised of the hosts not included in a regex.
-    // Here we are going to define it as also being on rack1
-    props.put(HostRegexTableLoadBalancer.HOST_BALANCER_PREFIX + DEFAULT_POOL, "r01.*");
-    init(props);
-    Map<String,SortedMap<TabletServerId,TServerStatus>> groups =
-        this.splitCurrentByRegex(createCurrent(15));
-    assertEquals(3, groups.size());
-    assertTrue(groups.containsKey(FOO.getTableName()));
-    SortedMap<TabletServerId,TServerStatus> fooHosts = groups.get(FOO.getTableName());
-    assertEquals(5, fooHosts.size());
-    assertTrue(
-        fooHosts.containsKey(new TabletServerIdImpl("192.168.0.1", 9997, Integer.toHexString(1))));
-    assertTrue(
-        fooHosts.containsKey(new TabletServerIdImpl("192.168.0.2", 9997, Integer.toHexString(1))));
-    assertTrue(
-        fooHosts.containsKey(new TabletServerIdImpl("192.168.0.3", 9997, Integer.toHexString(1))));
-    assertTrue(
-        fooHosts.containsKey(new TabletServerIdImpl("192.168.0.4", 9997, Integer.toHexString(1))));
-    assertTrue(
-        fooHosts.containsKey(new TabletServerIdImpl("192.168.0.5", 9997, Integer.toHexString(1))));
-    assertTrue(groups.containsKey(BAR.getTableName()));
-    SortedMap<TabletServerId,TServerStatus> barHosts = groups.get(BAR.getTableName());
-    assertEquals(5, barHosts.size());
-    assertTrue(
-        barHosts.containsKey(new TabletServerIdImpl("192.168.0.6", 9997, Integer.toHexString(1))));
-    assertTrue(
-        barHosts.containsKey(new TabletServerIdImpl("192.168.0.7", 9997, Integer.toHexString(1))));
-    assertTrue(
-        barHosts.containsKey(new TabletServerIdImpl("192.168.0.8", 9997, Integer.toHexString(1))));
-    assertTrue(
-        barHosts.containsKey(new TabletServerIdImpl("192.168.0.9", 9997, Integer.toHexString(1))));
-    assertTrue(
-        barHosts.containsKey(new TabletServerIdImpl("192.168.0.10", 9997, Integer.toHexString(1))));
-    assertTrue(groups.containsKey(DEFAULT_POOL));
-    SortedMap<TabletServerId,TServerStatus> defHosts = groups.get(DEFAULT_POOL);
-    assertEquals(10, defHosts.size());
-    assertTrue(
-        defHosts.containsKey(new TabletServerIdImpl("192.168.0.1", 9997, Integer.toHexString(1))));
-    assertTrue(
-        defHosts.containsKey(new TabletServerIdImpl("192.168.0.2", 9997, Integer.toHexString(1))));
-    assertTrue(
-        defHosts.containsKey(new TabletServerIdImpl("192.168.0.3", 9997, Integer.toHexString(1))));
-    assertTrue(
-        defHosts.containsKey(new TabletServerIdImpl("192.168.0.4", 9997, Integer.toHexString(1))));
-    assertTrue(
-        defHosts.containsKey(new TabletServerIdImpl("192.168.0.5", 9997, Integer.toHexString(1))));
-    assertTrue(
-        defHosts.containsKey(new TabletServerIdImpl("192.168.0.11", 9997, Integer.toHexString(1))));
-    assertTrue(
-        defHosts.containsKey(new TabletServerIdImpl("192.168.0.12", 9997, Integer.toHexString(1))));
-    assertTrue(
-        defHosts.containsKey(new TabletServerIdImpl("192.168.0.13", 9997, Integer.toHexString(1))));
-    assertTrue(
-        defHosts.containsKey(new TabletServerIdImpl("192.168.0.14", 9997, Integer.toHexString(1))));
-    assertTrue(
-        defHosts.containsKey(new TabletServerIdImpl("192.168.0.15", 9997, Integer.toHexString(1))));
-  }
-
-  @Test
-  public void testSplitCurrentByRegexDefineDefaultPoolNonOverlapping() {
-    HashMap<String,String> props = new HashMap<>(DEFAULT_TABLE_PROPERTIES);
-    props.put(HostRegexTableLoadBalancer.HOST_BALANCER_PREFIX + FOO.getTableName(), "r01.*");
-    props.put(HostRegexTableLoadBalancer.HOST_BALANCER_PREFIX + BAR.getTableName(), "r02.*");
-    // Normally the DEFAULT pool would be comprised of the hosts not included in a regex.
-    // Here we are going to define it as also being on rack3
-    props.put(HostRegexTableLoadBalancer.HOST_BALANCER_PREFIX + DEFAULT_POOL, "r03.*");
-    init(props);
-    Map<String,SortedMap<TabletServerId,TServerStatus>> groups =
-        this.splitCurrentByRegex(createCurrent(15));
-    assertEquals(3, groups.size());
-    assertTrue(groups.containsKey(FOO.getTableName()));
-    SortedMap<TabletServerId,TServerStatus> fooHosts = groups.get(FOO.getTableName());
-    assertEquals(5, fooHosts.size());
-    assertTrue(
-        fooHosts.containsKey(new TabletServerIdImpl("192.168.0.1", 9997, Integer.toHexString(1))));
-    assertTrue(
-        fooHosts.containsKey(new TabletServerIdImpl("192.168.0.2", 9997, Integer.toHexString(1))));
-    assertTrue(
-        fooHosts.containsKey(new TabletServerIdImpl("192.168.0.3", 9997, Integer.toHexString(1))));
-    assertTrue(
-        fooHosts.containsKey(new TabletServerIdImpl("192.168.0.4", 9997, Integer.toHexString(1))));
-    assertTrue(
-        fooHosts.containsKey(new TabletServerIdImpl("192.168.0.5", 9997, Integer.toHexString(1))));
-    assertTrue(groups.containsKey(BAR.getTableName()));
-    SortedMap<TabletServerId,TServerStatus> barHosts = groups.get(BAR.getTableName());
-    assertEquals(5, barHosts.size());
-    assertTrue(
-        barHosts.containsKey(new TabletServerIdImpl("192.168.0.6", 9997, Integer.toHexString(1))));
-    assertTrue(
-        barHosts.containsKey(new TabletServerIdImpl("192.168.0.7", 9997, Integer.toHexString(1))));
-    assertTrue(
-        barHosts.containsKey(new TabletServerIdImpl("192.168.0.8", 9997, Integer.toHexString(1))));
-    assertTrue(
-        barHosts.containsKey(new TabletServerIdImpl("192.168.0.9", 9997, Integer.toHexString(1))));
-    assertTrue(
-        barHosts.containsKey(new TabletServerIdImpl("192.168.0.10", 9997, Integer.toHexString(1))));
-    assertTrue(groups.containsKey(DEFAULT_POOL));
-    SortedMap<TabletServerId,TServerStatus> defHosts = groups.get(DEFAULT_POOL);
-    assertEquals(5, defHosts.size());
-    assertTrue(
-        defHosts.containsKey(new TabletServerIdImpl("192.168.0.11", 9997, Integer.toHexString(1))));
-    assertTrue(
-        defHosts.containsKey(new TabletServerIdImpl("192.168.0.12", 9997, Integer.toHexString(1))));
-    assertTrue(
-        defHosts.containsKey(new TabletServerIdImpl("192.168.0.13", 9997, Integer.toHexString(1))));
-    assertTrue(
-        defHosts.containsKey(new TabletServerIdImpl("192.168.0.14", 9997, Integer.toHexString(1))));
-    assertTrue(
-        defHosts.containsKey(new TabletServerIdImpl("192.168.0.15", 9997, Integer.toHexString(1))));
-
-  }
-
   @Test
   public void testSplitCurrentByRegexUsingOverlappingPools() {
     HashMap<String,String> props = new HashMap<>(DEFAULT_TABLE_PROPERTIES);
@@ -661,16 +487,13 @@ public class HostRegexTableLoadBalancerTest extends BaseHostRegexTableLoadBalanc
 
   @Test
   public void testOutOfBoundsTablets() {
-    // calls to balance will clear the lastOOBCheckTimes map
-    // in the HostRegexTableLoadBalancer. For this test we want
-    // to get into the out of bounds checking code, so we need to
-    // populate the map with an older time value
-    this.lastOOBCheckTimes.put(DataLevel.USER.name(), System.currentTimeMillis() / 2);
     init(DEFAULT_TABLE_PROPERTIES);
+    // Wait to trigger the out of bounds check which will call our version of
+    // getOnlineTabletsForTable
+    UtilWaitThread.sleep(11000);
     Set<TabletId> migrations = new HashSet<>();
     List<TabletMigration> migrationsOut = new ArrayList<>();
-    this.balance(new BalanceParamsImpl(createCurrent(15), migrations, migrationsOut,
-        DataLevel.USER.name(), environment.getTableIdMap()));
+    this.balance(new BalanceParamsImpl(createCurrent(15), migrations, migrationsOut));
     assertEquals(2, migrationsOut.size());
   }
 
@@ -682,8 +505,8 @@ public class HostRegexTableLoadBalancerTest extends BaseHostRegexTableLoadBalanc
       // Report that we have a bar tablet on this server
       TKeyExtent tke = new TKeyExtent();
       tke.setTable(BAR.getId().canonical().getBytes(UTF_8));
-      tke.setEndRow("11".getBytes(UTF_8));
-      tke.setPrevEndRow("10".getBytes(UTF_8));
+      tke.setEndRow("11".getBytes());
+      tke.setPrevEndRow("10".getBytes());
       TabletStats tstats = new TabletStats();
       tstats.setExtent(tke);
       TabletStatistics ts = new TabletStatisticsImpl(tstats);
@@ -692,8 +515,8 @@ public class HostRegexTableLoadBalancerTest extends BaseHostRegexTableLoadBalanc
       // Report that we have a foo tablet on this server
       TKeyExtent tke = new TKeyExtent();
       tke.setTable(FOO.getId().canonical().getBytes(UTF_8));
-      tke.setEndRow("1".getBytes(UTF_8));
-      tke.setPrevEndRow("0".getBytes(UTF_8));
+      tke.setEndRow("1".getBytes());
+      tke.setPrevEndRow("0".getBytes());
       TabletStats tstats = new TabletStats();
       tstats.setExtent(tke);
       TabletStatistics ts = new TabletStatisticsImpl(tstats);
