@@ -18,21 +18,18 @@
  */
 package org.apache.accumulo.core.spi.scan;
 
+import static org.apache.accumulo.core.util.LazySingletons.RANDOM;
 import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertNull;
 import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 
-import java.security.SecureRandom;
 import java.time.Duration;
 import java.util.Collection;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Map;
-import java.util.Optional;
 import java.util.Set;
-import java.util.concurrent.atomic.AtomicReference;
 import java.util.function.Supplier;
 import java.util.stream.Collectors;
 import java.util.stream.Stream;
@@ -42,7 +39,6 @@ import org.apache.accumulo.core.data.TabletId;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.dataImpl.TabletIdImpl;
 import org.apache.accumulo.core.spi.common.ServiceEnvironment;
-import org.apache.accumulo.core.util.UtilWaitThread;
 import org.apache.hadoop.io.Text;
 import org.junit.jupiter.api.Test;
 
@@ -51,7 +47,7 @@ public class ConfigurableScanServerSelectorTest {
   static class InitParams implements ScanServerSelector.InitParameters {
 
     private final Map<String,String> opts;
-    private final Supplier<Map<String,String>> scanServers;
+    private final Map<String,String> scanServers;
 
     InitParams(Set<String> scanServers) {
       this(scanServers, Map.of());
@@ -59,18 +55,12 @@ public class ConfigurableScanServerSelectorTest {
 
     InitParams(Set<String> scanServers, Map<String,String> opts) {
       this.opts = opts;
-      var scanServersMap = new HashMap<String,String>();
+      this.scanServers = new HashMap<>();
       scanServers.forEach(
-          sserv -> scanServersMap.put(sserv, ScanServerSelector.DEFAULT_SCAN_SERVER_GROUP_NAME));
-      this.scanServers = () -> scanServersMap;
+          sserv -> this.scanServers.put(sserv, ScanServerSelector.DEFAULT_SCAN_SERVER_GROUP_NAME));
     }
 
     InitParams(Map<String,String> scanServers, Map<String,String> opts) {
-      this.opts = opts;
-      this.scanServers = () -> scanServers;
-    }
-
-    InitParams(Supplier<Map<String,String>> scanServers, Map<String,String> opts) {
       this.opts = opts;
       this.scanServers = scanServers;
     }
@@ -87,7 +77,7 @@ public class ConfigurableScanServerSelectorTest {
 
     @Override
     public Supplier<Collection<ScanServerInfo>> getScanServers() {
-      return () -> scanServers.get().entrySet().stream().map(entry -> new ScanServerInfo() {
+      return () -> scanServers.entrySet().stream().map(entry -> new ScanServerInfo() {
 
         @Override
         public String getAddress() {
@@ -103,19 +93,19 @@ public class ConfigurableScanServerSelectorTest {
     }
   }
 
-  static class SelectorParams implements ScanServerSelector.SelectorParameters {
+  static class DaParams implements ScanServerSelector.SelectorParameters {
 
     private final Collection<TabletId> tablets;
     private final Map<TabletId,Collection<? extends ScanServerAttempt>> attempts;
     private final Map<String,String> hints;
 
-    SelectorParams(TabletId tablet) {
+    DaParams(TabletId tablet) {
       this.tablets = Set.of(tablet);
       this.attempts = Map.of();
       this.hints = Map.of();
     }
 
-    SelectorParams(TabletId tablet, Map<TabletId,Collection<? extends ScanServerAttempt>> attempts,
+    DaParams(TabletId tablet, Map<TabletId,Collection<? extends ScanServerAttempt>> attempts,
         Map<String,String> hints) {
       this.tablets = Set.of(tablet);
       this.attempts = attempts;
@@ -136,13 +126,6 @@ public class ConfigurableScanServerSelectorTest {
     public Map<String,String> getHints() {
       return hints;
     }
-
-    @Override
-    public <T> Optional<T> waitUntil(Supplier<Optional<T>> condition, Duration maxWaitTime,
-        String description) {
-      throw new UnsupportedOperationException();
-    }
-
   }
 
   static class TestScanServerAttempt implements ScanServerAttempt {
@@ -182,7 +165,7 @@ public class ConfigurableScanServerSelectorTest {
     for (int i = 0; i < 100; i++) {
       var tabletId = nti("1", "m");
 
-      ScanServerSelections actions = selector.selectServers(new SelectorParams(tabletId));
+      ScanServerSelections actions = selector.selectServers(new DaParams(tabletId));
 
       servers.add(actions.getScanServer(tabletId));
     }
@@ -222,7 +205,7 @@ public class ConfigurableScanServerSelectorTest {
 
     for (int i = 0; i < 100 * numServers; i++) {
       ScanServerSelections actions =
-          selector.selectServers(new SelectorParams(tabletId, attempts, hints));
+          selector.selectServers(new DaParams(tabletId, attempts, hints));
 
       assertEquals(expectedBusyTimeout, actions.getBusyTimeout().toMillis());
       assertEquals(0, actions.getDelay().toMillis());
@@ -270,17 +253,16 @@ public class ConfigurableScanServerSelectorTest {
 
     Map<String,Long> allServersSeen = new HashMap<>();
 
-    SecureRandom rand = new SecureRandom();
-
     for (int t = 0; t < 10000; t++) {
       Set<String> serversSeen = new HashSet<>();
 
-      String endRow = Long.toString(Math.abs(Math.max(rand.nextLong(), Long.MIN_VALUE + 1)), 36);
+      String endRow =
+          Long.toString(Math.abs(Math.max(RANDOM.get().nextLong(), Long.MIN_VALUE + 1)), 36);
 
       var tabletId = t % 1000 == 0 ? nti("" + t, null) : nti("" + t, endRow);
 
       for (int i = 0; i < 100; i++) {
-        ScanServerSelections actions = selector.selectServers(new SelectorParams(tabletId));
+        ScanServerSelections actions = selector.selectServers(new DaParams(tabletId));
         serversSeen.add(actions.getScanServer(tabletId));
         allServersSeen.merge(actions.getScanServer(tabletId), 1L, Long::sum);
       }
@@ -396,7 +378,7 @@ public class ConfigurableScanServerSelectorTest {
     selector.init(new InitParams(Set.of()));
 
     var tabletId = nti("1", "m");
-    ScanServerSelections actions = selector.selectServers(new SelectorParams(tabletId));
+    ScanServerSelections actions = selector.selectServers(new DaParams(tabletId));
     assertNull(actions.getScanServer(tabletId));
     assertEquals(Duration.ZERO, actions.getDelay());
     assertEquals(Duration.ZERO, actions.getBusyTimeout());
@@ -429,7 +411,7 @@ public class ConfigurableScanServerSelectorTest {
     for (int i = 0; i < 1000; i++) {
       var tabletId = nti("1", "m" + i);
 
-      ScanServerSelections actions = selector.selectServers(new SelectorParams(tabletId));
+      ScanServerSelections actions = selector.selectServers(new DaParams(tabletId));
 
       servers.add(actions.getScanServer(tabletId));
     }
@@ -445,7 +427,7 @@ public class ConfigurableScanServerSelectorTest {
       var tabletId = nti("1", "m" + i);
 
       ScanServerSelections actions =
-          selector.selectServers(new SelectorParams(tabletId, Map.of(), hints));
+          selector.selectServers(new DaParams(tabletId, Map.of(), hints));
 
       servers.add(actions.getScanServer(tabletId));
     }
@@ -461,7 +443,7 @@ public class ConfigurableScanServerSelectorTest {
       var tabletId = nti("1", "m" + i);
 
       ScanServerSelections actions =
-          selector.selectServers(new SelectorParams(tabletId, Map.of(), hints));
+          selector.selectServers(new DaParams(tabletId, Map.of(), hints));
 
       servers.add(actions.getScanServer(tabletId));
     }
@@ -477,56 +459,11 @@ public class ConfigurableScanServerSelectorTest {
       var tabletId = nti("1", "m" + i);
 
       ScanServerSelections actions =
-          selector.selectServers(new SelectorParams(tabletId, Map.of(), hints));
+          selector.selectServers(new DaParams(tabletId, Map.of(), hints));
 
       servers.add(actions.getScanServer(tabletId));
     }
 
     assertEquals(Set.of("ss1:1", "ss2:2", "ss3:3"), servers);
   }
-
-  @Test
-  public void testWaitForScanServers() {
-    // this test ensures that when there are no scan servers that the ConfigurableScanServerSelector
-    // will wait for scan servers
-
-    String defaultProfile =
-        "{'isDefault':true,'maxBusyTimeout':'5m','busyTimeoutMultiplier':4,'timeToWaitForScanServers':'120s',"
-            + "'attemptPlans':[{'servers':'100%', 'busyTimeout':'60s'}]}";
-
-    var opts = Map.of("profiles", "[" + defaultProfile + "]".replace('\'', '"'));
-
-    ConfigurableScanServerSelector selector = new ConfigurableScanServerSelector();
-
-    AtomicReference<Map<String,String>> scanServers = new AtomicReference<>(Map.of());
-
-    selector.init(new InitParams(scanServers::get, opts));
-
-    var tabletId = nti("1", "m");
-
-    var dg = ScanServerSelector.DEFAULT_SCAN_SERVER_GROUP_NAME;
-
-    var params = new SelectorParams(tabletId, Map.of(), Map.of()) {
-      @Override
-      public <T> Optional<T> waitUntil(Supplier<Optional<T>> condition, Duration maxWaitTime,
-          String description) {
-        // make some scan servers available now that wait was called
-        scanServers.set(Map.of("ss1:1", dg, "ss2:2", dg, "ss3:3", dg));
-
-        Optional<T> optional = condition.get();
-
-        while (optional.isEmpty()) {
-          UtilWaitThread.sleep(10);
-          optional = condition.get();
-        }
-
-        return optional;
-      }
-    };
-
-    ScanServerSelections actions = selector.selectServers(params);
-
-    assertTrue(Set.of("ss1:1", "ss2:2", "ss3:3").contains(actions.getScanServer(tabletId)));
-    assertFalse(scanServers.get().isEmpty());
-  }
 }
