@@ -18,11 +18,11 @@
  */
 package org.apache.accumulo.hadoopImpl.mapred;
 
-import static org.apache.accumulo.core.util.UtilWaitThread.sleepUninterruptibly;
+import static com.google.common.util.concurrent.Uninterruptibles.sleepUninterruptibly;
+import static org.apache.accumulo.core.util.LazySingletons.RANDOM;
 
 import java.io.IOException;
 import java.net.InetAddress;
-import java.security.SecureRandom;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.HashMap;
@@ -72,7 +72,6 @@ import org.slf4j.LoggerFactory;
  */
 public abstract class AccumuloRecordReader<K,V> implements RecordReader<K,V> {
 
-  private static final SecureRandom random = new SecureRandom();
   // class to serialize configuration under in the job
   private final Class<?> CLASS;
   private static final Logger log = LoggerFactory.getLogger(AccumuloRecordReader.class);
@@ -195,9 +194,7 @@ public abstract class AccumuloRecordReader<K,V> implements RecordReader<K,V> {
         }
         if (isIsolated) {
           log.info("Creating isolated scanner");
-          @SuppressWarnings("resource")
-          var wrapped = new IsolatedScanner(scanner);
-          scanner = wrapped;
+          scanner = new IsolatedScanner(scanner);
         }
         if (usesLocalIterators) {
           log.info("Using local iterators");
@@ -339,7 +336,7 @@ public abstract class AccumuloRecordReader<K,V> implements RecordReader<K,V> {
             while (binnedRanges == null) {
               // Some tablets were still online, try again
               // sleep randomly between 100 and 200 ms
-              sleepUninterruptibly(100 + random.nextInt(100), TimeUnit.MILLISECONDS);
+              sleepUninterruptibly(100 + RANDOM.get().nextInt(100), TimeUnit.MILLISECONDS);
               binnedRanges = binOfflineTable(job, tableId, ranges, callingClass);
             }
           } else {
@@ -355,7 +352,7 @@ public abstract class AccumuloRecordReader<K,V> implements RecordReader<K,V> {
               binnedRanges.clear();
               log.warn("Unable to locate bins for specified ranges. Retrying.");
               // sleep randomly between 100 and 200 ms
-              sleepUninterruptibly(100 + random.nextInt(100), TimeUnit.MILLISECONDS);
+              sleepUninterruptibly(100 + RANDOM.get().nextInt(100), TimeUnit.MILLISECONDS);
               tl.invalidateCache();
             }
           }
