@@ -18,7 +18,6 @@
  */
 package org.apache.accumulo.hadoop.its.mapred;
 
-import static java.nio.charset.StandardCharsets.UTF_8;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertNull;
 import static org.junit.jupiter.api.Assertions.fail;
@@ -76,13 +75,13 @@ public class AccumuloRowInputFormatIT extends AccumuloClusterHarness {
   @BeforeAll
   public static void prepareRows() {
     row1 = new ArrayList<>();
-    row1.add(new KeyValue(new Key(ROW1, COLF1, "colq1"), "v1".getBytes(UTF_8)));
-    row1.add(new KeyValue(new Key(ROW1, COLF1, "colq2"), "v2".getBytes(UTF_8)));
-    row1.add(new KeyValue(new Key(ROW1, "colf2", "colq3"), "v3".getBytes(UTF_8)));
+    row1.add(new KeyValue(new Key(ROW1, COLF1, "colq1"), "v1".getBytes()));
+    row1.add(new KeyValue(new Key(ROW1, COLF1, "colq2"), "v2".getBytes()));
+    row1.add(new KeyValue(new Key(ROW1, "colf2", "colq3"), "v3".getBytes()));
     row2 = new ArrayList<>();
-    row2.add(new KeyValue(new Key(ROW2, COLF1, "colq4"), "v4".getBytes(UTF_8)));
+    row2.add(new KeyValue(new Key(ROW2, COLF1, "colq4"), "v4".getBytes()));
     row3 = new ArrayList<>();
-    row3.add(new KeyValue(new Key(ROW3, COLF1, "colq5"), "v5".getBytes(UTF_8)));
+    row3.add(new KeyValue(new Key(ROW3, COLF1, "colq5"), "v5".getBytes()));
   }
 
   private static void checkLists(final List<Entry<Key,Value>> first,
