@@ -19,8 +19,6 @@
 package org.apache.accumulo.hadoop.its.mapreduce;
 
 import static java.lang.System.currentTimeMillis;
-import static java.nio.charset.StandardCharsets.UTF_8;
-import static org.apache.accumulo.core.util.UtilWaitThread.sleepUninterruptibly;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
 import static org.junit.jupiter.api.Assertions.assertThrows;
@@ -34,7 +32,6 @@ import java.util.Collection;
 import java.util.Collections;
 import java.util.List;
 import java.util.TreeSet;
-import java.util.concurrent.TimeUnit;
 
 import org.apache.accumulo.core.client.Accumulo;
 import org.apache.accumulo.core.client.AccumuloClient;
@@ -126,7 +123,7 @@ public class AccumuloInputFormatIT extends AccumuloClusterHarness {
       splitsToAdd.add(new Text(String.format("%09d", i)));
     }
     client.tableOperations().addSplits(table, splitsToAdd);
-    sleepUninterruptibly(500, TimeUnit.MILLISECONDS); // wait for splits to be propagated
+    Thread.sleep(500); // wait for splits to be propagated
 
     // get splits without setting any range
     // No ranges set on the job so it'll start with -inf
@@ -206,7 +203,7 @@ public class AccumuloInputFormatIT extends AccumuloClusterHarness {
     // Check we are getting back correct type pf split
     splits = inputFormat.getSplits(job);
     for (InputSplit split : splits) {
-      assertTrue(split instanceof BatchInputSplit);
+      assert (split instanceof BatchInputSplit);
     }
 
     // We should split along the tablet lines
@@ -244,10 +241,10 @@ public class AccumuloInputFormatIT extends AccumuloClusterHarness {
         assertNotNull(table);
         try {
           if (key != null) {
-            assertEquals(key.getRow().toString(), new String(v.get(), UTF_8));
+            assertEquals(key.getRow().toString(), new String(v.get()));
           }
           assertEquals(k.getRow(), new Text(String.format("%09x", count + 1)));
-          assertEquals(new String(v.get(), UTF_8), String.format("%09x", count));
+          assertEquals(new String(v.get()), String.format("%09x", count));
         } catch (AssertionError e) {
           assertionErrors.put(table + "_map", e);
         }
