@@ -18,6 +18,7 @@
  */
 package org.apache.accumulo.cluster.standalone;
 
+import static com.google.common.base.Preconditions.checkArgument;
 import static java.nio.charset.StandardCharsets.UTF_8;
 import static java.util.Objects.requireNonNull;
 
@@ -39,7 +40,6 @@ import org.apache.accumulo.core.manager.thrift.ManagerGoalState;
 import org.apache.accumulo.manager.state.SetGoalState;
 import org.apache.accumulo.minicluster.ServerType;
 import org.apache.accumulo.server.util.Admin;
-import org.apache.accumulo.tserver.ScanServer;
 import org.apache.hadoop.util.Shell.ExitCodeException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -149,7 +149,7 @@ public class StandaloneClusterControl implements ClusterControl {
    */
   public void setGoalState(String goalState) throws IOException {
     requireNonNull(goalState, "Goal state must not be null");
-    ManagerGoalState.valueOf(goalState);
+    checkArgument(ManagerGoalState.valueOf(goalState) != null, "Unknown goal state: " + goalState);
     String manager = getHosts(MANAGER_HOSTS_FILE).get(0);
     String[] cmd = {serverCmdPrefix, accumuloPath, SetGoalState.class.getName(), goalState};
     Entry<Integer,String> pair = exec(manager, cmd);
@@ -160,7 +160,6 @@ public class StandaloneClusterControl implements ClusterControl {
   }
 
   @Override
-  @SuppressWarnings("removal")
   public void startAllServers(ServerType server) throws IOException {
     switch (server) {
       case TABLET_SERVER:
@@ -168,7 +167,6 @@ public class StandaloneClusterControl implements ClusterControl {
           start(server, tserver);
         }
         break;
-      case MASTER:
       case MANAGER:
         for (String manager : getHosts(MANAGER_HOSTS_FILE)) {
           start(server, manager);
@@ -209,7 +207,6 @@ public class StandaloneClusterControl implements ClusterControl {
   }
 
   @Override
-  @SuppressWarnings("removal")
   public void stopAllServers(ServerType server) throws IOException {
     switch (server) {
       case TABLET_SERVER:
@@ -217,7 +214,6 @@ public class StandaloneClusterControl implements ClusterControl {
           stop(server, tserver);
         }
         break;
-      case MASTER:
       case MANAGER:
         for (String manager : getHosts(MANAGER_HOSTS_FILE)) {
           stop(server, manager);
@@ -311,14 +307,12 @@ public class StandaloneClusterControl implements ClusterControl {
         "'{print \\$2}'", "|", "head", "-1", "|", "tr", "-d", "'\\n'"};
   }
 
-  @SuppressWarnings("removal")
   protected String getProcessString(ServerType server) {
     switch (server) {
       case TABLET_SERVER:
         return "tserver";
       case GARBAGE_COLLECTOR:
         return "gc";
-      case MASTER:
       case MANAGER:
         return "manager";
       case MONITOR:
@@ -386,11 +380,4 @@ public class StandaloneClusterControl implements ClusterControl {
       throws IOException {
     throw new UnsupportedOperationException("Not yet implemented.");
   }
-
-  @Override
-  public void startScanServer(Class<? extends ScanServer> scanServer, int limit, String groupName)
-      throws IOException {
-    throw new UnsupportedOperationException("Not yet implemented.");
-  }
-
 }
