@@ -22,22 +22,12 @@ package org.apache.accumulo.minicluster;
  * @since 1.6.0
  */
 public enum ServerType {
-  /**
-   * @deprecated Use {@link #MANAGER} instead
-   */
-  @Deprecated(since = "2.1.0", forRemoval = true)
-  MASTER("Master"),
   MANAGER("Manager"),
   ZOOKEEPER("ZooKeeper"),
   TABLET_SERVER("TServer"),
   GARBAGE_COLLECTOR("GC"),
   COMPACTION_COORDINATOR("CompactionCoordinator"),
   COMPACTOR("Compactor"),
-  /**
-   * @deprecated Accumulo-managed Tracer service was removed
-   */
-  @Deprecated(since = "2.1.0", forRemoval = true)
-  TRACER("Tracer"),
   MONITOR("Monitor"),
   SCAN_SERVER("SServer");
 
