@@ -28,7 +28,6 @@ import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
 import java.util.Optional;
-import java.util.Set;
 import java.util.concurrent.ExecutionException;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.TimeoutException;
@@ -39,23 +38,28 @@ import org.apache.accumulo.coordinator.CompactionCoordinator;
 import org.apache.accumulo.core.clientImpl.ClientContext;
 import org.apache.accumulo.core.compaction.thrift.CompactionCoordinatorService;
 import org.apache.accumulo.core.compaction.thrift.TExternalCompactionList;
+import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.rpc.ThriftUtil;
 import org.apache.accumulo.core.rpc.clients.ThriftClientTypes;
 import org.apache.accumulo.core.trace.TraceUtil;
-import org.apache.accumulo.core.util.HostAndPort;
 import org.apache.accumulo.core.util.UtilWaitThread;
 import org.apache.accumulo.core.util.compaction.ExternalCompactionUtil;
+import org.apache.accumulo.gc.SimpleGarbageCollector;
+import org.apache.accumulo.manager.Manager;
 import org.apache.accumulo.minicluster.ServerType;
 import org.apache.accumulo.miniclusterImpl.MiniAccumuloClusterImpl.ProcessInfo;
+import org.apache.accumulo.monitor.Monitor;
 import org.apache.accumulo.server.util.Admin;
-import org.apache.accumulo.server.util.ZooZap;
 import org.apache.accumulo.tserver.ScanServer;
+import org.apache.accumulo.tserver.TabletServer;
 import org.apache.thrift.TException;
 import org.apache.thrift.transport.TTransportException;
+import org.apache.zookeeper.server.ZooKeeperServerMain;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import com.google.common.collect.Maps;
+import com.google.common.net.HostAndPort;
 
 import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
 
@@ -170,19 +174,9 @@ public class MiniAccumuloClusterControl implements ClusterControl {
       int count =
           Math.min(limit, cluster.getConfig().getNumCompactors() - compactorProcesses.size());
       for (int i = 0; i < count; i++) {
-        compactorProcesses.add(cluster.exec(compactor, "-q", queueName).getProcess());
-      }
-    }
-  }
-
-  @Override
-  public synchronized void startScanServer(Class<? extends ScanServer> scanServer, int limit,
-      String groupName) throws IOException {
-    synchronized (scanServerProcesses) {
-      int count =
-          Math.min(limit, cluster.getConfig().getNumScanServers() - scanServerProcesses.size());
-      for (int i = 0; i < count; i++) {
-        scanServerProcesses.add(cluster.exec(scanServer, "-g", groupName).getProcess());
+        compactorProcesses.add(
+            cluster.exec(compactor, "-o", Property.COMPACTOR_QUEUE_NAME.getKey() + "=" + queueName)
+                .getProcess());
       }
     }
   }
@@ -199,18 +193,10 @@ public class MiniAccumuloClusterControl implements ClusterControl {
 
   public synchronized void start(ServerType server, Map<String,String> configOverrides, int limit)
       throws IOException {
-    start(server, configOverrides, limit, new String[] {});
-  }
-
-  @SuppressWarnings("removal")
-  public synchronized void start(ServerType server, Map<String,String> configOverrides, int limit,
-      String... args) throws IOException {
     if (limit <= 0) {
       return;
     }
 
-    Class<?> classToUse = cluster.getConfig().getServerClass(server);
-
     switch (server) {
       case TABLET_SERVER:
         synchronized (tabletServerProcesses) {
@@ -218,31 +204,30 @@ public class MiniAccumuloClusterControl implements ClusterControl {
           for (int i = tabletServerProcesses.size();
               count < limit && i < cluster.getConfig().getNumTservers(); i++, ++count) {
             tabletServerProcesses
-                .add(cluster._exec(classToUse, server, configOverrides, args).getProcess());
+                .add(cluster._exec(TabletServer.class, server, configOverrides).getProcess());
           }
         }
         break;
-      case MASTER:
       case MANAGER:
         if (managerProcess == null) {
-          managerProcess = cluster._exec(classToUse, server, configOverrides, args).getProcess();
+          managerProcess = cluster._exec(Manager.class, server, configOverrides).getProcess();
         }
         break;
       case ZOOKEEPER:
         if (zooKeeperProcess == null) {
-          zooKeeperProcess = cluster
-              ._exec(classToUse, server, configOverrides, cluster.getZooCfgFile().getAbsolutePath())
-              .getProcess();
+          zooKeeperProcess = cluster._exec(ZooKeeperServerMain.class, server, configOverrides,
+              cluster.getZooCfgFile().getAbsolutePath()).getProcess();
         }
         break;
       case GARBAGE_COLLECTOR:
         if (gcProcess == null) {
-          gcProcess = cluster._exec(classToUse, server, configOverrides, args).getProcess();
+          gcProcess =
+              cluster._exec(SimpleGarbageCollector.class, server, configOverrides).getProcess();
         }
         break;
       case MONITOR:
         if (monitor == null) {
-          monitor = cluster._exec(classToUse, server, configOverrides, args).getProcess();
+          monitor = cluster._exec(Monitor.class, server, configOverrides).getProcess();
         }
         break;
       case SCAN_SERVER:
@@ -251,37 +236,16 @@ public class MiniAccumuloClusterControl implements ClusterControl {
           for (int i = scanServerProcesses.size();
               count < limit && i < cluster.getConfig().getNumScanServers(); i++, ++count) {
             scanServerProcesses
-                .add(cluster._exec(classToUse, server, configOverrides, args).getProcess());
+                .add(cluster._exec(ScanServer.class, server, configOverrides).getProcess());
           }
         }
         break;
       case COMPACTION_COORDINATOR:
-        if (coordinatorProcess == null) {
-          coordinatorProcess =
-              cluster._exec(classToUse, ServerType.COMPACTION_COORDINATOR, configOverrides, args)
-                  .getProcess();
-          // Wait for coordinator to start
-          TExternalCompactionList metrics = null;
-          while (metrics == null) {
-            try {
-              metrics = getRunningCompactions(cluster.getServerContext());
-            } catch (TException e) {
-              log.debug(
-                  "Error getting running compactions from coordinator, message: " + e.getMessage());
-              UtilWaitThread.sleep(250);
-            }
-          }
-        }
+        startCoordinator(CompactionCoordinator.class);
         break;
       case COMPACTOR:
-        synchronized (compactorProcesses) {
-          int count =
-              Math.min(limit, cluster.getConfig().getNumCompactors() - compactorProcesses.size());
-          for (int i = 0; i < count; i++) {
-            compactorProcesses
-                .add(cluster._exec(classToUse, server, configOverrides, args).getProcess());
-          }
-        }
+        startCompactors(Compactor.class, cluster.getConfig().getNumCompactors(),
+            configOverrides.get("QUEUE_NAME"));
         break;
       default:
         throw new UnsupportedOperationException("Cannot start process for " + server);
@@ -298,19 +262,12 @@ public class MiniAccumuloClusterControl implements ClusterControl {
   }
 
   @Override
-  @SuppressWarnings("removal")
   public synchronized void stop(ServerType server, String hostname) throws IOException {
     switch (server) {
-      case MASTER:
       case MANAGER:
         if (managerProcess != null) {
           try {
             cluster.stopProcessWithTimeout(managerProcess, 30, TimeUnit.SECONDS);
-            try {
-              new ZooZap().zap(cluster.getServerContext().getSiteConfiguration(), "-manager");
-            } catch (RuntimeException e) {
-              log.error("Error zapping Manager zookeeper lock", e);
-            }
           } catch (ExecutionException | TimeoutException e) {
             log.warn("Manager did not fully stop after 30 seconds", e);
           } catch (InterruptedException e) {
@@ -444,12 +401,10 @@ public class MiniAccumuloClusterControl implements ClusterControl {
     throw new UnsupportedOperationException();
   }
 
-  @SuppressWarnings("removal")
   public void killProcess(ServerType type, ProcessReference procRef)
       throws ProcessNotFoundException, InterruptedException {
     boolean found = false;
     switch (type) {
-      case MASTER:
       case MANAGER:
         if (procRef.getProcess().equals(managerProcess)) {
           try {
@@ -555,71 +510,4 @@ public class MiniAccumuloClusterControl implements ClusterControl {
     stop(server, hostname);
   }
 
-  @SuppressWarnings("removal")
-  public void refreshProcesses(ServerType type) {
-    switch (type) {
-      case COMPACTION_COORDINATOR:
-        if (!coordinatorProcess.isAlive()) {
-          coordinatorProcess = null;
-        }
-        break;
-      case COMPACTOR:
-        compactorProcesses.removeIf(process -> !process.isAlive());
-        break;
-      case GARBAGE_COLLECTOR:
-        if (!gcProcess.isAlive()) {
-          gcProcess = null;
-        }
-        break;
-      case MANAGER:
-      case MASTER:
-        if (!managerProcess.isAlive()) {
-          managerProcess = null;
-        }
-        break;
-      case MONITOR:
-        if (!monitor.isAlive()) {
-          monitor = null;
-        }
-        break;
-      case SCAN_SERVER:
-        scanServerProcesses.removeIf(process -> !process.isAlive());
-        break;
-      case TABLET_SERVER:
-        tabletServerProcesses.removeIf(process -> !process.isAlive());
-        break;
-      case ZOOKEEPER:
-        if (!zooKeeperProcess.isAlive()) {
-          zooKeeperProcess = null;
-        }
-        break;
-      default:
-        throw new IllegalArgumentException("Unhandled type: " + type);
-    }
-  }
-
-  @SuppressWarnings("removal")
-  public Set<Process> getProcesses(ServerType type) {
-    switch (type) {
-      case COMPACTION_COORDINATOR:
-        return coordinatorProcess == null ? Set.of() : Set.of(coordinatorProcess);
-      case COMPACTOR:
-        return Set.copyOf(compactorProcesses);
-      case GARBAGE_COLLECTOR:
-        return gcProcess == null ? Set.of() : Set.of(gcProcess);
-      case MANAGER:
-      case MASTER:
-        return managerProcess == null ? Set.of() : Set.of(managerProcess);
-      case MONITOR:
-        return monitor == null ? Set.of() : Set.of(monitor);
-      case SCAN_SERVER:
-        return Set.copyOf(scanServerProcesses);
-      case TABLET_SERVER:
-        return Set.copyOf(tabletServerProcesses);
-      case ZOOKEEPER:
-        return zooKeeperProcess == null ? Set.of() : Set.of(zooKeeperProcess);
-      default:
-        throw new IllegalArgumentException("Unhandled type: " + type);
-    }
-  }
 }
