@@ -18,48 +18,29 @@
  */
 package org.apache.accumulo.miniclusterImpl;
 
-import static org.apache.accumulo.minicluster.ServerType.COMPACTOR;
-import static org.apache.accumulo.minicluster.ServerType.GARBAGE_COLLECTOR;
-import static org.apache.accumulo.minicluster.ServerType.MANAGER;
-import static org.apache.accumulo.minicluster.ServerType.MONITOR;
-import static org.apache.accumulo.minicluster.ServerType.SCAN_SERVER;
-import static org.apache.accumulo.minicluster.ServerType.TABLET_SERVER;
-import static org.apache.accumulo.minicluster.ServerType.ZOOKEEPER;
-
 import java.io.File;
 import java.io.IOException;
 import java.net.MalformedURLException;
-import java.util.EnumMap;
 import java.util.HashMap;
 import java.util.Iterator;
 import java.util.Map;
 import java.util.Map.Entry;
-import java.util.Objects;
 import java.util.function.Consumer;
 
-import org.apache.accumulo.compactor.Compactor;
 import org.apache.accumulo.core.conf.AccumuloConfiguration;
 import org.apache.accumulo.core.conf.ClientProperty;
 import org.apache.accumulo.core.conf.HadoopCredentialProvider;
 import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.conf.SiteConfiguration;
-import org.apache.accumulo.gc.SimpleGarbageCollector;
-import org.apache.accumulo.manager.Manager;
 import org.apache.accumulo.minicluster.MemoryUnit;
 import org.apache.accumulo.minicluster.MiniAccumuloCluster;
 import org.apache.accumulo.minicluster.ServerType;
-import org.apache.accumulo.monitor.Monitor;
 import org.apache.accumulo.server.util.PortUtils;
-import org.apache.accumulo.tserver.ScanServer;
-import org.apache.accumulo.tserver.TabletServer;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FileSystem;
-import org.apache.zookeeper.server.ZooKeeperServerMain;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.base.Preconditions;
-
 /**
  * Holds configuration for {@link MiniAccumuloClusterImpl}. Required configurations must be passed
  * to constructor(s) and all other configurations are optional.
@@ -70,7 +51,6 @@ public class MiniAccumuloConfigImpl {
 
   private static final Logger log = LoggerFactory.getLogger(MiniAccumuloConfigImpl.class);
   private static final String DEFAULT_INSTANCE_SECRET = "DONTTELL";
-  static final String DEFAULT_ZOOKEEPER_HOST = "127.0.0.1";
 
   private File dir = null;
   private String rootPassword = null;
@@ -82,10 +62,6 @@ public class MiniAccumuloConfigImpl {
   private int numScanServers = 0;
   private int numCompactors = 1;
   private Map<ServerType,Long> memoryConfig = new HashMap<>();
-  private final EnumMap<ServerType,Class<?>> serverTypeClasses =
-      new EnumMap<>(Map.of(MANAGER, Manager.class, GARBAGE_COLLECTOR, SimpleGarbageCollector.class,
-          MONITOR, Monitor.class, ZOOKEEPER, ZooKeeperServerMain.class, TABLET_SERVER,
-          TabletServer.class, SCAN_SERVER, ScanServer.class, COMPACTOR, Compactor.class));
   private boolean jdwpEnabled = false;
   private Map<String,String> systemProperties = new HashMap<>();
 
@@ -113,7 +89,6 @@ public class MiniAccumuloConfigImpl {
   private Boolean existingInstance = null;
 
   private boolean useMiniDFS = false;
-  private int numMiniDFSDataNodes = 1;
 
   private boolean useCredentialProvider = false;
 
@@ -172,9 +147,6 @@ public class MiniAccumuloConfigImpl {
         mergeProp(Property.INSTANCE_SECRET.getKey(), DEFAULT_INSTANCE_SECRET);
       }
 
-      // enable metrics reporting - by default will appear in standard log files.
-      mergeProp(Property.GENERAL_MICROMETER_ENABLED.getKey(), "true");
-
       mergeProp(Property.TSERV_PORTSEARCH.getKey(), "true");
       mergeProp(Property.TSERV_DATACACHE_SIZE.getKey(), "10M");
       mergeProp(Property.TSERV_INDEXCACHE_SIZE.getKey(), "10M");
@@ -185,24 +157,12 @@ public class MiniAccumuloConfigImpl {
       // since there is a small amount of memory, check more frequently for majc... setting may not
       // be needed in 1.5
       mergeProp(Property.TSERV_MAJC_DELAY.getKey(), "3");
-      @SuppressWarnings("deprecation")
-      Property generalClasspaths = Property.GENERAL_CLASSPATHS;
-      mergeProp(generalClasspaths.getKey(), libDir.getAbsolutePath() + "/[^.].*[.]jar");
-      @SuppressWarnings("deprecation")
-      Property generalDynamicClasspaths = Property.GENERAL_DYNAMIC_CLASSPATHS;
-      mergeProp(generalDynamicClasspaths.getKey(), libExtDir.getAbsolutePath() + "/[^.].*[.]jar");
       mergeProp(Property.GC_CYCLE_DELAY.getKey(), "4s");
       mergeProp(Property.GC_CYCLE_START.getKey(), "0s");
       mergePropWithRandomPort(Property.MANAGER_CLIENTPORT.getKey());
       mergePropWithRandomPort(Property.TSERV_CLIENTPORT.getKey());
       mergePropWithRandomPort(Property.MONITOR_PORT.getKey());
       mergePropWithRandomPort(Property.GC_PORT.getKey());
-      @SuppressWarnings("deprecation")
-      Property p = Property.REPLICATION_RECEIPT_SERVICE_PORT;
-      mergePropWithRandomPort(p.getKey());
-      @SuppressWarnings("deprecation")
-      Property p2 = Property.MANAGER_REPLICATION_COORDINATOR_PORT;
-      mergePropWithRandomPort(p2.getKey());
 
       if (isUseCredentialProvider()) {
         updateConfigForCredentialProvider();
@@ -219,7 +179,7 @@ public class MiniAccumuloConfigImpl {
             zooKeeperPort = PortUtils.getRandomFreePort();
           }
 
-          zkHost = DEFAULT_ZOOKEEPER_HOST + ":" + zooKeeperPort;
+          zkHost = "localhost:" + zooKeeperPort;
         }
         siteConfig.put(Property.INSTANCE_ZK_HOST.getKey(), zkHost);
       }
@@ -439,25 +399,6 @@ public class MiniAccumuloConfigImpl {
     return this;
   }
 
-  /**
-   * Sets the class that will be used to instantiate this server type.
-   */
-  public MiniAccumuloConfigImpl setServerClass(ServerType type, Class<?> serverClass) {
-    serverTypeClasses.put(type, Objects.requireNonNull(serverClass));
-    return this;
-  }
-
-  /**
-   * @return the class to use to instantiate this server type.
-   */
-  public Class<?> getServerClass(ServerType type) {
-    var clazz = serverTypeClasses.get(type);
-    if (clazz == null) {
-      throw new IllegalStateException("Server type " + type + " has no class");
-    }
-    return clazz;
-  }
-
   /**
    * @return a copy of the site config
    */
@@ -611,7 +552,7 @@ public class MiniAccumuloConfigImpl {
     return this;
   }
 
-  public boolean getUseMiniDFS() {
+  public boolean useMiniDFS() {
     return useMiniDFS;
   }
 
@@ -622,27 +563,7 @@ public class MiniAccumuloConfigImpl {
    * underlying miniDFS cannot be restarted.
    */
   public void useMiniDFS(boolean useMiniDFS) {
-    useMiniDFS(useMiniDFS, 1);
-  }
-
-  public void useMiniDFS(boolean useMiniDFS, int numDataNodes) {
-    Preconditions.checkArgument(numDataNodes > 0);
     this.useMiniDFS = useMiniDFS;
-    this.numMiniDFSDataNodes = numDataNodes;
-  }
-
-  public int getNumDataNodes() {
-    return numMiniDFSDataNodes;
-  }
-
-  /**
-   * @return location of client conf file containing connection parameters for connecting to this
-   *         minicluster
-   *
-   * @since 1.6.0
-   */
-  public File getClientConfFile() {
-    return new File(getConfDir(), "client.conf");
   }
 
   public File getAccumuloPropsFile() {
