@@ -21,25 +21,21 @@ package org.apache.accumulo.server.compaction;
 import java.io.IOException;
 import java.text.DateFormat;
 import java.text.SimpleDateFormat;
-import java.time.Duration;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.Date;
-import java.util.EnumSet;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
 import java.util.Set;
 import java.util.concurrent.Callable;
-import java.util.concurrent.atomic.AtomicBoolean;
+import java.util.concurrent.atomic.AtomicInteger;
 import java.util.concurrent.atomic.AtomicLong;
-import java.util.concurrent.atomic.LongAdder;
 
 import org.apache.accumulo.core.client.IteratorSetting;
 import org.apache.accumulo.core.conf.AccumuloConfiguration;
-import org.apache.accumulo.core.conf.ConfigurationTypeHelper;
 import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.data.ByteSequence;
 import org.apache.accumulo.core.data.Key;
@@ -47,9 +43,7 @@ import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.data.Value;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.file.FileOperations;
-import org.apache.accumulo.core.file.FileOperations.ReaderBuilder;
 import org.apache.accumulo.core.file.FileOperations.WriterBuilder;
-import org.apache.accumulo.core.file.FilePrefix;
 import org.apache.accumulo.core.file.FileSKVIterator;
 import org.apache.accumulo.core.file.FileSKVWriter;
 import org.apache.accumulo.core.iterators.IteratorUtil;
@@ -58,13 +52,12 @@ import org.apache.accumulo.core.iterators.SortedKeyValueIterator;
 import org.apache.accumulo.core.iteratorsImpl.IteratorConfigUtil;
 import org.apache.accumulo.core.iteratorsImpl.system.ColumnFamilySkippingIterator;
 import org.apache.accumulo.core.iteratorsImpl.system.DeletingIterator;
-import org.apache.accumulo.core.iteratorsImpl.system.IterationInterruptedException;
+import org.apache.accumulo.core.iteratorsImpl.system.InterruptibleIterator;
 import org.apache.accumulo.core.iteratorsImpl.system.MultiIterator;
-import org.apache.accumulo.core.iteratorsImpl.system.TimeSettingIterator;
 import org.apache.accumulo.core.metadata.MetadataTable;
+import org.apache.accumulo.core.metadata.ReferencedTabletFile;
 import org.apache.accumulo.core.metadata.RootTable;
 import org.apache.accumulo.core.metadata.StoredTabletFile;
-import org.apache.accumulo.core.metadata.TabletFile;
 import org.apache.accumulo.core.metadata.schema.DataFileValue;
 import org.apache.accumulo.core.spi.crypto.CryptoService;
 import org.apache.accumulo.core.tabletserver.thrift.TCompactionReason;
@@ -75,6 +68,7 @@ import org.apache.accumulo.core.util.ratelimit.RateLimiter;
 import org.apache.accumulo.server.ServerContext;
 import org.apache.accumulo.server.fs.VolumeManager;
 import org.apache.accumulo.server.iterators.SystemIteratorEnvironment;
+import org.apache.accumulo.server.mem.LowMemoryDetector.DetectionScope;
 import org.apache.accumulo.server.problems.ProblemReport;
 import org.apache.accumulo.server.problems.ProblemReportingIterator;
 import org.apache.accumulo.server.problems.ProblemReports;
@@ -83,9 +77,6 @@ import org.apache.hadoop.fs.FileSystem;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.base.Preconditions;
-import com.google.common.collect.Collections2;
-
 import io.opentelemetry.api.trace.Span;
 import io.opentelemetry.context.Scope;
 
@@ -116,7 +107,7 @@ public class FileCompactor implements Callable<CompactionStats> {
   }
 
   private final Map<StoredTabletFile,DataFileValue> filesToCompact;
-  private final TabletFile outputFile;
+  private final ReferencedTabletFile outputFile;
   private final boolean propagateDeletes;
   private final AccumuloConfiguration acuTableConf;
   private final CompactionEnv env;
@@ -124,72 +115,22 @@ public class FileCompactor implements Callable<CompactionStats> {
   protected final KeyExtent extent;
   private final List<IteratorSetting> iterators;
   private final CryptoService cryptoService;
+  private final PausedCompactionMetrics metrics;
 
   // things to report
   private String currentLocalityGroup = "";
-  private volatile long startTime = -1;
-
-  private final AtomicLong currentEntriesRead = new AtomicLong(0);
-  private final AtomicLong currentEntriesWritten = new AtomicLong(0);
-
-  // These track the cumulative count of entries (read and written) that has been recorded in
-  // the global counts. Their purpose is to avoid double counting of metrics during the update of
-  // global statistics.
-  private final AtomicLong lastRecordedEntriesRead = new AtomicLong(0);
-  private final AtomicLong lastRecordedEntriesWritten = new AtomicLong(0);
-
-  private static final LongAdder totalEntriesRead = new LongAdder();
-  private static final LongAdder totalEntriesWritten = new LongAdder();
-  private static volatile long lastUpdateTime = 0;
+  private final long startTime;
 
+  private final AtomicLong entriesRead = new AtomicLong(0);
+  private final AtomicLong entriesWritten = new AtomicLong(0);
+  private final AtomicInteger timesPaused = new AtomicInteger(0);
   private final DateFormat dateFormatter = new SimpleDateFormat("yyyy/MM/dd HH:mm:ss.SSS");
 
   // a unique id to identify a compactor
   private final long compactorID = nextCompactorID.getAndIncrement();
-  private volatile Thread thread;
+  protected volatile Thread thread;
   private final ServerContext context;
 
-  private final AtomicBoolean interruptFlag = new AtomicBoolean(false);
-
-  public synchronized void interrupt() {
-    interruptFlag.set(true);
-
-    if (thread != null) {
-      // Never want to interrupt the thread after clearThread was called as the thread could have
-      // moved on to something completely different than the compaction. This method and clearThread
-      // being synchronized and clearThread setting thread to null prevent this.
-      thread.interrupt();
-    }
-  }
-
-  private class ThreadClearer implements AutoCloseable {
-    @Override
-    public void close() throws InterruptedException {
-      clearThread();
-    }
-  }
-
-  private synchronized ThreadClearer setThread() {
-    thread = Thread.currentThread();
-    return new ThreadClearer();
-  }
-
-  private synchronized void clearThread() throws InterruptedException {
-    Preconditions.checkState(thread == Thread.currentThread());
-    thread = null;
-    // If the thread was interrupted during compaction do not want to allow the thread to continue
-    // w/ the interrupt status set as this could impact code unrelated to the compaction. For
-    // internal compactions the thread will execute metadata update code after the compaction and
-    // would not want the interrupt status set for that.
-    if (Thread.interrupted()) {
-      throw new InterruptedException();
-    }
-  }
-
-  Thread getThread() {
-    return thread;
-  }
-
   public long getCompactorID() {
     return compactorID;
   }
@@ -202,61 +143,10 @@ public class FileCompactor implements Callable<CompactionStats> {
     return currentLocalityGroup;
   }
 
-  private void clearCurrentEntryCounts() {
-    currentEntriesRead.set(0);
-    currentEntriesWritten.set(0);
-  }
-
-  private void updateGlobalEntryCounts() {
-    updateTotalEntries(currentEntriesRead, lastRecordedEntriesRead, totalEntriesRead);
-    updateTotalEntries(currentEntriesWritten, lastRecordedEntriesWritten, totalEntriesWritten);
-  }
-
-  /**
-   * Updates the total count of entries by adding the difference between the current count and the
-   * last recorded count to the total.
-   *
-   * @param current The current count of entries
-   * @param recorded The last recorded count of entries
-   * @param total The total count to add the difference to
-   */
-  private void updateTotalEntries(AtomicLong current, AtomicLong recorded, LongAdder total) {
-    long currentCount = current.get();
-    long lastRecorded =
-        recorded.getAndUpdate(recordedValue -> Math.max(recordedValue, currentCount));
-    if (lastRecorded < currentCount) {
-      total.add(currentCount - lastRecorded);
-    }
-  }
-
-  /**
-   * @return the total entries written by compactions over the lifetime of this process.
-   */
-  public static long getTotalEntriesWritten() {
-    updateTotalEntries();
-    return totalEntriesWritten.sum();
-  }
-
-  /**
-   * @return the total entries read by compactions over the lifetime of this process.
-   */
-  public static long getTotalEntriesRead() {
-    updateTotalEntries();
-    return totalEntriesRead.sum();
-  }
-
-  /**
-   * Updates total entries read and written for all currently running compactions. Compactions will
-   * update the global stats when they finish. This can be called to update them sooner. This method
-   * is rate limited, so it will not cause issues if called too frequently.
-   */
-  private static void updateTotalEntries() {
-    long currentTime = System.nanoTime();
-    if (currentTime - lastUpdateTime < Duration.ofMillis(100).toNanos()) {
-      return;
-    }
-    runningCompactions.forEach(FileCompactor::updateGlobalEntryCounts);
-    lastUpdateTime = currentTime;
+  private void clearStats() {
+    entriesRead.set(0);
+    entriesWritten.set(0);
+    timesPaused.set(0);
   }
 
   protected static final Set<FileCompactor> runningCompactions =
@@ -275,9 +165,9 @@ public class FileCompactor implements Callable<CompactionStats> {
   }
 
   public FileCompactor(ServerContext context, KeyExtent extent,
-      Map<StoredTabletFile,DataFileValue> files, TabletFile outputFile, boolean propagateDeletes,
-      CompactionEnv env, List<IteratorSetting> iterators, AccumuloConfiguration tableConfiguation,
-      CryptoService cs) {
+      Map<StoredTabletFile,DataFileValue> files, ReferencedTabletFile outputFile,
+      boolean propagateDeletes, CompactionEnv env, List<IteratorSetting> iterators,
+      AccumuloConfiguration tableConfiguation, CryptoService cs, PausedCompactionMetrics metrics) {
     this.context = context;
     this.extent = extent;
     this.fs = context.getVolumeManager();
@@ -288,6 +178,9 @@ public class FileCompactor implements Callable<CompactionStats> {
     this.env = env;
     this.iterators = iterators;
     this.cryptoService = cs;
+    this.metrics = metrics;
+
+    startTime = System.currentTimeMillis();
   }
 
   public VolumeManager getVolumeManager() {
@@ -299,7 +192,7 @@ public class FileCompactor implements Callable<CompactionStats> {
   }
 
   protected String getOutputFile() {
-    return outputFile.toString();
+    return outputFile.getMetaInsert();
   }
 
   protected Map<String,Set<ByteSequence>> getLocalityGroups(AccumuloConfiguration acuTableConf)
@@ -312,46 +205,25 @@ public class FileCompactor implements Callable<CompactionStats> {
   }
 
   @Override
-  public CompactionStats call() throws IOException, CompactionCanceledException,
-      InterruptedException, ReflectiveOperationException {
+  public CompactionStats call() throws IOException, CompactionCanceledException {
 
     FileSKVWriter mfw = null;
 
     CompactionStats majCStats = new CompactionStats();
 
-    startTime = System.nanoTime();
-
     boolean remove = runningCompactions.add(this);
 
-    String threadStartDate = dateFormatter.format(new Date());
-
-    clearCurrentEntryCounts();
+    clearStats();
 
     String oldThreadName = Thread.currentThread().getName();
-    String newThreadName =
-        "MajC compacting " + extent + " started " + threadStartDate + " file: " + outputFile;
+    String newThreadName = "MajC compacting " + extent + " started "
+        + dateFormatter.format(new Date()) + " file: " + outputFile;
     Thread.currentThread().setName(newThreadName);
-    // Use try w/ resources for clearing the thread instead of finally because clearing may throw an
-    // exception. Java's handling of exceptions thrown in finally blocks is not good.
-    try (var ignored = setThread()) {
+    thread = Thread.currentThread();
+    try {
       FileOperations fileFactory = FileOperations.getInstance();
       FileSystem ns = this.fs.getFileSystemByPath(outputFile.getPath());
 
-      // Normally you would not want the DataNode to continue to
-      // cache blocks in the page cache for compaction input files
-      // as these files are normally marked for deletion after a
-      // compaction occurs. However there can be cases where the
-      // compaction input files will continue to be used, like in
-      // the case of bulk import files which may be assigned to many
-      // tablets and will still be needed until all of the tablets
-      // have compacted, or in the case of cloned tables where one
-      // of the tables has compacted the input file but the other
-      // has not.
-      final String dropCachePrefixProperty =
-          acuTableConf.get(Property.TABLE_COMPACTION_INPUT_DROP_CACHE_BEHIND);
-      final EnumSet<FilePrefix> dropCacheFileTypes =
-          ConfigurationTypeHelper.getDropCacheBehindFilePrefixes(dropCachePrefixProperty);
-
       final boolean isMinC = env.getIteratorScope() == IteratorUtil.IteratorScope.minc;
 
       final boolean dropCacheBehindOutput = !RootTable.ID.equals(this.extent.tableId())
@@ -359,9 +231,9 @@ public class FileCompactor implements Callable<CompactionStats> {
           && ((isMinC && acuTableConf.getBoolean(Property.TABLE_MINC_OUTPUT_DROP_CACHE))
               || (!isMinC && acuTableConf.getBoolean(Property.TABLE_MAJC_OUTPUT_DROP_CACHE)));
 
-      WriterBuilder outBuilder = fileFactory.newWriterBuilder()
-          .forFile(outputFile.getMetaInsert(), ns, ns.getConf(), cryptoService)
-          .withTableConfiguration(acuTableConf).withRateLimiter(env.getWriteLimiter());
+      WriterBuilder outBuilder =
+          fileFactory.newWriterBuilder().forFile(outputFile, ns, ns.getConf(), cryptoService)
+              .withTableConfiguration(acuTableConf).withRateLimiter(env.getWriteLimiter());
       if (dropCacheBehindOutput) {
         outBuilder.dropCachesBehind();
       }
@@ -376,14 +248,13 @@ public class FileCompactor implements Callable<CompactionStats> {
       if (mfw.supportsLocalityGroups()) {
         for (Entry<String,Set<ByteSequence>> entry : lGroups.entrySet()) {
           setLocalityGroup(entry.getKey());
-          compactLocalityGroup(entry.getKey(), entry.getValue(), true, mfw, majCStats,
-              dropCacheFileTypes);
+          compactLocalityGroup(entry.getKey(), entry.getValue(), true, mfw, majCStats);
           allColumnFamilies.addAll(entry.getValue());
         }
       }
 
       setLocalityGroup("");
-      compactLocalityGroup(null, allColumnFamilies, false, mfw, majCStats, dropCacheFileTypes);
+      compactLocalityGroup(null, allColumnFamilies, false, mfw, majCStats);
 
       long t2 = System.currentTimeMillis();
 
@@ -403,40 +274,27 @@ public class FileCompactor implements Callable<CompactionStats> {
 
       log.trace(String.format(
           "Compaction %s %,d read | %,d written | %,6d entries/sec"
-              + " | %,6.3f secs | %,12d bytes | %9.3f byte/sec",
+              + " | %,6.3f secs | %,12d bytes | %9.3f byte/sec | %,d paused",
           extent, majCStats.getEntriesRead(), majCStats.getEntriesWritten(),
           (int) (majCStats.getEntriesRead() / ((t2 - t1) / 1000.0)), (t2 - t1) / 1000.0,
-          mfwTmp.getLength(), mfwTmp.getLength() / ((t2 - t1) / 1000.0)));
+          mfwTmp.getLength(), mfwTmp.getLength() / ((t2 - t1) / 1000.0),
+          majCStats.getTimesPaused()));
 
       majCStats.setFileSize(mfwTmp.getLength());
       return majCStats;
     } catch (CompactionCanceledException e) {
       log.debug("Compaction canceled {}", extent);
       throw e;
-    } catch (IterationInterruptedException iie) {
-      if (!env.isCompactionEnabled()) {
-        log.debug("Compaction canceled {}", extent);
-        throw new CompactionCanceledException();
-      }
-      log.debug("RFile interrupted {}", extent);
-      throw iie;
     } catch (IOException | RuntimeException e) {
-      Collection<String> inputFileNames =
-          Collections2.transform(getFilesToCompact(), StoredTabletFile::getFileName);
-      String outputFileName = outputFile.getFileName();
-      log.error(
-          "Compaction error. Compaction info: "
-              + "extent: {}, input files: {}, output file: {}, iterators: {}, start date: {}",
-          getExtent(), inputFileNames, outputFileName, getIterators(), threadStartDate, e);
+      log.error("{}", e.getMessage(), e);
       throw e;
     } finally {
       Thread.currentThread().setName(oldThreadName);
       if (remove) {
+        thread = null;
         runningCompactions.remove(this);
       }
 
-      updateGlobalEntryCounts();
-
       try {
         if (mfw != null) {
           // compaction must not have finished successfully, so close its output file
@@ -467,61 +325,43 @@ public class FileCompactor implements Callable<CompactionStats> {
     }
   }
 
-  private List<SortedKeyValueIterator<Key,Value>> openMapDataFiles(
-      ArrayList<FileSKVIterator> readers, EnumSet<FilePrefix> dropCacheFilePrefixes)
-      throws IOException {
+  private List<SortedKeyValueIterator<Key,Value>>
+      openMapDataFiles(ArrayList<FileSKVIterator> readers) throws IOException {
 
     List<SortedKeyValueIterator<Key,Value>> iters = new ArrayList<>(filesToCompact.size());
 
-    for (StoredTabletFile mapFile : filesToCompact.keySet()) {
+    for (StoredTabletFile dataFile : filesToCompact.keySet()) {
       try {
 
         FileOperations fileFactory = FileOperations.getInstance();
-        FileSystem fs = this.fs.getFileSystemByPath(mapFile.getPath());
+        FileSystem fs = this.fs.getFileSystemByPath(dataFile.getPath());
         FileSKVIterator reader;
 
-        boolean dropCacheBehindCompactionInputFile = false;
-        if (dropCacheFilePrefixes.containsAll(EnumSet.allOf(FilePrefix.class))) {
-          dropCacheBehindCompactionInputFile = true;
-        } else {
-          FilePrefix type = FilePrefix.fromFileName(mapFile.getFileName());
-          if (dropCacheFilePrefixes.contains(type)) {
-            dropCacheBehindCompactionInputFile = true;
-          }
-        }
-
-        ReaderBuilder readerBuilder = fileFactory.newReaderBuilder()
-            .forFile(mapFile.getPathStr(), fs, fs.getConf(), cryptoService)
-            .withTableConfiguration(acuTableConf).withRateLimiter(env.getReadLimiter());
-        if (dropCacheBehindCompactionInputFile) {
-          readerBuilder.dropCachesBehind();
-        }
-        reader = readerBuilder.build();
+        reader = fileFactory.newReaderBuilder().forFile(dataFile, fs, fs.getConf(), cryptoService)
+            .withTableConfiguration(acuTableConf).withRateLimiter(env.getReadLimiter())
+            .dropCachesBehind().build();
 
         readers.add(reader);
 
-        SortedKeyValueIterator<Key,Value> iter = new ProblemReportingIterator(context,
-            extent.tableId(), mapFile.getPathStr(), false, reader);
-        ((ProblemReportingIterator) iter).setInterruptFlag(interruptFlag);
+        InterruptibleIterator iter = new ProblemReportingIterator(context, extent.tableId(),
+            dataFile.getNormalizedPathStr(), false, reader);
 
-        if (filesToCompact.get(mapFile).isTimeSet()) {
-          iter = new TimeSettingIterator(iter, filesToCompact.get(mapFile).getTime());
-        }
+        iter = filesToCompact.get(dataFile).wrapFileIterator(iter);
 
         iters.add(iter);
 
       } catch (Exception e) {
 
-        ProblemReports.getInstance(context).report(
-            new ProblemReport(extent.tableId(), ProblemType.FILE_READ, mapFile.getPathStr(), e));
+        ProblemReports.getInstance(context).report(new ProblemReport(extent.tableId(),
+            ProblemType.FILE_READ, dataFile.getNormalizedPathStr(), e));
 
-        log.warn("Some problem opening map file {} {}", mapFile, e.getMessage(), e);
-        // failed to open some map file... close the ones that were opened
+        log.warn("Some problem opening data file {} {}", dataFile, e.getMessage(), e);
+        // failed to open some data file... close the ones that were opened
         for (FileSKVIterator reader : readers) {
           try {
             reader.close();
           } catch (Exception e2) {
-            log.warn("Failed to close map file", e2);
+            log.warn("Failed to close data file", e2);
           }
         }
 
@@ -530,7 +370,7 @@ public class FileCompactor implements Callable<CompactionStats> {
         if (e instanceof IOException) {
           throw (IOException) e;
         }
-        throw new IOException("Failed to open map data files", e);
+        throw new IOException("Failed to open data files", e);
       }
     }
 
@@ -538,22 +378,20 @@ public class FileCompactor implements Callable<CompactionStats> {
   }
 
   private void compactLocalityGroup(String lgName, Set<ByteSequence> columnFamilies,
-      boolean inclusive, FileSKVWriter mfw, CompactionStats majCStats,
-      EnumSet<FilePrefix> dropCacheFilePrefixes)
-      throws IOException, CompactionCanceledException, ReflectiveOperationException {
+      boolean inclusive, FileSKVWriter mfw, CompactionStats majCStats)
+      throws IOException, CompactionCanceledException {
     ArrayList<FileSKVIterator> readers = new ArrayList<>(filesToCompact.size());
     Span compactSpan = TraceUtil.startSpan(this.getClass(), "compact");
     try (Scope span = compactSpan.makeCurrent()) {
       long entriesCompacted = 0;
-      List<SortedKeyValueIterator<Key,Value>> iters =
-          openMapDataFiles(readers, dropCacheFilePrefixes);
+      List<SortedKeyValueIterator<Key,Value>> iters = openMapDataFiles(readers);
 
       if (env.getIteratorScope() == IteratorScope.minc) {
         iters.add(env.getMinCIterator());
       }
 
       CountingIterator citr =
-          new CountingIterator(new MultiIterator(iters, extent.toDataRange()), currentEntriesRead);
+          new CountingIterator(new MultiIterator(iters, extent.toDataRange()), entriesRead);
       SortedKeyValueIterator<Key,Value> delIter =
           DeletingIterator.wrap(citr, propagateDeletes, DeletingIterator.getBehavior(acuTableConf));
       ColumnFamilySkippingIterator cfsi = new ColumnFamilySkippingIterator(delIter);
@@ -563,6 +401,7 @@ public class FileCompactor implements Callable<CompactionStats> {
 
       SortedKeyValueIterator<Key,Value> itr = iterEnv.getTopLevelIterator(IteratorConfigUtil
           .convertItersAndLoad(env.getIteratorScope(), cfsi, acuTableConf, iterators, iterEnv));
+
       itr.seek(extent.toDataRange(), columnFamilies, inclusive);
 
       if (inclusive) {
@@ -571,16 +410,38 @@ public class FileCompactor implements Callable<CompactionStats> {
         mfw.startDefaultLocalityGroup();
       }
 
+      DetectionScope scope =
+          env.getIteratorScope() == IteratorScope.minc ? DetectionScope.MINC : DetectionScope.MAJC;
       Span writeSpan = TraceUtil.startSpan(this.getClass(), "write");
       try (Scope write = writeSpan.makeCurrent()) {
         while (itr.hasTop() && env.isCompactionEnabled()) {
+
+          while (context.getLowMemoryDetector().isRunningLowOnMemory(context, scope, () -> {
+            return !extent.isMeta();
+          }, () -> {
+            log.info("Pausing compaction because low on memory, extent: {}", extent);
+            timesPaused.incrementAndGet();
+            if (scope == DetectionScope.MINC) {
+              metrics.incrementMinCPause();
+            } else {
+              metrics.incrementMajCPause();
+            }
+            try {
+              Thread.sleep(500);
+            } catch (InterruptedException e) {
+              Thread.currentThread().interrupt();
+              throw new IllegalStateException(
+                  "Interrupted while waiting for low memory condition to resolve", e);
+            }
+          })) {}
+
           mfw.append(itr.getTopKey(), itr.getTopValue());
           itr.next();
           entriesCompacted++;
 
           if (entriesCompacted % 1024 == 0) {
             // Periodically update stats, do not want to do this too often since its volatile
-            currentEntriesWritten.addAndGet(1024);
+            entriesWritten.addAndGet(1024);
           }
         }
 
@@ -601,12 +462,12 @@ public class FileCompactor implements Callable<CompactionStats> {
         }
 
       } finally {
-        CompactionStats lgMajcStats = new CompactionStats(citr.getCount(), entriesCompacted);
+        CompactionStats lgMajcStats =
+            new CompactionStats(citr.getCount(), entriesCompacted, timesPaused.get());
         majCStats.add(lgMajcStats);
         writeSpan.end();
       }
-
-    } catch (Exception e) {
+    } catch (IOException | CompactionCanceledException e) {
       TraceUtil.setException(compactSpan, e, true);
       throw e;
     } finally {
@@ -615,7 +476,7 @@ public class FileCompactor implements Callable<CompactionStats> {
         try {
           reader.close();
         } catch (Exception e) {
-          log.warn("Failed to close map file", e);
+          log.warn("Failed to close data file", e);
         }
       }
       compactSpan.end();
@@ -635,22 +496,19 @@ public class FileCompactor implements Callable<CompactionStats> {
   }
 
   long getEntriesRead() {
-    return currentEntriesRead.get();
+    return entriesRead.get();
   }
 
   long getEntriesWritten() {
-    return currentEntriesWritten.get();
+    return entriesWritten.get();
   }
 
-  /**
-   * @return the duration since {@link #call()} was called
-   */
-  Duration getAge() {
-    if (startTime == -1) {
-      // call() has not been called yet
-      return Duration.ZERO;
-    }
-    return Duration.ofNanos(System.nanoTime() - startTime);
+  long getTimesPaused() {
+    return timesPaused.get();
+  }
+
+  long getStartTime() {
+    return startTime;
   }
 
   Iterable<IteratorSetting> getIterators() {
