@@ -18,8 +18,6 @@
  */
 package org.apache.accumulo.server.conf;
 
-import static org.apache.accumulo.core.Constants.DEFAULT_COMPACTION_SERVICE_NAME;
-
 import java.io.FileNotFoundException;
 import java.nio.file.Path;
 import java.util.Set;
@@ -55,7 +53,7 @@ public class CheckCompactionConfig implements KeywordExecutable {
 
   private final static Logger log = LoggerFactory.getLogger(CheckCompactionConfig.class);
 
-  final static String DEFAULT = DEFAULT_COMPACTION_SERVICE_NAME;
+  final static String DEFAULT = "default";
   final static String META = "meta";
   final static String ROOT = "root";
 
@@ -94,12 +92,7 @@ public class CheckCompactionConfig implements KeywordExecutable {
     }
 
     AccumuloConfiguration config = SiteConfiguration.fromFile(path.toFile()).build();
-    validate(config);
-  }
-
-  public static void validate(AccumuloConfiguration config)
-      throws ReflectiveOperationException, SecurityException, IllegalArgumentException {
-    var servicesConfig = new CompactionServicesConfig(config, log::warn);
+    var servicesConfig = new CompactionServicesConfig(config);
     ServiceEnvironment senv = createServiceEnvironment(config);
 
     Set<String> defaultServices = Set.of(DEFAULT, META, ROOT);
@@ -136,10 +129,9 @@ public class CheckCompactionConfig implements KeywordExecutable {
     }
 
     log.info("Properties file has passed all checks.");
-
   }
 
-  private static ServiceEnvironment createServiceEnvironment(AccumuloConfiguration config) {
+  private ServiceEnvironment createServiceEnvironment(AccumuloConfiguration config) {
     return new ServiceEnvironment() {
 
       @Override
@@ -168,5 +160,4 @@ public class CheckCompactionConfig implements KeywordExecutable {
       }
     };
   }
-
 }
