@@ -77,12 +77,8 @@ public class ServerConfigurationFactory extends ServerConfiguration {
   public ServerConfigurationFactory(ServerContext context, SiteConfiguration siteConfig) {
     this.context = context;
     this.siteConfig = siteConfig;
-    this.systemConfig = memoize(() -> {
-      var sysConf =
-          new SystemConfiguration(context, SystemPropKey.of(context.getInstanceID()), siteConfig);
-      ConfigCheckUtil.validate(sysConf, "system config");
-      return sysConf;
-    });
+    this.systemConfig = memoize(() -> new SystemConfiguration(context,
+        SystemPropKey.of(context.getInstanceID()), siteConfig));
     tableParentConfigs =
         Caffeine.newBuilder().expireAfterAccess(CACHE_EXPIRATION_HRS, TimeUnit.HOURS).build();
     tableConfigs =
@@ -91,8 +87,8 @@ public class ServerConfigurationFactory extends ServerConfiguration {
         Caffeine.newBuilder().expireAfterAccess(CACHE_EXPIRATION_HRS, TimeUnit.HOURS).build();
 
     refresher = new ConfigRefreshRunner();
-    Runtime.getRuntime().addShutdownHook(
-        Threads.createNonCriticalThread("config-refresh-shutdownHook", refresher::shutdown));
+    Runtime.getRuntime()
+        .addShutdownHook(Threads.createThread("config-refresh-shutdownHook", refresher::shutdown));
   }
 
   public ServerContext getServerContext() {
@@ -120,6 +116,7 @@ public class ServerConfigurationFactory extends ServerConfiguration {
         var conf =
             new TableConfiguration(context, tableId, getNamespaceConfigurationForTable(tableId));
         ConfigCheckUtil.validate(conf, "table id: " + tableId.toString());
+
         return conf;
       }
       return null;
@@ -131,7 +128,7 @@ public class ServerConfigurationFactory extends ServerConfiguration {
     try {
       namespaceId = context.getNamespaceId(tableId);
     } catch (TableNotFoundException e) {
-      throw new RuntimeException(e);
+      throw new IllegalStateException(e);
     }
     return tableParentConfigs.get(tableId, key -> getNamespaceConfiguration(namespaceId));
   }
@@ -195,8 +192,8 @@ public class ServerConfigurationFactory extends ServerConfiguration {
 
       Runnable refreshTask = this::verifySnapshotVersions;
 
-      ScheduledThreadPoolExecutor executor =
-          ThreadPools.getServerThreadPools().createScheduledExecutorService(1, "config-refresh");
+      ScheduledThreadPoolExecutor executor = ThreadPools.getServerThreadPools()
+          .createScheduledExecutorService(1, "config-refresh", false);
 
       // scheduleWithFixedDelay - used so only one task will run concurrently.
       // staggering the initial delay prevents synchronization of Accumulo servers communicating
