@@ -31,14 +31,13 @@ import org.apache.accumulo.core.data.InstanceId;
 import org.apache.accumulo.core.fate.zookeeper.ZooReader;
 import org.apache.accumulo.core.fate.zookeeper.ZooReaderWriter;
 import org.apache.accumulo.core.fate.zookeeper.ZooUtil;
+import org.apache.accumulo.core.metrics.MetricsUtil;
 import org.apache.accumulo.server.conf.codec.VersionedPropCodec;
 import org.apache.accumulo.server.conf.codec.VersionedProperties;
 import org.apache.accumulo.server.conf.store.PropCache;
 import org.apache.accumulo.server.conf.store.PropChangeListener;
 import org.apache.accumulo.server.conf.store.PropStore;
 import org.apache.accumulo.server.conf.store.PropStoreKey;
-import org.apache.accumulo.server.conf.store.SystemPropKey;
-import org.apache.accumulo.server.conf.util.ConfigTransformer;
 import org.apache.zookeeper.KeeperException;
 import org.apache.zookeeper.data.Stat;
 import org.checkerframework.checker.nullness.qual.NonNull;
@@ -48,6 +47,8 @@ import org.slf4j.LoggerFactory;
 
 import com.github.benmanes.caffeine.cache.Ticker;
 
+import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
+
 public class ZooPropStore implements PropStore, PropChangeListener {
 
   private final static Logger log = LoggerFactory.getLogger(ZooPropStore.class);
@@ -56,6 +57,7 @@ public class ZooPropStore implements PropStore, PropChangeListener {
   private final ZooReaderWriter zrw;
   private final PropStoreWatcher propStoreWatcher;
   private final PropCacheCaffeineImpl cache;
+  private final PropStoreMetrics cacheMetrics = new PropStoreMetrics();
   private final ReadyMonitor zkReadyMon;
 
   /**
@@ -79,6 +81,8 @@ public class ZooPropStore implements PropStore, PropChangeListener {
    * @param watcher a watcher. Optional, if null, one is created.
    * @param ticker a synthetic clock used for testing. Optional, if null, one is created.
    */
+  @SuppressFBWarnings(value = "PREDICTABLE_RANDOM",
+      justification = "random number not used in secure context")
   ZooPropStore(final InstanceId instanceId, final ZooReaderWriter zrw, final ReadyMonitor monitor,
       final PropStoreWatcher watcher, final Ticker ticker) {
 
@@ -89,14 +93,17 @@ public class ZooPropStore implements PropStore, PropChangeListener {
 
     this.propStoreWatcher = requireNonNullElseGet(watcher, () -> new PropStoreWatcher(zkReadyMon));
 
-    ZooPropLoader propLoader = new ZooPropLoader(zrw, codec, this.propStoreWatcher);
+    ZooPropLoader propLoader = new ZooPropLoader(zrw, codec, this.propStoreWatcher, cacheMetrics);
 
     if (ticker == null) {
-      this.cache = new PropCacheCaffeineImpl.Builder(propLoader).build();
+      this.cache = new PropCacheCaffeineImpl.Builder(propLoader, cacheMetrics).build();
     } else {
-      this.cache = new PropCacheCaffeineImpl.Builder(propLoader).forTests(ticker).build();
+      this.cache =
+          new PropCacheCaffeineImpl.Builder(propLoader, cacheMetrics).forTests(ticker).build();
     }
 
+    MetricsUtil.initializeProducers(cacheMetrics);
+
     try {
       var path = ZooUtil.getRoot(instanceId);
       if (zrw.exists(path, propStoreWatcher)) {
@@ -136,6 +143,10 @@ public class ZooPropStore implements PropStore, PropChangeListener {
     return false;
   }
 
+  public PropStoreMetrics getMetrics() {
+    return cacheMetrics;
+  }
+
   @Override
   public void create(PropStoreKey<?> propStoreKey, Map<String,String> props) {
 
@@ -167,11 +178,6 @@ public class ZooPropStore implements PropStore, PropChangeListener {
       return props;
     }
 
-    if (propStoreKey instanceof SystemPropKey) {
-      return new ConfigTransformer(zrw, codec, propStoreWatcher).transform(propStoreKey,
-          propStoreKey.getPath(), false);
-    }
-
     throw new IllegalStateException(
         "Invalid request for " + propStoreKey + ", the property node does not exist");
   }
@@ -450,9 +456,4 @@ public class ZooPropStore implements PropStore, PropChangeListener {
     return true;
   }
 
-  @Override
-  public void invalidate(PropStoreKey<?> storeKey) {
-    cache.remove(storeKey);
-  }
-
 }
