@@ -81,7 +81,6 @@ public class PropSnapshot implements PropChangeListener {
     updateLock.lock();
     try {
       needsUpdate.set(true);
-      propStore.invalidate(propStoreKey);
     } finally {
       updateLock.unlock();
     }
@@ -114,7 +113,6 @@ public class PropSnapshot implements PropChangeListener {
   public void zkChangeEvent(final PropStoreKey<?> eventPropKey) {
     if (propStoreKey.equals(eventPropKey)) {
       requireUpdate();
-      log.debug("Saw zk change event for {} - update properties required", propStoreKey);
     }
   }
 
@@ -122,7 +120,6 @@ public class PropSnapshot implements PropChangeListener {
   public void cacheChangeEvent(final PropStoreKey<?> eventPropKey) {
     if (propStoreKey.equals(eventPropKey)) {
       requireUpdate();
-      log.debug("Saw cache change event for {} - update properties required", propStoreKey);
     }
   }
 
@@ -130,14 +127,14 @@ public class PropSnapshot implements PropChangeListener {
   public void deleteEvent(final PropStoreKey<?> eventPropKey) {
     if (propStoreKey.equals(eventPropKey)) {
       requireUpdate();
-      log.debug("Received property delete event for {} - update properties required", propStoreKey);
+      log.debug("Received property delete event for {}", propStoreKey);
     }
   }
 
   @Override
   public void connectionEvent() {
     requireUpdate();
-    log.debug("Received connection event for {} - update properties required", propStoreKey);
+    log.debug("Received connection event - update properties required");
   }
 
 }
