@@ -85,7 +85,8 @@ public class ZooInfoViewer implements KeywordExecutable {
       DateTimeFormatter.ISO_OFFSET_DATE_TIME.withZone(ZoneId.from(ZoneOffset.UTC));
   private static final Logger log = LoggerFactory.getLogger(ZooInfoViewer.class);
 
-  private NullWatcher nullWatcher;
+  private final NullWatcher nullWatcher =
+      new NullWatcher(new ReadyMonitor(ZooInfoViewer.class.getSimpleName(), 20_000L));
 
   private static final String INDENT = "  ";
 
@@ -106,7 +107,6 @@ public class ZooInfoViewer implements KeywordExecutable {
 
   @Override
   public void execute(String[] args) throws Exception {
-    nullWatcher = new NullWatcher(new ReadyMonitor(ZooInfoViewer.class.getSimpleName(), 20_000L));
 
     ZooInfoViewer.Opts opts = new ZooInfoViewer.Opts();
     opts.parseArgs(ZooInfoViewer.class.getName(), args);
@@ -115,13 +115,14 @@ public class ZooInfoViewer implements KeywordExecutable {
     log.info("print properties: {}", opts.printProps);
     log.info("print instances: {}", opts.printInstanceIds);
 
-    try (ServerContext context = getContext(opts)) {
-      generateReport(context.getInstanceID(), opts, context.getZooReader());
-    }
-  }
+    var conf = opts.getSiteConfiguration();
 
-  ServerContext getContext(ZooInfoViewer.Opts opts) {
-    return new ServerContext(opts.getSiteConfiguration());
+    ZooReader zooReader = new ZooReaderWriter(conf);
+
+    try (ServerContext context = new ServerContext(conf)) {
+      InstanceId iid = context.getInstanceID();
+      generateReport(iid, opts, zooReader);
+    }
   }
 
   void generateReport(final InstanceId iid, final ZooInfoViewer.Opts opts,
