@@ -61,7 +61,8 @@ import com.google.auto.service.AutoService;
 public class ZooPropEditor implements KeywordExecutable {
 
   private static final Logger LOG = LoggerFactory.getLogger(ZooPropEditor.class);
-  private NullWatcher nullWatcher;
+  private final NullWatcher nullWatcher =
+      new NullWatcher(new ReadyMonitor(ZooInfoViewer.class.getSimpleName(), 20_000L));
 
   /**
    * No-op constructor - provided so ServiceLoader autoload does not consume resources.
@@ -81,8 +82,6 @@ public class ZooPropEditor implements KeywordExecutable {
 
   @Override
   public void execute(String[] args) throws Exception {
-    nullWatcher = new NullWatcher(new ReadyMonitor(ZooInfoViewer.class.getSimpleName(), 20_000L));
-
     ZooPropEditor.Opts opts = new ZooPropEditor.Opts();
     opts.parseArgs(ZooPropEditor.class.getName(), args);
 
