@@ -46,8 +46,7 @@ import org.apache.accumulo.core.iterators.SortedKeyValueIterator;
 import org.apache.accumulo.core.iteratorsImpl.system.InterruptibleIterator;
 import org.apache.accumulo.core.iteratorsImpl.system.SourceSwitchingIterator;
 import org.apache.accumulo.core.iteratorsImpl.system.SourceSwitchingIterator.DataSource;
-import org.apache.accumulo.core.iteratorsImpl.system.TimeSettingIterator;
-import org.apache.accumulo.core.metadata.TabletFile;
+import org.apache.accumulo.core.metadata.StoredTabletFile;
 import org.apache.accumulo.core.metadata.schema.DataFileValue;
 import org.apache.accumulo.core.sample.impl.SamplerConfigurationImpl;
 import org.apache.accumulo.core.util.threads.ThreadPools;
@@ -57,25 +56,24 @@ import org.apache.accumulo.server.problems.ProblemReportingIterator;
 import org.apache.accumulo.server.problems.ProblemReports;
 import org.apache.accumulo.server.problems.ProblemType;
 import org.apache.hadoop.fs.FileSystem;
-import org.apache.hadoop.fs.Path;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.cache.Cache;
+import com.github.benmanes.caffeine.cache.Cache;
 
 public class FileManager {
 
   private static final Logger log = LoggerFactory.getLogger(FileManager.class);
 
-  private final int maxOpen;
+  private int maxOpen;
 
   private static class OpenReader implements Comparable<OpenReader> {
     long releaseTime;
     FileSKVIterator reader;
-    String fileName;
+    StoredTabletFile file;
 
-    public OpenReader(String fileName, FileSKVIterator reader) {
-      this.fileName = fileName;
+    public OpenReader(StoredTabletFile file, FileSKVIterator reader) {
+      this.file = file;
       this.reader = reader;
       this.releaseTime = System.currentTimeMillis();
     }
@@ -95,19 +93,19 @@ public class FileManager {
 
     @Override
     public int hashCode() {
-      return fileName.hashCode();
+      return file.hashCode();
     }
   }
 
-  private final Map<String,List<OpenReader>> openFiles;
-  private final HashMap<FileSKVIterator,String> reservedReaders;
+  private Map<StoredTabletFile,List<OpenReader>> openFiles;
+  private HashMap<FileSKVIterator,StoredTabletFile> reservedReaders;
 
-  private final Semaphore filePermits;
+  private Semaphore filePermits;
 
-  private final Cache<String,Long> fileLenCache;
+  private Cache<String,Long> fileLenCache;
 
-  private final long maxIdleTime;
-  private final long slowFilePermitMillis;
+  private long maxIdleTime;
+  private long slowFilePermitMillis;
 
   private final ServerContext context;
 
@@ -123,9 +121,9 @@ public class FileManager {
       // determine which files to close in a sync block, and then close the
       // files outside of the sync block
       synchronized (FileManager.this) {
-        Iterator<Entry<String,List<OpenReader>>> iter = openFiles.entrySet().iterator();
+        Iterator<Entry<StoredTabletFile,List<OpenReader>>> iter = openFiles.entrySet().iterator();
         while (iter.hasNext()) {
-          Entry<String,List<OpenReader>> entry = iter.next();
+          Entry<StoredTabletFile,List<OpenReader>> entry = iter.next();
           List<OpenReader> ofl = entry.getValue();
 
           for (Iterator<OpenReader> oflIter = ofl.iterator(); oflIter.hasNext();) {
@@ -174,7 +172,7 @@ public class FileManager {
         this.context.getConfiguration().getTimeInMillis(Property.TSERV_SLOW_FILEPERMIT_MILLIS);
   }
 
-  private static int countReaders(Map<String,List<OpenReader>> files) {
+  private static int countReaders(Map<StoredTabletFile,List<OpenReader>> files) {
     int count = 0;
 
     for (List<OpenReader> list : files.values()) {
@@ -188,7 +186,7 @@ public class FileManager {
 
     ArrayList<OpenReader> openReaders = new ArrayList<>();
 
-    for (Entry<String,List<OpenReader>> entry : openFiles.entrySet()) {
+    for (Entry<StoredTabletFile,List<OpenReader>> entry : openFiles.entrySet()) {
       openReaders.addAll(entry.getValue());
     }
 
@@ -199,13 +197,13 @@ public class FileManager {
     for (int i = 0; i < numToTake && i < openReaders.size(); i++) {
       OpenReader or = openReaders.get(i);
 
-      List<OpenReader> ofl = openFiles.get(or.fileName);
+      List<OpenReader> ofl = openFiles.get(or.file);
       if (!ofl.remove(or)) {
-        throw new RuntimeException("Failed to remove open reader that should have been there");
+        throw new IllegalStateException("Failed to remove open reader that should have been there");
       }
 
       if (ofl.isEmpty()) {
-        openFiles.remove(or.fileName);
+        openFiles.remove(or.file);
       }
 
       ret.add(or.reader);
@@ -224,10 +222,10 @@ public class FileManager {
     }
   }
 
-  private List<String> takeOpenFiles(Collection<String> files,
-      Map<FileSKVIterator,String> readersReserved) {
-    List<String> filesToOpen = Collections.emptyList();
-    for (String file : files) {
+  private List<StoredTabletFile> takeOpenFiles(Collection<StoredTabletFile> files,
+      Map<FileSKVIterator,StoredTabletFile> readersReserved) {
+    List<StoredTabletFile> filesToOpen = Collections.emptyList();
+    for (StoredTabletFile file : files) {
       List<OpenReader> ofl = openFiles.get(file);
       if (ofl != null && !ofl.isEmpty()) {
         OpenReader openReader = ofl.remove(ofl.size() - 1);
@@ -245,8 +243,9 @@ public class FileManager {
     return filesToOpen;
   }
 
-  private Map<FileSKVIterator,String> reserveReaders(KeyExtent tablet, Collection<String> files,
-      boolean continueOnFailure, CacheProvider cacheProvider) throws IOException {
+  private Map<FileSKVIterator,StoredTabletFile> reserveReaders(KeyExtent tablet,
+      Collection<StoredTabletFile> files, boolean continueOnFailure, CacheProvider cacheProvider)
+      throws IOException {
 
     if (!tablet.isMeta() && files.size() >= maxOpen) {
       throw new IllegalArgumentException("requested files exceeds max open");
@@ -256,9 +255,9 @@ public class FileManager {
       return Collections.emptyMap();
     }
 
-    List<String> filesToOpen = null;
+    List<StoredTabletFile> filesToOpen = null;
     List<FileSKVIterator> filesToClose = Collections.emptyList();
-    Map<FileSKVIterator,String> readersReserved = new HashMap<>();
+    Map<FileSKVIterator,StoredTabletFile> readersReserved = new HashMap<>();
 
     if (!tablet.isMeta()) {
       long start = System.currentTimeMillis();
@@ -298,24 +297,20 @@ public class FileManager {
     closeReaders(filesToClose);
 
     // open any files that need to be opened
-    for (String file : filesToOpen) {
+    for (StoredTabletFile file : filesToOpen) {
       try {
-        if (!file.contains(":")) {
-          throw new IllegalArgumentException("Expected uri, got : " + file);
-        }
-        Path path = new Path(file);
-        FileSystem ns = context.getVolumeManager().getFileSystemByPath(path);
+        FileSystem ns = context.getVolumeManager().getFileSystemByPath(file.getPath());
         // log.debug("Opening "+file + " path " + path);
         var tableConf = context.getTableConfiguration(tablet.tableId());
         FileSKVIterator reader = FileOperations.getInstance().newReaderBuilder()
-            .forFile(path.toString(), ns, ns.getConf(), tableConf.getCryptoService())
+            .forFile(file, ns, ns.getConf(), tableConf.getCryptoService())
             .withTableConfiguration(tableConf).withCacheProvider(cacheProvider)
             .withFileLenCache(fileLenCache).build();
         readersReserved.put(reader, file);
       } catch (Exception e) {
 
         ProblemReports.getInstance(context)
-            .report(new ProblemReport(tablet.tableId(), ProblemType.FILE_READ, file, e));
+            .report(new ProblemReport(tablet.tableId(), ProblemType.FILE_READ, file.toString(), e));
 
         if (continueOnFailure) {
           // release the permit for the file that failed to open
@@ -349,15 +344,6 @@ public class FileManager {
       boolean sawIOException) {
     // put files in openFiles
 
-    for (FileSKVIterator reader : readers) {
-      try {
-        reader.closeDeepCopies();
-      } catch (IOException e) {
-        log.warn("{}", e.getMessage(), e);
-        sawIOException = true;
-      }
-    }
-
     synchronized (this) {
 
       // check that readers were actually reserved ... want to make sure a thread does
@@ -367,10 +353,18 @@ public class FileManager {
       }
 
       for (FileSKVIterator reader : readers) {
-        String fileName = reservedReaders.remove(reader);
+        try {
+          reader.closeDeepCopies();
+        } catch (IOException e) {
+          log.warn("{}", e.getMessage(), e);
+          sawIOException = true;
+        }
+      }
+
+      for (FileSKVIterator reader : readers) {
+        StoredTabletFile file = reservedReaders.remove(reader);
         if (!sawIOException) {
-          openFiles.computeIfAbsent(fileName, k -> new ArrayList<>())
-              .add(new OpenReader(fileName, reader));
+          openFiles.computeIfAbsent(file, k -> new ArrayList<>()).add(new OpenReader(file, reader));
         }
       }
     }
@@ -389,13 +383,13 @@ public class FileManager {
   static class FileDataSource implements DataSource {
 
     private SortedKeyValueIterator<Key,Value> iter;
-    private final ArrayList<FileDataSource> deepCopies;
+    private ArrayList<FileDataSource> deepCopies;
     private boolean current = true;
     private IteratorEnvironment env;
-    private String file;
+    private StoredTabletFile file;
     private AtomicBoolean iflag;
 
-    FileDataSource(String file, SortedKeyValueIterator<Key,Value> iter) {
+    FileDataSource(StoredTabletFile file, SortedKeyValueIterator<Key,Value> iter) {
       this.file = file;
       this.iter = iter;
       this.deepCopies = new ArrayList<>();
@@ -462,11 +456,11 @@ public class FileManager {
 
   public class ScanFileManager {
 
-    private final ArrayList<FileDataSource> dataSources;
-    private final ArrayList<FileSKVIterator> tabletReservedReaders;
-    private final KeyExtent tablet;
+    private ArrayList<FileDataSource> dataSources;
+    private ArrayList<FileSKVIterator> tabletReservedReaders;
+    private KeyExtent tablet;
     private boolean continueOnFailure;
-    private final CacheProvider cacheProvider;
+    private CacheProvider cacheProvider;
 
     ScanFileManager(KeyExtent tablet, CacheProvider cacheProvider) {
       tabletReservedReaders = new ArrayList<>();
@@ -482,7 +476,7 @@ public class FileManager {
       }
     }
 
-    private Map<FileSKVIterator,String> openFiles(List<String> files)
+    private Map<FileSKVIterator,StoredTabletFile> openFiles(List<StoredTabletFile> files)
         throws TooManyFilesException, IOException {
       // one tablet can not open more than maxOpen files, otherwise it could get stuck
       // forever waiting on itself to release files
@@ -494,26 +488,28 @@ public class FileManager {
                 + maxOpen + " tablet = " + tablet);
       }
 
-      Map<FileSKVIterator,String> newlyReservedReaders =
+      Map<FileSKVIterator,StoredTabletFile> newlyReservedReaders =
           reserveReaders(tablet, files, continueOnFailure, cacheProvider);
 
       tabletReservedReaders.addAll(newlyReservedReaders.keySet());
       return newlyReservedReaders;
     }
 
-    public synchronized List<InterruptibleIterator> openFiles(Map<TabletFile,DataFileValue> files,
-        boolean detachable, SamplerConfigurationImpl samplerConfig) throws IOException {
+    public synchronized List<InterruptibleIterator> openFiles(
+        Map<StoredTabletFile,DataFileValue> files, boolean detachable,
+        SamplerConfigurationImpl samplerConfig) throws IOException {
 
-      Map<FileSKVIterator,String> newlyReservedReaders = openFiles(
-          files.keySet().stream().map(TabletFile::getPathStr).collect(Collectors.toList()));
+      Map<FileSKVIterator,StoredTabletFile> newlyReservedReaders =
+          openFiles(new ArrayList<>(files.keySet()));
 
       ArrayList<InterruptibleIterator> iters = new ArrayList<>();
 
-      boolean sawTimeSet = files.values().stream().anyMatch(DataFileValue::isTimeSet);
+      boolean someIteratorsWillWrap =
+          files.values().stream().anyMatch(DataFileValue::willWrapIterator);
 
-      for (Entry<FileSKVIterator,String> entry : newlyReservedReaders.entrySet()) {
+      for (Entry<FileSKVIterator,StoredTabletFile> entry : newlyReservedReaders.entrySet()) {
         FileSKVIterator source = entry.getKey();
-        String filename = entry.getValue();
+        StoredTabletFile file = entry.getValue();
         InterruptibleIterator iter;
 
         if (samplerConfig != null) {
@@ -523,15 +519,13 @@ public class FileManager {
           }
         }
 
-        iter = new ProblemReportingIterator(context, tablet.tableId(), filename, continueOnFailure,
-            detachable ? getSsi(filename, source) : source);
+        iter = new ProblemReportingIterator(context, tablet.tableId(), file.toString(),
+            continueOnFailure, detachable ? getSsi(file, source) : source);
 
-        if (sawTimeSet) {
+        if (someIteratorsWillWrap) {
           // constructing FileRef is expensive so avoid if not needed
-          DataFileValue value = files.get(new TabletFile(new Path(filename)));
-          if (value.isTimeSet()) {
-            iter = new TimeSettingIterator(iter, value.getTime());
-          }
+          DataFileValue value = files.get(file);
+          iter = value.wrapFileIterator(iter);
         }
 
         iters.add(iter);
@@ -540,8 +534,8 @@ public class FileManager {
       return iters;
     }
 
-    private SourceSwitchingIterator getSsi(String filename, FileSKVIterator source) {
-      FileDataSource fds = new FileDataSource(filename, source);
+    private SourceSwitchingIterator getSsi(StoredTabletFile file, FileSKVIterator source) {
+      FileDataSource fds = new FileDataSource(file, source);
       dataSources.add(fds);
       return new SourceSwitchingIterator(fds);
     }
@@ -561,11 +555,12 @@ public class FileManager {
         throw new IllegalStateException();
       }
 
-      List<String> files = dataSources.stream().map(x -> x.file).collect(Collectors.toList());
-      Map<FileSKVIterator,String> newlyReservedReaders = openFiles(files);
-      Map<String,List<FileSKVIterator>> map = new HashMap<>();
+      List<StoredTabletFile> files =
+          dataSources.stream().map(x -> x.file).collect(Collectors.toList());
+      Map<FileSKVIterator,StoredTabletFile> newlyReservedReaders = openFiles(files);
+      Map<StoredTabletFile,List<FileSKVIterator>> map = new HashMap<>();
       newlyReservedReaders.forEach(
-          (reader, fileName) -> map.computeIfAbsent(fileName, k -> new LinkedList<>()).add(reader));
+          (reader, file) -> map.computeIfAbsent(file, k -> new LinkedList<>()).add(reader));
 
       for (FileDataSource fds : dataSources) {
         FileSKVIterator source = map.get(fds.file).remove(0);
@@ -593,8 +588,4 @@ public class FileManager {
   public ScanFileManager newScanFileManager(KeyExtent tablet, CacheProvider cacheProvider) {
     return new ScanFileManager(tablet, cacheProvider);
   }
-
-  public int getOpenFiles() {
-    return maxOpen - filePermits.availablePermits();
-  }
 }
