@@ -38,14 +38,12 @@ import java.util.concurrent.ExecutionException;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Future;
 import java.util.concurrent.TimeUnit;
-import java.util.stream.Collectors;
 import java.util.stream.Stream;
 
 import org.apache.accumulo.core.conf.AccumuloConfiguration;
 import org.apache.accumulo.core.conf.DefaultConfiguration;
 import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.spi.fs.VolumeChooser;
-import org.apache.accumulo.core.util.Pair;
 import org.apache.accumulo.core.util.threads.ThreadPools;
 import org.apache.accumulo.core.volume.Volume;
 import org.apache.accumulo.core.volume.VolumeConfiguration;
@@ -68,8 +66,6 @@ import org.apache.hadoop.hdfs.protocol.HdfsConstants.SafeModeAction;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.github.benmanes.caffeine.cache.Cache;
-import com.github.benmanes.caffeine.cache.Caffeine;
 import com.google.common.collect.HashMultimap;
 import com.google.common.collect.Multimap;
 
@@ -79,9 +75,6 @@ public class VolumeManagerImpl implements VolumeManager {
 
   private static final HashSet<String> WARNED_ABOUT_SYNCONCLOSE = new HashSet<>();
 
-  private static final Cache<Pair<Configuration,String>,Configuration> HDFS_CONFIGS_FOR_VOLUME =
-      Caffeine.newBuilder().expireAfterWrite(24, TimeUnit.HOURS).build();
-
   private final Map<String,Volume> volumesByName;
   private final Multimap<URI,Volume> volumesByFileSystemUri;
   private final VolumeChooser chooser;
@@ -104,7 +97,7 @@ public class VolumeManagerImpl implements VolumeManager {
       // null chooser handled below
     }
     if (chooser1 == null) {
-      throw new RuntimeException(
+      throw new IllegalStateException(
           "Failed to load volume chooser specified by " + Property.GENERAL_VOLUME_CHOOSER);
     }
     chooser = chooser1;
@@ -228,7 +221,7 @@ public class VolumeManagerImpl implements VolumeManager {
               + " not be configured as false. " + ticketMessage;
           // ACCUMULO-3651 Changed level to error and added FATAL to message for slf4j compatibility
           log.error("FATAL {}", msg);
-          throw new RuntimeException(msg);
+          throw new IllegalStateException(msg);
         }
 
         // Warn if synconclose isn't set
@@ -323,8 +316,8 @@ public class VolumeManagerImpl implements VolumeManager {
   public void bulkRename(Map<Path,Path> oldToNewPathMap, int poolSize, String poolName,
       String transactionId) throws IOException {
     List<Future<Void>> results = new ArrayList<>();
-    ExecutorService workerPool = ThreadPools.getServerThreadPools().getPoolBuilder(poolName)
-        .numCoreThreads(poolSize).build();
+    ExecutorService workerPool =
+        ThreadPools.getServerThreadPools().createFixedThreadPool(poolSize, poolName, false);
     oldToNewPathMap.forEach((oldPath, newPath) -> results.add(workerPool.submit(() -> {
       boolean success;
       try {
@@ -384,41 +377,27 @@ public class VolumeManagerImpl implements VolumeManager {
    * </pre>
    *
    * We will use these properties to return a new Configuration object that can be used with the
-   * FileSystem URI to override properties in the original Configuration. If these properties are
-   * not set for a volume, then the original Configuration is returned. If they are set, a new
-   * Configuration is created with the overridden properties set. In either case, the returned
-   * Configuration is cached, to avoid unnecessary recomputation. This works because these override
-   * properties are instance properties and cannot change while the system is running.
+   * FileSystem URI.
    *
    * @param conf AccumuloConfiguration object
    * @param hadoopConf Hadoop Configuration object
    * @param filesystemURI Volume Filesystem URI
    * @return Hadoop Configuration with custom overrides for this FileSystem
    */
-  protected static Configuration getVolumeManagerConfiguration(AccumuloConfiguration conf,
+  private static Configuration getVolumeManagerConfiguration(AccumuloConfiguration conf,
       final Configuration hadoopConf, final String filesystemURI) {
 
-    final var cacheKey = new Pair<>(hadoopConf, filesystemURI);
-    return HDFS_CONFIGS_FOR_VOLUME.get(cacheKey, (key) -> {
+    final Configuration volumeConfig = new Configuration(hadoopConf);
 
-      Map<String,String> volumeHdfsConfigOverrides =
-          conf.getAllPropertiesWithPrefixStripped(Property.INSTANCE_VOLUME_CONFIG_PREFIX).entrySet()
-              .stream().filter(e -> e.getKey().startsWith(filesystemURI + "."))
-              .collect(Collectors.toUnmodifiableMap(
-                  e -> e.getKey().substring(filesystemURI.length() + 1), Entry::getValue));
+    conf.getAllPropertiesWithPrefixStripped(Property.INSTANCE_VOLUME_CONFIG_PREFIX).entrySet()
+        .stream().filter(e -> e.getKey().startsWith(filesystemURI + ".")).forEach(e -> {
+          String key = e.getKey().substring(filesystemURI.length() + 1);
+          String value = e.getValue();
+          log.info("Overriding property {} for volume {}", key, value, filesystemURI);
+          volumeConfig.set(key, value);
+        });
 
-      // use the original if no overrides exist
-      if (volumeHdfsConfigOverrides.isEmpty()) {
-        return hadoopConf;
-      }
-
-      Configuration volumeConfig = new Configuration(hadoopConf);
-      volumeHdfsConfigOverrides.forEach((k, v) -> {
-        log.info("Overriding property {}={} for volume {}", k, v, filesystemURI);
-        volumeConfig.set(k, v);
-      });
-      return volumeConfig;
-    });
+    return volumeConfig;
   }
 
   protected static Stream<Entry<String,String>>
@@ -506,7 +485,7 @@ public class VolumeManagerImpl implements VolumeManager {
     if (!options.contains(choice)) {
       String msg = "The configured volume chooser, '" + chooser.getClass()
           + "', or one of its delegates returned a volume not in the set of options provided";
-      throw new RuntimeException(msg);
+      throw new IllegalStateException(msg);
     }
     return choice;
   }
@@ -519,7 +498,7 @@ public class VolumeManagerImpl implements VolumeManager {
       if (!options.contains(choice)) {
         String msg = "The configured volume chooser, '" + chooser.getClass()
             + "', or one of its delegates returned a volume not in the set of options provided";
-        throw new RuntimeException(msg);
+        throw new IllegalStateException(msg);
       }
     }
     return choices;
