@@ -28,7 +28,7 @@ import org.apache.hadoop.fs.Path;
 public enum SortedLogState {
   FINISHED("finished"), FAILED("failed");
 
-  private final String marker;
+  private String marker;
 
   private SortedLogState(String marker) {
     this.marker = marker;
