@@ -27,15 +27,16 @@ import org.apache.accumulo.core.logging.TabletLogger;
 import org.apache.accumulo.core.metadata.TServerInstance;
 import org.apache.accumulo.core.metadata.TabletLocationState;
 import org.apache.accumulo.core.metadata.schema.Ample.DataLevel;
-import org.apache.accumulo.core.util.HostAndPort;
 import org.apache.hadoop.fs.Path;
 
+import com.google.common.net.HostAndPort;
+
 /**
  * Wraps a tablet state store and logs important events.
  */
 class LoggingTabletStateStore implements TabletStateStore {
 
-  private final TabletStateStore wrapped;
+  private TabletStateStore wrapped;
 
   LoggingTabletStateStore(TabletStateStore tss) {
     this.wrapped = tss;
