@@ -23,6 +23,7 @@ import java.util.List;
 import java.util.Map;
 
 import org.apache.accumulo.core.clientImpl.ClientContext;
+import org.apache.accumulo.core.metadata.MetadataTable;
 import org.apache.accumulo.core.metadata.TServerInstance;
 import org.apache.accumulo.core.metadata.TabletLocationState;
 import org.apache.accumulo.core.metadata.schema.Ample;
@@ -38,17 +39,21 @@ class MetaDataStateStore implements TabletStateStore {
 
   protected final ClientContext context;
   protected final CurrentState state;
+  private final String targetTableName;
   private final Ample ample;
   private final DataLevel level;
-  private final String name;
 
   protected MetaDataStateStore(DataLevel level, ClientContext context, CurrentState state,
-      String name) {
+      String targetTableName) {
     this.level = level;
     this.context = context;
     this.state = state;
     this.ample = context.getAmple();
-    this.name = name;
+    this.targetTableName = targetTableName;
+  }
+
+  MetaDataStateStore(DataLevel level, ClientContext context, CurrentState state) {
+    this(level, context, state, MetadataTable.NAME);
   }
 
   @Override
@@ -58,7 +63,7 @@ class MetaDataStateStore implements TabletStateStore {
 
   @Override
   public ClosableIterator<TabletLocationState> iterator() {
-    return new MetaDataTableScanner(context, TabletsSection.getRange(), state, level);
+    return new MetaDataTableScanner(context, TabletsSection.getRange(), state, targetTableName);
   }
 
   @Override
@@ -145,8 +150,9 @@ class MetaDataStateStore implements TabletStateStore {
     try (var tabletsMutator = ample.mutateTablets()) {
       for (TabletLocationState tls : tablets) {
         if (tls.suspend != null) {
-          tabletsMutator.mutateTablet(tls.extent).deleteSuspension().mutate();
+          continue;
         }
+        tabletsMutator.mutateTablet(tls.extent).deleteSuspension().mutate();
       }
     } catch (RuntimeException ex) {
       throw new DistributedStoreException(ex);
@@ -155,7 +161,7 @@ class MetaDataStateStore implements TabletStateStore {
 
   @Override
   public String name() {
-    return name;
+    return "Normal Tablets";
   }
 
 }
