@@ -18,8 +18,8 @@
  */
 package org.apache.accumulo.server.manager.state;
 
-import java.io.DataInputStream;
 import java.io.IOException;
+import java.io.UncheckedIOException;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Base64;
@@ -32,7 +32,6 @@ import java.util.Map;
 import java.util.Set;
 
 import org.apache.accumulo.core.client.IteratorSetting;
-import org.apache.accumulo.core.conf.AccumuloConfiguration;
 import org.apache.accumulo.core.data.Key;
 import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.data.Value;
@@ -45,7 +44,6 @@ import org.apache.accumulo.core.metadata.TServerInstance;
 import org.apache.accumulo.core.metadata.TabletLocationState;
 import org.apache.accumulo.core.metadata.TabletLocationState.BadLocationStateException;
 import org.apache.accumulo.core.util.AddressUtil;
-import org.apache.accumulo.server.iterators.ServerIteratorOptions;
 import org.apache.hadoop.io.DataInputBuffer;
 import org.apache.hadoop.io.DataOutputBuffer;
 import org.slf4j.Logger;
@@ -59,9 +57,7 @@ public class TabletStateChangeIterator extends SkippingIterator {
   private static final String TABLES_OPTION = "tables";
   private static final String MERGES_OPTION = "merges";
   private static final String DEBUG_OPTION = "debug";
-  static final String MIGRATIONS_OPTION = "migrations";
-  // this was added in 2.1.4
-  private static final String MIGRATIONS_COUNT_OPTION = "migrationsCount";
+  private static final String MIGRATIONS_OPTION = "migrations";
   private static final String MANAGER_STATE_OPTION = "managerState";
   private static final String SHUTTING_DOWN_OPTION = "shuttingDown";
   private static final Logger log = LoggerFactory.getLogger(TabletStateChangeIterator.class);
@@ -77,65 +73,41 @@ public class TabletStateChangeIterator extends SkippingIterator {
   public void init(SortedKeyValueIterator<Key,Value> source, Map<String,String> options,
       IteratorEnvironment env) throws IOException {
     super.init(source, options, env);
-    current = parseServers(ServerIteratorOptions.decompressOption(options, SERVERS_OPTION));
-    onlineTables = parseTableIDs(ServerIteratorOptions.decompressOption(options, TABLES_OPTION));
+    current = parseServers(options.get(SERVERS_OPTION));
+    onlineTables = parseTableIDs(options.get(TABLES_OPTION));
     merges = parseMerges(options.get(MERGES_OPTION));
     debug = options.containsKey(DEBUG_OPTION);
-    migrations = parseMigrations(options);
+    migrations = parseMigrations(options.get(MIGRATIONS_OPTION));
+    String managerStateOptionName = options.get(MANAGER_STATE_OPTION);
     try {
-      managerState = ManagerState.valueOf(options.get(MANAGER_STATE_OPTION));
-    } catch (Exception ex) {
-      if (options.get(MANAGER_STATE_OPTION) != null) {
-        log.error("Unable to decode managerState {}", options.get(MANAGER_STATE_OPTION));
+      managerState = ManagerState.valueOf(managerStateOptionName);
+    } catch (RuntimeException ex) {
+      if (managerStateOptionName != null) {
+        log.error("Unable to decode managerState {}", managerStateOptionName);
       }
     }
-    Set<TServerInstance> shuttingDown =
-        parseServers(ServerIteratorOptions.decompressOption(options, SHUTTING_DOWN_OPTION));
+    Set<TServerInstance> shuttingDown = parseServers(options.get(SHUTTING_DOWN_OPTION));
     if (current != null && shuttingDown != null) {
       current.removeAll(shuttingDown);
     }
   }
 
-  static Set<KeyExtent> parseMigrations(Map<String,String> options) {
-    String countStr = options.get(MIGRATIONS_COUNT_OPTION);
-    if (countStr != null) {
-      // this was created w/ 2.1.4 or newer so use the new decoding method that supports compression
-      int count = Integer.parseInt(countStr);
-      return ServerIteratorOptions.decompressOption(options, MIGRATIONS_OPTION,
-          dataInput -> decodeMigrations(dataInput, count));
-    } else {
-      // assume this was created by a 2.1.3 manager
-      String migrations = options.get(MIGRATIONS_OPTION);
-      if (migrations == null) {
-        return Collections.emptySet();
-      }
-      try {
-        Set<KeyExtent> result = new HashSet<>();
-        DataInputBuffer buffer = new DataInputBuffer();
-        byte[] data = Base64.getDecoder().decode(migrations);
-        buffer.reset(data, data.length);
-        while (buffer.available() > 0) {
-          result.add(KeyExtent.readFrom(buffer));
-        }
-        return result;
-      } catch (Exception ex) {
-        throw new RuntimeException(ex);
-      }
-    }
-
-  }
-
-  static Set<KeyExtent> decodeMigrations(DataInputStream input, int count) throws IOException {
-    if (input == null) {
+  private Set<KeyExtent> parseMigrations(String migrations) {
+    if (migrations == null) {
       return Collections.emptySet();
     }
-    Set<KeyExtent> result = new HashSet<>();
-    for (int i = 0; i < count; i++) {
-      // need a count and cannot use InputStream.available() because its behavior is not reliable
-      // across InputStream impls
-      result.add(KeyExtent.readFrom(input));
+    try {
+      Set<KeyExtent> result = new HashSet<>();
+      DataInputBuffer buffer = new DataInputBuffer();
+      byte[] data = Base64.getDecoder().decode(migrations);
+      buffer.reset(data, data.length);
+      while (buffer.available() > 0) {
+        result.add(KeyExtent.readFrom(buffer));
+      }
+      return result;
+    } catch (IOException ex) {
+      throw new UncheckedIOException(ex);
     }
-    return result;
   }
 
   private Set<TableId> parseTableIDs(String tableIDs) {
@@ -184,8 +156,8 @@ public class TabletStateChangeIterator extends SkippingIterator {
         result.put(mergeInfo.extent.tableId(), mergeInfo);
       }
       return result;
-    } catch (Exception ex) {
-      throw new RuntimeException(ex);
+    } catch (IOException ex) {
+      throw new UncheckedIOException(ex);
     }
   }
 
@@ -239,9 +211,6 @@ public class TabletStateChangeIterator extends SkippingIterator {
         case ASSIGNED_TO_DEAD_SERVER:
           return;
         case SUSPENDED:
-          // Always return data about suspended tablets. Need to clear the suspension stats when the
-          // tablet is offline. May need to assign the tablet when the tablet is online.
-          return;
         case UNASSIGNED:
           if (shouldBeOnline) {
             return;
@@ -261,23 +230,19 @@ public class TabletStateChangeIterator extends SkippingIterator {
     throw new UnsupportedOperationException();
   }
 
-  public static void setCurrentServers(AccumuloConfiguration aconf, IteratorSetting cfg,
-      Set<TServerInstance> goodServers) {
+  public static void setCurrentServers(IteratorSetting cfg, Set<TServerInstance> goodServers) {
     if (goodServers != null) {
       List<String> servers = new ArrayList<>();
       for (TServerInstance server : goodServers) {
         servers.add(server.getHostPortSession());
       }
-      ServerIteratorOptions.compressOption(aconf, cfg, SERVERS_OPTION,
-          Joiner.on(",").join(servers));
+      cfg.addOption(SERVERS_OPTION, Joiner.on(",").join(servers));
     }
   }
 
-  public static void setOnlineTables(AccumuloConfiguration aconf, IteratorSetting cfg,
-      Set<TableId> onlineTables) {
+  public static void setOnlineTables(IteratorSetting cfg, Set<TableId> onlineTables) {
     if (onlineTables != null) {
-      ServerIteratorOptions.compressOption(aconf, cfg, TABLES_OPTION,
-          Joiner.on(",").join(onlineTables));
+      cfg.addOption(TABLES_OPTION, Joiner.on(",").join(onlineTables));
     }
   }
 
@@ -287,37 +252,39 @@ public class TabletStateChangeIterator extends SkippingIterator {
       for (MergeInfo info : merges) {
         KeyExtent extent = info.getExtent();
         if (extent != null && !info.getState().equals(MergeState.NONE)) {
-
           info.write(buffer);
         }
       }
-    } catch (Exception ex) {
-      throw new RuntimeException(ex);
+    } catch (IOException ex) {
+      throw new UncheckedIOException(ex);
     }
     String encoded =
         Base64.getEncoder().encodeToString(Arrays.copyOf(buffer.getData(), buffer.getLength()));
     cfg.addOption(MERGES_OPTION, encoded);
   }
 
-  public static void setMigrations(AccumuloConfiguration aconf, IteratorSetting cfg,
-      Collection<KeyExtent> migrations) {
-    cfg.addOption(MIGRATIONS_COUNT_OPTION, migrations.size() + "");
-    ServerIteratorOptions.compressOption(aconf, cfg, MIGRATIONS_OPTION, dataOutput -> {
+  public static void setMigrations(IteratorSetting cfg, Collection<KeyExtent> migrations) {
+    DataOutputBuffer buffer = new DataOutputBuffer();
+    try {
       for (KeyExtent extent : migrations) {
-        extent.writeTo(dataOutput);
+        extent.writeTo(buffer);
       }
-    });
+    } catch (IOException ex) {
+      throw new UncheckedIOException(ex);
+    }
+    String encoded =
+        Base64.getEncoder().encodeToString(Arrays.copyOf(buffer.getData(), buffer.getLength()));
+    cfg.addOption(MIGRATIONS_OPTION, encoded);
   }
 
   public static void setManagerState(IteratorSetting cfg, ManagerState state) {
     cfg.addOption(MANAGER_STATE_OPTION, state.toString());
   }
 
-  public static void setShuttingDown(AccumuloConfiguration aconf, IteratorSetting cfg,
-      Set<TServerInstance> servers) {
+  public static void setShuttingDown(IteratorSetting cfg, Set<TServerInstance> servers) {
     if (servers != null) {
-      ServerIteratorOptions.compressOption(aconf, cfg, SHUTTING_DOWN_OPTION,
-          Joiner.on(",").join(servers));
+      cfg.addOption(SHUTTING_DOWN_OPTION, Joiner.on(",").join(servers));
     }
   }
+
 }
