@@ -33,7 +33,6 @@ import java.util.stream.Collectors;
 import java.util.stream.Stream;
 import java.util.stream.StreamSupport;
 
-import org.apache.accumulo.core.client.BatchScanner;
 import org.apache.accumulo.core.client.BatchWriter;
 import org.apache.accumulo.core.client.IsolatedScanner;
 import org.apache.accumulo.core.client.MutationsRejectedException;
@@ -46,7 +45,6 @@ import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.data.Value;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.fate.FateTxId;
-import org.apache.accumulo.core.gc.GcCandidate;
 import org.apache.accumulo.core.gc.ReferenceFile;
 import org.apache.accumulo.core.metadata.MetadataTable;
 import org.apache.accumulo.core.metadata.RootTable;
@@ -74,9 +72,9 @@ import com.google.common.base.Preconditions;
 
 public class ServerAmpleImpl extends AmpleImpl implements Ample {
 
-  private static final Logger log = LoggerFactory.getLogger(ServerAmpleImpl.class);
+  private static Logger log = LoggerFactory.getLogger(ServerAmpleImpl.class);
 
-  private final ServerContext context;
+  private ServerContext context;
 
   public ServerAmpleImpl(ServerContext context) {
     super(context);
@@ -115,7 +113,7 @@ public class ServerAmpleImpl extends AmpleImpl implements Ample {
         return newJson.getBytes(UTF_8);
       });
     } catch (Exception e) {
-      throw new RuntimeException(e);
+      throw new IllegalStateException(e);
     }
   }
 
@@ -132,7 +130,7 @@ public class ServerAmpleImpl extends AmpleImpl implements Ample {
         writer.addMutation(createDeleteMutation(file));
       }
     } catch (MutationsRejectedException | TableNotFoundException e) {
-      throw new RuntimeException(e);
+      throw new IllegalStateException(e);
     }
   }
 
@@ -151,7 +149,7 @@ public class ServerAmpleImpl extends AmpleImpl implements Ample {
         writer.addMutation(createDeleteMutation(fileOrDir));
       }
     } catch (MutationsRejectedException | TableNotFoundException e) {
-      throw new RuntimeException(e);
+      throw new IllegalStateException(e);
     }
   }
 
@@ -166,7 +164,7 @@ public class ServerAmpleImpl extends AmpleImpl implements Ample {
     try (BatchWriter bw = context.createBatchWriter(MetadataTable.NAME)) {
       bw.addMutation(m);
     } catch (MutationsRejectedException | TableNotFoundException e) {
-      throw new RuntimeException(e);
+      throw new IllegalStateException(e);
     }
   }
 
@@ -181,7 +179,7 @@ public class ServerAmpleImpl extends AmpleImpl implements Ample {
     try (BatchWriter bw = context.createBatchWriter(MetadataTable.NAME)) {
       bw.addMutation(m);
     } catch (MutationsRejectedException | TableNotFoundException e) {
-      throw new RuntimeException(e);
+      throw new IllegalStateException(e);
     }
   }
 
@@ -207,48 +205,31 @@ public class ServerAmpleImpl extends AmpleImpl implements Ample {
         }
       }
     } catch (MutationsRejectedException | TableNotFoundException e) {
-      throw new RuntimeException(e);
+      throw new IllegalStateException(e);
     }
   }
 
   @Override
-  public void deleteGcCandidates(DataLevel level, Collection<GcCandidate> candidates,
-      GcCandidateType type) {
+  public void deleteGcCandidates(DataLevel level, Collection<String> paths) {
 
     if (level == DataLevel.ROOT) {
-      if (type == GcCandidateType.INUSE) {
-        // Since there is only a single root tablet, supporting INUSE candidate deletions would add
-        // additional code complexity without any substantial benefit.
-        // Therefore, deletion of root INUSE candidates is not supported.
-        return;
-      }
-      mutateRootGcCandidates(rgcc -> rgcc.remove(candidates.stream()));
+      mutateRootGcCandidates(rgcc -> rgcc.remove(paths.stream()));
       return;
     }
 
     try (BatchWriter writer = context.createBatchWriter(level.metaTable())) {
-      if (type == GcCandidateType.VALID) {
-        for (GcCandidate candidate : candidates) {
-          Mutation m = new Mutation(DeletesSection.encodeRow(candidate.getPath()));
-          // Removes all versions of the candidate to avoid reprocessing deleted file entries
-          m.putDelete(EMPTY_TEXT, EMPTY_TEXT);
-          writer.addMutation(m);
-        }
-      } else {
-        for (GcCandidate candidate : candidates) {
-          Mutation m = new Mutation(DeletesSection.encodeRow(candidate.getPath()));
-          // Removes this and older versions while allowing newer candidate versions to persist
-          m.putDelete(EMPTY_TEXT, EMPTY_TEXT, candidate.getUid());
-          writer.addMutation(m);
-        }
+      for (String path : paths) {
+        Mutation m = new Mutation(DeletesSection.encodeRow(path));
+        m.putDelete(EMPTY_TEXT, EMPTY_TEXT);
+        writer.addMutation(m);
       }
     } catch (MutationsRejectedException | TableNotFoundException e) {
-      throw new RuntimeException(e);
+      throw new IllegalStateException(e);
     }
   }
 
   @Override
-  public Iterator<GcCandidate> getGcCandidates(DataLevel level) {
+  public Iterator<String> getGcCandidates(DataLevel level) {
     if (level == DataLevel.ROOT) {
       var zooReader = context.getZooReader();
       byte[] jsonBytes;
@@ -256,7 +237,7 @@ public class ServerAmpleImpl extends AmpleImpl implements Ample {
         jsonBytes =
             zooReader.getData(context.getZooKeeperRoot() + RootTable.ZROOT_TABLET_GC_CANDIDATES);
       } catch (KeeperException | InterruptedException e) {
-        throw new RuntimeException(e);
+        throw new IllegalStateException(e);
       }
       return new RootGcCandidates(new String(jsonBytes, UTF_8)).sortedStream().iterator();
     } else if (level == DataLevel.METADATA || level == DataLevel.USER) {
@@ -266,14 +247,11 @@ public class ServerAmpleImpl extends AmpleImpl implements Ample {
       try {
         scanner = context.createScanner(level.metaTable(), Authorizations.EMPTY);
       } catch (TableNotFoundException e) {
-        throw new RuntimeException(e);
+        throw new IllegalStateException(e);
       }
       scanner.setRange(range);
       return scanner.stream().filter(entry -> entry.getValue().equals(SkewedKeyValue.NAME))
-          .map(
-              entry -> new GcCandidate(DeletesSection.decodeRow(entry.getKey().getRow().toString()),
-                  entry.getKey().getTimestamp()))
-          .iterator();
+          .map(entry -> DeletesSection.decodeRow(entry.getKey().getRow().toString())).iterator();
     } else {
       throw new IllegalArgumentException();
     }
@@ -294,18 +272,33 @@ public class ServerAmpleImpl extends AmpleImpl implements Ample {
     return delFlag;
   }
 
+  @Override
+  public void
+      putExternalCompactionFinalStates(Collection<ExternalCompactionFinalState> finalStates) {
+    try (BatchWriter writer = context.createBatchWriter(DataLevel.USER.metaTable())) {
+      String prefix = ExternalCompactionSection.getRowPrefix();
+      for (ExternalCompactionFinalState finalState : finalStates) {
+        Mutation m = new Mutation(prefix + finalState.getExternalCompactionId().canonical());
+        m.put("", "", finalState.toJson());
+        writer.addMutation(m);
+      }
+    } catch (MutationsRejectedException | TableNotFoundException e) {
+      throw new IllegalStateException(e);
+    }
+  }
+
   @Override
   public Stream<ExternalCompactionFinalState> getExternalCompactionFinalStates() {
     Scanner scanner;
     try {
       scanner = context.createScanner(DataLevel.USER.metaTable(), Authorizations.EMPTY);
     } catch (TableNotFoundException e) {
-      throw new RuntimeException(e);
+      throw new IllegalStateException(e);
     }
 
     scanner.setRange(ExternalCompactionSection.getRange());
     int pLen = ExternalCompactionSection.getRowPrefix().length();
-    return scanner.stream().onClose(scanner::close)
+    return scanner.stream()
         .map(e -> ExternalCompactionFinalState.fromJson(
             ExternalCompactionId.of(e.getKey().getRowData().toString().substring(pLen)),
             e.getValue().toString()));
@@ -324,15 +317,18 @@ public class ServerAmpleImpl extends AmpleImpl implements Ample {
       log.debug("Deleted external compaction final state entries for external compactions: {}",
           statusesToDelete);
     } catch (MutationsRejectedException | TableNotFoundException e) {
-      throw new RuntimeException(e);
+      throw new IllegalStateException(e);
     }
   }
 
   @Override
   public void putScanServerFileReferences(Collection<ScanServerRefTabletFile> scanRefs) {
     try (BatchWriter writer = context.createBatchWriter(DataLevel.USER.metaTable())) {
+      String prefix = ScanServerFileReferenceSection.getRowPrefix();
       for (ScanServerRefTabletFile ref : scanRefs) {
-        writer.addMutation(ref.putMutation());
+        Mutation m = new Mutation(prefix + ref.getRowSuffix());
+        m.put(ref.getServerAddress(), ref.getServerLockUUID(), ref.getValue());
+        writer.addMutation(m);
       }
     } catch (MutationsRejectedException | TableNotFoundException e) {
       throw new IllegalStateException(
@@ -341,16 +337,14 @@ public class ServerAmpleImpl extends AmpleImpl implements Ample {
   }
 
   @Override
-  @SuppressWarnings("deprecation")
   public Stream<ScanServerRefTabletFile> getScanServerFileReferences() {
     try {
-      BatchScanner scanner =
-          context.createBatchScanner(DataLevel.USER.metaTable(), Authorizations.EMPTY);
-      scanner.setRanges(Set.of(ScanServerFileReferenceSection.getRange(),
-          org.apache.accumulo.core.metadata.schema.MetadataSchema.OldScanServerFileReferenceSection
-              .getRange()));
+      Scanner scanner = context.createScanner(DataLevel.USER.metaTable(), Authorizations.EMPTY);
+      scanner.setRange(ScanServerFileReferenceSection.getRange());
+      int pLen = ScanServerFileReferenceSection.getRowPrefix().length();
       return StreamSupport.stream(scanner.spliterator(), false)
-          .map(e -> new ScanServerRefTabletFile(e.getKey()));
+          .map(e -> new ScanServerRefTabletFile(e.getKey().getRowData().toString().substring(pLen),
+              e.getKey().getColumnFamily(), e.getKey().getColumnQualifier()));
     } catch (TableNotFoundException e) {
       throw new IllegalStateException(DataLevel.USER.metaTable() + " not found!", e);
     }
@@ -362,10 +356,14 @@ public class ServerAmpleImpl extends AmpleImpl implements Ample {
     Objects.requireNonNull(scanServerLockUUID, "Server uuid must be supplied");
     try (
         Scanner scanner = context.createScanner(DataLevel.USER.metaTable(), Authorizations.EMPTY)) {
-      scanner.setRange(ScanServerRefTabletFile.getRange(scanServerLockUUID));
+      scanner.setRange(ScanServerFileReferenceSection.getRange());
+      scanner.fetchColumn(new Text(serverAddress), new Text(scanServerLockUUID.toString()));
 
+      int pLen = ScanServerFileReferenceSection.getRowPrefix().length();
       Set<ScanServerRefTabletFile> refsToDelete = StreamSupport.stream(scanner.spliterator(), false)
-          .map(e -> new ScanServerRefTabletFile(e.getKey())).collect(Collectors.toSet());
+          .map(e -> new ScanServerRefTabletFile(e.getKey().getRowData().toString().substring(pLen),
+              e.getKey().getColumnFamily(), e.getKey().getColumnQualifier()))
+          .collect(Collectors.toSet());
 
       if (!refsToDelete.isEmpty()) {
         this.deleteScanServerFileReferences(refsToDelete);
@@ -378,12 +376,15 @@ public class ServerAmpleImpl extends AmpleImpl implements Ample {
   @Override
   public void deleteScanServerFileReferences(Collection<ScanServerRefTabletFile> refsToDelete) {
     try (BatchWriter writer = context.createBatchWriter(DataLevel.USER.metaTable())) {
+      String prefix = ScanServerFileReferenceSection.getRowPrefix();
       for (ScanServerRefTabletFile ref : refsToDelete) {
-        writer.addMutation(ref.putDeleteMutation());
+        Mutation m = new Mutation(prefix + ref.getRowSuffix());
+        m.putDelete(ref.getServerAddress(), ref.getServerLockUUID());
+        writer.addMutation(m);
       }
       log.debug("Deleted scan server file reference entries for files: {}", refsToDelete);
     } catch (MutationsRejectedException | TableNotFoundException e) {
-      throw new RuntimeException(e);
+      throw new IllegalStateException(e);
     }
   }
 
