@@ -33,7 +33,7 @@ import com.google.common.base.Preconditions;
 
 public class TabletsMutatorImpl implements TabletsMutator {
 
-  private final ServerContext context;
+  private ServerContext context;
 
   private BatchWriter rootWriter;
   private BatchWriter metaWriter;
@@ -61,7 +61,7 @@ public class TabletsMutatorImpl implements TabletsMutator {
         return metaWriter;
       }
     } catch (TableNotFoundException e) {
-      throw new RuntimeException(e);
+      throw new IllegalStateException(e);
     }
   }
 
@@ -85,7 +85,7 @@ public class TabletsMutatorImpl implements TabletsMutator {
         metaWriter.close();
       }
     } catch (MutationsRejectedException e) {
-      throw new RuntimeException(e);
+      throw new IllegalStateException(e);
     }
 
   }
