@@ -37,16 +37,16 @@ import org.apache.accumulo.core.data.Value;
 import org.apache.accumulo.core.fate.zookeeper.ZooReaderWriter;
 import org.apache.accumulo.core.fate.zookeeper.ZooUtil.NodeExistsPolicy;
 import org.apache.accumulo.core.fate.zookeeper.ZooUtil.NodeMissingPolicy;
-import org.apache.accumulo.core.metadata.MetadataTable;
 import org.apache.accumulo.core.metadata.schema.MetadataSchema.ProblemSection;
 import org.apache.accumulo.core.util.Encoding;
 import org.apache.accumulo.server.ServerContext;
+import org.apache.accumulo.server.util.MetadataTableUtil;
 import org.apache.zookeeper.KeeperException;
 
 public class ProblemReport {
-  private final TableId tableId;
-  private final ProblemType problemType;
-  private final String resource;
+  private TableId tableId;
+  private ProblemType problemType;
+  private String resource;
   private String exception;
   private String server;
   private long creationTime;
@@ -142,17 +142,13 @@ public class ProblemReport {
   void removeFromMetadataTable(ServerContext context) throws Exception {
     Mutation m = new Mutation(ProblemSection.getRowPrefix() + tableId);
     m.putDelete(problemType.name(), resource);
-    try (var writer = context.createBatchWriter(MetadataTable.NAME)) {
-      writer.addMutation(m);
-    }
+    MetadataTableUtil.getMetadataTable(context).update(m);
   }
 
   void saveToMetadataTable(ServerContext context) throws Exception {
     Mutation m = new Mutation(ProblemSection.getRowPrefix() + tableId);
     m.put(problemType.name(), resource, new Value(encode()));
-    try (var writer = context.createBatchWriter(MetadataTable.NAME)) {
-      writer.addMutation(m);
-    }
+    MetadataTableUtil.getMetadataTable(context).update(m);
   }
 
   void removeFromZooKeeper(ServerContext context) throws Exception {
