@@ -18,8 +18,8 @@
  */
 package org.apache.accumulo.server.problems;
 
-import static java.util.concurrent.TimeUnit.SECONDS;
-
+import java.io.IOException;
+import java.io.UncheckedIOException;
 import java.util.Collections;
 import java.util.EnumMap;
 import java.util.Iterator;
@@ -36,6 +36,7 @@ import java.util.concurrent.TimeUnit;
 import org.apache.accumulo.core.Constants;
 import org.apache.accumulo.core.client.IteratorSetting;
 import org.apache.accumulo.core.client.Scanner;
+import org.apache.accumulo.core.client.TableNotFoundException;
 import org.apache.accumulo.core.conf.SiteConfiguration;
 import org.apache.accumulo.core.data.Key;
 import org.apache.accumulo.core.data.Mutation;
@@ -50,7 +51,9 @@ import org.apache.accumulo.core.metadata.schema.MetadataSchema.ProblemSection;
 import org.apache.accumulo.core.security.Authorizations;
 import org.apache.accumulo.core.util.threads.ThreadPools;
 import org.apache.accumulo.server.ServerContext;
+import org.apache.accumulo.server.util.MetadataTableUtil;
 import org.apache.commons.collections4.map.LRUMap;
+import org.apache.zookeeper.KeeperException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -67,13 +70,12 @@ public class ProblemReports implements Iterable<ProblemReport> {
    * processed because the whole system is in a really bad state (like HDFS is down) and everything
    * is reporting lots of problems, but problem reports can not be processed
    */
-  private final ExecutorService reportExecutor = ThreadPools.getServerThreadPools()
-      .getPoolBuilder("problem.reporter").numCoreThreads(0).numMaxThreads(1)
-      .withTimeOut(60L, SECONDS).withQueue(new LinkedBlockingQueue<>(500)).build();
+  private ExecutorService reportExecutor = ThreadPools.getServerThreadPools().createThreadPool(0, 1,
+      60, TimeUnit.SECONDS, "acu-problem-reporter", new LinkedBlockingQueue<>(500), false);
 
   private final ServerContext context;
 
-  private ProblemReports(ServerContext context) {
+  public ProblemReports(ServerContext context) {
     this.context = context;
   }
 
@@ -174,9 +176,7 @@ public class ProblemReports implements Iterable<ProblemReport> {
     }
 
     if (hasProblems) {
-      try (var writer = context.createBatchWriter(MetadataTable.NAME)) {
-        writer.addMutation(delMut);
-      }
+      MetadataTableUtil.getMetadataTable(context).update(delMut);
     }
   }
 
@@ -185,97 +185,93 @@ public class ProblemReports implements Iterable<ProblemReport> {
   }
 
   public Iterator<ProblemReport> iterator(final TableId table) {
-    try {
+    return new Iterator<>() {
 
-      return new Iterator<>() {
+      ZooReaderWriter zoo = context.getZooReaderWriter();
+      private int iter1Count = 0;
+      private Iterator<String> iter1;
 
-        final ZooReaderWriter zoo = context.getZooReaderWriter();
-        private int iter1Count = 0;
-        private Iterator<String> iter1;
-
-        private Iterator<String> getIter1() {
-          if (iter1 == null) {
-            try {
-              List<String> children;
-              if (table == null || isMeta(table)) {
-                children = zoo.getChildren(context.getZooKeeperRoot() + Constants.ZPROBLEMS);
-              } else {
-                children = Collections.emptyList();
-              }
-              iter1 = children.iterator();
-            } catch (Exception e) {
-              throw new RuntimeException(e);
-            }
-          }
-
-          return iter1;
-        }
-
-        private Iterator<Entry<Key,Value>> iter2;
-
-        private Iterator<Entry<Key,Value>> getIter2() {
-          if (iter2 == null) {
-            try {
-              if ((table == null || !isMeta(table)) && iter1Count == 0) {
-                Scanner scanner = context.createScanner(MetadataTable.NAME, Authorizations.EMPTY);
-                scanner.setTimeout(3, TimeUnit.SECONDS);
-
-                if (table == null) {
-                  scanner.setRange(ProblemSection.getRange());
-                } else {
-                  scanner.setRange(new Range(ProblemSection.getRowPrefix() + table));
-                }
-
-                iter2 = scanner.iterator();
-
-              } else {
-                Map<Key,Value> m = Collections.emptyMap();
-                iter2 = m.entrySet().iterator();
-              }
-            } catch (Exception e) {
-              throw new RuntimeException(e);
-            }
-          }
-
-          return iter2;
-        }
-
-        @Override
-        public boolean hasNext() {
-          if (getIter1().hasNext()) {
-            return true;
-          }
-          return getIter2().hasNext();
-        }
-
-        @Override
-        public ProblemReport next() {
+      private Iterator<String> getIter1() {
+        if (iter1 == null) {
           try {
-            if (getIter1().hasNext()) {
-              iter1Count++;
-              return ProblemReport.decodeZooKeeperEntry(context, getIter1().next());
+            List<String> children;
+            if (table == null || isMeta(table)) {
+              children = zoo.getChildren(context.getZooKeeperRoot() + Constants.ZPROBLEMS);
+            } else {
+              children = Collections.emptyList();
             }
+            iter1 = children.iterator();
+          } catch (KeeperException | InterruptedException e) {
+            throw new IllegalStateException(e);
+          }
+        }
 
-            if (getIter2().hasNext()) {
-              return ProblemReport.decodeMetadataEntry(getIter2().next());
+        return iter1;
+      }
+
+      private Iterator<Entry<Key,Value>> iter2;
+
+      private Iterator<Entry<Key,Value>> getIter2() {
+        if (iter2 == null) {
+          try {
+            if ((table == null || !isMeta(table)) && iter1Count == 0) {
+              Scanner scanner = context.createScanner(MetadataTable.NAME, Authorizations.EMPTY);
+              scanner.setTimeout(3, TimeUnit.SECONDS);
+
+              if (table == null) {
+                scanner.setRange(ProblemSection.getRange());
+              } else {
+                scanner.setRange(new Range(ProblemSection.getRowPrefix() + table));
+              }
+
+              iter2 = scanner.iterator();
+
+            } else {
+              Map<Key,Value> m = Collections.emptyMap();
+              iter2 = m.entrySet().iterator();
             }
-          } catch (Exception e) {
-            throw new RuntimeException(e);
+          } catch (TableNotFoundException e) {
+            throw new IllegalStateException(e);
+          }
+        }
+
+        return iter2;
+      }
+
+      @Override
+      public boolean hasNext() {
+        if (getIter1().hasNext()) {
+          return true;
+        }
+        return getIter2().hasNext();
+      }
+
+      @Override
+      public ProblemReport next() {
+        try {
+          if (getIter1().hasNext()) {
+            iter1Count++;
+            return ProblemReport.decodeZooKeeperEntry(context, getIter1().next());
           }
 
-          throw new NoSuchElementException();
+          if (getIter2().hasNext()) {
+            return ProblemReport.decodeMetadataEntry(getIter2().next());
+          }
+        } catch (IOException e) {
+          throw new UncheckedIOException(e);
+        } catch (KeeperException | InterruptedException e) {
+          throw new IllegalStateException(e);
         }
 
-        @Override
-        public void remove() {
-          throw new UnsupportedOperationException();
-        }
+        throw new NoSuchElementException();
+      }
 
-      };
+      @Override
+      public void remove() {
+        throw new UnsupportedOperationException();
+      }
 
-    } catch (Exception e) {
-      throw new RuntimeException(e);
-    }
+    };
   }
 
   @Override
