@@ -24,12 +24,11 @@ import org.apache.accumulo.core.compaction.thrift.CompactorService;
 import org.apache.accumulo.core.gc.thrift.GCMonitorService;
 import org.apache.accumulo.core.manager.thrift.FateService;
 import org.apache.accumulo.core.manager.thrift.ManagerClientService;
-import org.apache.accumulo.core.process.thrift.ServerProcessService;
-import org.apache.accumulo.core.replication.thrift.ReplicationCoordinator;
-import org.apache.accumulo.core.replication.thrift.ReplicationServicer;
 import org.apache.accumulo.core.rpc.clients.ThriftClientTypes;
-import org.apache.accumulo.core.tabletserver.thrift.TabletClientService;
-import org.apache.accumulo.core.tabletserver.thrift.TabletScanClientService;
+import org.apache.accumulo.core.tablet.thrift.TabletManagementClientService;
+import org.apache.accumulo.core.tabletingest.thrift.TabletIngestClientService;
+import org.apache.accumulo.core.tabletscan.thrift.TabletScanClientService;
+import org.apache.accumulo.core.tabletserver.thrift.TabletServerClientService;
 import org.apache.accumulo.core.trace.TraceUtil;
 import org.apache.accumulo.server.ServerContext;
 import org.apache.accumulo.server.client.ClientServiceHandler;
@@ -82,66 +81,48 @@ public class ThriftProcessorTypes<C extends TServiceClient> extends ThriftClient
   private static final ThriftProcessorTypes<ManagerClientService.Client> MANAGER =
       new ThriftProcessorTypes<>(ThriftClientTypes.MANAGER);
 
-  private static final ThriftProcessorTypes<ReplicationCoordinator.Client> REPLICATION_COORDINATOR =
-      new ThriftProcessorTypes<>(ThriftClientTypes.REPLICATION_COORDINATOR);
-
-  private static final ThriftProcessorTypes<ReplicationServicer.Client> REPLICATION_SERVICER =
-      new ThriftProcessorTypes<>(ThriftClientTypes.REPLICATION_SERVICER);
-
   @VisibleForTesting
-  public static final ThriftProcessorTypes<TabletClientService.Client> TABLET_SERVER =
+  public static final ThriftProcessorTypes<TabletServerClientService.Client> TABLET_SERVER =
       new ThriftProcessorTypes<>(ThriftClientTypes.TABLET_SERVER);
 
   @VisibleForTesting
-  public static final ThriftProcessorTypes<TabletScanClientService.Client> TABLET_SERVER_SCAN =
+  public static final ThriftProcessorTypes<TabletScanClientService.Client> TABLET_SCAN =
       new ThriftProcessorTypes<>(ThriftClientTypes.TABLET_SCAN);
 
-  public static final ThriftProcessorTypes<ServerProcessService.Client> SERVER_PROCESS =
-      new ThriftProcessorTypes<>(ThriftClientTypes.SERVER_PROCESS);
+  public static final ThriftProcessorTypes<TabletIngestClientService.Client> TABLET_INGEST =
+      new ThriftProcessorTypes<>(ThriftClientTypes.TABLET_INGEST);
 
-  public static TMultiplexedProcessor getCompactorTProcessor(
-      ServerProcessService.Iface processHandler, CompactorService.Iface serviceHandler,
+  public static final ThriftProcessorTypes<TabletManagementClientService.Client> TABLET_MGMT =
+      new ThriftProcessorTypes<>(ThriftClientTypes.TABLET_MGMT);
+
+  public static TMultiplexedProcessor getCompactorTProcessor(CompactorService.Iface serviceHandler,
       ServerContext context) {
     TMultiplexedProcessor muxProcessor = new TMultiplexedProcessor();
-    muxProcessor.registerProcessor(SERVER_PROCESS.getServiceName(),
-        SERVER_PROCESS.getTProcessor(ServerProcessService.Processor.class,
-            ServerProcessService.Iface.class, processHandler, context));
     muxProcessor.registerProcessor(COMPACTOR.getServiceName(), COMPACTOR.getTProcessor(
         CompactorService.Processor.class, CompactorService.Iface.class, serviceHandler, context));
     return muxProcessor;
   }
 
   public static TMultiplexedProcessor getCoordinatorTProcessor(
-      ServerProcessService.Iface processHandler, CompactionCoordinatorService.Iface serviceHandler,
-      ServerContext context) {
+      CompactionCoordinatorService.Iface serviceHandler, ServerContext context) {
     TMultiplexedProcessor muxProcessor = new TMultiplexedProcessor();
-    muxProcessor.registerProcessor(SERVER_PROCESS.getServiceName(),
-        SERVER_PROCESS.getTProcessor(ServerProcessService.Processor.class,
-            ServerProcessService.Iface.class, processHandler, context));
     muxProcessor.registerProcessor(COORDINATOR.getServiceName(),
         COORDINATOR.getTProcessor(CompactionCoordinatorService.Processor.class,
             CompactionCoordinatorService.Iface.class, serviceHandler, context));
     return muxProcessor;
   }
 
-  public static TMultiplexedProcessor getGcTProcessor(ServerProcessService.Iface processHandler,
-      GCMonitorService.Iface serviceHandler, ServerContext context) {
+  public static TMultiplexedProcessor getGcTProcessor(GCMonitorService.Iface serviceHandler,
+      ServerContext context) {
     TMultiplexedProcessor muxProcessor = new TMultiplexedProcessor();
-    muxProcessor.registerProcessor(SERVER_PROCESS.getServiceName(),
-        SERVER_PROCESS.getTProcessor(ServerProcessService.Processor.class,
-            ServerProcessService.Iface.class, processHandler, context));
     muxProcessor.registerProcessor(GC.getServiceName(), GC.getTProcessor(
         GCMonitorService.Processor.class, GCMonitorService.Iface.class, serviceHandler, context));
     return muxProcessor;
   }
 
-  public static TMultiplexedProcessor getManagerTProcessor(
-      ServerProcessService.Iface processHandler, FateService.Iface fateServiceHandler,
+  public static TMultiplexedProcessor getManagerTProcessor(FateService.Iface fateServiceHandler,
       ManagerClientService.Iface managerServiceHandler, ServerContext context) {
     TMultiplexedProcessor muxProcessor = new TMultiplexedProcessor();
-    muxProcessor.registerProcessor(SERVER_PROCESS.getServiceName(),
-        SERVER_PROCESS.getTProcessor(ServerProcessService.Processor.class,
-            ServerProcessService.Iface.class, processHandler, context));
     muxProcessor.registerProcessor(FATE.getServiceName(), FATE.getTProcessor(
         FateService.Processor.class, FateService.Iface.class, fateServiceHandler, context));
     muxProcessor.registerProcessor(MANAGER.getServiceName(),
@@ -150,53 +131,35 @@ public class ThriftProcessorTypes<C extends TServiceClient> extends ThriftClient
     return muxProcessor;
   }
 
-  public static TMultiplexedProcessor getReplicationCoordinatorTProcessor(
-      ReplicationCoordinator.Iface serviceHandler, ServerContext context) {
+  public static TMultiplexedProcessor
+      getScanServerTProcessor(TabletScanClientService.Iface tserverHandler, ServerContext context) {
     TMultiplexedProcessor muxProcessor = new TMultiplexedProcessor();
-    muxProcessor.registerProcessor(REPLICATION_COORDINATOR.getServiceName(),
-        REPLICATION_COORDINATOR.getTProcessor(ReplicationCoordinator.Processor.class,
-            ReplicationCoordinator.Iface.class, serviceHandler, context));
-    return muxProcessor;
-  }
-
-  public static TMultiplexedProcessor getReplicationClientTProcessor(
-      ReplicationServicer.Iface serviceHandler, ServerContext context) {
-    TMultiplexedProcessor muxProcessor = new TMultiplexedProcessor();
-    muxProcessor.registerProcessor(REPLICATION_SERVICER.getServiceName(),
-        REPLICATION_SERVICER.getTProcessor(ReplicationServicer.Processor.class,
-            ReplicationServicer.Iface.class, serviceHandler, context));
-    return muxProcessor;
-  }
-
-  public static TMultiplexedProcessor getScanServerTProcessor(
-      ServerProcessService.Iface processHandler, TabletScanClientService.Iface tserverHandler,
-      ServerContext context) {
-    TMultiplexedProcessor muxProcessor = new TMultiplexedProcessor();
-    muxProcessor.registerProcessor(SERVER_PROCESS.getServiceName(),
-        SERVER_PROCESS.getTProcessor(ServerProcessService.Processor.class,
-            ServerProcessService.Iface.class, processHandler, context));
-    muxProcessor.registerProcessor(TABLET_SERVER_SCAN.getServiceName(),
-        TABLET_SERVER_SCAN.getTProcessor(TabletScanClientService.Processor.class,
+    muxProcessor.registerProcessor(TABLET_SCAN.getServiceName(),
+        TABLET_SCAN.getTProcessor(TabletScanClientService.Processor.class,
             TabletScanClientService.Iface.class, tserverHandler, context));
     return muxProcessor;
   }
 
-  public static TMultiplexedProcessor getTabletServerTProcessor(
-      ServerProcessService.Iface processHandler, ClientServiceHandler clientHandler,
-      TabletClientService.Iface tserverHandler, TabletScanClientService.Iface tserverScanHandler,
-      ServerContext context) {
+  public static TMultiplexedProcessor getTabletServerTProcessor(ClientServiceHandler clientHandler,
+      TabletServerClientService.Iface tserverHandler,
+      TabletScanClientService.Iface tserverScanHandler,
+      TabletIngestClientService.Iface tserverIngestHandler,
+      TabletManagementClientService.Iface tserverMgmtHandler, ServerContext context) {
     TMultiplexedProcessor muxProcessor = new TMultiplexedProcessor();
-    muxProcessor.registerProcessor(SERVER_PROCESS.getServiceName(),
-        SERVER_PROCESS.getTProcessor(ServerProcessService.Processor.class,
-            ServerProcessService.Iface.class, processHandler, context));
     muxProcessor.registerProcessor(CLIENT.getServiceName(), CLIENT.getTProcessor(
         ClientService.Processor.class, ClientService.Iface.class, clientHandler, context));
     muxProcessor.registerProcessor(TABLET_SERVER.getServiceName(),
-        TABLET_SERVER.getTProcessor(TabletClientService.Processor.class,
-            TabletClientService.Iface.class, tserverHandler, context));
-    muxProcessor.registerProcessor(TABLET_SERVER_SCAN.getServiceName(),
-        TABLET_SERVER_SCAN.getTProcessor(TabletScanClientService.Processor.class,
+        TABLET_SERVER.getTProcessor(TabletServerClientService.Processor.class,
+            TabletServerClientService.Iface.class, tserverHandler, context));
+    muxProcessor.registerProcessor(TABLET_SCAN.getServiceName(),
+        TABLET_SCAN.getTProcessor(TabletScanClientService.Processor.class,
             TabletScanClientService.Iface.class, tserverScanHandler, context));
+    muxProcessor.registerProcessor(TABLET_INGEST.getServiceName(),
+        TABLET_INGEST.getTProcessor(TabletIngestClientService.Processor.class,
+            TabletIngestClientService.Iface.class, tserverIngestHandler, context));
+    muxProcessor.registerProcessor(TABLET_MGMT.getServiceName(),
+        TABLET_MGMT.getTProcessor(TabletManagementClientService.Processor.class,
+            TabletManagementClientService.Iface.class, tserverMgmtHandler, context));
     return muxProcessor;
   }
 
