@@ -18,17 +18,13 @@
  */
 package org.apache.accumulo.server.security;
 
-import static java.util.stream.Collectors.toList;
-import static java.util.stream.Collectors.toMap;
-
 import java.nio.ByteBuffer;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.List;
 import java.util.Map;
-import java.util.Map.Entry;
 import java.util.Set;
-import java.util.function.Supplier;
+import java.util.stream.Collectors;
 
 import org.apache.accumulo.core.client.TableNotFoundException;
 import org.apache.accumulo.core.clientImpl.Credentials;
@@ -40,6 +36,7 @@ import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.dataImpl.thrift.IterInfo;
 import org.apache.accumulo.core.dataImpl.thrift.TColumn;
+import org.apache.accumulo.core.dataImpl.thrift.TKeyExtent;
 import org.apache.accumulo.core.dataImpl.thrift.TRange;
 import org.apache.accumulo.core.manager.thrift.FateOperation;
 import org.apache.accumulo.core.metadata.MetadataTable;
@@ -141,22 +138,26 @@ public class AuditedSecurityOperation extends SecurityOperation {
     return result;
   }
 
-  private boolean canScan(TCredentials credentials, TableId tableId, NamespaceId namespaceId,
-      Supplier<String> rangeStringSupplier, List<TColumn> columns, List<IterInfo> ssiList,
+  @Override
+  public boolean canScan(TCredentials credentials, TableId tableId, NamespaceId namespaceId,
+      TRange range, List<TColumn> columns, List<IterInfo> ssiList,
       Map<String,Map<String,String>> ssio, List<ByteBuffer> authorizations)
       throws ThriftSecurityException {
     if (shouldAudit(credentials, tableId)) {
-      String rangeString = rangeStringSupplier.get();
-      List<String> convertedColumns = truncate(columns.stream().map(Column::new).collect(toList()));
+      Range convertedRange = new Range(range);
+      List<String> convertedColumns =
+          truncate(columns.stream().map(Column::new).collect(Collectors.toList()));
       String tableName = getTableName(tableId);
+
       try {
         boolean canScan = super.canScan(credentials, tableId, namespaceId);
         audit(credentials, canScan, CAN_SCAN_AUDIT_TEMPLATE, tableName,
-            getAuthString(authorizations), rangeString, convertedColumns, ssiList, ssio);
+            getAuthString(authorizations), convertedRange, convertedColumns, ssiList, ssio);
+
         return canScan;
       } catch (ThriftSecurityException ex) {
         audit(credentials, ex, CAN_SCAN_AUDIT_TEMPLATE, getAuthString(authorizations), tableId,
-            rangeString, convertedColumns, ssiList, ssio);
+            convertedRange, convertedColumns, ssiList, ssio);
         throw ex;
       }
     } else {
@@ -164,30 +165,41 @@ public class AuditedSecurityOperation extends SecurityOperation {
     }
   }
 
-  public boolean canScan(TCredentials credentials, TableId tableId, NamespaceId namespaceId,
-      TRange range, List<TColumn> columns, List<IterInfo> ssiList,
-      Map<String,Map<String,String>> ssio, List<ByteBuffer> authorizations)
-      throws ThriftSecurityException {
-    Supplier<String> rangeToString = () -> new Range(range).toString();
-    return canScan(credentials, tableId, namespaceId, rangeToString, columns, ssiList, ssio,
-        authorizations);
-  }
+  public static final String CAN_SCAN_BATCH_AUDIT_TEMPLATE =
+      "action: scan; targetTable: %s; authorizations: %s; range: %s; columns: %s;"
+          + " iterators: %s; iteratorOptions: %s;";
 
+  @Override
   public boolean canScan(TCredentials credentials, TableId tableId, NamespaceId namespaceId,
-      Map<KeyExtent,List<TRange>> tbatch, List<TColumn> columns, List<IterInfo> ssiList,
+      Map<TKeyExtent,List<TRange>> tbatch, List<TColumn> tcolumns, List<IterInfo> ssiList,
       Map<String,Map<String,String>> ssio, List<ByteBuffer> authorizations)
       throws ThriftSecurityException {
-    Supplier<String> rangeToString = () -> {
+    if (shouldAudit(credentials, tableId)) {
+
       // @formatter:off
-      Map<KeyExtent,List<String>> truncated = tbatch.entrySet().stream().collect(toMap(
-          Entry::getKey,
-          entry -> truncate(entry.getValue().stream().map(Range::new).collect(toList()))
+      Map<KeyExtent, List<String>> truncated = tbatch.entrySet().stream().collect(Collectors.toMap(
+                      entry -> KeyExtent.fromThrift(entry.getKey()),
+                      entry -> truncate(entry.getValue().stream().map(Range::new).collect(Collectors.toList()))
       ));
       // @formatter:on
-      return truncated.toString();
-    };
-    return canScan(credentials, tableId, namespaceId, rangeToString, columns, ssiList, ssio,
-        authorizations);
+      List<Column> convertedColumns =
+          tcolumns.stream().map(Column::new).collect(Collectors.toList());
+      String tableName = getTableName(tableId);
+
+      try {
+        boolean canScan = super.canScan(credentials, tableId, namespaceId);
+        audit(credentials, canScan, CAN_SCAN_BATCH_AUDIT_TEMPLATE, tableName,
+            getAuthString(authorizations), truncated, convertedColumns, ssiList, ssio);
+
+        return canScan;
+      } catch (ThriftSecurityException ex) {
+        audit(credentials, ex, CAN_SCAN_BATCH_AUDIT_TEMPLATE, getAuthString(authorizations),
+            tableId, truncated, convertedColumns, ssiList, ssio);
+        throw ex;
+      }
+    } else {
+      return super.canScan(credentials, tableId, namespaceId);
+    }
   }
 
   public static final String CHANGE_AUTHORIZATIONS_AUDIT_TEMPLATE =
@@ -610,10 +622,10 @@ public class AuditedSecurityOperation extends SecurityOperation {
 
   @Override
   public void grantTablePermission(TCredentials credentials, String user, TableId tableId,
-      String tableName, TablePermission permission, NamespaceId namespaceId)
-      throws ThriftSecurityException, TableNotFoundException {
+      TablePermission permission, NamespaceId namespaceId) throws ThriftSecurityException {
+    String tableName = getTableName(tableId);
     try {
-      super.grantTablePermission(credentials, user, tableId, tableName, permission, namespaceId);
+      super.grantTablePermission(credentials, user, tableId, permission, namespaceId);
       audit(credentials, GRANT_TABLE_PERMISSION_AUDIT_TEMPLATE, permission, tableName, user);
     } catch (ThriftSecurityException ex) {
       audit(credentials, ex, GRANT_TABLE_PERMISSION_AUDIT_TEMPLATE, permission, tableName, user);
@@ -738,5 +750,4 @@ public class AuditedSecurityOperation extends SecurityOperation {
       throw e;
     }
   }
-
 }
