@@ -22,10 +22,10 @@ import static java.nio.charset.StandardCharsets.UTF_8;
 
 import java.nio.ByteBuffer;
 import java.util.List;
+import java.util.Map;
 import java.util.Set;
 import java.util.function.Supplier;
 
-import org.apache.accumulo.core.Constants;
 import org.apache.accumulo.core.client.AccumuloSecurityException;
 import org.apache.accumulo.core.client.NamespaceNotFoundException;
 import org.apache.accumulo.core.client.TableNotFoundException;
@@ -37,6 +37,10 @@ import org.apache.accumulo.core.clientImpl.thrift.ThriftSecurityException;
 import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.data.NamespaceId;
 import org.apache.accumulo.core.data.TableId;
+import org.apache.accumulo.core.dataImpl.thrift.IterInfo;
+import org.apache.accumulo.core.dataImpl.thrift.TColumn;
+import org.apache.accumulo.core.dataImpl.thrift.TKeyExtent;
+import org.apache.accumulo.core.dataImpl.thrift.TRange;
 import org.apache.accumulo.core.fate.zookeeper.ZooCache;
 import org.apache.accumulo.core.manager.thrift.FateOperation;
 import org.apache.accumulo.core.metadata.MetadataTable;
@@ -101,7 +105,7 @@ public class SecurityOperation {
   protected SecurityOperation(ServerContext context, Authorizor author, Authenticator authent,
       PermissionHandler pm) {
     this.context = context;
-    zkUserPath = Constants.ZROOT + "/" + context.getInstanceID() + "/users";
+    zkUserPath = context.zkUserPath();
     zooCache = new ZooCache(context.getZooReader(), null);
     rootUserName = Suppliers.memoize(() -> new String(zooCache.get(zkUserPath), UTF_8));
     authorizor = author;
@@ -111,7 +115,7 @@ public class SecurityOperation {
     if (!authorizor.validSecurityHandlers(authenticator, pm)
         || !authenticator.validSecurityHandlers()
         || !permHandle.validSecurityHandlers(authent, author)) {
-      throw new RuntimeException(authorizor + ", " + authenticator + ", and " + pm
+      throw new IllegalStateException(authorizor + ", " + authenticator + ", and " + pm
           + " do not play nice with each other. Please choose authentication and"
           + " authorization mechanisms that are compatible with one another.");
     }
@@ -134,7 +138,7 @@ public class SecurityOperation {
           TablePermission.ALTER_TABLE);
     } catch (TableNotFoundException e) {
       // Shouldn't happen
-      throw new RuntimeException(e);
+      throw new IllegalStateException(e);
     }
   }
 
@@ -339,7 +343,7 @@ public class SecurityOperation {
    *
    * @return true if a user exists and has permission; false otherwise
    */
-  private boolean hasTablePermission(TCredentials credentials, TableId tableId,
+  protected boolean hasTablePermission(TCredentials credentials, TableId tableId,
       NamespaceId namespaceId, TablePermission permission, boolean useCached)
       throws ThriftSecurityException {
     if (isSystemUser(credentials)) {
@@ -360,11 +364,8 @@ public class SecurityOperation {
       boolean useCached) throws ThriftSecurityException {
     targetUserExists(user);
 
-    @SuppressWarnings("deprecation")
-    TableId replicationTableId = org.apache.accumulo.core.replication.ReplicationTable.ID;
-
-    if ((table.equals(MetadataTable.ID) || table.equals(RootTable.ID)
-        || table.equals(replicationTableId)) && permission.equals(TablePermission.READ)) {
+    if ((table.equals(MetadataTable.ID) || table.equals(RootTable.ID))
+        && permission.equals(TablePermission.READ)) {
       return true;
     }
 
@@ -432,6 +433,20 @@ public class SecurityOperation {
     return hasTablePermission(credentials, tableId, namespaceId, TablePermission.READ, true);
   }
 
+  public boolean canScan(TCredentials credentials, TableId tableId, NamespaceId namespaceId,
+      TRange range, List<TColumn> columns, List<IterInfo> ssiList,
+      Map<String,Map<String,String>> ssio, List<ByteBuffer> authorizations)
+      throws ThriftSecurityException {
+    return canScan(credentials, tableId, namespaceId);
+  }
+
+  public boolean canScan(TCredentials credentials, TableId table, NamespaceId namespaceId,
+      Map<TKeyExtent,List<TRange>> tbatch, List<TColumn> tcolumns, List<IterInfo> ssiList,
+      Map<String,Map<String,String>> ssio, List<ByteBuffer> authorizations)
+      throws ThriftSecurityException {
+    return canScan(credentials, table, namespaceId);
+  }
+
   public boolean canWrite(TCredentials credentials, TableId tableId, NamespaceId namespaceId)
       throws ThriftSecurityException {
     authenticate(credentials);
@@ -447,8 +462,8 @@ public class SecurityOperation {
         && hasTablePermission(credentials, tableID, namespaceId, TablePermission.READ, true);
   }
 
-  protected boolean canSplitTablet(TCredentials credentials, TableId tableId,
-      NamespaceId namespaceId) throws ThriftSecurityException {
+  public boolean canSplitTablet(TCredentials credentials, TableId tableId, NamespaceId namespaceId)
+      throws ThriftSecurityException {
     authenticate(credentials);
     return hasSystemPermissionWithNamespaceId(credentials, SystemPermission.ALTER_TABLE,
         namespaceId, false)
@@ -462,40 +477,39 @@ public class SecurityOperation {
    * This is the check to perform any system action. This includes tserver's loading of a tablet,
    * shutting the system down, or altering system properties.
    */
-  protected boolean canPerformSystemActions(TCredentials credentials)
-      throws ThriftSecurityException {
+  public boolean canPerformSystemActions(TCredentials credentials) throws ThriftSecurityException {
     authenticate(credentials);
     return hasSystemPermission(credentials, SystemPermission.SYSTEM, false);
   }
 
-  protected boolean canFlush(TCredentials c, TableId tableId, NamespaceId namespaceId)
+  public boolean canFlush(TCredentials c, TableId tableId, NamespaceId namespaceId)
       throws ThriftSecurityException {
     authenticate(c);
     return hasTablePermission(c, tableId, namespaceId, TablePermission.WRITE, false)
         || hasTablePermission(c, tableId, namespaceId, TablePermission.ALTER_TABLE, false);
   }
 
-  protected boolean canAlterTable(TCredentials c, TableId tableId, NamespaceId namespaceId)
+  public boolean canAlterTable(TCredentials c, TableId tableId, NamespaceId namespaceId)
       throws ThriftSecurityException {
     authenticate(c);
     return hasTablePermission(c, tableId, namespaceId, TablePermission.ALTER_TABLE, false)
         || hasSystemPermissionWithNamespaceId(c, SystemPermission.ALTER_TABLE, namespaceId, false);
   }
 
-  protected boolean canCreateTable(TCredentials c, String tableName, NamespaceId namespaceId)
+  public boolean canCreateTable(TCredentials c, String tableName, NamespaceId namespaceId)
       throws ThriftSecurityException {
     authenticate(c);
     return hasSystemPermissionWithNamespaceId(c, SystemPermission.CREATE_TABLE, namespaceId, false);
   }
 
-  protected boolean canRenameTable(TCredentials c, TableId tableId, String oldTableName,
+  public boolean canRenameTable(TCredentials c, TableId tableId, String oldTableName,
       String newTableName, NamespaceId namespaceId) throws ThriftSecurityException {
     authenticate(c);
     return hasSystemPermissionWithNamespaceId(c, SystemPermission.ALTER_TABLE, namespaceId, false)
         || hasTablePermission(c, tableId, namespaceId, TablePermission.ALTER_TABLE, false);
   }
 
-  protected boolean canCloneTable(TCredentials c, TableId tableId, String tableName,
+  public boolean canCloneTable(TCredentials c, TableId tableId, String tableName,
       NamespaceId destinationNamespaceId, NamespaceId srcNamespaceId)
       throws ThriftSecurityException {
     authenticate(c);
@@ -504,14 +518,14 @@ public class SecurityOperation {
         && hasTablePermission(c, tableId, srcNamespaceId, TablePermission.READ, false);
   }
 
-  protected boolean canDeleteTable(TCredentials c, TableId tableId, NamespaceId namespaceId)
+  public boolean canDeleteTable(TCredentials c, TableId tableId, NamespaceId namespaceId)
       throws ThriftSecurityException {
     authenticate(c);
     return hasSystemPermissionWithNamespaceId(c, SystemPermission.DROP_TABLE, namespaceId, false)
         || hasTablePermission(c, tableId, namespaceId, TablePermission.DROP_TABLE, false);
   }
 
-  protected boolean canOnlineOfflineTable(TCredentials c, TableId tableId, FateOperation op,
+  public boolean canOnlineOfflineTable(TCredentials c, TableId tableId, FateOperation op,
       NamespaceId namespaceId) throws ThriftSecurityException {
     authenticate(c);
     return hasSystemPermissionWithNamespaceId(c, SystemPermission.SYSTEM, namespaceId, false)
@@ -519,7 +533,7 @@ public class SecurityOperation {
         || hasTablePermission(c, tableId, namespaceId, TablePermission.ALTER_TABLE, false);
   }
 
-  protected boolean canMerge(TCredentials c, TableId tableId, NamespaceId namespaceId)
+  public boolean canMerge(TCredentials c, TableId tableId, NamespaceId namespaceId)
       throws ThriftSecurityException {
     authenticate(c);
     return hasSystemPermissionWithNamespaceId(c, SystemPermission.SYSTEM, namespaceId, false)
@@ -527,20 +541,20 @@ public class SecurityOperation {
         || hasTablePermission(c, tableId, namespaceId, TablePermission.ALTER_TABLE, false);
   }
 
-  protected boolean canDeleteRange(TCredentials c, TableId tableId, String tableName, Text startRow,
+  public boolean canDeleteRange(TCredentials c, TableId tableId, String tableName, Text startRow,
       Text endRow, NamespaceId namespaceId) throws ThriftSecurityException {
     authenticate(c);
     return hasSystemPermissionWithNamespaceId(c, SystemPermission.SYSTEM, namespaceId, false)
         || hasTablePermission(c, tableId, namespaceId, TablePermission.WRITE, false);
   }
 
-  protected boolean canBulkImport(TCredentials c, TableId tableId, String tableName, String dir,
+  public boolean canBulkImport(TCredentials c, TableId tableId, String tableName, String dir,
       String failDir, NamespaceId namespaceId) throws ThriftSecurityException {
     authenticate(c);
     return hasTablePermission(c, tableId, namespaceId, TablePermission.BULK_IMPORT, false);
   }
 
-  protected boolean canCompact(TCredentials c, TableId tableId, NamespaceId namespaceId)
+  public boolean canCompact(TCredentials c, TableId tableId, NamespaceId namespaceId)
       throws ThriftSecurityException {
     authenticate(c);
     return hasSystemPermissionWithNamespaceId(c, SystemPermission.ALTER_TABLE, namespaceId, false)
@@ -548,24 +562,24 @@ public class SecurityOperation {
         || hasTablePermission(c, tableId, namespaceId, TablePermission.WRITE, false);
   }
 
-  protected boolean canChangeAuthorizations(TCredentials c, String user)
+  public boolean canChangeAuthorizations(TCredentials c, String user)
       throws ThriftSecurityException {
     authenticate(c);
     return hasSystemPermission(c, SystemPermission.ALTER_USER, false);
   }
 
-  protected boolean canChangePassword(TCredentials c, String user) throws ThriftSecurityException {
+  public boolean canChangePassword(TCredentials c, String user) throws ThriftSecurityException {
     authenticate(c);
     return c.getPrincipal().equals(user)
         || hasSystemPermission(c, SystemPermission.ALTER_USER, false);
   }
 
-  protected boolean canCreateUser(TCredentials c, String user) throws ThriftSecurityException {
+  public boolean canCreateUser(TCredentials c, String user) throws ThriftSecurityException {
     authenticate(c);
     return hasSystemPermission(c, SystemPermission.CREATE_USER, false);
   }
 
-  protected boolean canDropUser(TCredentials c, String user) throws ThriftSecurityException {
+  public boolean canDropUser(TCredentials c, String user) throws ThriftSecurityException {
     authenticate(c);
     if (user.equals(getRootUsername())) {
       throw new ThriftSecurityException(c.getPrincipal(), SecurityErrorCode.PERMISSION_DENIED);
@@ -573,20 +587,20 @@ public class SecurityOperation {
     return hasSystemPermission(c, SystemPermission.DROP_USER, false);
   }
 
-  protected boolean canGrantSystem(TCredentials c, String user, SystemPermission sysPerm)
+  public boolean canGrantSystem(TCredentials c, String user, SystemPermission sysPerm)
       throws ThriftSecurityException {
     authenticate(c);
     return hasSystemPermission(c, SystemPermission.GRANT, false);
   }
 
-  protected boolean canGrantTable(TCredentials c, String user, TableId tableId,
+  public boolean canGrantTable(TCredentials c, String user, TableId tableId,
       NamespaceId namespaceId) throws ThriftSecurityException {
     authenticate(c);
     return hasSystemPermissionWithNamespaceId(c, SystemPermission.ALTER_TABLE, namespaceId, false)
         || hasTablePermission(c, tableId, namespaceId, TablePermission.GRANT, false);
   }
 
-  private boolean canGrantNamespace(TCredentials c, NamespaceId namespace)
+  public boolean canGrantNamespace(TCredentials c, NamespaceId namespace)
       throws ThriftSecurityException {
     return canModifyNamespacePermission(c, namespace);
   }
@@ -605,7 +619,7 @@ public class SecurityOperation {
         || hasNamespacePermission(c, c.principal, namespace, NamespacePermission.GRANT);
   }
 
-  protected boolean canRevokeSystem(TCredentials c, String user, SystemPermission sysPerm)
+  public boolean canRevokeSystem(TCredentials c, String user, SystemPermission sysPerm)
       throws ThriftSecurityException {
     authenticate(c);
     // can't modify root user
@@ -616,19 +630,19 @@ public class SecurityOperation {
     return hasSystemPermission(c, SystemPermission.GRANT, false);
   }
 
-  protected boolean canRevokeTable(TCredentials c, String user, TableId tableId,
+  public boolean canRevokeTable(TCredentials c, String user, TableId tableId,
       NamespaceId namespaceId) throws ThriftSecurityException {
     authenticate(c);
     return hasSystemPermissionWithNamespaceId(c, SystemPermission.ALTER_TABLE, namespaceId, false)
         || hasTablePermission(c, tableId, namespaceId, TablePermission.GRANT, false);
   }
 
-  private boolean canRevokeNamespace(TCredentials c, NamespaceId namespace)
+  public boolean canRevokeNamespace(TCredentials c, NamespaceId namespace)
       throws ThriftSecurityException {
     return canModifyNamespacePermission(c, namespace);
   }
 
-  protected void changeAuthorizations(TCredentials credentials, String user,
+  public void changeAuthorizations(TCredentials credentials, String user,
       Authorizations authorizations) throws ThriftSecurityException {
     if (!canChangeAuthorizations(credentials, user)) {
       throw new ThriftSecurityException(credentials.getPrincipal(),
@@ -646,7 +660,7 @@ public class SecurityOperation {
     }
   }
 
-  protected void changePassword(TCredentials credentials, Credentials toChange)
+  public void changePassword(TCredentials credentials, Credentials toChange)
       throws ThriftSecurityException {
     if (!canChangePassword(credentials, toChange.getPrincipal())) {
       throw new ThriftSecurityException(credentials.getPrincipal(),
@@ -662,7 +676,7 @@ public class SecurityOperation {
     }
   }
 
-  protected void createUser(TCredentials credentials, Credentials newUser,
+  public void createUser(TCredentials credentials, Credentials newUser,
       Authorizations authorizations) throws ThriftSecurityException {
     if (!canCreateUser(credentials, newUser.getPrincipal())) {
       throw new ThriftSecurityException(credentials.getPrincipal(),
@@ -692,7 +706,7 @@ public class SecurityOperation {
     }
   }
 
-  protected void dropUser(TCredentials credentials, String user) throws ThriftSecurityException {
+  public void dropUser(TCredentials credentials, String user) throws ThriftSecurityException {
     if (!canDropUser(credentials, user)) {
       throw new ThriftSecurityException(credentials.getPrincipal(),
           SecurityErrorCode.PERMISSION_DENIED);
@@ -707,7 +721,7 @@ public class SecurityOperation {
     }
   }
 
-  protected void grantSystemPermission(TCredentials credentials, String user,
+  public void grantSystemPermission(TCredentials credentials, String user,
       SystemPermission permissionById) throws ThriftSecurityException {
     if (!canGrantSystem(credentials, user, permissionById)) {
       throw new ThriftSecurityException(credentials.getPrincipal(),
@@ -725,9 +739,8 @@ public class SecurityOperation {
     }
   }
 
-  protected void grantTablePermission(TCredentials c, String user, TableId tableId,
-      String tableName, TablePermission permission, NamespaceId namespaceId)
-      throws ThriftSecurityException, TableNotFoundException {
+  public void grantTablePermission(TCredentials c, String user, TableId tableId,
+      TablePermission permission, NamespaceId namespaceId) throws ThriftSecurityException {
     if (!canGrantTable(c, user, tableId, namespaceId)) {
       throw new ThriftSecurityException(c.getPrincipal(), SecurityErrorCode.PERMISSION_DENIED);
     }
@@ -764,7 +777,7 @@ public class SecurityOperation {
     }
   }
 
-  protected void revokeSystemPermission(TCredentials credentials, String user,
+  public void revokeSystemPermission(TCredentials credentials, String user,
       SystemPermission permission) throws ThriftSecurityException {
     if (!canRevokeSystem(credentials, user, permission)) {
       throw new ThriftSecurityException(credentials.getPrincipal(),
@@ -783,7 +796,7 @@ public class SecurityOperation {
     }
   }
 
-  protected void revokeTablePermission(TCredentials c, String user, TableId tableId,
+  public void revokeTablePermission(TCredentials c, String user, TableId tableId,
       TablePermission permission, NamespaceId namespaceId) throws ThriftSecurityException {
     if (!canRevokeTable(c, user, tableId, namespaceId)) {
       throw new ThriftSecurityException(c.getPrincipal(), SecurityErrorCode.PERMISSION_DENIED);
@@ -823,7 +836,7 @@ public class SecurityOperation {
     }
   }
 
-  protected boolean hasSystemPermission(TCredentials credentials, String user,
+  public boolean hasSystemPermission(TCredentials credentials, String user,
       SystemPermission permissionById) throws ThriftSecurityException {
     if (!canAskAboutOtherUsers(credentials, user)) {
       throw new ThriftSecurityException(credentials.getPrincipal(),
@@ -889,13 +902,13 @@ public class SecurityOperation {
     }
   }
 
-  protected boolean canExport(TCredentials credentials, TableId tableId, String tableName,
+  public boolean canExport(TCredentials credentials, TableId tableId, String tableName,
       String exportDir, NamespaceId namespaceId) throws ThriftSecurityException {
     authenticate(credentials);
     return hasTablePermission(credentials, tableId, namespaceId, TablePermission.READ, false);
   }
 
-  protected boolean canImport(TCredentials credentials, String tableName, Set<String> importDir,
+  public boolean canImport(TCredentials credentials, String tableName, Set<String> importDir,
       NamespaceId namespaceId) throws ThriftSecurityException {
     authenticate(credentials);
     return hasSystemPermissionWithNamespaceId(credentials, SystemPermission.CREATE_TABLE,
@@ -928,8 +941,7 @@ public class SecurityOperation {
         namespaceId, false);
   }
 
-  protected boolean canObtainDelegationToken(TCredentials credentials)
-      throws ThriftSecurityException {
+  public boolean canObtainDelegationToken(TCredentials credentials) throws ThriftSecurityException {
     authenticate(credentials);
     return hasSystemPermission(credentials, SystemPermission.OBTAIN_DELEGATION_TOKEN, false);
   }
@@ -940,11 +952,4 @@ public class SecurityOperation {
     return hasTablePermission(credentials, tableId, namespaceId, TablePermission.GET_SUMMARIES,
         false);
   }
-
-  public boolean validateStoredUserCredentials() {
-    if (authenticator instanceof ZKAuthenticator) {
-      return !((ZKAuthenticator) authenticator).hasOutdatedHashes();
-    }
-    return true;
-  }
 }
