@@ -19,6 +19,7 @@
 package org.apache.accumulo.server.security;
 
 import java.io.IOException;
+import java.io.UncheckedIOException;
 import java.net.InetAddress;
 
 import org.apache.accumulo.core.conf.AccumuloConfiguration;
@@ -63,7 +64,7 @@ public class SecurityUtil {
 
     if (login(principal, keyTab)) {
       try {
-        startTicketRenewalThread(UserGroupInformation.getCurrentUser(),
+        startTicketRenewalThread(acuConf, UserGroupInformation.getCurrentUser(),
             acuConf.getTimeInMillis(Property.GENERAL_KERBEROS_RENEWAL_PERIOD));
         return;
       } catch (IOException e) {
@@ -71,7 +72,7 @@ public class SecurityUtil {
       }
     }
 
-    throw new RuntimeException(
+    throw new IllegalStateException(
         "Failed to perform Kerberos login for " + principal + " using  " + keyTab);
   }
 
@@ -107,7 +108,7 @@ public class SecurityUtil {
       return org.apache.hadoop.security.SecurityUtil.getServerPrincipal(configuredPrincipal,
           InetAddress.getLocalHost().getCanonicalHostName());
     } catch (IOException e) {
-      throw new RuntimeException(
+      throw new UncheckedIOException(
           "Could not convert configured server principal: " + configuredPrincipal, e);
     }
   }
@@ -115,11 +116,13 @@ public class SecurityUtil {
   /**
    * Start a thread that periodically attempts to renew the current Kerberos user's ticket.
    *
+   * @param conf Accumulo configuration
    * @param ugi The current Kerberos user.
    * @param renewalPeriod The amount of time between attempting renewals.
    */
-  static void startTicketRenewalThread(final UserGroupInformation ugi, final long renewalPeriod) {
-    Threads.createCriticalThread("Kerberos Ticket Renewal", () -> {
+  static void startTicketRenewalThread(AccumuloConfiguration conf, final UserGroupInformation ugi,
+      final long renewalPeriod) {
+    Threads.createThread("Kerberos Ticket Renewal", () -> {
       while (true) {
         try {
           renewalLog.debug("Invoking renewal attempt for Kerberos ticket");
