@@ -45,8 +45,6 @@ import org.slf4j.LoggerFactory;
 import com.google.common.annotations.VisibleForTesting;
 import com.google.common.collect.Maps;
 
-import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
-
 /**
  * Manages an internal list of secret keys used to sign new authentication tokens as they are
  * generated, and to validate existing tokens used for authentication.
@@ -84,7 +82,7 @@ public class AuthenticationTokenSecretManager extends SecretManager<Authenticati
       DelegationTokenConfig cfg) {
     long now = System.currentTimeMillis();
     identifier.setIssueDate(now);
-    identifier.setExpirationDate(calculateExpirationDate(now));
+    identifier.setExpirationDate(calculateExpirationDate());
     // Limit the lifetime if the user requests it
     if (cfg != null) {
       long requestedLifetime = cfg.getTokenLifetime(TimeUnit.MILLISECONDS);
@@ -96,7 +94,7 @@ public class AuthenticationTokenSecretManager extends SecretManager<Authenticati
         }
         // Ensure that the user doesn't try to extend the expiration date -- they may only limit it
         if (requestedExpirationDate > identifier.getExpirationDate()) {
-          throw new RuntimeException("Requested token lifetime exceeds configured maximum");
+          throw new IllegalStateException("Requested token lifetime exceeds configured maximum");
         }
         log.trace("Overriding token expiration date from {} to {}", identifier.getExpirationDate(),
             requestedExpirationDate);
@@ -106,7 +104,8 @@ public class AuthenticationTokenSecretManager extends SecretManager<Authenticati
     return createPassword(identifier);
   }
 
-  private long calculateExpirationDate(long now) {
+  private long calculateExpirationDate() {
+    long now = System.currentTimeMillis();
     long expiration = now + tokenMaxLifetime;
     // Catch overflow
     if (expiration < now) {
@@ -124,12 +123,11 @@ public class AuthenticationTokenSecretManager extends SecretManager<Authenticati
     identifier.setKeyId(secretKey.getKeyId());
     identifier.setInstanceId(instanceID);
 
-    long now = System.currentTimeMillis();
     if (!identifier.isSetIssueDate()) {
-      identifier.setIssueDate(now);
+      identifier.setIssueDate(System.currentTimeMillis());
     }
     if (!identifier.isSetExpirationDate()) {
-      identifier.setExpirationDate(calculateExpirationDate(now));
+      identifier.setExpirationDate(calculateExpirationDate());
     }
     return createPassword(identifier.getBytes(), secretKey.getKey());
   }
@@ -258,7 +256,7 @@ public class AuthenticationTokenSecretManager extends SecretManager<Authenticati
           keyDistributor.remove(key);
         } catch (KeeperException | InterruptedException e) {
           log.error("Failed to remove AuthenticationKey from ZooKeeper. Exiting", e);
-          throw new RuntimeException(e);
+          throw new IllegalStateException(e);
         }
       }
     }
@@ -284,7 +282,6 @@ public class AuthenticationTokenSecretManager extends SecretManager<Authenticati
     return super.generateSecret();
   }
 
-  @SuppressFBWarnings(value = "HSM_HIDING_METHOD", justification = "")
   public static SecretKey createSecretKey(byte[] raw) {
     return SecretManager.createSecretKey(raw);
   }
