@@ -35,7 +35,6 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
-import java.util.Objects;
 import java.util.Set;
 import java.util.SortedSet;
 import java.util.TreeMap;
@@ -58,12 +57,11 @@ import org.apache.accumulo.core.fate.AdminUtil;
 import org.apache.accumulo.core.fate.FateTxId;
 import org.apache.accumulo.core.fate.ReadOnlyTStore;
 import org.apache.accumulo.core.fate.ZooStore;
-import org.apache.accumulo.core.fate.zookeeper.ServiceLock;
 import org.apache.accumulo.core.fate.zookeeper.ZooCache;
 import org.apache.accumulo.core.fate.zookeeper.ZooReaderWriter;
+import org.apache.accumulo.core.lock.ServiceLock;
 import org.apache.accumulo.core.manager.thrift.FateService;
 import org.apache.accumulo.core.metadata.MetadataTable;
-import org.apache.accumulo.core.process.thrift.ServerProcessService;
 import org.apache.accumulo.core.rpc.ThriftUtil;
 import org.apache.accumulo.core.rpc.clients.ThriftClientTypes;
 import org.apache.accumulo.core.security.Authorizations;
@@ -74,14 +72,12 @@ import org.apache.accumulo.core.singletons.SingletonManager;
 import org.apache.accumulo.core.singletons.SingletonManager.Mode;
 import org.apache.accumulo.core.trace.TraceUtil;
 import org.apache.accumulo.core.util.AddressUtil;
-import org.apache.accumulo.core.util.HostAndPort;
 import org.apache.accumulo.core.util.tables.TableMap;
 import org.apache.accumulo.server.ServerContext;
 import org.apache.accumulo.server.cli.ServerUtilOpts;
 import org.apache.accumulo.server.security.SecurityUtil;
 import org.apache.accumulo.server.util.fateCommand.FateSummaryReport;
 import org.apache.accumulo.start.spi.KeywordExecutable;
-import org.apache.thrift.TException;
 import org.apache.zookeeper.KeeperException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -92,6 +88,7 @@ import com.beust.jcommander.Parameters;
 import com.google.auto.service.AutoService;
 import com.google.common.collect.ImmutableSortedMap;
 import com.google.common.collect.Lists;
+import com.google.common.net.HostAndPort;
 
 import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
 
@@ -99,29 +96,26 @@ import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
 public class Admin implements KeywordExecutable {
   private static final Logger log = LoggerFactory.getLogger(Admin.class);
 
-  private static class SubCommandOpts {
-    @Parameter(names = {"-h", "-?", "--help", "-help"}, help = true)
-    public boolean help = false;
+  static class AdminOpts extends ServerUtilOpts {
+    @Parameter(names = {"-f", "--force"},
+        description = "force the given server to stop by removing its lock")
+    boolean force = false;
   }
 
-  @Parameters(
-      commandDescription = "Stop the servers at the given addresses allowing them to complete current task but not start new task.  When no port is specified uses ports from tserver.port.client property.")
-  static class StopCommand extends SubCommandOpts {
-    @Parameter(names = {"-f", "--force"},
-        description = "force the given server to stop immediately by removing its lock.  Does not wait for any task the server is currently working.")
-    boolean force = false;
-    @Parameter(description = "<host[:port]> {<host[:port]> ... }")
+  @Parameters(commandDescription = "stop the tablet server on the given hosts")
+  static class StopCommand {
+    @Parameter(description = "<host> {<host> ... }")
     List<String> args = new ArrayList<>();
   }
 
   @Parameters(commandDescription = "Ping tablet servers.  If no arguments, pings all.")
-  static class PingCommand extends SubCommandOpts {
+  static class PingCommand {
     @Parameter(description = "{<host> ... }")
     List<String> args = new ArrayList<>();
   }
 
   @Parameters(commandDescription = "print tablets that are offline in online tables")
-  static class CheckTabletsCommand extends SubCommandOpts {
+  static class CheckTabletsCommand {
     @Parameter(names = "--fixFiles", description = "Remove dangling file pointers")
     boolean fixFiles = false;
 
@@ -131,17 +125,13 @@ public class Admin implements KeywordExecutable {
   }
 
   @Parameters(commandDescription = "stop the manager")
-  static class StopManagerCommand extends SubCommandOpts {}
-
-  @Deprecated(since = "2.1.0")
-  @Parameters(commandDescription = "stop the master (DEPRECATED -- use stopManager instead)")
-  static class StopMasterCommand {}
+  static class StopManagerCommand {}
 
   @Parameters(commandDescription = "stop all tablet servers and the manager")
-  static class StopAllCommand extends SubCommandOpts {}
+  static class StopAllCommand {}
 
   @Parameters(commandDescription = "list Accumulo instances in zookeeper")
-  static class ListInstancesCommand extends SubCommandOpts {
+  static class ListInstancesCommand {
     @Parameter(names = "--print-errors", description = "display errors while listing instances")
     boolean printErrors = false;
     @Parameter(names = "--print-all",
@@ -150,13 +140,13 @@ public class Admin implements KeywordExecutable {
   }
 
   @Parameters(commandDescription = "Accumulo volume utility")
-  static class VolumesCommand extends SubCommandOpts {
+  static class VolumesCommand {
     @Parameter(names = {"-l", "--list"}, description = "list volumes currently in use")
     boolean printErrors = false;
   }
 
   @Parameters(commandDescription = "print out non-default configuration settings")
-  static class DumpConfigCommand extends SubCommandOpts {
+  static class DumpConfigCommand {
     @Parameter(names = {"-a", "--all"},
         description = "print the system and all table configurations")
     boolean allConfiguration = false;
@@ -173,19 +163,8 @@ public class Admin implements KeywordExecutable {
     boolean users = false;
   }
 
-  private static final String RV_DEPRECATION_MSG =
-      "Randomizing tablet directories is deprecated and now does nothing. Accumulo now always"
-          + " calls the volume chooser for each file created by a tablet, so its no longer "
-          + "necessary.";
-
-  @Parameters(commandDescription = RV_DEPRECATION_MSG)
-  static class RandomizeVolumesCommand extends SubCommandOpts {
-    @Parameter(names = {"-t"}, description = "table to update", required = true)
-    String tableName = null;
-  }
-
   @Parameters(commandDescription = "Verify all Tablets are assigned to tablet servers")
-  static class VerifyTabletAssignmentsCommand extends SubCommandOpts {
+  static class VerifyTabletAssignmentsCommand {
     @Parameter(names = {"-v", "--verbose"},
         description = "verbose mode (prints locations of tablets)")
     boolean verbose = false;
@@ -200,14 +179,14 @@ public class Admin implements KeywordExecutable {
 
   @Parameters(
       commandDescription = "List or delete Tablet Server locks. Default with no arguments is to list the locks.")
-  static class TabletServerLocksCommand extends SubCommandOpts {
+  static class TabletServerLocksCommand {
     @Parameter(names = "-delete", description = "specify a tablet server lock to delete")
     String delete = null;
   }
 
   @Parameters(
       commandDescription = "Deletes specific instance name or id from zookeeper or cleans up all old instances.")
-  static class DeleteZooInstanceCommand extends SubCommandOpts {
+  static class DeleteZooInstanceCommand {
     @Parameter(names = {"-i", "--instance"}, description = "the instance name or id to delete")
     String instance;
     @Parameter(names = {"-c", "--clean"},
@@ -220,7 +199,7 @@ public class Admin implements KeywordExecutable {
   }
 
   @Parameters(commandDescription = "Restore Zookeeper data from a file.")
-  static class RestoreZooCommand extends SubCommandOpts {
+  static class RestoreZooCommand {
     @Parameter(names = "--overwrite")
     boolean overwrite = false;
 
@@ -230,7 +209,7 @@ public class Admin implements KeywordExecutable {
 
   @Parameters(commandNames = "fate",
       commandDescription = "Operations performed on the Manager FaTE system.")
-  static class FateOpsCommand extends SubCommandOpts {
+  static class FateOpsCommand {
     @Parameter(description = "[<txId>...]")
     List<String> txList = new ArrayList<>();
 
@@ -243,7 +222,7 @@ public class Admin implements KeywordExecutable {
     boolean fail;
 
     @Parameter(names = {"-d", "--delete"},
-        description = "<txId>... Delete FaTE transaction and its associated table locks (requires Manager to be down)")
+        description = "<txId>... Delete locks associated with transactions (Requires Manager to be down)")
     boolean delete;
 
     @Parameter(names = {"-p", "--print", "-print", "-l", "--list", "-list"},
@@ -261,15 +240,6 @@ public class Admin implements KeywordExecutable {
     List<String> states = new ArrayList<>();
   }
 
-  @Parameters(commandDescription = "show service status")
-  public static class ServiceStatusCmdOpts extends SubCommandOpts {
-    @Parameter(names = "--json", description = "provide output in json format")
-    boolean json = false;
-    @Parameter(names = "--showHosts",
-        description = "provide a summary of service counts with host details")
-    boolean showHosts = false;
-  }
-
   public static void main(String[] args) {
     new Admin().execute(args);
   }
@@ -292,14 +262,12 @@ public class Admin implements KeywordExecutable {
   @SuppressFBWarnings(value = "DM_EXIT", justification = "System.exit okay for CLI tool")
   @Override
   public void execute(final String[] args) {
+    boolean everything;
 
-    ServerUtilOpts opts = new ServerUtilOpts();
+    AdminOpts opts = new AdminOpts();
     JCommander cl = new JCommander(opts);
     cl.setProgramName("accumulo admin");
 
-    ServiceStatusCmdOpts serviceStatusCommandOpts = new ServiceStatusCmdOpts();
-    cl.addCommand("serviceStatus", serviceStatusCommandOpts);
-
     ChangeSecretCommand changeSecretCommand = new ChangeSecretCommand();
     cl.addCommand("changeSecret", changeSecretCommand);
 
@@ -327,9 +295,6 @@ public class Admin implements KeywordExecutable {
     RestoreZooCommand restoreZooOpts = new RestoreZooCommand();
     cl.addCommand("restoreZoo", restoreZooOpts);
 
-    RandomizeVolumesCommand randomizeVolumesOpts = new RandomizeVolumesCommand();
-    cl.addCommand("randomizeVolumes", randomizeVolumesOpts);
-
     StopCommand stopOpts = new StopCommand();
     cl.addCommand("stop", stopOpts);
 
@@ -339,9 +304,6 @@ public class Admin implements KeywordExecutable {
     StopManagerCommand stopManagerOpts = new StopManagerCommand();
     cl.addCommand("stopManager", stopManagerOpts);
 
-    StopMasterCommand stopMasterOpts = new StopMasterCommand();
-    cl.addCommand("stopMaster", stopMasterOpts);
-
     VerifyTabletAssignmentsCommand verifyTabletAssignmentsOpts =
         new VerifyTabletAssignmentsCommand();
     cl.addCommand("verifyTabletAssigns", verifyTabletAssignmentsOpts);
@@ -351,21 +313,11 @@ public class Admin implements KeywordExecutable {
 
     cl.parse(args);
 
-    if (cl.getParsedCommand() == null) {
+    if (opts.help || cl.getParsedCommand() == null) {
       cl.usage();
       return;
     }
 
-    for (var command : cl.getCommands().entrySet()) {
-      var objects = command.getValue().getObjects();
-      for (var obj : objects) {
-        if (obj instanceof SubCommandOpts && ((SubCommandOpts) obj).help) {
-          command.getValue().usage();
-          return;
-        }
-      }
-    }
-
     ServerContext context = opts.getServerContext();
 
     AccumuloConfiguration conf = context.getConfiguration();
@@ -404,13 +356,11 @@ public class Admin implements KeywordExecutable {
         }
 
       } else if (cl.getParsedCommand().equals("stop")) {
-        stopServers(context, stopOpts.args, stopOpts.force);
+        stopTabletServer(context, stopOpts.args, opts.force);
       } else if (cl.getParsedCommand().equals("dumpConfig")) {
         printConfig(context, dumpConfigCommand);
       } else if (cl.getParsedCommand().equals("volumes")) {
         ListVolumesUsed.listVolumes(context);
-      } else if (cl.getParsedCommand().equals("randomizeVolumes")) {
-        System.out.println(RV_DEPRECATION_MSG);
       } else if (cl.getParsedCommand().equals("verifyTabletAssigns")) {
         VerifyTabletAssignments.execute(opts.getClientProps(), verifyTabletAssignmentsOpts.verbose);
       } else if (cl.getParsedCommand().equals("changeSecret")) {
@@ -425,20 +375,14 @@ public class Admin implements KeywordExecutable {
             tServerLocksOpts.delete);
       } else if (cl.getParsedCommand().equals("fate")) {
         executeFateOpsCommand(context, fateOpsCommand);
-      } else if (cl.getParsedCommand().equals("serviceStatus")) {
-        ServiceStatusCmd ssc = new ServiceStatusCmd();
-        ssc.execute(context, serviceStatusCommandOpts.json, serviceStatusCommandOpts.showHosts);
-      } else if (cl.getParsedCommand().equals("stopManager")
-          || cl.getParsedCommand().equals("stopAll")) {
-        boolean everything = cl.getParsedCommand().equals("stopAll");
+      } else {
+        everything = cl.getParsedCommand().equals("stopAll");
 
         if (everything) {
           flushAll(context);
         }
 
         stopServer(context, everything);
-      } else {
-        cl.usage();
       }
 
       if (rc != 0) {
@@ -517,8 +461,7 @@ public class Admin implements KeywordExecutable {
     try {
       flusher.join(3000);
     } catch (InterruptedException e) {
-      Thread.currentThread().interrupt();
-      log.warn("Interrupted while waiting to join Flush thread", e);
+      // ignore
     }
 
     while (flusher.isAlive() && System.currentTimeMillis() - start < 15000) {
@@ -526,8 +469,7 @@ public class Admin implements KeywordExecutable {
       try {
         flusher.join(1000);
       } catch (InterruptedException e) {
-        Thread.currentThread().interrupt();
-        log.warn("Interrupted while waiting to join Flush thread", e);
+        // ignore
       }
 
       if (flushCount == flushesStarted.get()) {
@@ -535,14 +477,6 @@ public class Admin implements KeywordExecutable {
         break;
       }
     }
-
-    flusher.interrupt();
-    try {
-      flusher.join();
-    } catch (InterruptedException e) {
-      Thread.currentThread().interrupt();
-      log.warn("Interrupted while waiting to join Flush thread", e);
-    }
   }
 
   private static void stopServer(final ClientContext context, final boolean tabletServersToo)
@@ -552,76 +486,6 @@ public class Admin implements KeywordExecutable {
         client -> client.shutdown(TraceUtil.traceInfo(), context.rpcCreds(), tabletServersToo));
   }
 
-  private static void stopServers(final ServerContext context, List<String> servers,
-      final boolean force)
-      throws AccumuloException, AccumuloSecurityException, InterruptedException, KeeperException {
-    List<String> hostOnly = new ArrayList<>();
-    Set<HostAndPort> hostAndPort = new TreeSet<>();
-
-    for (var server : servers) {
-      if (server.contains(":")) {
-        hostAndPort.add(HostAndPort.fromString(server));
-      } else {
-        hostOnly.add(server);
-      }
-    }
-
-    if (!hostOnly.isEmpty()) {
-      // The old impl of this command with the old behavior
-      stopTabletServer(context, hostOnly, force);
-    }
-
-    if (!hostAndPort.isEmpty()) {
-      // New behavior for this command when ports are present, supports more than just tservers. Is
-      // also async.
-      if (force) {
-        ZooZap.Opts opts = new ZooZap.Opts();
-        var zk = context.getZooReaderWriter();
-        var iid = context.getInstanceID();
-
-        String tserversPath = Constants.ZROOT + "/" + iid + Constants.ZTSERVERS;
-        ZooZap.removeLocks(zk, tserversPath, hostAndPort::contains, opts);
-        String compactorsBasepath = Constants.ZROOT + "/" + iid + Constants.ZCOMPACTORS;
-        ZooZap.removeGroupedLocks(zk, compactorsBasepath, rg -> true, hostAndPort::contains, opts);
-        String sserversPath = Constants.ZROOT + "/" + iid + Constants.ZSSERVERS;
-        ZooZap.removeGroupedLocks(zk, sserversPath, rg -> true, hostAndPort::contains, opts);
-
-        String managerLockPath = Constants.ZROOT + "/" + iid + Constants.ZMANAGER_LOCK;
-        ZooZap.removeSingletonLock(zk, managerLockPath, hostAndPort::contains, opts);
-        String gcLockPath = Constants.ZROOT + "/" + iid + Constants.ZGC_LOCK;
-        ZooZap.removeSingletonLock(zk, gcLockPath, hostAndPort::contains, opts);
-        String monitorLockPath = Constants.ZROOT + "/" + iid + Constants.ZMONITOR_LOCK;
-        ZooZap.removeSingletonLock(zk, monitorLockPath, hostAndPort::contains, opts);
-      } else {
-        for (var server : hostAndPort) {
-          signalGracefulShutdown(context, server);
-        }
-      }
-    }
-  }
-
-  // Visible for tests
-  public static void signalGracefulShutdown(final ClientContext context, HostAndPort hp) {
-    Objects.requireNonNull(hp, "address not set");
-    ServerProcessService.Client client = null;
-    try {
-      client = ThriftClientTypes.SERVER_PROCESS.getServerProcessConnection(context, log,
-          hp.getHost(), hp.getPort());
-      if (client == null) {
-        log.warn("Failed to initiate shutdown for {}", hp);
-        return;
-      }
-      client.gracefulShutdown(context.rpcCreds());
-      log.info("Initiated shutdown for {}", hp);
-    } catch (TException e) {
-      log.warn("Failed to initiate shutdown for {}", hp, e);
-    } finally {
-      if (client != null) {
-        ThriftUtil.returnClient(client, context);
-      }
-    }
-  }
-
   private static void stopTabletServer(final ClientContext context, List<String> servers,
       final boolean force) throws AccumuloException, AccumuloSecurityException {
     if (context.getManagerLocations().isEmpty()) {
@@ -703,11 +567,21 @@ public class Admin implements KeywordExecutable {
   private Map<String,String> siteConfig, systemConfig;
   private List<String> localUsers;
 
+  @SuppressFBWarnings(value = "PATH_TRAVERSAL_IN",
+      justification = "code runs in same security context as user who provided input")
   public void printConfig(ClientContext context, DumpConfigCommand opts) throws Exception {
 
-    @SuppressFBWarnings(value = "PATH_TRAVERSAL_IN",
-        justification = "app is run in same security context as user providing the filename")
-    File outputDirectory = getOutputDirectory(opts.directory);
+    File outputDirectory = null;
+    if (opts.directory != null) {
+      outputDirectory = new File(opts.directory);
+      if (!outputDirectory.isDirectory()) {
+        throw new IllegalArgumentException(
+            opts.directory + " does not exist on the local filesystem.");
+      }
+      if (!outputDirectory.canWrite()) {
+        throw new IllegalArgumentException(opts.directory + " is not writable");
+      }
+    }
     defaultConfig = DefaultConfiguration.getInstance();
     siteConfig = context.instanceOperations().getSiteConfiguration();
     systemConfig = context.instanceOperations().getSystemConfiguration();
@@ -754,22 +628,6 @@ public class Admin implements KeywordExecutable {
     }
   }
 
-  @SuppressFBWarnings(value = "PATH_TRAVERSAL_IN",
-      justification = "app is run in same security context as user providing the filename")
-  private static File getOutputDirectory(final String directory) {
-    File outputDirectory = null;
-    if (directory != null) {
-      outputDirectory = new File(directory);
-      if (!outputDirectory.isDirectory()) {
-        throw new IllegalArgumentException(directory + " does not exist on the local filesystem.");
-      }
-      if (!outputDirectory.canWrite()) {
-        throw new IllegalArgumentException(directory + " is not writable");
-      }
-    }
-    return outputDirectory;
-  }
-
   private String getDefaultConfigValue(String key) {
     if (key == null) {
       return null;
@@ -903,7 +761,7 @@ public class Admin implements KeywordExecutable {
     var zTableLocksPath = ServiceLock.path(zkRoot + Constants.ZTABLE_LOCKS);
     String fateZkPath = zkRoot + Constants.ZFATE;
     ZooReaderWriter zk = context.getZooReaderWriter();
-    ZooStore<Admin> zs = new ZooStore<>(fateZkPath, zk, context.getZooCache());
+    ZooStore<Admin> zs = new ZooStore<>(fateZkPath, zk);
 
     if (fateOpsCommand.cancel) {
       cancelSubmittedFateTxs(context, fateOpsCommand.txList);
