@@ -93,7 +93,7 @@ public class ChangeSecret {
         recurse(zoo, root + "/" + child, v);
       }
     } catch (Exception ex) {
-      throw new RuntimeException(ex);
+      throw new IllegalStateException(ex);
     }
   }
 
