@@ -27,6 +27,8 @@ import org.apache.accumulo.core.data.Range;
 import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.manager.state.tables.TableState;
+import org.apache.accumulo.core.metadata.MetadataTable;
+import org.apache.accumulo.core.metadata.RootTable;
 import org.apache.accumulo.core.metadata.TServerInstance;
 import org.apache.accumulo.core.metadata.TabletLocationState;
 import org.apache.accumulo.core.metadata.TabletState;
@@ -89,22 +91,22 @@ public class FindOfflineTablets {
       return offline;
     }
 
-    if (DataLevel.METADATA.metaTable().equals(tableName)) {
+    if (RootTable.NAME.equals(tableName)) {
       return 0;
     }
 
-    System.out.println("Scanning " + DataLevel.METADATA.metaTable());
+    System.out.println("Scanning " + RootTable.NAME);
     Iterator<TabletLocationState> rootScanner =
-        new MetaDataTableScanner(context, TabletsSection.getRange(), DataLevel.METADATA);
+        new MetaDataTableScanner(context, TabletsSection.getRange(), RootTable.NAME);
     if ((offline = checkTablets(context, rootScanner, tservers)) > 0) {
       return offline;
     }
 
-    if (DataLevel.USER.metaTable().equals(tableName)) {
+    if (MetadataTable.NAME.equals(tableName)) {
       return 0;
     }
 
-    System.out.println("Scanning " + DataLevel.USER.metaTable());
+    System.out.println("Scanning " + MetadataTable.NAME);
 
     Range range = TabletsSection.getRange();
     if (tableName != null) {
@@ -113,7 +115,7 @@ public class FindOfflineTablets {
     }
 
     try (MetaDataTableScanner metaScanner =
-        new MetaDataTableScanner(context, range, DataLevel.USER)) {
+        new MetaDataTableScanner(context, range, MetadataTable.NAME)) {
       return checkTablets(context, metaScanner, tservers);
     }
   }
