@@ -18,7 +18,8 @@
  */
 package org.apache.accumulo.server.util;
 
-import java.security.SecureRandom;
+import static org.apache.accumulo.core.util.LazySingletons.RANDOM;
+
 import java.util.Iterator;
 import java.util.Properties;
 
@@ -41,13 +42,12 @@ import io.opentelemetry.context.Scope;
 
 public class RandomWriter {
 
-  private static final int num_columns_per_row = 1;
-  private static final int num_payload_bytes = 1024;
+  private static int num_columns_per_row = 1;
+  private static int num_payload_bytes = 1024;
   private static final Logger log = LoggerFactory.getLogger(RandomWriter.class);
-  private static final SecureRandom random = new SecureRandom();
 
   public static class RandomMutationGenerator implements Iterable<Mutation>, Iterator<Mutation> {
-    private final long max_mutations;
+    private long max_mutations;
     private int mutations_so_far = 0;
     private static final Logger log = LoggerFactory.getLogger(RandomMutationGenerator.class);
 
@@ -63,12 +63,12 @@ public class RandomWriter {
     @Override
     public Mutation next() {
       Text row_value = new Text(
-          Long.toString(((random.nextLong() & 0x7fffffffffffffffL) / 177) % 100000000000L));
+          Long.toString(((RANDOM.get().nextLong() & 0x7fffffffffffffffL) / 177) % 100000000000L));
       Mutation m = new Mutation(row_value);
       for (int column = 0; column < num_columns_per_row; column++) {
         Text column_fam = new Text("col_fam");
         byte[] bytes = new byte[num_payload_bytes];
-        random.nextBytes(bytes);
+        RANDOM.get().nextBytes(bytes);
         m.put(column_fam, new Text("" + column), new Value(bytes));
       }
       mutations_so_far++;
