@@ -18,8 +18,6 @@
  */
 package org.apache.accumulo.server.util;
 
-import static org.apache.accumulo.core.util.threads.ThreadPoolNames.UTILITY_CHECK_FILE_TASKS;
-
 import java.util.HashSet;
 import java.util.Map;
 import java.util.Map.Entry;
@@ -57,7 +55,7 @@ import io.opentelemetry.api.trace.Span;
 import io.opentelemetry.context.Scope;
 
 /**
- * Remove file entries for map files that don't exist.
+ * Remove file entries for data files that don't exist.
  */
 public class RemoveEntriesForMissingFiles {
 
@@ -123,8 +121,8 @@ public class RemoveEntriesForMissingFiles {
 
     Map<Path,Path> cache = new LRUMap<>(100000);
     Set<Path> processing = new HashSet<>();
-    ExecutorService threadPool = ThreadPools.getServerThreadPools()
-        .getPoolBuilder(UTILITY_CHECK_FILE_TASKS).numCoreThreads(16).build();
+    ExecutorService threadPool =
+        ThreadPools.getServerThreadPools().createFixedThreadPool(16, "CheckFileTasks", false);
 
     System.out.printf("Scanning : %s %s\n", tableName, range);
 
