@@ -23,8 +23,7 @@ import static java.nio.charset.StandardCharsets.UTF_8;
 import java.io.FileInputStream;
 import java.io.InputStream;
 import java.util.Base64;
-import java.util.Deque;
-import java.util.LinkedList;
+import java.util.Stack;
 
 import javax.xml.parsers.SAXParser;
 import javax.xml.parsers.SAXParserFactory;
@@ -42,7 +41,7 @@ public class RestoreZookeeper {
 
   private static class Restore extends DefaultHandler {
     ZooReaderWriter zk = null;
-    Deque<String> cwd = new LinkedList<>();
+    Stack<String> cwd = new Stack<>();
     boolean overwrite = false;
 
     Restore(ZooReaderWriter zk, boolean overwrite) {
@@ -55,14 +54,14 @@ public class RestoreZookeeper {
       if ("node".equals(name)) {
         String child = attributes.getValue("name");
         if (child == null) {
-          throw new RuntimeException("name attribute not set");
+          throw new IllegalStateException("name attribute not set");
         }
         String encoding = attributes.getValue("encoding");
         String value = attributes.getValue("value");
         if (value == null) {
           value = "";
         }
-        String path = cwd.element() + "/" + child;
+        String path = cwd.lastElement() + "/" + child;
         create(path, value, encoding);
         cwd.push(path);
       } else if ("dump".equals(name)) {
@@ -95,12 +94,12 @@ public class RestoreZookeeper {
               overwrite ? NodeExistsPolicy.OVERWRITE : NodeExistsPolicy.FAIL);
         } catch (KeeperException e) {
           if (e.code().equals(KeeperException.Code.NODEEXISTS)) {
-            throw new RuntimeException(path + " exists.  Remove it first.");
+            throw new IllegalStateException(path + " exists.  Remove it first.");
           }
           throw e;
         }
       } catch (Exception e) {
-        throw new RuntimeException(e);
+        throw new IllegalStateException(e);
       }
     }
   }
