@@ -138,8 +138,6 @@ public class TableConfigurationTest {
     expect(propStore.get(eq(propKey)))
         .andReturn(new VersionedProperties(37, Instant.now(), Map.of(p.getKey(), "sekrit")))
         .anyTimes();
-    propStore.invalidate(propKey);
-    expectLastCall().atLeastOnce();
     replay(propStore);
 
     tableConfig.zkChangeEvent(propKey);
@@ -161,8 +159,6 @@ public class TableConfigurationTest {
         .anyTimes();
     expect(propStore.get(eq(TablePropKey.of(instanceId, TID))))
         .andReturn(new VersionedProperties(Map.of())).anyTimes();
-    propStore.invalidate(NamespacePropKey.of(instanceId, NID));
-    expectLastCall().atLeastOnce();
     replay(propStore);
 
     nsConfig.zkChangeEvent(NamespacePropKey.of(instanceId, NID));
@@ -188,10 +184,6 @@ public class TableConfigurationTest {
     expect(propStore.get(eq(TablePropKey.of(instanceId, TID))))
         .andReturn(new VersionedProperties(4, Instant.now(), Map.of("foo", "bar", "tick", "tock")))
         .anyTimes();
-    propStore.invalidate(TablePropKey.of(instanceId, TID));
-    expectLastCall().atLeastOnce();
-    propStore.invalidate(NamespacePropKey.of(instanceId, NID));
-    expectLastCall().atLeastOnce();
 
     replay(propStore);
 
@@ -229,10 +221,6 @@ public class TableConfigurationTest {
     expect(propStore.get(eq(TablePropKey.of(instanceId, TID)))).andReturn(new VersionedProperties(4,
         Instant.now(), Map.of("filter", "not_returned_by_table", "foo", "bar", "tick", "tock")))
         .anyTimes();
-    propStore.invalidate(TablePropKey.of(instanceId, TID));
-    expectLastCall().atLeastOnce();
-    propStore.invalidate(NamespacePropKey.of(instanceId, NID));
-    expectLastCall().atLeastOnce();
 
     replay(propStore);
 
@@ -269,8 +257,6 @@ public class TableConfigurationTest {
         .once();
     expect(propStore.get(eq(propKey)))
         .andReturn(new VersionedProperties(39, Instant.now(), Map.of(p.getKey(), "sekrit"))).once();
-    propStore.invalidate(propKey);
-    expectLastCall().atLeastOnce();
 
     replay(propStore);
 
