@@ -18,10 +18,8 @@
  */
 package org.apache.accumulo.server.rpc;
 
-import static org.easymock.EasyMock.anyObject;
 import static org.easymock.EasyMock.createMock;
 import static org.easymock.EasyMock.expect;
-import static org.easymock.EasyMock.expectLastCall;
 import static org.easymock.EasyMock.replay;
 import static org.easymock.EasyMock.verify;
 import static org.junit.jupiter.api.Assertions.assertEquals;
@@ -43,8 +41,6 @@ import org.apache.accumulo.core.conf.ConfigurationCopy;
 import org.apache.accumulo.core.conf.DefaultConfiguration;
 import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.data.InstanceId;
-import org.apache.accumulo.core.metrics.MetricsInfo;
-import org.apache.accumulo.core.metrics.MetricsProducer;
 import org.apache.accumulo.core.trace.TraceUtil;
 import org.apache.accumulo.server.ServerContext;
 import org.apache.accumulo.server.client.ClientServiceHandler;
@@ -58,7 +54,6 @@ import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
 public class TServerUtilsTest {
 
   private ServerContext context;
-  private MetricsInfo metricsInfo;
   private final ConfigurationCopy conf = new ConfigurationCopy(DefaultConfiguration.getInstance());
 
   @BeforeEach
@@ -77,16 +72,12 @@ public class TServerUtilsTest {
     expect(context.getSaslParams()).andReturn(null).anyTimes();
     expect(context.getClientTimeoutInMillis()).andReturn((long) 1000).anyTimes();
     expect(context.getSecurityOperation()).andReturn(null).anyTimes();
-    metricsInfo = createMock(MetricsInfo.class);
-    metricsInfo.addMetricsProducers(anyObject(MetricsProducer.class));
-    expectLastCall().anyTimes();
-    expect(context.getMetricsInfo()).andReturn(metricsInfo).anyTimes();
-    replay(context, metricsInfo);
+    replay(context);
   }
 
   @AfterEach
   public void verifyMockServerContext() {
-    verify(context, metricsInfo);
+    verify(context);
   }
 
   @Test
@@ -166,14 +157,13 @@ public class TServerUtilsTest {
   public void testStartServerNonDefaultPorts() throws Exception {
     TServer server = null;
 
-    // This test finds 6 free ports in more-or-less a contiguous way and then
+    // This test finds 5 free ports in more-or-less a contiguous way and then
     // uses those port numbers to Accumulo services in the below (ascending) sequence
     // 0. TServer default client port (this test binds to this port to force a port search)
     // 1. GC
     // 2. Manager
     // 3. Monitor
-    // 4. Manager Replication Coordinator
-    // 5. One free port - this is the one that we expect the TServer to finally use
+    // 4. One free port - this is the one that we expect the TServer to finally use
     int[] ports = findTwoFreeSequentialPorts(1024);
     int tserverDefaultPort = ports[0];
     conf.set(Property.TSERV_CLIENTPORT, Integer.toString(tserverDefaultPort));
@@ -187,11 +177,7 @@ public class TServerUtilsTest {
     conf.set(Property.MONITOR_PORT, Integer.toString(monitorPort));
 
     ports = findTwoFreeSequentialPorts(monitorPort + 1);
-    int managerReplCoordPort = ports[0];
-    @SuppressWarnings("deprecation")
-    Property p = Property.MANAGER_REPLICATION_COORDINATOR_PORT;
-    conf.set(p, Integer.toString(managerReplCoordPort));
-    int tserverFinalPort = ports[1];
+    int tserverFinalPort = ports[0];
 
     conf.set(Property.TSERV_PORTSEARCH, "true");
 
@@ -205,7 +191,6 @@ public class TServerUtilsTest {
     assertTrue(reservedPorts.containsKey(gcPort));
     assertTrue(reservedPorts.containsKey(managerPort));
     assertTrue(reservedPorts.containsKey(monitorPort));
-    assertTrue(reservedPorts.containsKey(managerReplCoordPort));
 
     InetAddress addr = InetAddress.getByName("localhost");
     try (ServerSocket s = new ServerSocket(tserverDefaultPort, 50, addr)) {
@@ -215,7 +200,7 @@ public class TServerUtilsTest {
       assertNotNull(server);
 
       // Finally ensure that the TServer is using the last port (i.e. port search worked)
-      assertEquals(address.getAddress().getPort(), tserverFinalPort);
+      assertTrue(address.getAddress().getPort() == tserverFinalPort);
     } finally {
       if (server != null) {
         server.stop();
@@ -268,9 +253,9 @@ public class TServerUtilsTest {
   }
 
   private int[] findTwoFreeSequentialPorts(int startingAddress) throws UnknownHostException {
-    boolean sequential;
+    boolean sequential = false;
     int low = startingAddress;
-    int high;
+    int high = 0;
     do {
       low = getFreePort(low);
       high = getFreePort(low + 1);
@@ -292,7 +277,7 @@ public class TServerUtilsTest {
         // keep trying
       }
     }
-    throw new RuntimeException("Unable to find open port");
+    throw new IllegalStateException("Unable to find open port");
   }
 
   private ServerAddress startServer() throws Exception {
@@ -306,7 +291,7 @@ public class TServerUtilsTest {
     return TServerUtils.startServer(context, hostname, Property.TSERV_CLIENTPORT, processor,
         "TServerUtilsTest", "TServerUtilsTestThread", Property.TSERV_PORTSEARCH,
         Property.TSERV_MINTHREADS, Property.TSERV_MINTHREADS_TIMEOUT, Property.TSERV_THREADCHECK,
-        Property.RPC_MAX_MESSAGE_SIZE);
+        Property.GENERAL_MAX_MESSAGE_SIZE);
 
   }
 }
