@@ -18,14 +18,12 @@
  */
 package org.apache.accumulo.coordinator;
 
-import static java.nio.charset.StandardCharsets.UTF_8;
-import static org.apache.accumulo.core.conf.Property.COMPACTION_COORDINATOR_SUMMARIES_MAXTHREADS;
-import static org.apache.accumulo.core.util.UtilWaitThread.sleepUninterruptibly;
-import static org.apache.accumulo.core.util.threads.ThreadPoolNames.COMPACTION_COORDINATOR_SUMMARY_POOL;
+import static com.google.common.util.concurrent.Uninterruptibles.sleepUninterruptibly;
 
+import java.lang.reflect.InvocationTargetException;
 import java.net.UnknownHostException;
-import java.util.Collection;
-import java.util.HashSet;
+import java.util.ArrayList;
+import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
@@ -33,15 +31,19 @@ import java.util.UUID;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentSkipListSet;
 import java.util.concurrent.ExecutorService;
+import java.util.concurrent.Future;
 import java.util.concurrent.ScheduledFuture;
+import java.util.concurrent.ScheduledThreadPoolExecutor;
 import java.util.concurrent.TimeUnit;
 import java.util.stream.Collectors;
 
 import org.apache.accumulo.coordinator.QueueSummaries.PrioTserver;
 import org.apache.accumulo.core.Constants;
+import org.apache.accumulo.core.cli.ConfigOpts;
 import org.apache.accumulo.core.client.AccumuloSecurityException;
 import org.apache.accumulo.core.client.TableNotFoundException;
 import org.apache.accumulo.core.clientImpl.thrift.SecurityErrorCode;
+import org.apache.accumulo.core.clientImpl.thrift.TInfo;
 import org.apache.accumulo.core.clientImpl.thrift.TableOperation;
 import org.apache.accumulo.core.clientImpl.thrift.TableOperationExceptionType;
 import org.apache.accumulo.core.clientImpl.thrift.ThriftSecurityException;
@@ -51,69 +53,59 @@ import org.apache.accumulo.core.compaction.thrift.TCompactionState;
 import org.apache.accumulo.core.compaction.thrift.TCompactionStatusUpdate;
 import org.apache.accumulo.core.compaction.thrift.TExternalCompaction;
 import org.apache.accumulo.core.compaction.thrift.TExternalCompactionList;
-import org.apache.accumulo.core.compaction.thrift.TNextCompactionJob;
 import org.apache.accumulo.core.conf.AccumuloConfiguration;
 import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.data.NamespaceId;
-import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.dataImpl.thrift.TKeyExtent;
-import org.apache.accumulo.core.fate.zookeeper.ServiceLock;
-import org.apache.accumulo.core.fate.zookeeper.ServiceLockSupport.HAServiceLockWatcher;
 import org.apache.accumulo.core.fate.zookeeper.ZooReaderWriter;
+import org.apache.accumulo.core.lock.ServiceLock;
+import org.apache.accumulo.core.lock.ServiceLockData;
+import org.apache.accumulo.core.lock.ServiceLockData.ThriftService;
 import org.apache.accumulo.core.metadata.TServerInstance;
 import org.apache.accumulo.core.metadata.schema.Ample;
 import org.apache.accumulo.core.metadata.schema.ExternalCompactionId;
 import org.apache.accumulo.core.metadata.schema.TabletMetadata;
-import org.apache.accumulo.core.metrics.MetricsInfo;
-import org.apache.accumulo.core.process.thrift.ServerProcessService;
+import org.apache.accumulo.core.metrics.MetricsUtil;
 import org.apache.accumulo.core.rpc.ThriftUtil;
 import org.apache.accumulo.core.rpc.clients.ThriftClientTypes;
 import org.apache.accumulo.core.securityImpl.thrift.TCredentials;
 import org.apache.accumulo.core.tabletserver.thrift.TCompactionQueueSummary;
 import org.apache.accumulo.core.tabletserver.thrift.TCompactionStats;
 import org.apache.accumulo.core.tabletserver.thrift.TExternalCompactionJob;
-import org.apache.accumulo.core.tabletserver.thrift.TabletClientService;
+import org.apache.accumulo.core.tabletserver.thrift.TabletServerClientService;
 import org.apache.accumulo.core.trace.TraceUtil;
-import org.apache.accumulo.core.trace.thrift.TInfo;
-import org.apache.accumulo.core.util.HostAndPort;
+import org.apache.accumulo.core.util.UtilWaitThread;
 import org.apache.accumulo.core.util.compaction.ExternalCompactionUtil;
 import org.apache.accumulo.core.util.compaction.RunningCompaction;
 import org.apache.accumulo.core.util.threads.ThreadPools;
 import org.apache.accumulo.server.AbstractServer;
-import org.apache.accumulo.server.GarbageCollectionLogger;
 import org.apache.accumulo.server.ServerContext;
-import org.apache.accumulo.server.ServerOpts;
 import org.apache.accumulo.server.manager.LiveTServerSet;
 import org.apache.accumulo.server.manager.LiveTServerSet.TServerConnection;
 import org.apache.accumulo.server.rpc.ServerAddress;
 import org.apache.accumulo.server.rpc.TServerUtils;
 import org.apache.accumulo.server.rpc.ThriftProcessorTypes;
-import org.apache.accumulo.server.security.AuditedSecurityOperation;
+import org.apache.accumulo.server.security.SecurityOperation;
 import org.apache.thrift.TException;
 import org.apache.thrift.transport.TTransport;
 import org.apache.thrift.transport.TTransportException;
 import org.apache.zookeeper.KeeperException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
-import org.slf4j.event.Level;
 
 import com.github.benmanes.caffeine.cache.Cache;
 import com.github.benmanes.caffeine.cache.Caffeine;
-import com.github.benmanes.caffeine.cache.LoadingCache;
 import com.google.common.collect.Sets;
+import com.google.common.net.HostAndPort;
+import com.google.common.util.concurrent.Uninterruptibles;
 
-import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
-import io.micrometer.core.instrument.Tag;
-
-public class CompactionCoordinator extends AbstractServer implements
-    CompactionCoordinatorService.Iface, LiveTServerSet.Listener, ServerProcessService.Iface {
+public class CompactionCoordinator extends AbstractServer
+    implements CompactionCoordinatorService.Iface, LiveTServerSet.Listener {
 
   private static final Logger LOG = LoggerFactory.getLogger(CompactionCoordinator.class);
+  private static final long FIFTEEN_MINUTES = TimeUnit.MINUTES.toMillis(15);
 
-  private static final Logger STATUS_LOG =
-      LoggerFactory.getLogger(CompactionCoordinator.class.getName() + ".compaction.status");
-  private static final long TIME_BETWEEN_GC_CHECKS = 5000;
   protected static final QueueSummaries QUEUE_SUMMARIES = new QueueSummaries();
 
   /*
@@ -132,63 +124,35 @@ public class CompactionCoordinator extends AbstractServer implements
   /* Map of queue name to last time compactor called to get a compaction job */
   private static final Map<String,Long> TIME_COMPACTOR_LAST_CHECKED = new ConcurrentHashMap<>();
 
-  static class FailureCounts {
-    long failures;
-    long successes;
-
-    FailureCounts(long failures, long successes) {
-      this.failures = failures;
-      this.successes = successes;
-    }
-
-    static FailureCounts incrementFailure(Object key, FailureCounts counts) {
-      if (counts == null) {
-        return new FailureCounts(1, 0);
-      }
-      counts.failures++;
-      return counts;
-    }
-
-    static FailureCounts incrementSuccess(Object key, FailureCounts counts) {
-      if (counts == null) {
-        return new FailureCounts(0, 1);
-      }
-      counts.successes++;
-      return counts;
-    }
-  }
-
-  private final ConcurrentHashMap<String,FailureCounts> failingQueues = new ConcurrentHashMap<>();
-  private final ConcurrentHashMap<String,FailureCounts> failingCompactors =
-      new ConcurrentHashMap<>();
-  private final ConcurrentHashMap<TableId,FailureCounts> failingTables = new ConcurrentHashMap<>();
-
-  private final GarbageCollectionLogger gcLogger = new GarbageCollectionLogger();
-  protected AuditedSecurityOperation security;
+  protected SecurityOperation security;
   protected final AccumuloConfiguration aconf;
   protected CompactionFinalizer compactionFinalizer;
   protected LiveTServerSet tserverSet;
 
   private ServiceLock coordinatorLock;
 
-  private final LoadingCache<String,Integer> compactorCounts;
+  // Exposed for tests
+  protected volatile Boolean shutdown = false;
 
-  protected CompactionCoordinator(ServerOpts opts, String[] args) {
+  private final ScheduledThreadPoolExecutor schedExecutor;
+  private final ExecutorService summariesExecutor;
+
+  protected CompactionCoordinator(ConfigOpts opts, String[] args) {
     this(opts, args, null);
   }
 
-  protected CompactionCoordinator(ServerOpts opts, String[] args, AccumuloConfiguration conf) {
+  protected CompactionCoordinator(ConfigOpts opts, String[] args, AccumuloConfiguration conf) {
     super("compaction-coordinator", opts, args);
     aconf = conf == null ? super.getConfiguration() : conf;
-    compactionFinalizer = createCompactionFinalizer();
+    schedExecutor = ThreadPools.getServerThreadPools().createGeneralScheduledExecutorService(aconf);
+    summariesExecutor = ThreadPools.getServerThreadPools().createFixedThreadPool(10,
+        "Compaction Summary Gatherer", false);
+    compactionFinalizer = createCompactionFinalizer(schedExecutor);
     tserverSet = createLiveTServerSet();
     setupSecurity();
-    startGCLogger();
     printStartupMsg();
-    startCompactionCleaner();
-    startRunningCleaner();
-    compactorCounts = Caffeine.newBuilder().expireAfterWrite(30, TimeUnit.SECONDS)
-        .build(queue -> ExternalCompactionUtil.countCompactors(queue, getContext()));
+    startCompactionCleaner(schedExecutor);
+    startRunningCleaner(schedExecutor);
   }
 
   @Override
@@ -196,8 +160,9 @@ public class CompactionCoordinator extends AbstractServer implements
     return aconf;
   }
 
-  protected CompactionFinalizer createCompactionFinalizer() {
-    return new CompactionFinalizer(getContext(), getContext().getScheduledExecutor());
+  protected CompactionFinalizer
+      createCompactionFinalizer(ScheduledThreadPoolExecutor schedExecutor) {
+    return new CompactionFinalizer(getContext(), schedExecutor);
   }
 
   protected LiveTServerSet createLiveTServerSet() {
@@ -208,22 +173,15 @@ public class CompactionCoordinator extends AbstractServer implements
     security = getContext().getSecurityOperation();
   }
 
-  protected void startGCLogger() {
-    ScheduledFuture<?> future = getContext().getScheduledExecutor().scheduleWithFixedDelay(
-        () -> gcLogger.logGCInfo(getConfiguration()), 0, TIME_BETWEEN_GC_CHECKS,
-        TimeUnit.MILLISECONDS);
+  protected void startCompactionCleaner(ScheduledThreadPoolExecutor schedExecutor) {
+    ScheduledFuture<?> future =
+        schedExecutor.scheduleWithFixedDelay(this::cleanUpCompactors, 0, 5, TimeUnit.MINUTES);
     ThreadPools.watchNonCriticalScheduledTask(future);
   }
 
-  protected void startCompactionCleaner() {
-    ScheduledFuture<?> future = getContext().getScheduledExecutor()
-        .scheduleWithFixedDelay(this::cleanUpCompactors, 0, 5, TimeUnit.MINUTES);
-    ThreadPools.watchNonCriticalScheduledTask(future);
-  }
-
-  protected void startRunningCleaner() {
-    ScheduledFuture<?> future = getContext().getScheduledExecutor()
-        .scheduleWithFixedDelay(this::cleanUpRunning, 0, 5, TimeUnit.MINUTES);
+  protected void startRunningCleaner(ScheduledThreadPoolExecutor schedExecutor) {
+    ScheduledFuture<?> future =
+        schedExecutor.scheduleWithFixedDelay(this::cleanUpRunning, 0, 5, TimeUnit.MINUTES);
     ThreadPools.watchNonCriticalScheduledTask(future);
   }
 
@@ -247,16 +205,16 @@ public class CompactionCoordinator extends AbstractServer implements
     final String lockPath = getContext().getZooKeeperRoot() + Constants.ZCOORDINATOR_LOCK;
     final UUID zooLockUUID = UUID.randomUUID();
 
-    coordinatorLock = new ServiceLock(getContext().getZooReaderWriter().getZooKeeper(),
-        ServiceLock.path(lockPath), zooLockUUID);
-    HAServiceLockWatcher coordinatorLockWatcher =
-        new HAServiceLockWatcher("coordinator", () -> getShutdownComplete().get());
     while (true) {
 
-      coordinatorLock.lock(coordinatorLockWatcher, coordinatorClientAddress.getBytes(UTF_8));
+      CoordinatorLockWatcher coordinatorLockWatcher = new CoordinatorLockWatcher();
+      coordinatorLock = new ServiceLock(getContext().getZooReaderWriter().getZooKeeper(),
+          ServiceLock.path(lockPath), zooLockUUID);
+      coordinatorLock.lock(coordinatorLockWatcher,
+          new ServiceLockData(zooLockUUID, coordinatorClientAddress, ThriftService.COORDINATOR));
 
       coordinatorLockWatcher.waitForChange();
-      if (coordinatorLockWatcher.isLockAcquired()) {
+      if (coordinatorLockWatcher.isAcquiredLock()) {
         break;
       }
       if (!coordinatorLockWatcher.isFailedToAcquireLock()) {
@@ -275,11 +233,11 @@ public class CompactionCoordinator extends AbstractServer implements
    * @throws UnknownHostException host unknown
    */
   protected ServerAddress startCoordinatorClientService() throws UnknownHostException {
-    var processor = ThriftProcessorTypes.getCoordinatorTProcessor(this, this, getContext());
-    @SuppressWarnings("deprecation")
-    var maxMessageSizeProperty = getConfiguration().resolve(Property.RPC_MAX_MESSAGE_SIZE,
-        Property.GENERAL_MAX_MESSAGE_SIZE);
-    ServerAddress sp = TServerUtils.startServer(getContext(), getBindAddress(),
+    var processor = ThriftProcessorTypes.getCoordinatorTProcessor(this, getContext());
+    Property maxMessageSizeProperty =
+        (getConfiguration().get(Property.COMPACTION_COORDINATOR_MAX_MESSAGE_SIZE) != null
+            ? Property.COMPACTION_COORDINATOR_MAX_MESSAGE_SIZE : Property.GENERAL_MAX_MESSAGE_SIZE);
+    ServerAddress sp = TServerUtils.startServer(getContext(), getHostname(),
         Property.COMPACTION_COORDINATOR_CLIENTPORT, processor, this.getClass().getSimpleName(),
         "Thrift Client Server", Property.COMPACTION_COORDINATOR_THRIFTCLIENT_PORTSEARCH,
         Property.COMPACTION_COORDINATOR_MINTHREADS,
@@ -289,30 +247,16 @@ public class CompactionCoordinator extends AbstractServer implements
     return sp;
   }
 
-  protected Collection<Tag> getServiceTags(HostAndPort clientAddress) {
-    return (MetricsInfo.serviceTags(getContext().getInstanceName(), getApplicationName(),
-        clientAddress, ""));
-  }
-
   @Override
-  @SuppressFBWarnings(value = "DM_EXIT", justification = "main class can call System.exit")
   public void run() {
 
-    try {
-      waitForUpgrade();
-    } catch (InterruptedException e) {
-      LOG.error("Interrupted while waiting for upgrade to complete, exiting...");
-      System.exit(1);
-    }
-
     ServerAddress coordinatorAddress = null;
     try {
       coordinatorAddress = startCoordinatorClientService();
     } catch (UnknownHostException e1) {
-      throw new RuntimeException("Failed to start the coordinator service", e1);
+      throw new IllegalStateException("Failed to start the coordinator service", e1);
     }
-    updateAdvertiseAddress(coordinatorAddress.getAddress());
-    final HostAndPort clientAddress = getAdvertiseAddress();
+    final HostAndPort clientAddress = coordinatorAddress.address;
 
     try {
       getCoordinatorLock(clientAddress);
@@ -320,8 +264,15 @@ public class CompactionCoordinator extends AbstractServer implements
       throw new IllegalStateException("Exception getting Coordinator lock", e);
     }
 
-    MetricsInfo metricsInfo = getContext().getMetricsInfo();
-    metricsInfo.init(getServiceTags(clientAddress));
+    try {
+      MetricsUtil.initializeMetrics(getContext().getConfiguration(), this.applicationName,
+          clientAddress);
+      MetricsUtil.initializeProducers(this);
+    } catch (ClassNotFoundException | InstantiationException | IllegalAccessException
+        | IllegalArgumentException | InvocationTargetException | NoSuchMethodException
+        | SecurityException e1) {
+      LOG.error("Error initializing metrics, metrics will not be emitted.", e1);
+    }
 
     // On a re-start of the coordinator it's possible that external compactions are in-progress.
     // Attempt to get the running compactions on the compactors and then resolve which tserver
@@ -345,137 +296,77 @@ public class CompactionCoordinator extends AbstractServer implements
 
     tserverSet.startListeningForTabletServerChanges();
     startDeadCompactionDetector();
-    startFailureSummaryLogging();
 
     LOG.info("Starting loop to check tservers for compaction summaries");
-    while (!isShutdownRequested()) {
-      if (Thread.currentThread().isInterrupted()) {
-        LOG.info("Server process thread has been interrupted, shutting down");
-        break;
-      }
-      try {
-        long start = System.currentTimeMillis();
+    while (!shutdown) {
+      long start = System.currentTimeMillis();
 
-        updateSummaries();
+      updateSummaries();
 
-        long now = System.currentTimeMillis();
-        LOG.debug("Time spent checking compaction summaries: {}ms", (now - start));
-
-        Map<String,List<HostAndPort>> idleCompactors = getIdleCompactors();
-        TIME_COMPACTOR_LAST_CHECKED.forEach((queue, lastCheckTime) -> {
-          if ((now - lastCheckTime) > getMissingCompactorWarningTime()
-              && QUEUE_SUMMARIES.isCompactionsQueued(queue) && idleCompactors.containsKey(queue)) {
-            LOG.warn("No compactors have checked in with coordinator for queue {} in {}ms", queue,
-                getMissingCompactorWarningTime());
-          }
-        });
-
-        long checkInterval = getTServerCheckInterval();
-        long duration = (System.currentTimeMillis() - start);
-        if (checkInterval - duration > 0) {
-          LOG.debug("Waiting {}ms for next tserver check", (checkInterval - duration));
-          Thread.sleep(checkInterval - duration);
+      long now = System.currentTimeMillis();
+      TIME_COMPACTOR_LAST_CHECKED.forEach((k, v) -> {
+        if ((now - v) > getMissingCompactorWarningTime()) {
+          LOG.warn("No compactors have checked in with coordinator for queue {} in {}ms", k,
+              getMissingCompactorWarningTime());
         }
-      } catch (InterruptedException e) {
-        LOG.info("Interrupt Exception received, shutting down");
-        gracefulShutdown(getContext().rpcCreds());
+      });
+
+      long checkInterval = getTServerCheckInterval();
+      long duration = (System.currentTimeMillis() - start);
+      if (checkInterval - duration > 0) {
+        LOG.debug("Waiting {}ms for next tserver check", (checkInterval - duration));
+        UtilWaitThread.sleep(checkInterval - duration);
       }
     }
 
-    LOG.debug("Stopping Thrift Servers");
-    if (coordinatorAddress.server != null) {
-      coordinatorAddress.server.stop();
-    }
-    super.close();
-    getShutdownComplete().set(true);
-    LOG.info("stop requested. exiting ... ");
-    try {
-      coordinatorLock.unlock();
-    } catch (Exception e) {
-      LOG.warn("Failed to release Coordinator lock", e);
-    }
-
-  }
-
-  private Map<String,List<HostAndPort>> getIdleCompactors() {
-
-    Map<String,List<HostAndPort>> allCompactors =
-        ExternalCompactionUtil.getCompactorAddrs(getContext());
-
-    Set<String> emptyQueues = new HashSet<>();
-
-    // Remove all of the compactors that are running a compaction
-    RUNNING_CACHE.values().forEach(rc -> {
-      List<HostAndPort> busyCompactors = allCompactors.get(rc.getQueueName());
-      if (busyCompactors != null
-          && busyCompactors.remove(HostAndPort.fromString(rc.getCompactorAddress()))) {
-        if (busyCompactors.isEmpty()) {
-          emptyQueues.add(rc.getQueueName());
-        }
-      }
-    });
-    // Remove entries with empty queues
-    emptyQueues.forEach(e -> allCompactors.remove(e));
-    return allCompactors;
+    summariesExecutor.shutdownNow();
+    LOG.info("Shutting down");
   }
 
   private void updateSummaries() {
-    int maxThreads =
-        Integer.parseInt(getConfiguration().get(COMPACTION_COORDINATOR_SUMMARIES_MAXTHREADS));
-    ExecutorService executor =
-        ThreadPools.getServerThreadPools().getPoolBuilder(COMPACTION_COORDINATOR_SUMMARY_POOL)
-            .numCoreThreads(10).numMaxThreads(maxThreads).build();
-    try {
-      Set<String> queuesSeen = new ConcurrentSkipListSet<>();
 
-      tserverSet.getCurrentServers().forEach(tsi -> {
-        executor.execute(() -> updateSummaries(tsi, queuesSeen));
-      });
+    final ArrayList<Future<?>> tasks = new ArrayList<>();
+    Set<String> queuesSeen = new ConcurrentSkipListSet<>();
 
-      executor.shutdown();
+    tserverSet.getCurrentServers().forEach(tsi -> {
+      tasks.add(summariesExecutor.submit(() -> updateSummaries(tsi, queuesSeen)));
+    });
 
-      try {
-        while (!executor.awaitTermination(1, TimeUnit.MINUTES)) {}
-      } catch (InterruptedException e) {
-        Thread.currentThread().interrupt();
-        throw new RuntimeException(e);
+    // Wait for all tasks to complete
+    while (!tasks.isEmpty()) {
+      Iterator<Future<?>> iter = tasks.iterator();
+      while (iter.hasNext()) {
+        Future<?> f = iter.next();
+        if (f.isDone()) {
+          iter.remove();
+        }
       }
-
-      // remove any queues that were seen in the past, but were not seen in the latest gathering of
-      // summaries
-      TIME_COMPACTOR_LAST_CHECKED.keySet().retainAll(queuesSeen);
-
-      // add any queues that were never seen before
-      queuesSeen.forEach(q -> {
-        TIME_COMPACTOR_LAST_CHECKED.computeIfAbsent(q, k -> System.currentTimeMillis());
-      });
-    } finally {
-      executor.shutdownNow();
+      Uninterruptibles.sleepUninterruptibly(1, TimeUnit.SECONDS);
     }
+
+    // remove any queues that were seen in the past, but were not seen in the latest gathering of
+    // summaries
+    TIME_COMPACTOR_LAST_CHECKED.keySet().retainAll(queuesSeen);
+
+    // add any queues that were never seen before
+    queuesSeen.forEach(q -> {
+      TIME_COMPACTOR_LAST_CHECKED.computeIfAbsent(q, k -> System.currentTimeMillis());
+    });
   }
 
   private void updateSummaries(TServerInstance tsi, Set<String> queuesSeen) {
-
-    String originalThreadName = Thread.currentThread().getName();
-    Thread.currentThread().setName(originalThreadName + " [tserver=" + tsi.getHostPort() + "]");
     try {
-      TabletClientService.Client client = null;
+      TabletServerClientService.Client client = null;
       try {
-        LOG.trace("Contacting tablet server {} to get external compaction summaries",
+        LOG.debug("Contacting tablet server {} to get external compaction summaries",
             tsi.getHostPort());
         client = getTabletServerConnection(tsi);
-        if (client != null) {
-          List<TCompactionQueueSummary> summaries =
-              client.getCompactionQueueInfo(TraceUtil.traceInfo(), getContext().rpcCreds());
-          QUEUE_SUMMARIES.update(tsi, summaries);
-          summaries.forEach(summary -> {
-            queuesSeen.add(summary.getQueue());
-          });
-        } else {
-          LOG.trace("Connection to get summaries could not be established {} ",
-              tsi.getHostAndPort());
-          QUEUE_SUMMARIES.remove(Set.of(tsi));
-        }
+        List<TCompactionQueueSummary> summaries =
+            client.getCompactionQueueInfo(TraceUtil.traceInfo(), getContext().rpcCreds());
+        QUEUE_SUMMARIES.update(tsi, summaries);
+        summaries.forEach(summary -> {
+          queuesSeen.add(summary.getQueue());
+        });
       } finally {
         ThriftUtil.returnClient(client, getContext());
       }
@@ -483,17 +374,15 @@ public class CompactionCoordinator extends AbstractServer implements
       LOG.warn("Error getting external compaction summaries from tablet server: {}",
           tsi.getHostAndPort(), e);
       QUEUE_SUMMARIES.remove(Set.of(tsi));
-    } finally {
-      Thread.currentThread().setName(originalThreadName);
     }
   }
 
   protected void startDeadCompactionDetector() {
-    new DeadCompactionDetector(getContext(), this, getContext().getScheduledExecutor()).start();
+    new DeadCompactionDetector(getContext(), this, schedExecutor).start();
   }
 
   protected long getMissingCompactorWarningTime() {
-    return getConfiguration().getTimeInMillis(Property.COMPACTOR_MAX_JOB_WAIT_TIME) * 3;
+    return FIFTEEN_MINUTES;
   }
 
   protected long getTServerCheckInterval() {
@@ -528,7 +417,7 @@ public class CompactionCoordinator extends AbstractServer implements
    * @return compaction job
    */
   @Override
-  public TNextCompactionJob getCompactionJob(TInfo tinfo, TCredentials credentials,
+  public TExternalCompactionJob getCompactionJob(TInfo tinfo, TCredentials credentials,
       String queueName, String compactorAddress, String externalCompactionId)
       throws ThriftSecurityException {
 
@@ -550,31 +439,20 @@ public class CompactionCoordinator extends AbstractServer implements
 
       LOG.trace("Getting compaction for queue {} from tserver {}", queue, tserver.getHostAndPort());
       // Get a compaction from the tserver
-      TabletClientService.Client client = null;
-      String originalThreadName = Thread.currentThread().getName();
-      Thread.currentThread()
-          .setName(originalThreadName + " [tserver=" + tserver.getHostPort() + "]");
+      TabletServerClientService.Client client = null;
       try {
         client = getTabletServerConnection(tserver);
-        if (client == null) {
-          LOG.trace("No connection established for queue {} on tserver {}, trying next tserver",
-              queue, tserver.getHostAndPort());
-          QUEUE_SUMMARIES.removeSummary(tserver, queue, prioTserver.prio);
-          prioTserver = QUEUE_SUMMARIES.getNextTserver(queue);
-          continue;
-        }
-
         TExternalCompactionJob job =
             client.reserveCompactionJob(TraceUtil.traceInfo(), getContext().rpcCreds(), queue,
                 prioTserver.prio, compactorAddress, externalCompactionId);
         if (null == job.getExternalCompactionId()) {
           LOG.trace("No compactions found for queue {} on tserver {}, trying next tserver", queue,
               tserver.getHostAndPort());
+
           QUEUE_SUMMARIES.removeSummary(tserver, queue, prioTserver.prio);
           prioTserver = QUEUE_SUMMARIES.getNextTserver(queue);
           continue;
         }
-
         // It is possible that by the time this added that the tablet has already canceled the
         // compaction or the compactor that made this request is dead. In these cases the compaction
         // is not actually running.
@@ -586,11 +464,10 @@ public class CompactionCoordinator extends AbstractServer implements
       } catch (TException e) {
         LOG.warn("Error from tserver {} while trying to reserve compaction, trying next tserver",
             ExternalCompactionUtil.getHostPortString(tserver.getHostAndPort()), e);
-        QUEUE_SUMMARIES.remove(Set.of(tserver));
+        QUEUE_SUMMARIES.removeSummary(tserver, queue, prioTserver.prio);
         prioTserver = QUEUE_SUMMARIES.getNextTserver(queue);
       } finally {
         ThriftUtil.returnClient(client, getContext());
-        Thread.currentThread().setName(originalThreadName);
       }
     }
 
@@ -600,7 +477,7 @@ public class CompactionCoordinator extends AbstractServer implements
       result = new TExternalCompactionJob();
     }
 
-    return new TNextCompactionJob(result, compactorCounts.get(queue));
+    return result;
 
   }
 
@@ -611,16 +488,12 @@ public class CompactionCoordinator extends AbstractServer implements
    * @return thrift client
    * @throws TTransportException thrift error
    */
-  protected TabletClientService.Client getTabletServerConnection(TServerInstance tserver)
+  protected TabletServerClientService.Client getTabletServerConnection(TServerInstance tserver)
       throws TTransportException {
     TServerConnection connection = tserverSet.getConnection(tserver);
-    if (connection == null) {
-      return null;
-    }
     ServerContext serverContext = getContext();
     TTransport transport =
-        serverContext.getTransportPool().getTransport(ThriftClientTypes.TABLET_SERVER,
-            connection.getAddress(), getContext().getClientTimeoutInMillis(), serverContext, true);
+        serverContext.getTransportPool().getTransport(connection.getAddress(), 0, serverContext);
     return ThriftUtil.createClient(ThriftClientTypes.TABLET_SERVER, transport);
   }
 
@@ -645,10 +518,9 @@ public class CompactionCoordinator extends AbstractServer implements
     }
 
     var extent = KeyExtent.fromThrift(textent);
-    LOG.debug("Compaction completed, id: {}, stats: {}, extent: {}", externalCompactionId, stats,
+    LOG.info("Compaction completed, id: {}, stats: {}, extent: {}", externalCompactionId, stats,
         extent);
     final var ecid = ExternalCompactionId.of(externalCompactionId);
-    captureSuccess(ecid, extent);
     compactionFinalizer.commitCompaction(ecid, extent, stats.fileSize, stats.entriesWritten);
     // It's possible that RUNNING might not have an entry for this ecid in the case
     // of a coordinator restart when the Coordinator can't find the TServer for the
@@ -658,89 +530,17 @@ public class CompactionCoordinator extends AbstractServer implements
 
   @Override
   public void compactionFailed(TInfo tinfo, TCredentials credentials, String externalCompactionId,
-      TKeyExtent extent, String exceptionClassName) throws ThriftSecurityException {
+      TKeyExtent extent) throws ThriftSecurityException {
     // do not expect users to call this directly, expect other tservers to call this method
     if (!security.canPerformSystemActions(credentials)) {
       throw new AccumuloSecurityException(credentials.getPrincipal(),
           SecurityErrorCode.PERMISSION_DENIED).asThriftException();
     }
-    KeyExtent fromThriftExtent = KeyExtent.fromThrift(extent);
-    LOG.info("Compaction failed: id: {}, extent: {}, compactor exception:{}", externalCompactionId,
-        fromThriftExtent, exceptionClassName);
+    LOG.info("Compaction failed, id: {}", externalCompactionId);
     final var ecid = ExternalCompactionId.of(externalCompactionId);
-    if (exceptionClassName != null) {
-      captureFailure(ecid, fromThriftExtent);
-    }
     compactionFailed(Map.of(ecid, KeyExtent.fromThrift(extent)));
   }
 
-  private void captureFailure(ExternalCompactionId ecid, KeyExtent extent) {
-    var rc = RUNNING_CACHE.get(ecid);
-    if (rc != null) {
-      final String queue = rc.getQueueName();
-      failingQueues.compute(queue, FailureCounts::incrementFailure);
-      final String compactor = rc.getCompactorAddress();
-      failingCompactors.compute(compactor, FailureCounts::incrementFailure);
-    }
-    failingTables.compute(extent.tableId(), FailureCounts::incrementFailure);
-  }
-
-  protected void startFailureSummaryLogging() {
-    ScheduledFuture<?> future = getContext().getScheduledExecutor()
-        .scheduleWithFixedDelay(this::printStats, 0, 5, TimeUnit.MINUTES);
-    ThreadPools.watchNonCriticalScheduledTask(future);
-  }
-
-  private <T> void printStats(String logPrefix, ConcurrentHashMap<T,FailureCounts> failureCounts,
-      boolean logSuccessAtTrace) {
-    for (var key : failureCounts.keySet()) {
-      failureCounts.compute(key, (k, counts) -> {
-        if (counts != null) {
-          Level level;
-          if (counts.failures > 0) {
-            level = Level.WARN;
-          } else if (logSuccessAtTrace) {
-            level = Level.TRACE;
-          } else {
-            level = Level.DEBUG;
-          }
-
-          LOG.atLevel(level).log("{} {} failures:{} successes:{} since last time this was logged ",
-              logPrefix, k, counts.failures, counts.successes);
-        }
-
-        // clear the counts so they can start building up for the next logging if this key is ever
-        // used again
-        return null;
-      });
-    }
-  }
-
-  private void printStats() {
-
-    // Remove down compactors from failing list
-    Map<String,List<HostAndPort>> allCompactors =
-        ExternalCompactionUtil.getCompactorAddrs(getContext());
-    Set<String> allCompactorAddrs = new HashSet<>();
-    allCompactors.values().forEach(l -> l.forEach(c -> allCompactorAddrs.add(c.toString())));
-    failingCompactors.keySet().retainAll(allCompactorAddrs);
-
-    printStats("Queue", failingQueues, false);
-    printStats("Table", failingTables, false);
-    printStats("Compactor", failingCompactors, true);
-  }
-
-  private void captureSuccess(ExternalCompactionId ecid, KeyExtent extent) {
-    var rc = RUNNING_CACHE.get(ecid);
-    if (rc != null) {
-      final String queue = rc.getQueueName();
-      failingQueues.compute(queue, FailureCounts::incrementSuccess);
-      final String compactor = rc.getCompactorAddress();
-      failingCompactors.compute(compactor, FailureCounts::incrementSuccess);
-    }
-    failingTables.compute(extent.tableId(), FailureCounts::incrementSuccess);
-  }
-
   void compactionFailed(Map<ExternalCompactionId,KeyExtent> compactions) {
     compactionFinalizer.failCompactions(compactions);
     compactions.forEach((k, v) -> recordCompletion(k));
@@ -765,8 +565,8 @@ public class CompactionCoordinator extends AbstractServer implements
       throw new AccumuloSecurityException(credentials.getPrincipal(),
           SecurityErrorCode.PERMISSION_DENIED).asThriftException();
     }
-    STATUS_LOG.trace("Compaction status update, id: {}, timestamp: {}, update: {}",
-        externalCompactionId, timestamp, update);
+    LOG.debug("Compaction status update, id: {}, timestamp: {}, update: {}", externalCompactionId,
+        timestamp, update);
     final RunningCompaction rc = RUNNING_CACHE.get(ExternalCompactionId.of(externalCompactionId));
     if (null != rc) {
       rc.addUpdate(timestamp, update);
@@ -799,19 +599,14 @@ public class CompactionCoordinator extends AbstractServer implements
     // grab the ids that are listed as running in the metadata table. It important that this is done
     // after getting the snapshot.
     Set<ExternalCompactionId> idsInMetadata = readExternalCompactionIds();
-    LOG.debug("Current ECIDs in metadata: {}", idsInMetadata.size());
-    LOG.debug("Current ECIDs in running cache: {}", idsSnapshot.size());
 
     var idsToRemove = Sets.difference(idsSnapshot, idsInMetadata);
 
     // remove ids that are in the running set but not in the metadata table
-    idsToRemove.forEach(this::recordCompletion);
+    idsToRemove.forEach(ecid -> recordCompletion(ecid));
 
-    if (!idsToRemove.isEmpty()) {
-      LOG.debug("Removed {} stale entries from RUNNING_CACHE", idsToRemove.size());
-      if (LOG.isTraceEnabled()) {
-        idsToRemove.forEach(ecid -> LOG.trace("Removing stale entry: {} from RUNNING_CACHE", ecid));
-      }
+    if (idsToRemove.size() > 0) {
+      LOG.debug("Removed stale entries from RUNNING_CACHE : {}", idsToRemove);
     }
   }
 
@@ -932,17 +727,12 @@ public class CompactionCoordinator extends AbstractServer implements
       LOG.warn("Failed to clean up compactors", e);
     } catch (InterruptedException e) {
       Thread.currentThread().interrupt();
-      throw new RuntimeException(e);
+      throw new IllegalStateException(e);
     }
   }
 
-  @Override
-  public ServiceLock getLock() {
-    return coordinatorLock;
-  }
-
   public static void main(String[] args) throws Exception {
-    try (CompactionCoordinator compactor = new CompactionCoordinator(new ServerOpts(), args)) {
+    try (CompactionCoordinator compactor = new CompactionCoordinator(new ConfigOpts(), args)) {
       compactor.runServer();
     }
   }
