@@ -31,7 +31,6 @@ import java.util.stream.Collectors;
 import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.metadata.schema.Ample.DataLevel;
-import org.apache.accumulo.core.metadata.schema.ExternalCompactionFinalState;
 import org.apache.accumulo.core.metadata.schema.ExternalCompactionId;
 import org.apache.accumulo.core.metadata.schema.TabletMetadata.ColumnType;
 import org.apache.accumulo.core.util.compaction.ExternalCompactionUtil;
@@ -61,8 +60,7 @@ public class DeadCompactionDetector {
 
     // The order of obtaining information is very important to avoid race conditions.
 
-    log.debug("Starting to look for dead compactions, deadCompactions.size():{}",
-        deadCompactions.size());
+    log.trace("Starting to look for dead compactions");
 
     Map<ExternalCompactionId,KeyExtent> tabletCompactions = new HashMap<>();
 
@@ -82,9 +80,6 @@ public class DeadCompactionDetector {
       return;
     }
 
-    log.debug("tabletCompactions.size():{} read into memory from metadata table",
-        tabletCompactions.size());
-
     if (log.isTraceEnabled()) {
       tabletCompactions.forEach((ecid, extent) -> log.trace("Saw {} for {}", ecid, extent));
     }
@@ -111,34 +106,21 @@ public class DeadCompactionDetector {
     });
 
     // Determine which compactions are currently committing and remove those
-    try (
-        var externalCompactionFinalStates = context.getAmple().getExternalCompactionFinalStates()) {
-      externalCompactionFinalStates.map(ExternalCompactionFinalState::getExternalCompactionId)
-          .forEach(ecid -> {
-            if (tabletCompactions.remove(ecid) != null) {
-              log.trace("Removed compaction {} that is committing", ecid);
-            }
-            if (this.deadCompactions.remove(ecid) != null) {
-              log.trace("Removed {} from the dead compaction map, it's committing", ecid);
-            }
-          });
-    }
+    context.getAmple().getExternalCompactionFinalStates()
+        .map(ecfs -> ecfs.getExternalCompactionId()).forEach(ecid -> {
+          if (tabletCompactions.remove(ecid) != null) {
+            log.trace("Removed compaction {} that is committing", ecid);
+          }
+          if (this.deadCompactions.remove(ecid) != null) {
+            log.trace("Removed {} from the dead compaction map, it's committing", ecid);
+          }
+        });
 
-    log.trace("deadCompactions.size() after removals {}", deadCompactions.size());
     tabletCompactions.forEach((ecid, extent) -> {
-      var count = this.deadCompactions.merge(ecid, 1L, Long::sum);
-      if (count == 1) {
-        // The first time a possible dead compaction is seen, for quick compactions there is a good
-        // chance that it is already complete instead of dead. In order to avoid spamming the logs
-        // w/ false positives, log the first seen at trace.
-        log.trace("Possible dead compaction detected {} {} {}", ecid, extent, count);
-      } else {
-        log.debug("Possible dead compaction detected {} {} {}", ecid, extent, count);
-      }
+      log.debug("Possible dead compaction detected {} {}", ecid, extent);
+      this.deadCompactions.merge(ecid, 1L, Long::sum);
     });
 
-    log.debug("deadCompactions.size() after additions {}", deadCompactions.size());
-
     // Everything left in tabletCompactions is no longer running anywhere and should be failed.
     // Its possible that a compaction committed while going through the steps above, if so then
     // that is ok and marking it failed will end up being a no-op.
@@ -146,8 +128,8 @@ public class DeadCompactionDetector {
         this.deadCompactions.entrySet().stream().filter(e -> e.getValue() > 2).map(e -> e.getKey())
             .collect(Collectors.toCollection(TreeSet::new));
     tabletCompactions.keySet().retainAll(toFail);
-    tabletCompactions.forEach((ecid, extent) -> {
-      log.warn("Compaction believed to be dead, failing it: id: {}, extent: {}", ecid, extent);
+    tabletCompactions.forEach((eci, v) -> {
+      log.warn("Compaction {} believed to be dead, failing it.", eci);
     });
     coordinator.compactionFailed(tabletCompactions);
     this.deadCompactions.keySet().removeAll(toFail);
