@@ -18,7 +18,6 @@
  */
 package org.apache.accumulo.coordinator;
 
-import static java.nio.charset.StandardCharsets.UTF_8;
 import static org.easymock.EasyMock.anyObject;
 import static org.easymock.EasyMock.expect;
 import static org.junit.Assert.assertEquals;
@@ -28,7 +27,6 @@ import static org.junit.Assert.assertTrue;
 
 import java.net.UnknownHostException;
 import java.util.ArrayList;
-import java.util.Collection;
 import java.util.Collections;
 import java.util.List;
 import java.util.Map;
@@ -37,35 +35,28 @@ import java.util.Set;
 import java.util.TreeMap;
 import java.util.TreeSet;
 import java.util.UUID;
-import java.util.concurrent.atomic.AtomicBoolean;
+import java.util.concurrent.ScheduledThreadPoolExecutor;
 
+import org.apache.accumulo.core.cli.ConfigOpts;
+import org.apache.accumulo.core.clientImpl.thrift.TInfo;
 import org.apache.accumulo.core.clientImpl.thrift.ThriftSecurityException;
 import org.apache.accumulo.core.compaction.thrift.TExternalCompaction;
-import org.apache.accumulo.core.compaction.thrift.TNextCompactionJob;
-import org.apache.accumulo.core.conf.ConfigurationCopy;
 import org.apache.accumulo.core.conf.DefaultConfiguration;
-import org.apache.accumulo.core.conf.Property;
-import org.apache.accumulo.core.conf.SiteConfiguration;
 import org.apache.accumulo.core.dataImpl.thrift.TKeyExtent;
 import org.apache.accumulo.core.metadata.TServerInstance;
 import org.apache.accumulo.core.metadata.schema.ExternalCompactionId;
-import org.apache.accumulo.core.metrics.MetricsInfo;
-import org.apache.accumulo.core.process.thrift.ServerProcessService;
 import org.apache.accumulo.core.rpc.ThriftUtil;
 import org.apache.accumulo.core.securityImpl.thrift.TCredentials;
 import org.apache.accumulo.core.tabletserver.thrift.TCompactionQueueSummary;
 import org.apache.accumulo.core.tabletserver.thrift.TCompactionStats;
 import org.apache.accumulo.core.tabletserver.thrift.TExternalCompactionJob;
-import org.apache.accumulo.core.tabletserver.thrift.TabletClientService;
-import org.apache.accumulo.core.tabletserver.thrift.TabletClientService.Client;
+import org.apache.accumulo.core.tabletserver.thrift.TabletServerClientService;
+import org.apache.accumulo.core.tabletserver.thrift.TabletServerClientService.Client;
 import org.apache.accumulo.core.trace.TraceUtil;
-import org.apache.accumulo.core.trace.thrift.TInfo;
-import org.apache.accumulo.core.util.HostAndPort;
 import org.apache.accumulo.core.util.compaction.ExternalCompactionUtil;
 import org.apache.accumulo.core.util.compaction.RunningCompaction;
 import org.apache.accumulo.server.AbstractServer;
 import org.apache.accumulo.server.ServerContext;
-import org.apache.accumulo.server.ServerOpts;
 import org.apache.accumulo.server.manager.LiveTServerSet;
 import org.apache.accumulo.server.rpc.ServerAddress;
 import org.apache.accumulo.server.security.AuditedSecurityOperation;
@@ -80,8 +71,7 @@ import org.powermock.core.classloader.annotations.SuppressStaticInitializationFo
 import org.powermock.modules.junit4.PowerMockRunner;
 
 import com.google.common.collect.Sets;
-
-import io.micrometer.core.instrument.Tag;
+import com.google.common.net.HostAndPort;
 
 @RunWith(PowerMockRunner.class)
 @PrepareForTest({CompactionCoordinator.class, DeadCompactionDetector.class, ThriftUtil.class,
@@ -92,20 +82,18 @@ import io.micrometer.core.instrument.Tag;
     "com.sun.org.apache.xerces.*"})
 public class CompactionCoordinatorTest {
 
-  public class TestCoordinator extends CompactionCoordinator implements ServerProcessService.Iface {
+  public class TestCoordinator extends CompactionCoordinator {
 
     private final ServerContext context;
     private final ServerAddress client;
-    private final TabletClientService.Client tabletServerClient;
-    private final AtomicBoolean shutdown = new AtomicBoolean(false);
-    private final AtomicBoolean shutdownComplete = new AtomicBoolean(false);
+    private final Client tabletServerClient;
 
     private Set<ExternalCompactionId> metadataCompactionIds = null;
 
     protected TestCoordinator(CompactionFinalizer finalizer, LiveTServerSet tservers,
-        ServerAddress client, TabletClientService.Client tabletServerClient, ServerContext context,
+        ServerAddress client, Client tabletServerClient, ServerContext context,
         AuditedSecurityOperation security) {
-      super(new ServerOpts(), new String[] {}, context.getConfiguration());
+      super(new ConfigOpts(), new String[] {}, context.getConfiguration());
       this.compactionFinalizer = finalizer;
       this.tserverSet = tservers;
       this.client = client;
@@ -117,40 +105,20 @@ public class CompactionCoordinatorTest {
     @Override
     protected void startDeadCompactionDetector() {}
 
-    @Override
-    protected void startFailureSummaryLogging() {}
-
     @Override
     protected long getTServerCheckInterval() {
-      gracefulShutdown(null);
+      this.shutdown = true;
       return 0L;
     }
 
     @Override
-    public void gracefulShutdown(TCredentials credentials) {
-      shutdown.set(true);
-    }
+    protected void startCompactionCleaner(ScheduledThreadPoolExecutor schedExecutor) {}
 
     @Override
-    public boolean isShutdownRequested() {
-      return shutdown.get();
-    }
-
-    public AtomicBoolean getShutdownComplete() {
-      return shutdownComplete;
-    }
-
-    @Override
-    protected void startCompactionCleaner() {}
-
-    @Override
-    protected CompactionFinalizer createCompactionFinalizer() {
+    protected CompactionFinalizer createCompactionFinalizer(ScheduledThreadPoolExecutor stpe) {
       return null;
     }
 
-    @Override
-    protected void startRunningCleaner() {}
-
     @Override
     protected LiveTServerSet createLiveTServerSet() {
       return null;
@@ -159,9 +127,6 @@ public class CompactionCoordinatorTest {
     @Override
     protected void setupSecurity() {}
 
-    @Override
-    protected void startGCLogger() {}
-
     @Override
     protected void printStartupMsg() {}
 
@@ -191,7 +156,7 @@ public class CompactionCoordinatorTest {
 
     @Override
     public void compactionFailed(TInfo tinfo, TCredentials credentials, String externalCompactionId,
-        TKeyExtent extent, String exceptionClassName) throws ThriftSecurityException {}
+        TKeyExtent extent) throws ThriftSecurityException {}
 
     void setMetadataCompactionIds(Set<ExternalCompactionId> mci) {
       metadataCompactionIds = mci;
@@ -225,33 +190,6 @@ public class CompactionCoordinatorTest {
       metadataCompactionIds = null;
     }
 
-    @Override
-    public Collection<Tag> getServiceTags(HostAndPort clientAddr) {
-      return List.of();
-    }
-
-    @Override
-    protected void waitForUpgrade() throws InterruptedException {}
-
-  }
-
-  @Test
-  public void testCoordinatorWarningTime() {
-    PowerMock.resetAll();
-    PowerMock.suppress(PowerMock.constructor(AbstractServer.class));
-    ServerContext context = PowerMock.createNiceMock(ServerContext.class);
-
-    SiteConfiguration aconf = SiteConfiguration.empty()
-        .withOverrides(Map.of(Property.COMPACTOR_MAX_JOB_WAIT_TIME.getKey(), "15s")).build();
-    ConfigurationCopy config = new ConfigurationCopy(aconf);
-    expect(context.getConfiguration()).andReturn(config).anyTimes();
-
-    PowerMock.replay(context);
-
-    var coordinator = new TestCoordinator(null, null, null, null, context, null);
-    // Should be equal to 3 * 15_000 milliseconds
-    assertEquals(45_000, coordinator.getMissingCompactorWarningTime());
-    coordinator.close();
   }
 
   @Test
@@ -264,14 +202,11 @@ public class CompactionCoordinatorTest {
 
     ServerContext context = PowerMock.createNiceMock(ServerContext.class);
     expect(context.getConfiguration()).andReturn(DefaultConfiguration.getInstance()).anyTimes();
-    MetricsInfo metricsInfo = PowerMock.createNiceMock(MetricsInfo.class);
-    expect(context.getMetricsInfo()).andReturn(metricsInfo).anyTimes();
 
     PowerMock.mockStatic(ExternalCompactionUtil.class);
     List<RunningCompaction> runningCompactions = new ArrayList<>();
     expect(ExternalCompactionUtil.getCompactionsRunningOnCompactors(context))
         .andReturn(runningCompactions);
-    expect(ExternalCompactionUtil.getCompactorAddrs(context)).andReturn(Map.of()).anyTimes();
 
     CompactionFinalizer finalizer = PowerMock.createNiceMock(CompactionFinalizer.class);
     LiveTServerSet tservers = PowerMock.createNiceMock(LiveTServerSet.class);
@@ -284,7 +219,8 @@ public class CompactionCoordinatorTest {
     TServerInstance tsi = PowerMock.createNiceMock(TServerInstance.class);
     expect(tsi.getHostPort()).andReturn("localhost:9997").anyTimes();
 
-    TabletClientService.Client tsc = PowerMock.createNiceMock(TabletClientService.Client.class);
+    TabletServerClientService.Client tsc =
+        PowerMock.createNiceMock(TabletServerClientService.Client.class);
     expect(tsc.getCompactionQueueInfo(anyObject(), anyObject())).andReturn(Collections.emptyList())
         .anyTimes();
 
@@ -317,8 +253,6 @@ public class CompactionCoordinatorTest {
 
     ServerContext context = PowerMock.createNiceMock(ServerContext.class);
     expect(context.getConfiguration()).andReturn(DefaultConfiguration.getInstance()).anyTimes();
-    MetricsInfo metricsInfo = PowerMock.createNiceMock(MetricsInfo.class);
-    expect(context.getMetricsInfo()).andReturn(metricsInfo).anyTimes();
 
     TCredentials creds = PowerMock.createNiceMock(TCredentials.class);
     expect(context.rpcCreds()).andReturn(creds);
@@ -327,7 +261,6 @@ public class CompactionCoordinatorTest {
     List<RunningCompaction> runningCompactions = new ArrayList<>();
     expect(ExternalCompactionUtil.getCompactionsRunningOnCompactors(context))
         .andReturn(runningCompactions);
-    expect(ExternalCompactionUtil.getCompactorAddrs(context)).andReturn(Map.of()).anyTimes();
 
     CompactionFinalizer finalizer = PowerMock.createNiceMock(CompactionFinalizer.class);
     LiveTServerSet tservers = PowerMock.createNiceMock(LiveTServerSet.class);
@@ -341,7 +274,8 @@ public class CompactionCoordinatorTest {
     TServerInstance tsi = PowerMock.createNiceMock(TServerInstance.class);
     expect(tsi.getHostPort()).andReturn("localhost:9997").anyTimes();
 
-    TabletClientService.Client tsc = PowerMock.createNiceMock(TabletClientService.Client.class);
+    TabletServerClientService.Client tsc =
+        PowerMock.createNiceMock(TabletServerClientService.Client.class);
     TCompactionQueueSummary queueSummary = PowerMock.createNiceMock(TCompactionQueueSummary.class);
     expect(tsc.getCompactionQueueInfo(anyObject(), anyObject()))
         .andReturn(Collections.singletonList(queueSummary)).anyTimes();
@@ -391,8 +325,6 @@ public class CompactionCoordinatorTest {
 
     ServerContext context = PowerMock.createNiceMock(ServerContext.class);
     expect(context.getConfiguration()).andReturn(DefaultConfiguration.getInstance()).anyTimes();
-    MetricsInfo metricsInfo = PowerMock.createNiceMock(MetricsInfo.class);
-    expect(context.getMetricsInfo()).andReturn(metricsInfo).anyTimes();
 
     TCredentials creds = PowerMock.createNiceMock(TCredentials.class);
     expect(context.rpcCreds()).andReturn(creds);
@@ -409,7 +341,6 @@ public class CompactionCoordinatorTest {
     List<RunningCompaction> runningCompactions = new ArrayList<>();
     expect(ExternalCompactionUtil.getCompactionsRunningOnCompactors(context))
         .andReturn(runningCompactions);
-    expect(ExternalCompactionUtil.getCompactorAddrs(context)).andReturn(Map.of()).anyTimes();
 
     ServerAddress client = PowerMock.createNiceMock(ServerAddress.class);
     HostAndPort address = HostAndPort.fromString("localhost:10240");
@@ -417,7 +348,8 @@ public class CompactionCoordinatorTest {
 
     expect(instance.getHostPort()).andReturn("localhost:9997").anyTimes();
 
-    TabletClientService.Client tsc = PowerMock.createNiceMock(TabletClientService.Client.class);
+    TabletServerClientService.Client tsc =
+        PowerMock.createNiceMock(TabletServerClientService.Client.class);
     TCompactionQueueSummary queueSummary = PowerMock.createNiceMock(TCompactionQueueSummary.class);
     expect(tsc.getCompactionQueueInfo(anyObject(), anyObject()))
         .andReturn(Collections.singletonList(queueSummary)).anyTimes();
@@ -468,8 +400,6 @@ public class CompactionCoordinatorTest {
 
     ServerContext context = PowerMock.createNiceMock(ServerContext.class);
     expect(context.getConfiguration()).andReturn(DefaultConfiguration.getInstance()).anyTimes();
-    MetricsInfo metricsInfo = PowerMock.createNiceMock(MetricsInfo.class);
-    expect(context.getMetricsInfo()).andReturn(metricsInfo).anyTimes();
 
     TCredentials creds = PowerMock.createNiceMock(TCredentials.class);
     expect(context.rpcCreds()).andReturn(creds);
@@ -488,11 +418,10 @@ public class CompactionCoordinatorTest {
     TExternalCompactionJob job = PowerMock.createNiceMock(TExternalCompactionJob.class);
     expect(job.getExternalCompactionId()).andReturn(eci.toString()).anyTimes();
     TKeyExtent extent = new TKeyExtent();
-    extent.setTable("1".getBytes(UTF_8));
+    extent.setTable("1".getBytes());
     runningCompactions.add(new RunningCompaction(job, tserverAddress.toString(), "queue"));
     expect(ExternalCompactionUtil.getCompactionsRunningOnCompactors(context))
         .andReturn(runningCompactions);
-    expect(ExternalCompactionUtil.getCompactorAddrs(context)).andReturn(Map.of()).anyTimes();
 
     ServerAddress client = PowerMock.createNiceMock(ServerAddress.class);
     HostAndPort address = HostAndPort.fromString("localhost:10240");
@@ -500,7 +429,8 @@ public class CompactionCoordinatorTest {
 
     expect(instance.getHostPort()).andReturn("localhost:9997").anyTimes();
 
-    TabletClientService.Client tsc = PowerMock.createNiceMock(TabletClientService.Client.class);
+    TabletServerClientService.Client tsc =
+        PowerMock.createNiceMock(TabletServerClientService.Client.class);
     TCompactionQueueSummary queueSummary = PowerMock.createNiceMock(TCompactionQueueSummary.class);
     expect(tsc.getCompactionQueueInfo(anyObject(), anyObject()))
         .andReturn(Collections.singletonList(queueSummary)).anyTimes();
@@ -550,8 +480,6 @@ public class CompactionCoordinatorTest {
 
     ServerContext context = PowerMock.createNiceMock(ServerContext.class);
     expect(context.getConfiguration()).andReturn(DefaultConfiguration.getInstance()).anyTimes();
-    MetricsInfo metricsInfo = PowerMock.createNiceMock(MetricsInfo.class);
-    expect(context.getMetricsInfo()).andReturn(metricsInfo).anyTimes();
 
     TCredentials creds = PowerMock.createNiceMock(TCredentials.class);
     expect(context.rpcCreds()).andReturn(creds).anyTimes();
@@ -560,8 +488,6 @@ public class CompactionCoordinatorTest {
     List<RunningCompaction> runningCompactions = new ArrayList<>();
     expect(ExternalCompactionUtil.getCompactionsRunningOnCompactors(context))
         .andReturn(runningCompactions);
-    expect(ExternalCompactionUtil.getCompactorAddrs(context)).andReturn(Map.of()).anyTimes();
-    expect(ExternalCompactionUtil.countCompactors("R2DQ", context)).andReturn(3).anyTimes();
 
     CompactionFinalizer finalizer = PowerMock.createNiceMock(CompactionFinalizer.class);
     LiveTServerSet tservers = PowerMock.createNiceMock(LiveTServerSet.class);
@@ -577,7 +503,8 @@ public class CompactionCoordinatorTest {
     TServerInstance tsi = PowerMock.createNiceMock(TServerInstance.class);
     expect(tsi.getHostPort()).andReturn("localhost:9997").anyTimes();
 
-    TabletClientService.Client tsc = PowerMock.createNiceMock(TabletClientService.Client.class);
+    TabletServerClientService.Client tsc =
+        PowerMock.createNiceMock(TabletServerClientService.Client.class);
     TCompactionQueueSummary queueSummary = PowerMock.createNiceMock(TCompactionQueueSummary.class);
     expect(tsc.getCompactionQueueInfo(anyObject(), anyObject()))
         .andReturn(Collections.singletonList(queueSummary)).anyTimes();
@@ -624,10 +551,8 @@ public class CompactionCoordinatorTest {
     assertEquals(0, coordinator.getRunning().size());
 
     // Get the next job
-    TNextCompactionJob next =
+    TExternalCompactionJob createdJob =
         coordinator.getCompactionJob(trace, creds, "R2DQ", "localhost:10241", eci.toString());
-    assertEquals(3, next.getCompactorCount());
-    var createdJob = next.getJob();
     assertEquals(eci.toString(), createdJob.getExternalCompactionId());
 
     assertEquals(1, coordinator.getQueues().size());
@@ -662,22 +587,18 @@ public class CompactionCoordinatorTest {
     HostAndPort address = HostAndPort.fromString("localhost:10240");
     expect(client.getAddress()).andReturn(address).anyTimes();
 
-    TabletClientService.Client tsc = PowerMock.createNiceMock(TabletClientService.Client.class);
+    TabletServerClientService.Client tsc =
+        PowerMock.createNiceMock(TabletServerClientService.Client.class);
 
     AuditedSecurityOperation security = PowerMock.createNiceMock(AuditedSecurityOperation.class);
     expect(security.canPerformSystemActions(creds)).andReturn(true);
 
-    PowerMock.mockStatic(ExternalCompactionUtil.class);
-    expect(ExternalCompactionUtil.countCompactors("R2DQ", context)).andReturn(1).anyTimes();
-
     PowerMock.replayAll();
 
     var coordinator = new TestCoordinator(finalizer, tservers, client, tsc, context, security);
     coordinator.resetInternals();
-    var next = coordinator.getCompactionJob(TraceUtil.traceInfo(), creds, "R2DQ", "localhost:10240",
-        UUID.randomUUID().toString());
-    assertEquals(1, next.getCompactorCount());
-    var job = next.getJob();
+    TExternalCompactionJob job = coordinator.getCompactionJob(TraceUtil.traceInfo(), creds, "R2DQ",
+        "localhost:10240", UUID.randomUUID().toString());
     assertNull(job.getExternalCompactionId());
 
     PowerMock.verifyAll();
@@ -702,7 +623,8 @@ public class CompactionCoordinatorTest {
     HostAndPort address = HostAndPort.fromString("localhost:10240");
     expect(client.getAddress()).andReturn(address).anyTimes();
 
-    TabletClientService.Client tsc = PowerMock.createNiceMock(TabletClientService.Client.class);
+    TabletServerClientService.Client tsc =
+        PowerMock.createNiceMock(TabletServerClientService.Client.class);
 
     AuditedSecurityOperation security = PowerMock.createNiceMock(AuditedSecurityOperation.class);
     expect(security.canPerformSystemActions(creds)).andReturn(true);
