@@ -18,55 +18,42 @@
  */
 package org.apache.accumulo.compactor;
 
-import static java.nio.charset.StandardCharsets.UTF_8;
 import static org.easymock.EasyMock.expect;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 
 import java.net.UnknownHostException;
-import java.time.Duration;
-import java.util.Collection;
-import java.util.List;
 import java.util.Timer;
 import java.util.TimerTask;
 import java.util.UUID;
 import java.util.concurrent.CountDownLatch;
-import java.util.concurrent.ScheduledThreadPoolExecutor;
-import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicReference;
 import java.util.concurrent.atomic.LongAdder;
 import java.util.function.Supplier;
 
-import org.apache.accumulo.compactor.Compactor.FileCompactorRunnable;
+import org.apache.accumulo.core.cli.ConfigOpts;
 import org.apache.accumulo.core.compaction.thrift.TCompactionState;
 import org.apache.accumulo.core.compaction.thrift.TCompactionStatusUpdate;
-import org.apache.accumulo.core.compaction.thrift.TNextCompactionJob;
+import org.apache.accumulo.core.conf.AccumuloConfiguration;
 import org.apache.accumulo.core.conf.ConfigurationCopy;
 import org.apache.accumulo.core.conf.DefaultConfiguration;
 import org.apache.accumulo.core.conf.Property;
-import org.apache.accumulo.core.data.TableId;
-import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.dataImpl.thrift.TKeyExtent;
 import org.apache.accumulo.core.fate.zookeeper.ZooReaderWriter;
 import org.apache.accumulo.core.metadata.schema.ExternalCompactionId;
-import org.apache.accumulo.core.metrics.MetricsInfo;
-import org.apache.accumulo.core.process.thrift.ServerProcessService;
-import org.apache.accumulo.core.securityImpl.thrift.TCredentials;
 import org.apache.accumulo.core.tabletserver.thrift.TCompactionStats;
 import org.apache.accumulo.core.tabletserver.thrift.TExternalCompactionJob;
 import org.apache.accumulo.core.util.Halt;
-import org.apache.accumulo.core.util.HostAndPort;
 import org.apache.accumulo.core.util.UtilWaitThread;
 import org.apache.accumulo.server.AbstractServer;
 import org.apache.accumulo.server.ServerContext;
-import org.apache.accumulo.server.compaction.FileCompactor;
 import org.apache.accumulo.server.compaction.RetryableThriftCall.RetriesExceededException;
 import org.apache.accumulo.server.fs.VolumeManagerImpl;
+import org.apache.accumulo.server.mem.LowMemoryDetector;
 import org.apache.accumulo.server.rpc.ServerAddress;
 import org.apache.zookeeper.KeeperException;
 import org.apache.zookeeper.ZooKeeper;
-import org.easymock.EasyMock;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.powermock.api.easymock.PowerMock;
@@ -77,7 +64,7 @@ import org.powermock.modules.junit4.PowerMockRunner;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import io.micrometer.core.instrument.Tag;
+import com.google.common.net.HostAndPort;
 
 @RunWith(PowerMockRunner.class)
 @PrepareForTest({Compactor.class})
@@ -86,7 +73,8 @@ import io.micrometer.core.instrument.Tag;
     "org.apache.commons.logging.*", "org.xml.*", "javax.xml.*", "org.w3c.dom.*",
     "com.sun.org.apache.xerces.*"})
 public class CompactorTest {
-  public class SuccessfulCompaction implements FileCompactorRunnable {
+
+  public class SuccessfulCompaction implements Runnable {
 
     protected final Logger LOG = LoggerFactory.getLogger(this.getClass());
 
@@ -95,7 +83,6 @@ public class CompactorTest {
     protected final CountDownLatch started;
     protected final CountDownLatch stopped;
     protected final AtomicReference<Throwable> err;
-    private final FileCompactor compactor = EasyMock.createMock(FileCompactor.class);
 
     public SuccessfulCompaction(LongAdder totalInputEntries, LongAdder totalInputBytes,
         CountDownLatch started, CountDownLatch stopped, AtomicReference<Throwable> err) {
@@ -106,19 +93,6 @@ public class CompactorTest {
       this.stopped = stopped;
     }
 
-    @Override
-    public void initialize() throws RetriesExceededException {}
-
-    @Override
-    public AtomicReference<FileCompactor> getFileCompactor() {
-      return new AtomicReference<>(compactor);
-    }
-
-    @Override
-    public Duration getCompactionAge() {
-      return Duration.ZERO;
-    }
-
     @Override
     public void run() {
       try {
@@ -130,7 +104,6 @@ public class CompactorTest {
         stopped.countDown();
       }
     }
-
   }
 
   public class FailedCompaction extends SuccessfulCompaction {
@@ -186,7 +159,7 @@ public class CompactorTest {
 
   }
 
-  public class SuccessfulCompactor extends Compactor implements ServerProcessService.Iface {
+  public class SuccessfulCompactor extends Compactor {
 
     private final Logger LOG = LoggerFactory.getLogger(SuccessfulCompactor.class);
 
@@ -198,12 +171,12 @@ public class CompactorTest {
     private volatile boolean completedCalled = false;
     private volatile boolean failedCalled = false;
     private TCompactionStatusUpdate latestState = null;
-    private final AtomicBoolean shutdown = new AtomicBoolean(false);
-    private final AtomicBoolean shutdownComplete = new AtomicBoolean(false);
 
     SuccessfulCompactor(Supplier<UUID> uuid, ServerAddress address, TExternalCompactionJob job,
-        ServerContext context, ExternalCompactionId eci, CompactorServerOpts compactorServerOpts) {
-      super(compactorServerOpts, new String[] {"-q", "testQ"});
+        ServerContext context, ExternalCompactionId eci) {
+      super(new ConfigOpts(),
+          new String[] {"-o", Property.COMPACTOR_QUEUE_NAME.getKey() + "=testQ"},
+          context.getConfiguration());
       this.uuid = uuid;
       this.address = address;
       this.job = job;
@@ -212,7 +185,15 @@ public class CompactorTest {
     }
 
     @Override
-    protected void startGCLogger(ScheduledThreadPoolExecutor schedExecutor) {}
+    public AccumuloConfiguration getConfiguration() {
+      return context.getConfiguration();
+    }
+
+    @Override
+    protected void setupSecurity() {}
+
+    @Override
+    protected void printStartupMsg() {}
 
     @Override
     public ServerContext getContext() {
@@ -229,34 +210,21 @@ public class CompactorTest {
     }
 
     @Override
-    protected TNextCompactionJob getNextJob(Supplier<UUID> uuid) throws RetriesExceededException {
+    protected TExternalCompactionJob getNextJob(Supplier<UUID> uuid)
+        throws RetriesExceededException {
       LOG.info("Attempting to get next job, eci = {}", eci);
       currentCompactionId.set(eci);
-      gracefulShutdown(null);
-      return new TNextCompactionJob(job, 1);
-    }
-
-    @Override
-    public void gracefulShutdown(TCredentials creds) {
-      shutdown.set(true);
-    }
-
-    @Override
-    public boolean isShutdownRequested() {
-      return shutdown.get();
-    }
-
-    public AtomicBoolean getShutdownComplete() {
-      return shutdownComplete;
+      this.shutdown = true;
+      return job;
     }
 
     @Override
     protected synchronized void checkIfCanceled() {}
 
     @Override
-    protected FileCompactorRunnable createCompactionJob(TExternalCompactionJob job,
-        LongAdder totalInputEntries, LongAdder totalInputBytes, CountDownLatch started,
-        CountDownLatch stopped, AtomicReference<Throwable> err) {
+    protected Runnable createCompactionJob(TExternalCompactionJob job, LongAdder totalInputEntries,
+        LongAdder totalInputBytes, CountDownLatch started, CountDownLatch stopped,
+        AtomicReference<Throwable> err) {
       return new SuccessfulCompaction(totalInputEntries, totalInputBytes, started, stopped, err);
     }
 
@@ -272,7 +240,7 @@ public class CompactorTest {
     }
 
     @Override
-    protected void updateCompactionFailed(TExternalCompactionJob job, Throwable exception)
+    protected void updateCompactionFailed(TExternalCompactionJob job)
         throws RetriesExceededException {
       failedCalled = true;
     }
@@ -295,44 +263,34 @@ public class CompactorTest {
       return failedCalled;
     }
 
-    @Override
-    protected Collection<Tag> getServiceTags(HostAndPort clientAddress) {
-      return List.of();
-    }
-
-    @Override
-    protected void startCancelChecker(ScheduledThreadPoolExecutor schedExecutor,
-        long timeBetweenChecks) {}
-
   }
 
-  public class FailedCompactor extends SuccessfulCompactor implements ServerProcessService.Iface {
+  public class FailedCompactor extends SuccessfulCompactor {
 
     FailedCompactor(Supplier<UUID> uuid, ServerAddress address, TExternalCompactionJob job,
-        ServerContext context, ExternalCompactionId eci, CompactorServerOpts compactorServerOpts) {
-      super(uuid, address, job, context, eci, compactorServerOpts);
+        ServerContext context, ExternalCompactionId eci) {
+      super(uuid, address, job, context, eci);
     }
 
     @Override
-    protected FileCompactorRunnable createCompactionJob(TExternalCompactionJob job,
-        LongAdder totalInputEntries, LongAdder totalInputBytes, CountDownLatch started,
-        CountDownLatch stopped, AtomicReference<Throwable> err) {
+    protected Runnable createCompactionJob(TExternalCompactionJob job, LongAdder totalInputEntries,
+        LongAdder totalInputBytes, CountDownLatch started, CountDownLatch stopped,
+        AtomicReference<Throwable> err) {
       return new FailedCompaction(totalInputEntries, totalInputBytes, started, stopped, err);
     }
   }
 
-  public class InterruptedCompactor extends SuccessfulCompactor
-      implements ServerProcessService.Iface {
+  public class InterruptedCompactor extends SuccessfulCompactor {
 
     InterruptedCompactor(Supplier<UUID> uuid, ServerAddress address, TExternalCompactionJob job,
-        ServerContext context, ExternalCompactionId eci, CompactorServerOpts compactorServerOpts) {
-      super(uuid, address, job, context, eci, compactorServerOpts);
+        ServerContext context, ExternalCompactionId eci) {
+      super(uuid, address, job, context, eci);
     }
 
     @Override
-    protected FileCompactorRunnable createCompactionJob(TExternalCompactionJob job,
-        LongAdder totalInputEntries, LongAdder totalInputBytes, CountDownLatch started,
-        CountDownLatch stopped, AtomicReference<Throwable> err) {
+    protected Runnable createCompactionJob(TExternalCompactionJob job, LongAdder totalInputEntries,
+        LongAdder totalInputBytes, CountDownLatch started, CountDownLatch stopped,
+        AtomicReference<Throwable> err) {
       return new InterruptedCompaction(totalInputEntries, totalInputBytes, started, stopped, err);
     }
 
@@ -357,7 +315,6 @@ public class CompactorTest {
     PowerMock.resetAll();
     PowerMock.suppress(PowerMock.methods(Halt.class, "halt"));
     PowerMock.suppress(PowerMock.constructor(AbstractServer.class));
-    PowerMock.suppress(PowerMock.methods(AbstractServer.class, "updateIdleStatus"));
 
     ServerAddress client = PowerMock.createNiceMock(ServerAddress.class);
     HostAndPort address = HostAndPort.fromString("localhost:10240");
@@ -368,20 +325,14 @@ public class CompactorTest {
     expect(job.isSetExternalCompactionId()).andReturn(true).anyTimes();
     expect(job.getExternalCompactionId()).andReturn(eci.toString()).anyTimes();
     expect(job.getExtent()).andReturn(extent).anyTimes();
-    expect(extent.getTable()).andReturn("testTable".getBytes(UTF_8)).anyTimes();
+    expect(extent.getTable()).andReturn("testTable".getBytes()).anyTimes();
 
     var conf = new ConfigurationCopy(DefaultConfiguration.getInstance());
     conf.set(Property.INSTANCE_ZK_TIMEOUT, "1d");
 
     ServerContext context = PowerMock.createNiceMock(ServerContext.class);
     expect(context.getConfiguration()).andReturn(conf).anyTimes();
-    MetricsInfo metricsInfo = PowerMock.createNiceMock(MetricsInfo.class);
-    expect(context.getMetricsInfo()).andReturn(metricsInfo).anyTimes();
-
-    Compactor.CompactorServerOpts compactorServerOpts =
-        PowerMock.createNiceMock(Compactor.CompactorServerOpts.class);
-    expect(compactorServerOpts.getQueueName()).andReturn("testQ");
-
+    expect(context.getLowMemoryDetector()).andReturn(new LowMemoryDetector()).anyTimes();
     ZooReaderWriter zrw = PowerMock.createNiceMock(ZooReaderWriter.class);
     ZooKeeper zk = PowerMock.createNiceMock(ZooKeeper.class);
     expect(context.getZooReaderWriter()).andReturn(zrw).anyTimes();
@@ -392,8 +343,7 @@ public class CompactorTest {
 
     PowerMock.replayAll();
 
-    SuccessfulCompactor c =
-        new SuccessfulCompactor(supplier, client, job, context, eci, compactorServerOpts);
+    SuccessfulCompactor c = new SuccessfulCompactor(supplier, client, job, context, eci);
     c.run();
 
     PowerMock.verifyAll();
@@ -413,14 +363,14 @@ public class CompactorTest {
     PowerMock.resetAll();
     PowerMock.suppress(PowerMock.methods(Halt.class, "halt"));
     PowerMock.suppress(PowerMock.constructor(AbstractServer.class));
-    PowerMock.suppress(PowerMock.methods(AbstractServer.class, "updateIdleStatus"));
 
     ServerAddress client = PowerMock.createNiceMock(ServerAddress.class);
     HostAndPort address = HostAndPort.fromString("localhost:10240");
     expect(client.getAddress()).andReturn(address);
 
     TExternalCompactionJob job = PowerMock.createNiceMock(TExternalCompactionJob.class);
-    TKeyExtent extent = new KeyExtent(TableId.of("testTable"), null, null).toThrift();
+    TKeyExtent extent = PowerMock.createNiceMock(TKeyExtent.class);
+    expect(extent.getTable()).andReturn("testTable".getBytes()).anyTimes();
 
     expect(job.isSetExternalCompactionId()).andReturn(true).anyTimes();
     expect(job.getExternalCompactionId()).andReturn(eci.toString()).anyTimes();
@@ -431,13 +381,7 @@ public class CompactorTest {
 
     ServerContext context = PowerMock.createNiceMock(ServerContext.class);
     expect(context.getConfiguration()).andReturn(conf).anyTimes();
-    MetricsInfo metricsInfo = PowerMock.createNiceMock(MetricsInfo.class);
-    expect(context.getMetricsInfo()).andReturn(metricsInfo).anyTimes();
-
-    Compactor.CompactorServerOpts compactorServerOpts =
-        PowerMock.createNiceMock(Compactor.CompactorServerOpts.class);
-    expect(compactorServerOpts.getQueueName()).andReturn("testQ");
-
+    expect(context.getLowMemoryDetector()).andReturn(new LowMemoryDetector()).anyTimes();
     ZooReaderWriter zrw = PowerMock.createNiceMock(ZooReaderWriter.class);
     ZooKeeper zk = PowerMock.createNiceMock(ZooKeeper.class);
     expect(context.getZooReaderWriter()).andReturn(zrw).anyTimes();
@@ -448,8 +392,7 @@ public class CompactorTest {
 
     PowerMock.replayAll();
 
-    FailedCompactor c =
-        new FailedCompactor(supplier, client, job, context, eci, compactorServerOpts);
+    FailedCompactor c = new FailedCompactor(supplier, client, job, context, eci);
     c.run();
 
     PowerMock.verifyAll();
@@ -470,7 +413,6 @@ public class CompactorTest {
     PowerMock.resetAll();
     PowerMock.suppress(PowerMock.methods(Halt.class, "halt"));
     PowerMock.suppress(PowerMock.constructor(AbstractServer.class));
-    PowerMock.suppress(PowerMock.methods(AbstractServer.class, "updateIdleStatus"));
 
     ServerAddress client = PowerMock.createNiceMock(ServerAddress.class);
     HostAndPort address = HostAndPort.fromString("localhost:10240");
@@ -481,20 +423,14 @@ public class CompactorTest {
     expect(job.isSetExternalCompactionId()).andReturn(true).anyTimes();
     expect(job.getExternalCompactionId()).andReturn(eci.toString()).anyTimes();
     expect(job.getExtent()).andReturn(extent).anyTimes();
-    expect(extent.getTable()).andReturn("testTable".getBytes(UTF_8)).anyTimes();
+    expect(extent.getTable()).andReturn("testTable".getBytes()).anyTimes();
 
     var conf = new ConfigurationCopy(DefaultConfiguration.getInstance());
     conf.set(Property.INSTANCE_ZK_TIMEOUT, "1d");
 
     ServerContext context = PowerMock.createNiceMock(ServerContext.class);
     expect(context.getConfiguration()).andReturn(conf).anyTimes();
-    MetricsInfo metricsInfo = PowerMock.createNiceMock(MetricsInfo.class);
-    expect(context.getMetricsInfo()).andReturn(metricsInfo).anyTimes();
-
-    Compactor.CompactorServerOpts compactorServerOpts =
-        PowerMock.createNiceMock(Compactor.CompactorServerOpts.class);
-    expect(compactorServerOpts.getQueueName()).andReturn("testQ");
-
+    expect(context.getLowMemoryDetector()).andReturn(new LowMemoryDetector()).anyTimes();
     ZooReaderWriter zrw = PowerMock.createNiceMock(ZooReaderWriter.class);
     ZooKeeper zk = PowerMock.createNiceMock(ZooKeeper.class);
     expect(context.getZooReaderWriter()).andReturn(zrw).anyTimes();
@@ -505,8 +441,7 @@ public class CompactorTest {
 
     PowerMock.replayAll();
 
-    InterruptedCompactor c =
-        new InterruptedCompactor(supplier, client, job, context, eci, compactorServerOpts);
+    InterruptedCompactor c = new InterruptedCompactor(supplier, client, job, context, eci);
     c.run();
 
     PowerMock.verifyAll();
@@ -517,32 +452,4 @@ public class CompactorTest {
     assertEquals(TCompactionState.CANCELLED, c.getLatestState());
   }
 
-  @Test
-  public void testCompactionWaitProperty() {
-    PowerMock.resetAll();
-    PowerMock.suppress(PowerMock.methods(Halt.class, "halt"));
-    PowerMock.suppress(PowerMock.constructor(AbstractServer.class));
-
-    var conf = new ConfigurationCopy(DefaultConfiguration.getInstance());
-    conf.set(Property.COMPACTOR_MAX_JOB_WAIT_TIME, "800ms");
-
-    ServerContext context = PowerMock.createNiceMock(ServerContext.class);
-    expect(context.getConfiguration()).andReturn(conf).anyTimes();
-
-    Compactor.CompactorServerOpts compactorServerOpts =
-        PowerMock.createNiceMock(Compactor.CompactorServerOpts.class);
-    expect(compactorServerOpts.getQueueName()).andReturn("default");
-
-    PowerMock.replayAll();
-
-    try (var c = new SuccessfulCompactor(null, null, null, context, null, compactorServerOpts)) {
-      Long maxWait = c.getWaitTimeBetweenCompactionChecks(1);
-      // compaction jitter means maxWait is between 0.9 and 1.1 of the desired value.
-      assertTrue(maxWait >= 720L);
-      assertTrue(maxWait <= 968L);
-    }
-
-    PowerMock.verifyAll();
-  }
-
 }
