@@ -18,6 +18,7 @@
  */
 package org.apache.accumulo.gc;
 
+import static com.google.common.util.concurrent.Uninterruptibles.sleepUninterruptibly;
 import static java.nio.charset.StandardCharsets.UTF_8;
 import static org.apache.accumulo.core.metadata.schema.TabletMetadata.ColumnType.DIR;
 import static org.apache.accumulo.core.metadata.schema.TabletMetadata.ColumnType.FILES;
@@ -25,9 +26,7 @@ import static org.apache.accumulo.core.metadata.schema.TabletMetadata.ColumnType
 
 import java.io.FileNotFoundException;
 import java.io.IOException;
-import java.time.Duration;
 import java.util.ArrayList;
-import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
@@ -37,22 +36,19 @@ import java.util.Map;
 import java.util.Objects;
 import java.util.Set;
 import java.util.SortedMap;
-import java.util.concurrent.ThreadPoolExecutor;
+import java.util.concurrent.ExecutorService;
 import java.util.concurrent.TimeUnit;
-import java.util.concurrent.atomic.AtomicInteger;
 import java.util.stream.Stream;
 
 import org.apache.accumulo.core.Constants;
-import org.apache.accumulo.core.client.AccumuloClient;
 import org.apache.accumulo.core.client.IsolatedScanner;
-import org.apache.accumulo.core.client.Scanner;
 import org.apache.accumulo.core.client.TableNotFoundException;
 import org.apache.accumulo.core.conf.AccumuloConfiguration;
 import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.fate.zookeeper.ZooReader;
-import org.apache.accumulo.core.gc.GcCandidate;
 import org.apache.accumulo.core.gc.Reference;
+import org.apache.accumulo.core.gc.ReferenceDirectory;
 import org.apache.accumulo.core.gc.ReferenceFile;
 import org.apache.accumulo.core.manager.state.tables.TableState;
 import org.apache.accumulo.core.metadata.MetadataTable;
@@ -61,21 +57,17 @@ import org.apache.accumulo.core.metadata.StoredTabletFile;
 import org.apache.accumulo.core.metadata.ValidationUtil;
 import org.apache.accumulo.core.metadata.schema.Ample;
 import org.apache.accumulo.core.metadata.schema.Ample.DataLevel;
-import org.apache.accumulo.core.metadata.schema.Ample.GcCandidateType;
 import org.apache.accumulo.core.metadata.schema.MetadataSchema;
 import org.apache.accumulo.core.metadata.schema.TabletMetadata;
 import org.apache.accumulo.core.metadata.schema.TabletsMetadata;
 import org.apache.accumulo.core.security.Authorizations;
 import org.apache.accumulo.core.util.Pair;
-import org.apache.accumulo.core.util.Timer;
-import org.apache.accumulo.core.util.UtilWaitThread;
 import org.apache.accumulo.core.util.threads.ThreadPools;
 import org.apache.accumulo.core.volume.Volume;
 import org.apache.accumulo.server.ServerContext;
 import org.apache.accumulo.server.fs.VolumeManager;
 import org.apache.accumulo.server.fs.VolumeUtil;
 import org.apache.accumulo.server.gc.GcVolumeUtil;
-import org.apache.accumulo.server.replication.proto.Replication;
 import org.apache.hadoop.fs.FileStatus;
 import org.apache.hadoop.fs.Path;
 import org.apache.zookeeper.KeeperException;
@@ -84,77 +76,43 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import com.google.common.annotations.VisibleForTesting;
-import com.google.common.collect.Iterators;
-import com.google.common.collect.Maps;
-import com.google.protobuf.InvalidProtocolBufferException;
 
 /**
  * A single garbage collection performed on a table (Root, MD) or all User tables.
  */
 public class GCRun implements GarbageCollectionEnvironment {
-  // loggers are not static to support unique naming by level
   private final Logger log;
-  private static final String fileActionPrefix = "FILE-ACTION:";
   private final Ample.DataLevel level;
   private final ServerContext context;
   private final AccumuloConfiguration config;
-  private final Duration loggingInterval = Duration.ofMinutes(1);
   private long candidates = 0;
   private long inUse = 0;
   private long deleted = 0;
   private long errors = 0;
-  private AtomicInteger batchCount;
 
   public GCRun(Ample.DataLevel level, ServerContext context) {
-    this.log = LoggerFactory.getLogger(GCRun.class.getName() + "." + level.name());
+    this.log = LoggerFactory.getLogger(level.name() + GCRun.class);
     this.level = level;
     this.context = context;
     this.config = context.getConfiguration();
-    this.batchCount = new AtomicInteger(0);
   }
 
   @Override
-  public Iterator<GcCandidate> getCandidates() {
+  public Iterator<String> getCandidates() {
     return context.getAmple().getGcCandidates(level);
   }
 
-  /**
-   * Removes gcCandidates from the metadata location depending on type.
-   *
-   * @param gcCandidates Collection of deletion reference candidates to remove.
-   * @param type type of deletion reference candidates.
-   */
   @Override
-  public void deleteGcCandidates(Collection<GcCandidate> gcCandidates, GcCandidateType type) {
-    if (inSafeMode()) {
-      System.out.println("SAFEMODE: There are " + gcCandidates.size()
-          + " reference file gcCandidates entries marked for deletion from " + level + " of type: "
-          + type + ".\n          Examine the log files to identify them.\n");
-      log.info("SAFEMODE: Listing all ref file gcCandidates for deletion");
-      for (GcCandidate gcCandidate : gcCandidates) {
-        log.info("SAFEMODE: {}", gcCandidate);
-      }
-      log.info("SAFEMODE: End reference candidates for deletion");
-      return;
-    }
-
-    log.info("Batch {} attempting to delete {} gcCandidates of type {} from metadata",
-        batchCount.get(), gcCandidates.size(), type);
-    context.getAmple().deleteGcCandidates(level, gcCandidates, type);
-  }
-
-  @Override
-  public List<GcCandidate> readCandidatesThatFitInMemory(Iterator<GcCandidate> candidates) {
+  public List<String> readCandidatesThatFitInMemory(Iterator<String> candidates) {
     long candidateLength = 0;
     // Converting the bytes to approximate number of characters for batch size.
     long candidateBatchSize = getCandidateBatchSize() / 2;
 
-    List<GcCandidate> candidatesBatch = new ArrayList<>();
-    batchCount.incrementAndGet();
+    List<String> candidatesBatch = new ArrayList<>();
 
     while (candidates.hasNext()) {
-      GcCandidate candidate = candidates.next();
-      candidateLength += candidate.getPath().length();
+      String candidate = candidates.next();
+      candidateLength += candidate.length();
       candidatesBatch.add(candidate);
       if (candidateLength > candidateBatchSize) {
         log.info("Candidate batch of size {} has exceeded the threshold. Attempting to delete "
@@ -196,40 +154,26 @@ public class GCRun implements GarbageCollectionEnvironment {
 
     // there is a lot going on in this "one line" so see below for more info
     var tabletReferences = tabletStream.flatMap(tm -> {
-      var tableId = tm.getTableId();
-
-      // verify that dir and prev row entries present for to check for complete row scan
-      log.trace("tablet metadata table id: {}, end row:{}, dir:{}, saw: {}, prev row: {}", tableId,
-          tm.getEndRow(), tm.getDirName(), tm.sawPrevEndRow(), tm.getPrevEndRow());
-      if (tm.getDirName() == null || tm.getDirName().isEmpty() || !tm.sawPrevEndRow()) {
-        throw new IllegalStateException("possible incomplete metadata scan for table id: " + tableId
-            + ", end row: " + tm.getEndRow() + ", dir: " + tm.getDirName() + ", saw prev row: "
-            + tm.sawPrevEndRow());
-      }
-
       // combine all the entries read from file and scan columns in the metadata table
-      Stream<StoredTabletFile> stfStream = tm.getFiles().stream();
-      // map the files to Reference objects
-      var fileStream = stfStream.map(f -> ReferenceFile.forFile(tableId, f.getMetaUpdateDelete()));
-
+      Stream<StoredTabletFile> fileStream = tm.getFiles().stream();
       // scans are normally empty, so only introduce a layer of indirection when needed
       final var tmScans = tm.getScans();
       if (!tmScans.isEmpty()) {
-        var scanStream =
-            tmScans.stream().map(s -> ReferenceFile.forScan(tableId, s.getMetaUpdateDelete()));
-        fileStream = Stream.concat(fileStream, scanStream);
+        fileStream = Stream.concat(fileStream, tmScans.stream());
       }
-      // if dirName is populated, then we have a tablet directory aka srv:dir
+      // map the files to Reference objects
+      var stream = fileStream.map(f -> new ReferenceFile(tm.getTableId(), f.getMetaUpdateDelete()));
+      // if dirName is populated then we have a tablet directory aka srv:dir
       if (tm.getDirName() != null) {
         // add the tablet directory to the stream
-        var tabletDir = ReferenceFile.forDirectory(tableId, tm.getDirName());
-        fileStream = Stream.concat(fileStream, Stream.of(tabletDir));
+        var tabletDir = new ReferenceDirectory(tm.getTableId(), tm.getDirName());
+        stream = Stream.concat(stream, Stream.of(tabletDir));
       }
-      return fileStream;
+      return stream;
     });
 
     var scanServerRefs = context.getAmple().getScanServerFileReferences()
-        .map(sfr -> ReferenceFile.forScan(sfr.getTableId(), sfr.getPathStr()));
+        .map(sfr -> new ReferenceFile(sfr.getTableId(), sfr.getNormalizedPathStr()));
 
     return Stream.concat(tabletReferences, scanServerRefs);
   }
@@ -269,14 +213,14 @@ public class GCRun implements GarbageCollectionEnvironment {
         }
         ioe.addSuppressed(e);
         log.error("Error getting tables from ZooKeeper, retrying in {} seconds", retries, e);
-        UtilWaitThread.sleepUninterruptibly(retries, TimeUnit.SECONDS);
+        sleepUninterruptibly(retries, TimeUnit.SECONDS);
       }
     }
     throw ioe;
   }
 
   @Override
-  public void deleteConfirmedCandidates(SortedMap<String,GcCandidate> confirmedDeletes)
+  public void deleteConfirmedCandidates(SortedMap<String,String> confirmedDeletes)
       throws TableNotFoundException {
     final VolumeManager fs = context.getVolumeManager();
     var metadataLocation = level == Ample.DataLevel.ROOT
@@ -286,34 +230,32 @@ public class GCRun implements GarbageCollectionEnvironment {
       System.out.println("SAFEMODE: There are " + confirmedDeletes.size()
           + " data file candidates marked for deletion in " + metadataLocation + ".\n"
           + "          Examine the log files to identify them.\n");
-      log.info("{} SAFEMODE: Listing all data file candidates for deletion", fileActionPrefix);
-      for (GcCandidate candidate : confirmedDeletes.values()) {
-        log.info("{} SAFEMODE: {}", fileActionPrefix, candidate);
+      log.info("SAFEMODE: Listing all data file candidates for deletion");
+      for (String s : confirmedDeletes.values()) {
+        log.info("SAFEMODE: {}", s);
       }
       log.info("SAFEMODE: End candidates for deletion");
       return;
     }
 
-    List<GcCandidate> processedDeletes = Collections.synchronizedList(new ArrayList<>());
+    List<String> processedDeletes = Collections.synchronizedList(new ArrayList<>());
 
-    minimizeDeletes(confirmedDeletes, processedDeletes, fs, log, loggingInterval);
+    minimizeDeletes(confirmedDeletes, processedDeletes, fs, log);
 
-    ThreadPoolExecutor deleteThreadPool = ThreadPools.getServerThreadPools()
-        .createExecutorService(config, Property.GC_DELETE_THREADS);
+    ExecutorService deleteThreadPool = ThreadPools.getServerThreadPools()
+        .createExecutorService(config, Property.GC_DELETE_THREADS, false);
 
     final List<Pair<Path,Path>> replacements = context.getVolumeReplacements();
 
-    log.info("Batch {} attempting to delete {} gcCandidate files", batchCount.get(),
-        confirmedDeletes.size());
-    Timer timer = Timer.startNew();
-    for (final GcCandidate delete : confirmedDeletes.values()) {
+    for (final String delete : confirmedDeletes.values()) {
+
       Runnable deleteTask = () -> {
         boolean removeFlag = false;
 
         try {
           Path fullPath;
           Path switchedDelete =
-              VolumeUtil.switchVolume(delete.getPath(), VolumeManager.FileType.TABLE, replacements);
+              VolumeUtil.switchVolume(delete, VolumeManager.FileType.TABLE, replacements);
           if (switchedDelete != null) {
             // actually replacing the volumes in the metadata table would be tricky because the
             // entries would be different rows. So it could not be
@@ -323,14 +265,14 @@ public class GCRun implements GarbageCollectionEnvironment {
             // uses suffixes to compare delete entries, there is no danger
             // of deleting something that should not be deleted. Must not change value of delete
             // variable because that's what's stored in metadata table.
-            log.debug("Volume replaced {} -> {}", delete.getPath(), switchedDelete);
+            log.debug("Volume replaced {} -> {}", delete, switchedDelete);
             fullPath = ValidationUtil.validate(switchedDelete);
           } else {
-            fullPath = new Path(ValidationUtil.validate(delete.getPath()));
+            fullPath = new Path(ValidationUtil.validate(delete));
           }
 
           for (Path pathToDel : GcVolumeUtil.expandAllVolumesUri(fs, fullPath)) {
-            log.debug("Batch {} {} Deleting {}", batchCount.get(), fileActionPrefix, pathToDel);
+            log.debug("Deleting {}", pathToDel);
 
             if (moveToTrash(pathToDel) || fs.deleteRecursively(pathToDel)) {
               // delete succeeded, still want to delete
@@ -340,8 +282,7 @@ public class GCRun implements GarbageCollectionEnvironment {
               // leave the entry in the metadata; we'll try again later
               removeFlag = false;
               errors++;
-              log.warn("{} File exists, but was not deleted for an unknown reason: {}",
-                  fileActionPrefix, pathToDel);
+              log.warn("File exists, but was not deleted for an unknown reason: {}", pathToDel);
               break;
             } else {
               // this failure, we still want to remove the metadata entry
@@ -356,12 +297,11 @@ public class GCRun implements GarbageCollectionEnvironment {
                 if (tableState != null && tableState != TableState.DELETING) {
                   // clone directories don't always exist
                   if (!tabletDir.startsWith(Constants.CLONE_PREFIX)) {
-                    log.debug("{} File doesn't exist: {}", fileActionPrefix, pathToDel);
+                    log.debug("File doesn't exist: {}", pathToDel);
                   }
                 }
               } else {
-                log.warn("{} Delete failed due to invalid file path format: {}", fileActionPrefix,
-                    delete.getPath());
+                log.warn("Very strange path name: {}", delete);
               }
             }
           }
@@ -372,7 +312,7 @@ public class GCRun implements GarbageCollectionEnvironment {
             processedDeletes.add(delete);
           }
         } catch (Exception e) {
-          log.error("{} Exception while deleting files ", fileActionPrefix, e);
+          log.error("{}", e.getMessage(), e);
         }
 
       };
@@ -383,18 +323,13 @@ public class GCRun implements GarbageCollectionEnvironment {
     deleteThreadPool.shutdown();
 
     try {
-      while (!deleteThreadPool.awaitTermination(1000, TimeUnit.MILLISECONDS)) {
-        if (timer.hasElapsed(loggingInterval)) {
-          log.info("Batch {} deleting file {} of {}", batchCount.get(),
-              deleteThreadPool.getCompletedTaskCount(), confirmedDeletes.size());
-          timer.restart();
-        }
+      while (!deleteThreadPool.awaitTermination(1000, TimeUnit.MILLISECONDS)) { // empty
       }
     } catch (InterruptedException e1) {
       log.error("{}", e1.getMessage(), e1);
     }
 
-    deleteGcCandidates(processedDeletes, GcCandidateType.VALID);
+    context.getAmple().deleteGcCandidates(level, processedDeletes);
   }
 
   @Override
@@ -412,7 +347,7 @@ public class GCRun implements GarbageCollectionEnvironment {
 
       if (tabletDirs.length == 0) {
         Path p = new Path(dir + "/" + tableID);
-        log.debug("{} Removing table dir {}", fileActionPrefix, p);
+        log.debug("Removing table dir {}", p);
         if (!moveToTrash(p)) {
           fs.delete(p);
         }
@@ -430,51 +365,22 @@ public class GCRun implements GarbageCollectionEnvironment {
     inUse += i;
   }
 
-  @Override
-  @Deprecated
-  public Iterator<Map.Entry<String,Replication.Status>> getReplicationNeededIterator() {
-    AccumuloClient client = context;
-    try {
-      Scanner s = org.apache.accumulo.core.replication.ReplicationTable.getScanner(client);
-      org.apache.accumulo.core.replication.ReplicationSchema.StatusSection.limit(s);
-      return Iterators.transform(s.iterator(), input -> {
-        String file = input.getKey().getRow().toString();
-        Replication.Status stat;
-        try {
-          stat = Replication.Status.parseFrom(input.getValue().get());
-        } catch (InvalidProtocolBufferException e) {
-          log.warn("Could not deserialize protobuf for: {}", input.getKey());
-          stat = null;
-        }
-        return Maps.immutableEntry(file, stat);
-      });
-    } catch (org.apache.accumulo.core.replication.ReplicationTableOfflineException e) {
-      // No elements that we need to preclude
-      return Collections.emptyIterator();
-    }
-  }
-
   @VisibleForTesting
-  static void minimizeDeletes(SortedMap<String,GcCandidate> confirmedDeletes,
-      List<GcCandidate> processedDeletes, VolumeManager fs, Logger logger,
-      Duration loggingInterval) {
+  static void minimizeDeletes(SortedMap<String,String> confirmedDeletes,
+      List<String> processedDeletes, VolumeManager fs, Logger logger) {
     Set<Path> seenVolumes = new HashSet<>();
 
     // when deleting a dir and all files in that dir, only need to delete the dir.
     // The dir will sort right before the files... so remove the files in this case
     // to minimize namenode ops
-    Iterator<Map.Entry<String,GcCandidate>> cdIter = confirmedDeletes.entrySet().iterator();
+    Iterator<Map.Entry<String,String>> cdIter = confirmedDeletes.entrySet().iterator();
 
     String lastDirRel = null;
     Path lastDirAbs = null;
-    Timer progressTimer = Timer.startNew();
-    int progressCount = 0;
-    int totalDeletes = confirmedDeletes.size();
     while (cdIter.hasNext()) {
-      progressCount++;
-      Map.Entry<String,GcCandidate> entry = cdIter.next();
+      Map.Entry<String,String> entry = cdIter.next();
       String relPath = entry.getKey();
-      Path absPath = new Path(entry.getValue().getPath());
+      Path absPath = new Path(entry.getValue());
 
       if (SimpleGarbageCollector.isDir(relPath)) {
         lastDirRel = relPath;
@@ -501,8 +407,7 @@ public class GCRun implements GarbageCollectionEnvironment {
           }
 
           if (sameVol) {
-            logger.info("{} Ignoring {} because {} exist", fileActionPrefix,
-                entry.getValue().getPath(), lastDirAbs);
+            logger.info("Ignoring {} because {} exist", entry.getValue(), lastDirAbs);
             processedDeletes.add(entry.getValue());
             cdIter.remove();
           }
@@ -511,32 +416,18 @@ public class GCRun implements GarbageCollectionEnvironment {
           lastDirAbs = null;
         }
       }
-      if (progressTimer.hasElapsed(loggingInterval)) {
-        logger.debug("Minimizing delete {} of {}", progressCount, totalDeletes);
-        progressTimer.restart();
-      }
     }
   }
 
   /**
    * Checks if safemode is set - files will not be deleted.
    *
-   * @return value of {@link Property#GC_SAFEMODE}
+   * @return number of delete threads
    */
   boolean inSafeMode() {
     return context.getConfiguration().getBoolean(Property.GC_SAFEMODE);
   }
 
-  /**
-   * Checks if InUse Candidates can be removed.
-   *
-   * @return value of {@link Property#GC_REMOVE_IN_USE_CANDIDATES}
-   */
-  @Override
-  public boolean canRemoveInUseCandidates() {
-    return context.getConfiguration().getBoolean(Property.GC_REMOVE_IN_USE_CANDIDATES);
-  }
-
   /**
    * Moves a file to trash. If this garbage collector is not using trash, this method returns false
    * and leaves the file alone. If the file is missing, this method returns false as opposed to
@@ -547,10 +438,6 @@ public class GCRun implements GarbageCollectionEnvironment {
    */
   boolean moveToTrash(Path path) throws IOException {
     final VolumeManager fs = context.getVolumeManager();
-    if (!isUsingTrash()) {
-      log.trace("Accumulo Trash is disabled. Skipped for {}", path);
-      return false;
-    }
     try {
       boolean success = fs.moveToTrash(path);
       log.trace("Accumulo Trash enabled, moving to trash succeeded?: {}", success);
@@ -561,17 +448,6 @@ public class GCRun implements GarbageCollectionEnvironment {
     }
   }
 
-  /**
-   * Checks if the volume manager should move files to the trash rather than delete them.
-   *
-   * @return true if trash is used
-   */
-  boolean isUsingTrash() {
-    @SuppressWarnings("removal")
-    Property p = Property.GC_TRASH_IGNORE;
-    return !config.getBoolean(p);
-  }
-
   /**
    * Gets the batch size for garbage collecting.
    *
