@@ -22,14 +22,12 @@ import static java.util.Arrays.stream;
 import static java.util.function.Predicate.not;
 
 import java.io.IOException;
-import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Locale;
-import java.util.Map.Entry;
 import java.util.Set;
 import java.util.SortedMap;
 import java.util.TreeMap;
@@ -38,18 +36,14 @@ import java.util.stream.Stream;
 import org.apache.accumulo.core.Constants;
 import org.apache.accumulo.core.client.TableNotFoundException;
 import org.apache.accumulo.core.data.TableId;
-import org.apache.accumulo.core.gc.GcCandidate;
 import org.apache.accumulo.core.gc.Reference;
-import org.apache.accumulo.core.metadata.schema.Ample.GcCandidateType;
+import org.apache.accumulo.core.gc.ReferenceDirectory;
 import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection.ServerColumnFamily;
 import org.apache.accumulo.core.trace.TraceUtil;
-import org.apache.accumulo.server.replication.proto.Replication.Status;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import com.google.common.annotations.VisibleForTesting;
-import com.google.common.collect.Iterators;
-import com.google.common.collect.PeekingIterator;
 
 import io.opentelemetry.api.trace.Span;
 import io.opentelemetry.context.Scope;
@@ -123,13 +117,13 @@ public class GarbageCollectionAlgorithm {
     return relPath;
   }
 
-  private SortedMap<String,GcCandidate> makeRelative(Collection<GcCandidate> candidates) {
-    SortedMap<String,GcCandidate> ret = new TreeMap<>();
+  private SortedMap<String,String> makeRelative(Collection<String> candidates) {
+    SortedMap<String,String> ret = new TreeMap<>();
 
-    for (GcCandidate candidate : candidates) {
+    for (String candidate : candidates) {
       String relPath;
       try {
-        relPath = makeRelative(candidate.getPath(), 0);
+        relPath = makeRelative(candidate, 0);
       } catch (IllegalArgumentException iae) {
         log.warn("Ignoring invalid deletion candidate {}", candidate);
         continue;
@@ -141,9 +135,8 @@ public class GarbageCollectionAlgorithm {
   }
 
   private void removeCandidatesInUse(GarbageCollectionEnvironment gce,
-      SortedMap<String,GcCandidate> candidateMap) throws InterruptedException {
+      SortedMap<String,String> candidateMap) throws InterruptedException {
 
-    List<GcCandidate> candidateEntriesToBeDeleted = new ArrayList<>();
     Set<TableId> tableIdsBefore = gce.getCandidateTableIDs();
     Set<TableId> tableIdsSeen = new HashSet<>();
     Iterator<Reference> iter = gce.getReferences().iterator();
@@ -152,16 +145,15 @@ public class GarbageCollectionAlgorithm {
       tableIdsSeen.add(ref.getTableId());
 
       if (ref.isDirectory()) {
-        ServerColumnFamily.validateDirCol(ref.getMetadataEntry());
+        var dirReference = (ReferenceDirectory) ref;
+        ServerColumnFamily.validateDirCol(dirReference.getTabletDir());
 
-        String dir = "/" + ref.getTableId() + "/" + ref.getMetadataEntry();
+        String dir = "/" + dirReference.tableId + "/" + dirReference.getTabletDir();
 
         dir = makeRelative(dir, 2);
 
-        GcCandidate gcTemp = candidateMap.remove(dir);
-        if (gcTemp != null) {
-          log.debug("Directory Candidate was still in use by dir ref: {}", dir);
-          // Do not add dir candidates to candidateEntriesToBeDeleted as they are only created once.
+        if (candidateMap.remove(dir) != null) {
+          log.debug("Candidate was still in use: {}", dir);
         }
       } else {
         String reference = ref.getMetadataEntry();
@@ -177,34 +169,23 @@ public class GarbageCollectionAlgorithm {
 
         // WARNING: This line is EXTREMELY IMPORTANT.
         // You MUST REMOVE candidates that are still in use
-        GcCandidate gcTemp = candidateMap.remove(relativePath);
-        if (gcTemp != null) {
-          log.debug("File Candidate was still in use: {}", relativePath);
-          // Prevent deletion of candidates that are still in use by scans, because they won't be
-          // recreated once the scan is finished.
-          if (!ref.isScan()) {
-            candidateEntriesToBeDeleted.add(gcTemp);
-          }
+        if (candidateMap.remove(relativePath) != null) {
+          log.debug("Candidate was still in use: {}", relativePath);
         }
 
         String dir = relativePath.substring(0, relativePath.lastIndexOf('/'));
-        GcCandidate gcT = candidateMap.remove(dir);
-        if (gcT != null) {
-          log.debug("Directory Candidate was still in use by file ref: {}", relativePath);
-          // Do not add dir candidates to candidateEntriesToBeDeleted as they are only created once.
+        if (candidateMap.remove(dir) != null) {
+          log.debug("Candidate was still in use: {}", relativePath);
         }
       }
     }
     Set<TableId> tableIdsAfter = gce.getCandidateTableIDs();
     ensureAllTablesChecked(Collections.unmodifiableSet(tableIdsBefore),
         Collections.unmodifiableSet(tableIdsSeen), Collections.unmodifiableSet(tableIdsAfter));
-    if (gce.canRemoveInUseCandidates()) {
-      gce.deleteGcCandidates(candidateEntriesToBeDeleted, GcCandidateType.INUSE);
-    }
   }
 
   private long removeBlipCandidates(GarbageCollectionEnvironment gce,
-      SortedMap<String,GcCandidate> candidateMap) throws TableNotFoundException {
+      SortedMap<String,String> candidateMap) throws TableNotFoundException {
     long blipCount = 0;
     boolean checkForBulkProcessingFiles = candidateMap.keySet().stream().anyMatch(
         relativePath -> relativePath.toLowerCase(Locale.ENGLISH).contains(Constants.BULK_PREFIX));
@@ -285,46 +266,8 @@ public class GarbageCollectionAlgorithm {
     }
   }
 
-  protected void confirmDeletesFromReplication(GarbageCollectionEnvironment gce,
-      SortedMap<String,GcCandidate> candidateMap) {
-    var replicationNeededIterator = gce.getReplicationNeededIterator();
-    var candidateMapIterator = candidateMap.entrySet().iterator();
-
-    PeekingIterator<Entry<String,Status>> pendingReplication =
-        Iterators.peekingIterator(replicationNeededIterator);
-    PeekingIterator<Entry<String,GcCandidate>> candidates =
-        Iterators.peekingIterator(candidateMapIterator);
-    while (pendingReplication.hasNext() && candidates.hasNext()) {
-      Entry<String,Status> pendingReplica = pendingReplication.peek();
-      Entry<String,GcCandidate> candidate = candidates.peek();
-
-      String filePendingReplication = pendingReplica.getKey();
-      String fullPathCandidate = candidate.getValue().getPath();
-
-      int comparison = filePendingReplication.compareTo(fullPathCandidate);
-      if (comparison < 0) {
-        pendingReplication.next();
-      } else if (comparison > 1) {
-        candidates.next();
-      } else {
-        // We want to advance both, and try to delete the candidate if we can
-        candidates.next();
-        pendingReplication.next();
-
-        // We cannot delete a file if it is still needed for replication
-        @SuppressWarnings("deprecation")
-        boolean safeToRemove = org.apache.accumulo.server.replication.StatusUtil
-            .isSafeForRemoval(pendingReplica.getValue());
-        if (!safeToRemove) {
-          // If it must be replicated, we must remove it from the candidate set to prevent deletion
-          candidates.remove();
-        }
-      }
-    }
-  }
-
   private void cleanUpDeletedTableDirs(GarbageCollectionEnvironment gce,
-      SortedMap<String,GcCandidate> candidateMap) throws InterruptedException, IOException {
+      SortedMap<String,String> candidateMap) throws InterruptedException, IOException {
     HashSet<TableId> tableIdsWithDeletes = new HashSet<>();
 
     // find the table ids that had dirs deleted
@@ -349,14 +292,12 @@ public class GarbageCollectionAlgorithm {
   }
 
   private long confirmDeletesTrace(GarbageCollectionEnvironment gce,
-      SortedMap<String,GcCandidate> candidateMap)
-      throws InterruptedException, TableNotFoundException {
+      SortedMap<String,String> candidateMap) throws InterruptedException, TableNotFoundException {
     long blips = 0;
     Span confirmDeletesSpan = TraceUtil.startSpan(this.getClass(), "confirmDeletes");
     try (Scope scope = confirmDeletesSpan.makeCurrent()) {
       blips = removeBlipCandidates(gce, candidateMap);
       removeCandidatesInUse(gce, candidateMap);
-      confirmDeletesFromReplication(gce, candidateMap);
     } catch (Exception e) {
       TraceUtil.setException(confirmDeletesSpan, e, true);
       throw e;
@@ -367,7 +308,7 @@ public class GarbageCollectionAlgorithm {
   }
 
   private void deleteConfirmedCandidates(GarbageCollectionEnvironment gce,
-      SortedMap<String,GcCandidate> candidateMap)
+      SortedMap<String,String> candidateMap)
       throws InterruptedException, IOException, TableNotFoundException {
     Span deleteSpan = TraceUtil.startSpan(this.getClass(), "deleteFiles");
     try (Scope deleteScope = deleteSpan.makeCurrent()) {
@@ -385,12 +326,11 @@ public class GarbageCollectionAlgorithm {
   public long collect(GarbageCollectionEnvironment gce)
       throws InterruptedException, TableNotFoundException, IOException {
 
-    Iterator<GcCandidate> candidatesIter = gce.getCandidates();
+    Iterator<String> candidatesIter = gce.getCandidates();
     long totalBlips = 0;
-    int batchCount = 0;
 
     while (candidatesIter.hasNext()) {
-      List<GcCandidate> batchOfCandidates;
+      List<String> batchOfCandidates;
       Span candidatesSpan = TraceUtil.startSpan(this.getClass(), "getCandidates");
       try (Scope candidatesScope = candidatesSpan.makeCurrent()) {
         batchOfCandidates = gce.readCandidatesThatFitInMemory(candidatesIter);
@@ -400,8 +340,7 @@ public class GarbageCollectionAlgorithm {
       } finally {
         candidatesSpan.end();
       }
-      batchCount++;
-      totalBlips = deleteBatch(gce, batchOfCandidates, batchCount);
+      totalBlips = deleteBatch(gce, batchOfCandidates);
     }
     return totalBlips;
   }
@@ -409,14 +348,13 @@ public class GarbageCollectionAlgorithm {
   /**
    * Given a sub-list of possible deletion candidates, process and remove valid deletion candidates.
    */
-  private long deleteBatch(GarbageCollectionEnvironment gce, List<GcCandidate> currentBatch,
-      int batchCount) throws InterruptedException, TableNotFoundException, IOException {
+  private long deleteBatch(GarbageCollectionEnvironment gce, List<String> currentBatch)
+      throws InterruptedException, TableNotFoundException, IOException {
 
     long origSize = currentBatch.size();
     gce.incrementCandidatesStat(origSize);
-    log.info("Batch {} total deletion candidates: {}", batchCount, origSize);
 
-    SortedMap<String,GcCandidate> candidateMap = makeRelative(currentBatch);
+    SortedMap<String,String> candidateMap = makeRelative(currentBatch);
 
     long blips = confirmDeletesTrace(gce, candidateMap);
     gce.incrementInUseStat(origSize - candidateMap.size());
@@ -425,4 +363,5 @@ public class GarbageCollectionAlgorithm {
 
     return blips;
   }
+
 }
