@@ -19,27 +19,21 @@
 package org.apache.accumulo.gc;
 
 import java.io.IOException;
-import java.util.Collection;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
-import java.util.Map.Entry;
 import java.util.Set;
 import java.util.SortedMap;
 import java.util.stream.Stream;
 
 import org.apache.accumulo.core.client.TableNotFoundException;
-import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.data.TableId;
-import org.apache.accumulo.core.gc.GcCandidate;
 import org.apache.accumulo.core.gc.Reference;
 import org.apache.accumulo.core.manager.state.tables.TableState;
 import org.apache.accumulo.core.metadata.MetadataTable;
 import org.apache.accumulo.core.metadata.RootTable;
-import org.apache.accumulo.core.metadata.schema.Ample.GcCandidateType;
 import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection.DataFileColumnFamily;
 import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection.ScanFileColumnFamily;
-import org.apache.accumulo.server.replication.proto.Replication.Status;
 
 public interface GarbageCollectionEnvironment {
 
@@ -49,14 +43,7 @@ public interface GarbageCollectionEnvironment {
    *
    * @return an iterator referencing a List containing deletion candidates
    */
-  Iterator<GcCandidate> getCandidates() throws TableNotFoundException;
-
-  /**
-   * Used for determining if deletion of InUse candidates is enabled.
-   *
-   * @return value of {@link Property#GC_REMOVE_IN_USE_CANDIDATES}
-   */
-  boolean canRemoveInUseCandidates();
+  Iterator<String> getCandidates() throws TableNotFoundException;
 
   /**
    * Given an iterator to a deletion candidate list, return a sub-list of candidates which fit
@@ -65,7 +52,7 @@ public interface GarbageCollectionEnvironment {
    * @param candidatesIter iterator referencing a List of possible deletion candidates
    * @return a List of possible deletion candidates
    */
-  List<GcCandidate> readCandidatesThatFitInMemory(Iterator<GcCandidate> candidatesIter);
+  List<String> readCandidatesThatFitInMemory(Iterator<String> candidatesIter);
 
   /**
    * Fetch a list of paths for all bulk loads in progress (blip) from a given table,
@@ -109,16 +96,9 @@ public interface GarbageCollectionEnvironment {
    *
    * @param candidateMap A Map from relative path to absolute path for files to be deleted.
    */
-  void deleteConfirmedCandidates(SortedMap<String,GcCandidate> candidateMap)
+  void deleteConfirmedCandidates(SortedMap<String,String> candidateMap)
       throws TableNotFoundException;
 
-  /**
-   * Delete in-use reference candidates based on property settings
-   *
-   * @param GcCandidates Collection of deletion reference candidates to remove.
-   */
-  void deleteGcCandidates(Collection<GcCandidate> GcCandidates, GcCandidateType type);
-
   /**
    * Delete a table's directory if it is empty.
    *
@@ -140,10 +120,4 @@ public interface GarbageCollectionEnvironment {
    */
   void incrementInUseStat(long i);
 
-  /**
-   * Determine if the given absolute file is still pending replication
-   *
-   * @return True if the file still needs to be replicated
-   */
-  Iterator<Entry<String,Status>> getReplicationNeededIterator();
 }
