@@ -18,40 +18,40 @@
  */
 package org.apache.accumulo.gc;
 
-import static java.nio.charset.StandardCharsets.UTF_8;
-import static org.apache.accumulo.core.util.UtilWaitThread.sleepUninterruptibly;
+import static com.google.common.util.concurrent.Uninterruptibles.sleepUninterruptibly;
 
 import java.io.FileNotFoundException;
 import java.io.IOException;
+import java.lang.reflect.InvocationTargetException;
 import java.util.UUID;
 import java.util.concurrent.TimeUnit;
 import java.util.stream.IntStream;
 
 import org.apache.accumulo.core.Constants;
+import org.apache.accumulo.core.cli.ConfigOpts;
 import org.apache.accumulo.core.client.AccumuloClient;
+import org.apache.accumulo.core.clientImpl.thrift.TInfo;
 import org.apache.accumulo.core.conf.AccumuloConfiguration;
 import org.apache.accumulo.core.conf.Property;
-import org.apache.accumulo.core.fate.zookeeper.ServiceLock;
-import org.apache.accumulo.core.fate.zookeeper.ServiceLockSupport.HAServiceLockWatcher;
 import org.apache.accumulo.core.gc.thrift.GCMonitorService.Iface;
 import org.apache.accumulo.core.gc.thrift.GCStatus;
 import org.apache.accumulo.core.gc.thrift.GcCycleStats;
+import org.apache.accumulo.core.lock.ServiceLock;
+import org.apache.accumulo.core.lock.ServiceLock.LockLossReason;
+import org.apache.accumulo.core.lock.ServiceLock.LockWatcher;
+import org.apache.accumulo.core.lock.ServiceLockData;
+import org.apache.accumulo.core.lock.ServiceLockData.ThriftService;
 import org.apache.accumulo.core.metadata.MetadataTable;
 import org.apache.accumulo.core.metadata.RootTable;
 import org.apache.accumulo.core.metadata.schema.Ample.DataLevel;
-import org.apache.accumulo.core.metrics.MetricsInfo;
-import org.apache.accumulo.core.process.thrift.ServerProcessService;
+import org.apache.accumulo.core.metrics.MetricsUtil;
 import org.apache.accumulo.core.securityImpl.thrift.TCredentials;
 import org.apache.accumulo.core.trace.TraceUtil;
-import org.apache.accumulo.core.trace.thrift.TInfo;
-import org.apache.accumulo.core.util.HostAndPort;
-import org.apache.accumulo.core.util.ServerServices;
-import org.apache.accumulo.core.util.ServerServices.Service;
+import org.apache.accumulo.core.util.Halt;
 import org.apache.accumulo.core.util.threads.ThreadPools;
 import org.apache.accumulo.gc.metrics.GcCycleMetrics;
 import org.apache.accumulo.gc.metrics.GcMetrics;
 import org.apache.accumulo.server.AbstractServer;
-import org.apache.accumulo.server.ServerOpts;
 import org.apache.accumulo.server.fs.VolumeManager;
 import org.apache.accumulo.server.manager.LiveTServerSet;
 import org.apache.accumulo.server.rpc.ServerAddress;
@@ -62,6 +62,8 @@ import org.apache.zookeeper.KeeperException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import com.google.common.net.HostAndPort;
+
 import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
 import io.opentelemetry.api.trace.Span;
 import io.opentelemetry.context.Scope;
@@ -69,8 +71,7 @@ import io.opentelemetry.context.Scope;
 // Could/Should implement HighlyAvailableService but the Thrift server is already started before
 // the ZK lock is acquired. The server is only for metrics, there are no concerns about clients
 // using the service before the lock is acquired.
-public class SimpleGarbageCollector extends AbstractServer
-    implements Iface, ServerProcessService.Iface {
+public class SimpleGarbageCollector extends AbstractServer implements Iface {
 
   private static final Logger log = LoggerFactory.getLogger(SimpleGarbageCollector.class);
 
@@ -78,9 +79,8 @@ public class SimpleGarbageCollector extends AbstractServer
       new GCStatus(new GcCycleStats(), new GcCycleStats(), new GcCycleStats(), new GcCycleStats());
 
   private final GcCycleMetrics gcCycleMetrics = new GcCycleMetrics();
-  private ServiceLock gcLock;
 
-  SimpleGarbageCollector(ServerOpts opts, String[] args) {
+  SimpleGarbageCollector(ConfigOpts opts, String[] args) {
     super("gc", opts, args);
 
     final AccumuloConfiguration conf = getConfiguration();
@@ -97,7 +97,7 @@ public class SimpleGarbageCollector extends AbstractServer
   }
 
   public static void main(String[] args) throws Exception {
-    try (SimpleGarbageCollector gc = new SimpleGarbageCollector(new ServerOpts(), args)) {
+    try (SimpleGarbageCollector gc = new SimpleGarbageCollector(new ConfigOpts(), args)) {
       gc.runServer();
     }
   }
@@ -111,17 +111,6 @@ public class SimpleGarbageCollector extends AbstractServer
     return getConfiguration().getTimeInMillis(Property.GC_CYCLE_START);
   }
 
-  /**
-   * Checks if the volume manager should move files to the trash rather than delete them.
-   *
-   * @return true if trash is used
-   */
-  boolean isUsingTrash() {
-    @SuppressWarnings("removal")
-    Property p = Property.GC_TRASH_IGNORE;
-    return !getConfiguration().getBoolean(p);
-  }
-
   /**
    * Gets the number of threads used for deleting files.
    *
@@ -143,7 +132,7 @@ public class SimpleGarbageCollector extends AbstractServer
   /**
    * Checks if safemode is set - files will not be deleted.
    *
-   * @return true if safe mode is set, false otherwise
+   * @return number of delete threads
    */
   boolean inSafeMode() {
     return getConfiguration().getBoolean(Property.GC_SAFEMODE);
@@ -152,14 +141,6 @@ public class SimpleGarbageCollector extends AbstractServer
   @Override
   @SuppressFBWarnings(value = "DM_EXIT", justification = "main class can call System.exit")
   public void run() {
-
-    try {
-      waitForUpgrade();
-    } catch (InterruptedException e) {
-      LOG.error("Interrupted while waiting for upgrade to complete, exiting...");
-      System.exit(1);
-    }
-
     final VolumeManager fs = getContext().getVolumeManager();
 
     // Sleep for an initial period, giving the manager time to start up and
@@ -167,20 +148,23 @@ public class SimpleGarbageCollector extends AbstractServer
     log.info("Trying to acquire ZooKeeper lock for garbage collector");
 
     HostAndPort address = startStatsService();
-    updateAdvertiseAddress(address);
 
     try {
-      getZooLock(getAdvertiseAddress());
+      getZooLock(address);
     } catch (Exception ex) {
       log.error("{}", ex.getMessage(), ex);
       System.exit(1);
     }
 
-    MetricsInfo metricsInfo = getContext().getMetricsInfo();
+    try {
+      MetricsUtil.initializeMetrics(getContext().getConfiguration(), this.applicationName, address);
+      MetricsUtil.initializeProducers(this, new GcMetrics(this));
+    } catch (ClassNotFoundException | InstantiationException | IllegalAccessException
+        | IllegalArgumentException | InvocationTargetException | NoSuchMethodException
+        | SecurityException e1) {
+      log.error("Error initializing metrics, metrics will not be emitted.", e1);
+    }
 
-    metricsInfo.addMetricsProducers(new GcMetrics(this));
-    metricsInfo.init(
-        MetricsInfo.serviceTags(getContext().getInstanceName(), getApplicationName(), address, ""));
     try {
       long delay = getStartDelay();
       log.debug("Sleeping for {} milliseconds before beginning garbage collection cycles", delay);
@@ -202,157 +186,120 @@ public class SimpleGarbageCollector extends AbstractServer
           }
         });
 
-    while (!isShutdownRequested()) {
-      if (Thread.currentThread().isInterrupted()) {
-        LOG.info("Server process thread has been interrupted, shutting down");
-        break;
-      }
-      try {
-        Span outerSpan = TraceUtil.startSpan(this.getClass(), "gc");
-        try (Scope outerScope = outerSpan.makeCurrent()) {
-          Span innerSpan = TraceUtil.startSpan(this.getClass(), "loop");
-          try (Scope innerScope = innerSpan.makeCurrent()) {
-            final long tStart = System.nanoTime();
-            try {
-              System.gc(); // make room
+    while (true) {
+      Span outerSpan = TraceUtil.startSpan(this.getClass(), "gc");
+      try (Scope outerScope = outerSpan.makeCurrent()) {
+        Span innerSpan = TraceUtil.startSpan(this.getClass(), "loop");
+        try (Scope innerScope = innerSpan.makeCurrent()) {
+          final long tStart = System.nanoTime();
+          try {
+            System.gc(); // make room
 
-              status.current.started = System.currentTimeMillis();
-              var rootGC = new GCRun(DataLevel.ROOT, getContext());
-              var mdGC = new GCRun(DataLevel.METADATA, getContext());
-              var userGC = new GCRun(DataLevel.USER, getContext());
+            status.current.started = System.currentTimeMillis();
+            var rootGC = new GCRun(DataLevel.ROOT, getContext());
+            var mdGC = new GCRun(DataLevel.METADATA, getContext());
+            var userGC = new GCRun(DataLevel.USER, getContext());
 
-              log.info("Starting Root table Garbage Collection.");
-              status.current.bulks += new GarbageCollectionAlgorithm().collect(rootGC);
-              incrementStatsForRun(rootGC);
-              logStats();
+            log.info("Starting Root table Garbage Collection.");
+            status.current.bulks += new GarbageCollectionAlgorithm().collect(rootGC);
+            incrementStatsForRun(rootGC);
+            logStats();
 
-              log.info("Starting Metadata table Garbage Collection.");
-              status.current.bulks += new GarbageCollectionAlgorithm().collect(mdGC);
-              incrementStatsForRun(mdGC);
-              logStats();
+            log.info("Starting Metadata table Garbage Collection.");
+            status.current.bulks += new GarbageCollectionAlgorithm().collect(mdGC);
+            incrementStatsForRun(mdGC);
+            logStats();
 
-              log.info("Starting User table Garbage Collection.");
-              status.current.bulks += new GarbageCollectionAlgorithm().collect(userGC);
-              incrementStatsForRun(userGC);
-              logStats();
+            log.info("Starting User table Garbage Collection.");
+            status.current.bulks += new GarbageCollectionAlgorithm().collect(userGC);
+            incrementStatsForRun(userGC);
+            logStats();
 
-            } catch (Exception e) {
-              TraceUtil.setException(innerSpan, e, false);
-              log.error("{}", e.getMessage(), e);
-            } finally {
-              status.current.finished = System.currentTimeMillis();
-              status.last = status.current;
-              gcCycleMetrics.setLastCollect(status.current);
-              status.current = new GcCycleStats();
-            }
-
-            final long tStop = System.nanoTime();
-            log.info(String.format("Collect cycle took %.2f seconds",
-                (TimeUnit.NANOSECONDS.toMillis(tStop - tStart) / 1000.0)));
-
-            /*
-             * We want to prune references to fully-replicated WALs from the replication table which
-             * are no longer referenced in the metadata table before running
-             * GarbageCollectWriteAheadLogs to ensure we delete as many files as possible.
-             */
-            Span replSpan = TraceUtil.startSpan(this.getClass(), "replicationClose");
-            try (Scope replScope = replSpan.makeCurrent()) {
-              @SuppressWarnings("deprecation")
-              Runnable closeWals =
-                  new org.apache.accumulo.gc.replication.CloseWriteAheadLogReferences(getContext());
-              closeWals.run();
-            } catch (Exception e) {
-              TraceUtil.setException(replSpan, e, false);
-              log.error("Error trying to close write-ahead logs for replication table", e);
-            } finally {
-              replSpan.end();
-            }
-
-            // Clean up any unused write-ahead logs
-            Span walSpan = TraceUtil.startSpan(this.getClass(), "walogs");
-            try (Scope walScope = walSpan.makeCurrent()) {
-              GarbageCollectWriteAheadLogs walogCollector = new GarbageCollectWriteAheadLogs(
-                  getContext(), fs, liveTServerSet, isUsingTrash());
-              log.info("Beginning garbage collection of write-ahead logs");
-              walogCollector.collect(status);
-              gcCycleMetrics.setLastWalCollect(status.lastLog);
-            } catch (Exception e) {
-              TraceUtil.setException(walSpan, e, false);
-              log.error("{}", e.getMessage(), e);
-            } finally {
-              walSpan.end();
-            }
           } catch (Exception e) {
-            TraceUtil.setException(innerSpan, e, true);
-            throw e;
+            TraceUtil.setException(innerSpan, e, false);
+            log.error("{}", e.getMessage(), e);
           } finally {
-            innerSpan.end();
+            status.current.finished = System.currentTimeMillis();
+            status.last = status.current;
+            gcCycleMetrics.setLastCollect(status.current);
+            status.current = new GcCycleStats();
           }
 
-          // we just made a lot of metadata changes: flush them out
-          try {
-            AccumuloClient accumuloClient = getContext();
-
-            final long actionStart = System.nanoTime();
-
-            String action = getConfiguration().get(Property.GC_USE_FULL_COMPACTION);
-            log.debug("gc post action {} started", action);
-
-            switch (action) {
-              case "compact":
-                accumuloClient.tableOperations().compact(MetadataTable.NAME, null, null, true,
-                    true);
-                accumuloClient.tableOperations().compact(RootTable.NAME, null, null, true, true);
-                break;
-              case "flush":
-                accumuloClient.tableOperations().flush(MetadataTable.NAME, null, null, true);
-                accumuloClient.tableOperations().flush(RootTable.NAME, null, null, true);
-                break;
-              default:
-                log.trace("'none - no action' or invalid value provided: {}", action);
-            }
-
-            final long actionComplete = System.nanoTime();
-
-            gcCycleMetrics.setPostOpDurationNanos(actionComplete - actionStart);
-
-            log.info("gc post action {} completed in {} seconds", action, String.format("%.2f",
-                (TimeUnit.NANOSECONDS.toMillis(actionComplete - actionStart) / 1000.0)));
+          final long tStop = System.nanoTime();
+          log.info(String.format("Collect cycle took %.2f seconds",
+              (TimeUnit.NANOSECONDS.toMillis(tStop - tStart) / 1000.0)));
 
+          // Clean up any unused write-ahead logs
+          Span walSpan = TraceUtil.startSpan(this.getClass(), "walogs");
+          try (Scope walScope = walSpan.makeCurrent()) {
+            GarbageCollectWriteAheadLogs walogCollector =
+                new GarbageCollectWriteAheadLogs(getContext(), fs, liveTServerSet);
+            log.info("Beginning garbage collection of write-ahead logs");
+            walogCollector.collect(status);
+            gcCycleMetrics.setLastWalCollect(status.lastLog);
           } catch (Exception e) {
-            TraceUtil.setException(outerSpan, e, false);
-            log.warn("{}", e.getMessage(), e);
+            TraceUtil.setException(walSpan, e, false);
+            log.error("{}", e.getMessage(), e);
+          } finally {
+            walSpan.end();
           }
         } catch (Exception e) {
-          TraceUtil.setException(outerSpan, e, true);
+          TraceUtil.setException(innerSpan, e, true);
           throw e;
         } finally {
-          outerSpan.end();
+          innerSpan.end();
         }
-        try {
 
-          gcCycleMetrics.incrementRunCycleCount();
-          long gcDelay = getConfiguration().getTimeInMillis(Property.GC_CYCLE_DELAY);
-          log.debug("Sleeping for {} milliseconds", gcDelay);
-          Thread.sleep(gcDelay);
-        } catch (InterruptedException e) {
+        // we just made a lot of metadata changes: flush them out
+        try {
+          AccumuloClient accumuloClient = getContext();
+
+          final long actionStart = System.nanoTime();
+
+          String action = getConfiguration().get(Property.GC_USE_FULL_COMPACTION);
+          log.debug("gc post action {} started", action);
+
+          switch (action) {
+            case "compact":
+              accumuloClient.tableOperations().compact(MetadataTable.NAME, null, null, true, true);
+              accumuloClient.tableOperations().compact(RootTable.NAME, null, null, true, true);
+              break;
+            case "flush":
+              accumuloClient.tableOperations().flush(MetadataTable.NAME, null, null, true);
+              accumuloClient.tableOperations().flush(RootTable.NAME, null, null, true);
+              break;
+            default:
+              log.trace("'none - no action' or invalid value provided: {}", action);
+          }
+
+          final long actionComplete = System.nanoTime();
+
+          gcCycleMetrics.setPostOpDurationNanos(actionComplete - actionStart);
+
+          log.info("gc post action {} completed in {} seconds", action, String.format("%.2f",
+              (TimeUnit.NANOSECONDS.toMillis(actionComplete - actionStart) / 1000.0)));
+
+        } catch (Exception e) {
+          TraceUtil.setException(outerSpan, e, false);
           log.warn("{}", e.getMessage(), e);
-          throw e;
         }
+      } catch (Exception e) {
+        TraceUtil.setException(outerSpan, e, true);
+        throw e;
+      } finally {
+        outerSpan.end();
+      }
+      try {
+
+        gcCycleMetrics.incrementRunCycleCount();
+        long gcDelay = getConfiguration().getTimeInMillis(Property.GC_CYCLE_DELAY);
+        log.debug("Sleeping for {} milliseconds", gcDelay);
+        Thread.sleep(gcDelay);
       } catch (InterruptedException e) {
-        log.info("Interrupt Exception received, shutting down");
-        gracefulShutdown(getContext().rpcCreds());
+        log.warn("{}", e.getMessage(), e);
+        return;
       }
     }
-    super.close();
-    getShutdownComplete().set(true);
-    log.info("stop requested. exiting ... ");
-    try {
-      gcLock.unlock();
-    } catch (Exception e) {
-      log.warn("Failed to release GarbageCollector lock", e);
-    }
-
   }
 
   private void incrementStatsForRun(GCRun gcRun) {
@@ -380,9 +327,6 @@ public class SimpleGarbageCollector extends AbstractServer
    */
   boolean moveToTrash(Path path) throws IOException {
     final VolumeManager fs = getContext().getVolumeManager();
-    if (!isUsingTrash()) {
-      return false;
-    }
     try {
       return fs.moveToTrash(path);
     } catch (FileNotFoundException ex) {
@@ -393,50 +337,43 @@ public class SimpleGarbageCollector extends AbstractServer
   private void getZooLock(HostAndPort addr) throws KeeperException, InterruptedException {
     var path = ServiceLock.path(getContext().getZooKeeperRoot() + Constants.ZGC_LOCK);
 
+    LockWatcher lockWatcher = new LockWatcher() {
+      @Override
+      public void lostLock(LockLossReason reason) {
+        Halt.halt("GC lock in zookeeper lost (reason = " + reason + "), exiting!", 1);
+      }
+
+      @Override
+      public void unableToMonitorLockNode(final Exception e) {
+        // ACCUMULO-3651 Level changed to error and FATAL added to message for slf4j compatibility
+        Halt.halt(-1, () -> log.error("FATAL: No longer able to monitor lock node ", e));
+
+      }
+    };
+
     UUID zooLockUUID = UUID.randomUUID();
-    gcLock = new ServiceLock(getContext().getZooReaderWriter().getZooKeeper(), path, zooLockUUID);
-    HAServiceLockWatcher gcLockWatcher =
-        new HAServiceLockWatcher("gc", () -> getShutdownComplete().get());
-
     while (true) {
-      gcLock.lock(gcLockWatcher,
-          new ServerServices(addr.toString(), Service.GC_CLIENT).toString().getBytes(UTF_8));
-
-      gcLockWatcher.waitForChange();
-
-      if (gcLockWatcher.isLockAcquired()) {
-        break;
+      ServiceLock lock =
+          new ServiceLock(getContext().getZooReaderWriter().getZooKeeper(), path, zooLockUUID);
+      if (lock.tryLock(lockWatcher,
+          new ServiceLockData(zooLockUUID, addr.toString(), ThriftService.GC))) {
+        log.debug("Got GC ZooKeeper lock");
+        return;
       }
-
-      if (!gcLockWatcher.isFailedToAcquireLock()) {
-        throw new IllegalStateException("gc lock in unknown state");
-      }
-
-      gcLock.tryToCancelAsyncLockOrUnlock();
-
       log.debug("Failed to get GC ZooKeeper lock, will retry");
-      sleepUninterruptibly(1000, TimeUnit.MILLISECONDS);
+      sleepUninterruptibly(1, TimeUnit.SECONDS);
     }
-
-    log.info("Got GC lock.");
-
   }
 
   private HostAndPort startStatsService() {
-    var processor = ThriftProcessorTypes.getGcTProcessor(this, this, getContext());
+    var processor = ThriftProcessorTypes.getGcTProcessor(this, getContext());
     IntStream port = getConfiguration().getPortStream(Property.GC_PORT);
-    String hostname = HostAndPort.fromString(getBindAddress()).getHost();
-    HostAndPort[] addresses = TServerUtils.getHostAndPorts(hostname, port);
-    @SuppressWarnings("deprecation")
-    var maxMessageSizeProperty = getConfiguration().resolve(Property.RPC_MAX_MESSAGE_SIZE,
-        Property.GENERAL_MAX_MESSAGE_SIZE);
-    long maxMessageSize = getConfiguration().getAsBytes(maxMessageSizeProperty);
+    HostAndPort[] addresses = TServerUtils.getHostAndPorts(getHostname(), port);
+    long maxMessageSize = getConfiguration().getAsBytes(Property.GENERAL_MAX_MESSAGE_SIZE);
     ServerAddress server = TServerUtils.startTServer(getConfiguration(),
         getContext().getThriftServerType(), processor, this.getClass().getSimpleName(),
         "GC Monitor Service", 2, ThreadPools.DEFAULT_TIMEOUT_MILLISECS, 1000, maxMessageSize,
-        getContext().getServerSslParams(), getContext().getSaslParams(), 0,
-        getConfiguration().getCount(Property.RPC_BACKLOG), getContext().getMetricsInfo(), false,
-        addresses);
+        getContext().getServerSslParams(), getContext().getSaslParams(), 0, addresses);
     log.debug("Starting garbage collector listening on " + server.address);
     return server.address;
   }
@@ -470,9 +407,4 @@ public class SimpleGarbageCollector extends AbstractServer
     return gcCycleMetrics;
   }
 
-  @Override
-  public ServiceLock getLock() {
-    return gcLock;
-  }
-
 }
