@@ -18,16 +18,15 @@
  */
 package org.apache.accumulo.manager;
 
+import static com.google.common.util.concurrent.Uninterruptibles.sleepUninterruptibly;
 import static java.nio.charset.StandardCharsets.UTF_8;
 import static org.apache.accumulo.core.metadata.schema.TabletMetadata.ColumnType.FLUSH_ID;
 import static org.apache.accumulo.core.metadata.schema.TabletMetadata.ColumnType.LOCATION;
 import static org.apache.accumulo.core.metadata.schema.TabletMetadata.ColumnType.LOGS;
 import static org.apache.accumulo.core.metadata.schema.TabletMetadata.ColumnType.PREV_ROW;
-import static org.apache.accumulo.core.util.UtilWaitThread.sleepUninterruptibly;
 
 import java.nio.ByteBuffer;
 import java.util.ArrayList;
-import java.util.Collections;
 import java.util.ConcurrentModificationException;
 import java.util.HashSet;
 import java.util.List;
@@ -37,26 +36,23 @@ import java.util.Set;
 import java.util.concurrent.TimeUnit;
 
 import org.apache.accumulo.core.Constants;
-import org.apache.accumulo.core.client.AccumuloClient;
-import org.apache.accumulo.core.client.BatchScanner;
 import org.apache.accumulo.core.client.TableNotFoundException;
 import org.apache.accumulo.core.client.admin.DelegationTokenConfig;
 import org.apache.accumulo.core.clientImpl.AuthenticationTokenIdentifier;
 import org.apache.accumulo.core.clientImpl.ClientContext;
 import org.apache.accumulo.core.clientImpl.DelegationTokenConfigSerializer;
 import org.apache.accumulo.core.clientImpl.thrift.SecurityErrorCode;
+import org.apache.accumulo.core.clientImpl.thrift.TInfo;
 import org.apache.accumulo.core.clientImpl.thrift.TVersionedProperties;
 import org.apache.accumulo.core.clientImpl.thrift.TableOperation;
 import org.apache.accumulo.core.clientImpl.thrift.TableOperationExceptionType;
 import org.apache.accumulo.core.clientImpl.thrift.ThriftConcurrentModificationException;
-import org.apache.accumulo.core.clientImpl.thrift.ThriftNotActiveServiceException;
 import org.apache.accumulo.core.clientImpl.thrift.ThriftSecurityException;
 import org.apache.accumulo.core.clientImpl.thrift.ThriftTableOperationException;
-import org.apache.accumulo.core.data.Key;
+import org.apache.accumulo.core.conf.DeprecatedPropertyUtil;
+import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.data.NamespaceId;
-import org.apache.accumulo.core.data.Range;
 import org.apache.accumulo.core.data.TableId;
-import org.apache.accumulo.core.data.Value;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.dataImpl.thrift.TKeyExtent;
 import org.apache.accumulo.core.fate.Fate;
@@ -71,16 +67,12 @@ import org.apache.accumulo.core.manager.thrift.ThriftPropertyException;
 import org.apache.accumulo.core.metadata.MetadataTable;
 import org.apache.accumulo.core.metadata.RootTable;
 import org.apache.accumulo.core.metadata.TServerInstance;
-import org.apache.accumulo.core.metadata.schema.MetadataSchema.ReplicationSection;
 import org.apache.accumulo.core.metadata.schema.TabletDeletedException;
 import org.apache.accumulo.core.metadata.schema.TabletMetadata;
 import org.apache.accumulo.core.metadata.schema.TabletsMetadata;
-import org.apache.accumulo.core.protobuf.ProtobufUtil;
-import org.apache.accumulo.core.security.Authorizations;
 import org.apache.accumulo.core.securityImpl.thrift.TCredentials;
 import org.apache.accumulo.core.securityImpl.thrift.TDelegationToken;
 import org.apache.accumulo.core.securityImpl.thrift.TDelegationTokenConfig;
-import org.apache.accumulo.core.trace.thrift.TInfo;
 import org.apache.accumulo.core.util.ByteBufferUtil;
 import org.apache.accumulo.manager.tableOps.TraceRepo;
 import org.apache.accumulo.manager.tserverOps.ShutdownTServer;
@@ -88,7 +80,6 @@ import org.apache.accumulo.server.client.ClientServiceHandler;
 import org.apache.accumulo.server.conf.store.NamespacePropKey;
 import org.apache.accumulo.server.conf.store.TablePropKey;
 import org.apache.accumulo.server.manager.LiveTServerSet.TServerConnection;
-import org.apache.accumulo.server.replication.proto.Replication.Status;
 import org.apache.accumulo.server.security.delegation.AuthenticationTokenSecretManager;
 import org.apache.accumulo.server.util.PropUtil;
 import org.apache.accumulo.server.util.SystemPropUtil;
@@ -97,15 +88,10 @@ import org.apache.hadoop.security.token.Token;
 import org.apache.thrift.TException;
 import org.apache.zookeeper.KeeperException.NoNodeException;
 import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
-
-import com.google.protobuf.InvalidProtocolBufferException;
 
 public class ManagerClientServiceHandler implements ManagerClientService.Iface {
 
   private static final Logger log = Manager.log;
-  private static final Logger drainLog =
-      LoggerFactory.getLogger("org.apache.accumulo.manager.ManagerDrainImpl");
   private final Manager manager;
 
   protected ManagerClientServiceHandler(Manager manager) {
@@ -139,7 +125,7 @@ public class ManagerClientServiceHandler implements ManagerClientService.Iface {
       throw new ThriftTableOperationException(tableId.canonical(), null, TableOperation.FLUSH,
           TableOperationExceptionType.OTHER, null);
     }
-    return Long.parseLong(new String(fid, UTF_8));
+    return Long.parseLong(new String(fid));
   }
 
   @Override
@@ -287,7 +273,7 @@ public class ManagerClientServiceHandler implements ManagerClientService.Iface {
           TableOperation.SET_PROPERTY, TableOperationExceptionType.OTHER,
           "Error modifying table properties: tableId: " + tableId.canonical());
     } catch (IllegalArgumentException iae) {
-      throw new ThriftPropertyException("Modify properties", "failed", iae.getMessage());
+      throw new ThriftPropertyException();
     }
 
   }
@@ -341,26 +327,6 @@ public class ManagerClientServiceHandler implements ManagerClientService.Iface {
     log.debug("FATE op shutting down " + tabletServer + " finished");
   }
 
-  @Override
-  public void tabletServerStopping(TInfo tinfo, TCredentials credentials, String tabletServer)
-      throws ThriftSecurityException, ThriftNotActiveServiceException, TException {
-    if (!manager.security.canPerformSystemActions(credentials)) {
-      throw new ThriftSecurityException(credentials.getPrincipal(),
-          SecurityErrorCode.PERMISSION_DENIED);
-    }
-    log.info("Tablet Server {} has reported it's shutting down", tabletServer);
-    var tserver = new TServerInstance(tabletServer);
-    if (manager.shutdownTServer(tserver)) {
-      // If there is an exception seeding the fate tx this should cause the RPC to fail which should
-      // cause the tserver to halt. Because of that not making an attempt to handle failure here.
-      Fate<Manager> fate = manager.fate();
-      long tid = fate.startTransaction();
-      String msg = "Shutdown tserver " + tabletServer;
-      fate.seedTransaction("ShutdownTServer", tid,
-          new TraceRepo<>(new ShutdownTServer(tserver, false)), true, msg);
-    }
-  }
-
   @Override
   public void reportSplitExtent(TInfo info, TCredentials credentials, String serverName,
       TabletSplit split) throws ThriftSecurityException {
@@ -370,7 +336,7 @@ public class ManagerClientServiceHandler implements ManagerClientService.Iface {
     }
 
     KeyExtent oldTablet = KeyExtent.fromThrift(split.oldTablet);
-    if (manager.migrations.removeExtent(oldTablet) != null) {
+    if (manager.migrations.remove(oldTablet) != null) {
       Manager.log.info("Canceled migration of {}", split.oldTablet);
     }
     for (TServerInstance instance : manager.tserverSet.getCurrentServers()) {
@@ -438,6 +404,7 @@ public class ManagerClientServiceHandler implements ManagerClientService.Iface {
 
     try {
       SystemPropUtil.removeSystemProperty(manager.getContext(), property);
+      updatePlugins(property);
     } catch (Exception e) {
       Manager.log.error("Problem removing config property in zookeeper", e);
       throw new RuntimeException(e.getMessage());
@@ -453,10 +420,10 @@ public class ManagerClientServiceHandler implements ManagerClientService.Iface {
 
     try {
       SystemPropUtil.setSystemProperty(manager.getContext(), property, value);
+      updatePlugins(property);
     } catch (IllegalArgumentException iae) {
       Manager.log.error("Problem setting invalid property", iae);
-      throw new ThriftPropertyException(property, value,
-          "Property is invalid. message: " + iae.getMessage());
+      throw new ThriftPropertyException(property, value, "Property is invalid");
     } catch (Exception e) {
       Manager.log.error("Problem setting config property in zookeeper", e);
       throw new TException(e.getMessage());
@@ -473,6 +440,9 @@ public class ManagerClientServiceHandler implements ManagerClientService.Iface {
     try {
       SystemPropUtil.modifyProperties(manager.getContext(), properties.getVersion(),
           properties.getProperties());
+      for (Map.Entry<String,String> entry : properties.getProperties().entrySet()) {
+        updatePlugins(entry.getKey());
+      }
     } catch (IllegalArgumentException iae) {
       Manager.log.error("Problem setting invalid property", iae);
       throw new ThriftPropertyException("Modify properties", "failed", iae.getMessage());
@@ -518,7 +488,7 @@ public class ManagerClientServiceHandler implements ManagerClientService.Iface {
           TableOperation.SET_PROPERTY, TableOperationExceptionType.OTHER,
           "Error modifying namespace properties");
     } catch (IllegalArgumentException iae) {
-      throw new ThriftPropertyException("Modify properties", "failed", iae.getMessage());
+      throw new ThriftPropertyException("All properties", "failed", iae.getMessage());
     }
   }
 
@@ -570,13 +540,10 @@ public class ManagerClientServiceHandler implements ManagerClientService.Iface {
     }
 
     try {
-      if (op == TableOperation.REMOVE_PROPERTY) {
+      if (value == null || value.isEmpty()) {
         PropUtil.removeProperties(manager.getContext(),
             TablePropKey.of(manager.getContext(), tableId), List.of(property));
-      } else if (op == TableOperation.SET_PROPERTY) {
-        if (value == null || value.isEmpty()) {
-          value = "";
-        }
+      } else {
         PropUtil.setProperties(manager.getContext(), TablePropKey.of(manager.getContext(), tableId),
             Map.of(property, value));
       }
@@ -594,6 +561,15 @@ public class ManagerClientServiceHandler implements ManagerClientService.Iface {
     }
   }
 
+  private void updatePlugins(String property) {
+    // resolve without warning; any warnings should have already occurred
+    String resolved = DeprecatedPropertyUtil.getReplacementName(property, (log, replacement) -> {});
+    if (resolved.equals(Property.MANAGER_TABLET_BALANCER.getKey())) {
+      manager.initializeBalancer();
+      log.info("tablet balancer changed to {}", manager.getBalancerClass().getName());
+    }
+  }
+
   @Override
   public void waitForBalance(TInfo tinfo) {
     manager.waitForBalance();
@@ -643,107 +619,9 @@ public class ManagerClientServiceHandler implements ManagerClientService.Iface {
     }
   }
 
-  @SuppressWarnings("deprecation")
-  @Override
-  public boolean drainReplicationTable(TInfo tfino, TCredentials credentials, String tableName,
-      Set<String> logsToWatch) throws TException {
-    AccumuloClient client = manager.getContext();
-
-    final Text tableId = new Text(getTableId(manager.getContext(), tableName).canonical());
-
-    drainLog.trace("Waiting for {} to be replicated for {}", logsToWatch, tableId);
-
-    drainLog.trace("Reading from metadata table");
-    final Set<Range> range = Collections.singleton(new Range(ReplicationSection.getRange()));
-    BatchScanner bs;
-    try {
-      bs = client.createBatchScanner(MetadataTable.NAME, Authorizations.EMPTY, 4);
-    } catch (TableNotFoundException e) {
-      throw new RuntimeException("Could not read metadata table", e);
-    }
-    bs.setRanges(range);
-    bs.fetchColumnFamily(ReplicationSection.COLF);
-    try {
-      // Return immediately if there are records in metadata for these WALs
-      if (!allReferencesReplicated(bs, tableId, logsToWatch)) {
-        return false;
-      }
-    } finally {
-      bs.close();
-    }
-
-    drainLog.trace("reading from replication table");
-    try {
-      bs = client.createBatchScanner(org.apache.accumulo.core.replication.ReplicationTable.NAME,
-          Authorizations.EMPTY, 4);
-    } catch (TableNotFoundException e) {
-      throw new RuntimeException("Replication table was not found", e);
-    }
-    bs.setRanges(Collections.singleton(new Range()));
-    try {
-      // No records in metadata, check replication table
-      return allReferencesReplicated(bs, tableId, logsToWatch);
-    } finally {
-      bs.close();
-    }
-  }
-
   protected TableId getTableId(ClientContext context, String tableName)
       throws ThriftTableOperationException {
     return ClientServiceHandler.checkTableId(context, tableName, null);
   }
 
-  /**
-   * @return return true records are only in place which are fully replicated
-   */
-  @Deprecated
-  protected boolean allReferencesReplicated(BatchScanner bs, Text tableId,
-      Set<String> relevantLogs) {
-    Text rowHolder = new Text(), colfHolder = new Text();
-    for (Entry<Key,Value> entry : bs) {
-      drainLog.trace("Got key {}", entry.getKey().toStringNoTruncate());
-
-      entry.getKey().getColumnQualifier(rowHolder);
-      if (tableId.equals(rowHolder)) {
-        entry.getKey().getRow(rowHolder);
-        entry.getKey().getColumnFamily(colfHolder);
-
-        String file;
-        if (colfHolder.equals(ReplicationSection.COLF)) {
-          file = rowHolder.toString();
-          file = file.substring(ReplicationSection.getRowPrefix().length());
-        } else if (colfHolder
-            .equals(org.apache.accumulo.core.replication.ReplicationSchema.OrderSection.NAME)) {
-          file = org.apache.accumulo.core.replication.ReplicationSchema.OrderSection
-              .getFile(entry.getKey(), rowHolder);
-          long timeClosed = org.apache.accumulo.core.replication.ReplicationSchema.OrderSection
-              .getTimeClosed(entry.getKey(), rowHolder);
-          drainLog.trace("Order section: {} and {}", timeClosed, file);
-        } else {
-          file = rowHolder.toString();
-        }
-
-        // Skip files that we didn't observe when we started (new files/data)
-        if (relevantLogs.contains(file)) {
-          drainLog.trace("Found file that we *do* care about {}", file);
-        } else {
-          drainLog.trace("Found file that we didn't care about {}", file);
-          continue;
-        }
-
-        try {
-          Status stat = Status.parseFrom(entry.getValue().get());
-          if (!org.apache.accumulo.server.replication.StatusUtil.isFullyReplicated(stat)) {
-            drainLog.trace("{} and {} is not replicated", file, ProtobufUtil.toString(stat));
-            return false;
-          }
-          drainLog.trace("{} and {} is replicated", file, ProtobufUtil.toString(stat));
-        } catch (InvalidProtocolBufferException e) {
-          drainLog.trace("Could not parse protobuf for {}", entry.getKey(), e);
-        }
-      }
-    }
-
-    return true;
-  }
 }
