@@ -18,8 +18,7 @@
  */
 package org.apache.accumulo.manager.metrics;
 
-import java.util.ArrayList;
-import java.util.List;
+import static java.util.Objects.requireNonNull;
 
 import org.apache.accumulo.core.conf.AccumuloConfiguration;
 import org.apache.accumulo.core.conf.Property;
@@ -27,15 +26,21 @@ import org.apache.accumulo.core.metrics.MetricsProducer;
 import org.apache.accumulo.manager.Manager;
 import org.apache.accumulo.manager.metrics.fate.FateMetrics;
 
-public class ManagerMetrics {
+import io.micrometer.core.instrument.MeterRegistry;
 
-  public static List<MetricsProducer> getProducers(AccumuloConfiguration conf, Manager m) {
-    ArrayList<MetricsProducer> producers = new ArrayList<>();
-    @SuppressWarnings("deprecation")
-    ReplicationMetrics replMetrics = new ReplicationMetrics(m);
-    producers.add(replMetrics);
-    producers.add(new FateMetrics(m.getContext(),
-        conf.getTimeInMillis(Property.MANAGER_FATE_METRICS_MIN_UPDATE_INTERVAL)));
-    return producers;
+public class ManagerMetrics implements MetricsProducer {
+
+  private final FateMetrics fateMetrics;
+
+  public ManagerMetrics(final AccumuloConfiguration conf, final Manager manager) {
+    requireNonNull(conf, "AccumuloConfiguration must not be null");
+    requireNonNull(conf, "Manager must not be null");
+    fateMetrics = new FateMetrics(manager.getContext(),
+        conf.getTimeInMillis(Property.MANAGER_FATE_METRICS_MIN_UPDATE_INTERVAL));
+  }
+
+  @Override
+  public void registerMetrics(MeterRegistry registry) {
+    fateMetrics.registerMetrics(registry);
   }
 }
