@@ -26,22 +26,16 @@ import org.apache.accumulo.core.fate.zookeeper.ZooUtil.NodeExistsPolicy;
 import org.apache.accumulo.core.manager.thrift.ManagerGoalState;
 import org.apache.accumulo.core.singletons.SingletonManager;
 import org.apache.accumulo.core.singletons.SingletonManager.Mode;
-import org.apache.accumulo.manager.upgrade.RenameMasterDirInZK;
 import org.apache.accumulo.server.ServerContext;
 import org.apache.accumulo.server.security.SecurityUtil;
 
-import com.google.common.base.Preconditions;
-
 public class SetGoalState {
 
   /**
    * Utility program that will change the goal state for the manager from the command line.
    */
   public static void main(String[] args) throws Exception {
-    try {
-      Preconditions.checkArgument(args.length == 1);
-      ManagerGoalState.valueOf(args[0]);
-    } catch (IllegalArgumentException e) {
+    if (args.length != 1 || ManagerGoalState.valueOf(args[0]) == null) {
       System.err.println(
           "Usage: accumulo " + SetGoalState.class.getName() + " [NORMAL|SAFE_MODE|CLEAN_STOP]");
       System.exit(-1);
@@ -50,12 +44,12 @@ public class SetGoalState {
     try {
       var siteConfig = SiteConfiguration.auto();
       SecurityUtil.serverLogin(siteConfig);
-      var context = new ServerContext(siteConfig);
-      RenameMasterDirInZK.renameMasterDirInZK(context);
-      context.waitForZookeeperAndHdfs();
-      context.getZooReaderWriter().putPersistentData(
-          context.getZooKeeperRoot() + Constants.ZMANAGER_GOAL_STATE, args[0].getBytes(UTF_8),
-          NodeExistsPolicy.OVERWRITE);
+      try (var context = new ServerContext(siteConfig)) {
+        context.waitForZookeeperAndHdfs();
+        context.getZooReaderWriter().putPersistentData(
+            context.getZooKeeperRoot() + Constants.ZMANAGER_GOAL_STATE, args[0].getBytes(UTF_8),
+            NodeExistsPolicy.OVERWRITE);
+      }
     } finally {
       SingletonManager.setMode(Mode.CLOSED);
     }
