@@ -52,8 +52,8 @@ class PopulateZookeeper extends ManagerRepo {
     Utils.getTableNameLock().lock();
     try {
       // write tableName & tableId to zookeeper
-      Utils.checkTableNameDoesNotExist(manager.getContext(), tableInfo.getTableName(),
-          tableInfo.getNamespaceId(), tableInfo.getTableId(), TableOperation.CREATE);
+      Utils.checkTableDoesNotExist(manager.getContext(), tableInfo.getTableName(),
+          tableInfo.getTableId(), TableOperation.CREATE);
 
       manager.getTableManager().addTable(tableInfo.getTableId(), tableInfo.getNamespaceId(),
           tableInfo.getTableName());
