@@ -44,9 +44,9 @@ public class TableRangeOp extends ManagerRepo {
 
   private final TableId tableId;
   private final NamespaceId namespaceId;
-  private final byte[] startRow;
-  private final byte[] endRow;
-  private final Operation op;
+  private byte[] startRow;
+  private byte[] endRow;
+  private Operation op;
 
   @Override
   public long isReady(long tid, Manager env) throws Exception {
