@@ -42,7 +42,7 @@ class ImportPopulateZookeeper extends ManagerRepo {
 
   private static final long serialVersionUID = 1L;
 
-  private final ImportedTableInfo tableInfo;
+  private ImportedTableInfo tableInfo;
 
   ImportPopulateZookeeper(ImportedTableInfo ti) {
     this.tableInfo = ti;
@@ -75,8 +75,8 @@ class ImportPopulateZookeeper extends ManagerRepo {
     Utils.getTableNameLock().lock();
     try {
       // write tableName & tableId to zookeeper
-      Utils.checkTableNameDoesNotExist(env.getContext(), tableInfo.tableName, tableInfo.namespaceId,
-          tableInfo.tableId, TableOperation.CREATE);
+      Utils.checkTableDoesNotExist(env.getContext(), tableInfo.tableName, tableInfo.tableId,
+          TableOperation.CREATE);
 
       String namespace = TableNameUtil.qualify(tableInfo.tableName).getFirst();
       NamespaceId namespaceId = Namespaces.getNamespaceId(env.getContext(), namespace);
