@@ -18,14 +18,11 @@
  */
 package org.apache.accumulo.manager.tableOps.tableImport;
 
-import static org.apache.accumulo.core.util.threads.ThreadPoolNames.IMPORT_TABLE_RENAME_POOL;
-
 import java.io.IOException;
 import java.util.Arrays;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Map;
-import java.util.Objects;
 import java.util.Set;
 import java.util.function.Function;
 import java.util.stream.Collectors;
@@ -51,7 +48,7 @@ class MoveExportedFiles extends ManagerRepo {
 
   private static final long serialVersionUID = 1L;
 
-  private final ImportedTableInfo tableInfo;
+  private ImportedTableInfo tableInfo;
 
   MoveExportedFiles(ImportedTableInfo ti) {
     this.tableInfo = ti;
@@ -74,27 +71,24 @@ class MoveExportedFiles extends ManagerRepo {
 
       Function<FileStatus,String> fileStatusName = fstat -> fstat.getPath().getName();
 
-      Set<Path> importing =
-          Arrays.stream(exportedFiles).map(fileStatusName).map(fileNameMappings::get)
-              .filter(Objects::nonNull).map(Path::new).collect(Collectors.toSet());
+      Set<String> importing = Arrays.stream(exportedFiles).map(fileStatusName)
+          .map(fileNameMappings::get).collect(Collectors.toSet());
 
-      Set<Path> imported =
-          Arrays.stream(importedFiles).map(FileStatus::getPath).collect(Collectors.toSet());
+      Set<String> imported =
+          Arrays.stream(importedFiles).map(fileStatusName).collect(Collectors.toSet());
 
       if (log.isDebugEnabled()) {
         log.debug("{} files already present in imported (target) directory: {}", fmtTid,
-            imported.stream().map(Path::getName).collect(Collectors.joining(",")));
+            String.join(",", imported));
       }
 
-      Set<Path> missingFiles = Sets.difference(
-          fileNameMappings.values().stream().map(Path::new).collect(Collectors.toSet()),
+      Set<String> missingFiles = Sets.difference(new HashSet<>(fileNameMappings.values()),
           new HashSet<>(Sets.union(importing, imported)));
 
       if (!missingFiles.isEmpty()) {
         throw new AcceptableThriftTableOperationException(tableInfo.tableId.canonical(),
             tableInfo.tableName, TableOperation.IMPORT, TableOperationExceptionType.OTHER,
-            "Missing source files corresponding to files "
-                + missingFiles.stream().map(Path::getName).collect(Collectors.joining(",")));
+            "Missing source files corresponding to files " + String.join(",", missingFiles));
       }
 
       for (FileStatus fileStatus : exportedFiles) {
@@ -114,7 +108,7 @@ class MoveExportedFiles extends ManagerRepo {
       }
     }
     try {
-      fs.bulkRename(oldToNewPaths, workerCount, IMPORT_TABLE_RENAME_POOL.poolName, fmtTid);
+      fs.bulkRename(oldToNewPaths, workerCount, "importtable rename", fmtTid);
     } catch (IOException ioe) {
       throw new AcceptableThriftTableOperationException(tableInfo.tableId.canonical(), null,
           TableOperation.IMPORT, TableOperationExceptionType.OTHER, ioe.getCause().getMessage());
