@@ -18,23 +18,20 @@
  */
 package org.apache.accumulo.manager.upgrade;
 
-import static java.util.concurrent.TimeUnit.SECONDS;
-import static org.apache.accumulo.core.util.threads.ThreadPoolNames.MANAGER_UPGRADE_COORDINATOR_METADATA_POOL;
+import static org.apache.accumulo.server.AccumuloDataVersion.ROOT_TABLET_META_CHANGES;
 
 import java.io.IOException;
 import java.util.Collections;
 import java.util.Map;
+import java.util.Objects;
 import java.util.TreeMap;
 import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.Future;
 import java.util.concurrent.SynchronousQueue;
+import java.util.concurrent.TimeUnit;
 
 import org.apache.accumulo.core.Constants;
 import org.apache.accumulo.core.client.AccumuloException;
-import org.apache.accumulo.core.client.AccumuloSecurityException;
-import org.apache.accumulo.core.client.NamespaceNotFoundException;
-import org.apache.accumulo.core.client.TableNotFoundException;
-import org.apache.accumulo.core.conf.ConfigCheckUtil;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.fate.ReadOnlyTStore;
 import org.apache.accumulo.core.fate.ZooStore;
@@ -44,7 +41,6 @@ import org.apache.accumulo.manager.EventCoordinator;
 import org.apache.accumulo.server.AccumuloDataVersion;
 import org.apache.accumulo.server.ServerContext;
 import org.apache.accumulo.server.ServerDirs;
-import org.apache.accumulo.server.conf.CheckCompactionConfig;
 import org.apache.accumulo.server.fs.VolumeManager;
 import org.apache.hadoop.fs.Path;
 import org.slf4j.Logger;
@@ -58,7 +54,7 @@ public class UpgradeCoordinator {
 
   public enum UpgradeStatus {
     /**
-     * This signifies the upgrade status is in the process of being determined. Its best to assume
+     * This signifies the upgrade status is in the process of being determined. It is best to assume
      * nothing is upgraded when seeing this.
      */
     INITIAL {
@@ -85,15 +81,6 @@ public class UpgradeCoordinator {
         return extent.isMeta();
       }
     },
-    /**
-     * This signifies that zookeeper and the root and metadata tables have been upgraded so far.
-     */
-    UPGRADED_METADATA {
-      @Override
-      public boolean isParentLevelUpgraded(KeyExtent extent) {
-        return extent.isMeta();
-      }
-    },
     /**
      * This signifies that everything (zookeeper, root table, metadata table) is upgraded.
      */
@@ -123,12 +110,10 @@ public class UpgradeCoordinator {
   private static final Logger log = LoggerFactory.getLogger(UpgradeCoordinator.class);
 
   private int currentVersion;
-
-  // unmodifiable map of "current version" -> upgrader to next version.
+  // map of "current version" -> upgrader to next version.
   // Sorted so upgrades execute in order from the oldest supported data version to current
-  private final Map<Integer,Upgrader> upgraders =
-      Collections.unmodifiableMap(new TreeMap<>(Map.of(AccumuloDataVersion.SHORTEN_RFILE_KEYS,
-          new Upgrader8to9(), AccumuloDataVersion.CRYPTO_CHANGES, new Upgrader9to10())));
+  private final Map<Integer,Upgrader> upgraders = Collections
+      .unmodifiableMap(new TreeMap<>(Map.of(ROOT_TABLET_META_CHANGES, new Upgrader10to11())));
 
   private volatile UpgradeStatus status;
 
@@ -172,8 +157,12 @@ public class UpgradeCoordinator {
         abortIfFateTransactions(context);
 
         for (int v = currentVersion; v < AccumuloDataVersion.get(); v++) {
-          log.info("Upgrading Zookeeper from data version {}", v);
-          upgraders.get(v).upgradeZookeeper(context);
+          log.info("Upgrading Zookeeper - current version {} as step towards target version {}", v,
+              AccumuloDataVersion.get());
+          var upgrader = upgraders.get(v);
+          Objects.requireNonNull(upgrader,
+              "upgrade ZooKeeper: failed to find upgrader for version " + currentVersion);
+          upgrader.upgradeZookeeper(context);
         }
       }
 
@@ -194,25 +183,30 @@ public class UpgradeCoordinator {
         "Not currently in a suitable state to do metadata upgrade %s", status);
 
     if (currentVersion < AccumuloDataVersion.get()) {
-      return ThreadPools.getServerThreadPools()
-          .getPoolBuilder(MANAGER_UPGRADE_COORDINATOR_METADATA_POOL).numCoreThreads(0)
-          .numMaxThreads(Integer.MAX_VALUE).withTimeOut(60L, SECONDS)
-          .withQueue(new SynchronousQueue<>()).build().submit(() -> {
+      return ThreadPools.getServerThreadPools().createThreadPool(0, Integer.MAX_VALUE, 60L,
+          TimeUnit.SECONDS, "UpgradeMetadataThreads", new SynchronousQueue<>(), false)
+          .submit(() -> {
             try {
               for (int v = currentVersion; v < AccumuloDataVersion.get(); v++) {
-                log.info("Upgrading Root from data version {}", v);
+                log.info("Upgrading Root - current version {} as step towards target version {}", v,
+                    AccumuloDataVersion.get());
+                var upgrader = upgraders.get(v);
+                Objects.requireNonNull(upgrader,
+                    "upgrade root: failed to find root upgrader for version " + currentVersion);
                 upgraders.get(v).upgradeRoot(context);
               }
+
               setStatus(UpgradeStatus.UPGRADED_ROOT, eventCoordinator);
 
               for (int v = currentVersion; v < AccumuloDataVersion.get(); v++) {
-                log.info("Upgrading Metadata from data version {}", v);
+                log.info(
+                    "Upgrading Metadata - current version {} as step towards target version {}", v,
+                    AccumuloDataVersion.get());
+                var upgrader = upgraders.get(v);
+                Objects.requireNonNull(upgrader,
+                    "upgrade metadata: failed to find upgrader for version " + currentVersion);
                 upgraders.get(v).upgradeMetadata(context);
               }
-              setStatus(UpgradeStatus.UPGRADED_METADATA, eventCoordinator);
-
-              log.info("Validating configuration properties.");
-              validateProperties(context);
 
               log.info("Updating persistent data version.");
               updateAccumuloVersion(context.getServerDirs(), context.getVolumeManager(),
@@ -229,30 +223,6 @@ public class UpgradeCoordinator {
     }
   }
 
-  private void validateProperties(ServerContext context) {
-    ConfigCheckUtil.validate(context.getSiteConfiguration(), "site configuration");
-    ConfigCheckUtil.validate(context.getConfiguration(), "system configuration");
-    try {
-      for (String ns : context.namespaceOperations().list()) {
-        ConfigCheckUtil.validate(
-            context.namespaceOperations().getNamespaceProperties(ns).entrySet(),
-            ns + " namespace configuration");
-      }
-      for (String table : context.tableOperations().list()) {
-        ConfigCheckUtil.validate(context.tableOperations().getTableProperties(table).entrySet(),
-            table + " table configuration");
-      }
-    } catch (AccumuloException | AccumuloSecurityException | NamespaceNotFoundException
-        | TableNotFoundException e) {
-      throw new IllegalStateException("Error checking properties", e);
-    }
-    try {
-      CheckCompactionConfig.validate(context.getConfiguration());
-    } catch (SecurityException | IllegalArgumentException | ReflectiveOperationException e) {
-      throw new IllegalStateException("Error validating compaction configuration", e);
-    }
-  }
-
   // visible for testing
   synchronized void updateAccumuloVersion(ServerDirs serverDirs, VolumeManager fs, int oldVersion) {
     for (Volume volume : fs.getVolumes()) {
@@ -285,27 +255,26 @@ public class UpgradeCoordinator {
    * need to make sure there are no queued transactions from a previous version before continuing an
    * upgrade. The status of the operations is irrelevant; those in SUCCESSFUL status cause the same
    * problem as those just queued.
-   *
+   * <p>
    * Note that the Manager should not allow write access to Fate until after all upgrade steps are
    * complete.
-   *
+   * <p>
    * Should be called as a guard before performing any upgrade steps, after determining that an
    * upgrade is needed.
-   *
+   * <p>
    * see ACCUMULO-2519
    */
   @SuppressFBWarnings(value = "DM_EXIT",
       justification = "Want to immediately stop all manager threads on upgrade error")
   private void abortIfFateTransactions(ServerContext context) {
     try {
-      final ReadOnlyTStore<UpgradeCoordinator> fate =
-          new ZooStore<>(context.getZooKeeperRoot() + Constants.ZFATE, context.getZooReaderWriter(),
-              context.getZooCache());
+      final ReadOnlyTStore<UpgradeCoordinator> fate = new ZooStore<>(
+          context.getZooKeeperRoot() + Constants.ZFATE, context.getZooReaderWriter());
       if (!fate.list().isEmpty()) {
         throw new AccumuloException("Aborting upgrade because there are"
             + " outstanding FATE transactions from a previous Accumulo version."
             + " You can start the tservers and then use the shell to delete completed "
-            + " transactions. If there are uncomplete transactions, you will need to roll"
+            + " transactions. If there are incomplete transactions, you will need to roll"
             + " back and fix those issues. Please see the following page for more information: "
             + " https://accumulo.apache.org/docs/2.x/troubleshooting/advanced#upgrade-issues");
       }
