@@ -26,16 +26,17 @@ import java.util.Collections;
 import java.util.HashMap;
 
 import org.apache.accumulo.core.fate.Repo;
-import org.apache.accumulo.core.master.thrift.TableInfo;
-import org.apache.accumulo.core.master.thrift.TabletServerStatus;
+import org.apache.accumulo.core.manager.thrift.TableInfo;
+import org.apache.accumulo.core.manager.thrift.TabletServerStatus;
 import org.apache.accumulo.core.metadata.TServerInstance;
-import org.apache.accumulo.core.util.HostAndPort;
 import org.apache.accumulo.manager.Manager;
 import org.apache.accumulo.manager.tserverOps.ShutdownTServer;
 import org.apache.accumulo.server.manager.LiveTServerSet.TServerConnection;
 import org.easymock.EasyMock;
 import org.junit.jupiter.api.Test;
 
+import com.google.common.net.HostAndPort;
+
 public class ShutdownTServerTest {
 
   @Test
@@ -55,7 +56,8 @@ public class ShutdownTServerTest {
     // Put in a table info record, don't care what
     status.tableMap.put("a_table", new TableInfo());
 
-    EasyMock.expect(manager.shutdownTServer(tserver)).andReturn(true).once();
+    manager.shutdownTServer(tserver);
+    EasyMock.expectLastCall().once();
     EasyMock.expect(manager.onlineTabletServers()).andReturn(Collections.singleton(tserver));
     EasyMock.expect(manager.getConnection(tserver)).andReturn(tserverCnxn);
     EasyMock.expect(tserverCnxn.getTableMap(false)).andReturn(status);
@@ -73,7 +75,8 @@ public class ShutdownTServerTest {
 
     // reset the table map to the empty set to simulate all tablets unloaded
     status.tableMap = new HashMap<>();
-    EasyMock.expect(manager.shutdownTServer(tserver)).andReturn(false).once();
+    manager.shutdownTServer(tserver);
+    EasyMock.expectLastCall().once();
     EasyMock.expect(manager.onlineTabletServers()).andReturn(Collections.singleton(tserver));
     EasyMock.expect(manager.getConnection(tserver)).andReturn(tserverCnxn);
     EasyMock.expect(tserverCnxn.getTableMap(false)).andReturn(status);
