@@ -31,7 +31,6 @@ import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Optional;
@@ -56,7 +55,7 @@ import com.google.common.collect.Sets;
 
 public class PrepBulkImportTest {
 
-  static KeyExtent nke(String prev, String end) {
+  KeyExtent nke(String prev, String end) {
     Text per = prev == null ? null : new Text(prev);
     Text er = end == null ? null : new Text(end);
 
@@ -89,37 +88,29 @@ public class PrepBulkImportTest {
     }).iterator();
   }
 
-  private void runTest(List<KeyExtent> loadRanges, List<KeyExtent> tabletRanges, int skipDistance)
-      throws Exception {
+  private void runTest(List<KeyExtent> loadRanges, List<KeyExtent> tabletRanges) throws Exception {
     Map<KeyExtent,String> lrm = new HashMap<>();
     loadRanges.forEach(e -> lrm.put(e, "f1 f2 f3"));
-    runTest(lrm, tabletRanges, 100, skipDistance);
+    runTest(lrm, tabletRanges, 100);
   }
 
   public void runTest(Map<KeyExtent,String> loadRanges, List<KeyExtent> tabletRanges,
-      int maxTablets, int skipDistance) throws Exception {
-    TabletIterFactory tabletIterFactory = new TabletIterFactory() {
+      int maxTablets) throws Exception {
+    TabletIterFactory tabletIterFactory = startRow -> {
+      int start = -1;
 
-      @Override
-      public Iterator<KeyExtent> newTabletIter(Text startRow) {
-        int start = -1;
-
-        if (startRow == null) {
-          start = 0;
-        } else {
-          for (int i = 0; i < tabletRanges.size(); i++) {
-            if (tabletRanges.get(i).contains(startRow)) {
-              start = i;
-              break;
-            }
+      if (startRow == null) {
+        start = 0;
+      } else {
+        for (int i = 0; i < tabletRanges.size(); i++) {
+          if (tabletRanges.get(i).contains(startRow)) {
+            start = i;
+            break;
           }
         }
-
-        return tabletRanges.subList(start, tabletRanges.size()).iterator();
       }
 
-      @Override
-      public void close() {}
+      return tabletRanges.subList(start, tabletRanges.size()).iterator();
     };
 
     var sortedExtents = loadRanges.keySet().stream().sorted().collect(Collectors.toList());
@@ -129,13 +120,13 @@ public class PrepBulkImportTest {
         .map(Text::toString).orElse(null);
 
     try (LoadMappingIterator lmi = createLoadMappingIter(loadRanges)) {
-      var extent = PrepBulkImport.validateLoadMapping("1", lmi, tabletIterFactory, maxTablets,
-          10001, skipDistance);
+      var extent =
+          PrepBulkImport.validateLoadMapping("1", lmi, tabletIterFactory, maxTablets, 10001);
       assertEquals(nke(minPrevEndRow, maxPrevEndRow), extent, loadRanges + " " + tabletRanges);
     }
   }
 
-  static LoadMappingIterator createLoadMappingIter(Map<KeyExtent,String> loadRanges)
+  private LoadMappingIterator createLoadMappingIter(Map<KeyExtent,String> loadRanges)
       throws IOException {
     SortedMap<KeyExtent,Bulk.Files> mapping = new TreeMap<>();
 
@@ -163,24 +154,23 @@ public class PrepBulkImportTest {
         .collect(Collectors.joining(","));
   }
 
-  public void runExceptionTest(List<KeyExtent> loadRanges, List<KeyExtent> tabletRanges,
-      int skipDistance) {
+  public void runExceptionTest(List<KeyExtent> loadRanges, List<KeyExtent> tabletRanges) {
     String message = "expected " + toRangeStrings(loadRanges) + " to fail against "
         + toRangeStrings(tabletRanges);
     assertThrows(AcceptableThriftTableOperationException.class,
-        () -> runTest(loadRanges, tabletRanges, skipDistance), message);
+        () -> runTest(loadRanges, tabletRanges), message);
   }
 
   @Test
   public void testSingleTablet() throws Exception {
-    runTest(Arrays.asList(nke(null, null)), Arrays.asList(nke(null, null)), 0);
+    runTest(Arrays.asList(nke(null, null)), Arrays.asList(nke(null, null)));
 
     for (List<KeyExtent> loadRanges : powerSet(nke(null, "b"), nke("b", "k"), nke("k", "r"),
         nke("r", null))) {
       if (loadRanges.isEmpty()) {
         continue;
       }
-      runExceptionTest(loadRanges, Arrays.asList(nke(null, null)), 0);
+      runExceptionTest(loadRanges, Arrays.asList(nke(null, null)));
     }
   }
 
@@ -196,8 +186,8 @@ public class PrepBulkImportTest {
 
       List<String> requiredRows = List.of("b", "m", "r", "v");
       for (Set<String> otherRows : Sets.powerSet(Set.of("a", "c", "q", "t", "x"))) {
-        runTest(loadRanges, createExtents(Stream.concat(requiredRows.stream(), otherRows.stream())),
-            0);
+        runTest(loadRanges,
+            createExtents(Stream.concat(requiredRows.stream(), otherRows.stream())));
       }
     }
   }
@@ -227,14 +217,14 @@ public class PrepBulkImportTest {
         // test will all but one of the rows in the load mapping
         for (Set<String> otherRows : Sets.powerSet(Set.of("a", "c", "q", "t", "x"))) {
           runExceptionTest(loadRanges,
-              createExtents(Stream.concat(rows2.stream(), otherRows.stream())), 0);
+              createExtents(Stream.concat(rows2.stream(), otherRows.stream())));
         }
       }
 
       if (rows.size() > 1) {
         // test with none of the rows in the load mapping
         for (Set<String> otherRows : Sets.powerSet(Set.of("a", "c", "q", "t", "x"))) {
-          runExceptionTest(loadRanges, createExtents(otherRows.stream()), 0);
+          runExceptionTest(loadRanges, createExtents(otherRows.stream()));
         }
       }
     }
@@ -260,14 +250,14 @@ public class PrepBulkImportTest {
         int totalTablets = requiredRows.size() + otherRows.size() + 1;
 
         if (totalTablets > maxTablets) {
-          runTooManyTest(loadRanges, tablets, "{f2=" + totalTablets + "}", maxTablets, 2);
+          runTooManyTest(loadRanges, tablets, "{f2=" + totalTablets + "}", maxTablets);
         } else {
-          runTest(loadRanges, createExtents(tablets), maxTablets, 2);
+          runTest(loadRanges, createExtents(tablets), maxTablets);
         }
       }
 
       runTest(loadRanges, createExtents(Stream.concat(requiredRows.stream(), otherRows.stream())),
-          0, 2);
+          0);
     }
 
     loadRanges.clear();
@@ -277,20 +267,20 @@ public class PrepBulkImportTest {
     loadRanges.put(nke("re", "rz"), "f4");
 
     runTooManyTest(loadRanges, Stream.of("ca", "cd", "cz", "e", "ma", "md", "mm", "re", "rz"),
-        "{f3=4}", 3, 2);
+        "{f3=4}", 3);
     runTooManyTest(loadRanges, Stream.of("b", "ca", "cd", "cz", "e", "ma", "md", "mm", "re", "rz"),
-        "{f3=4}", 3, 2);
+        "{f3=4}", 3);
     runTooManyTest(loadRanges,
         Stream.of("ca", "cd", "cz", "e", "ma", "md", "mm", "re", "rf", "rh", "rm", "rz"),
-        "{f3=4, f4=4}", 3, 2);
+        "{f3=4, f4=4}", 3);
     runTooManyTest(loadRanges,
-        Stream.of("ca", "cd", "cz", "e", "ma", "mm", "re", "rf", "rh", "rm", "rz"), "{f4=4}", 3, 2);
+        Stream.of("ca", "cd", "cz", "e", "ma", "mm", "re", "rf", "rh", "rm", "rz"), "{f4=4}", 3);
   }
 
   private void runTooManyTest(Map<KeyExtent,String> loadRanges, Stream<String> tablets,
-      String expectedMessage, int maxTablets, int skipDistance) {
+      String expectedMessage, int maxTablets) {
     var exception = assertThrows(ThriftTableOperationException.class,
-        () -> runTest(loadRanges, createExtents(tablets), maxTablets, skipDistance));
+        () -> runTest(loadRanges, createExtents(tablets), maxTablets));
     String message = exception.toString();
     assertTrue(exception.toString().contains(expectedMessage), expectedMessage + " -- " + message);
   }
