@@ -22,7 +22,6 @@ import java.util.EnumSet;
 
 import org.apache.accumulo.core.conf.AccumuloConfiguration;
 import org.apache.accumulo.core.conf.Property;
-import org.apache.commons.validator.routines.UrlValidator;
 import org.eclipse.jetty.server.AbstractConnectionFactory;
 import org.eclipse.jetty.server.HttpConnectionFactory;
 import org.eclipse.jetty.server.Server;
@@ -34,9 +33,6 @@ import org.eclipse.jetty.util.ssl.SslContextFactory;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.annotations.VisibleForTesting;
-import com.google.common.base.Preconditions;
-
 public class EmbeddedWebServer {
   private static final Logger LOG = LoggerFactory.getLogger(EmbeddedWebServer.class);
 
@@ -55,23 +51,13 @@ public class EmbeddedWebServer {
     secure = requireForSecure.stream().map(conf::get).allMatch(s -> s != null && !s.isEmpty());
 
     connector = new ServerConnector(server, getConnectionFactories(conf, secure));
-    connector.setHost(monitor.getBindAddress());
+    connector.setHost(monitor.getHostname());
     connector.setPort(port);
 
     handler =
         new ServletContextHandler(ServletContextHandler.SESSIONS | ServletContextHandler.SECURITY);
     handler.getSessionHandler().getSessionCookieConfig().setHttpOnly(true);
-    String rootContext = monitor.getConfiguration().get(Property.MONITOR_ROOT_CONTEXT);
-    // Validate URL
-    String[] scheme = {"https"};
-    UrlValidator validator = new UrlValidator(scheme);
-    Preconditions.checkArgument(validator.isValid("https://example.com" + rootContext),
-        "Root context: \"%s\" is not a valid URL", rootContext);
-    // Remove the trailing slash since jetty will warn otherwise.
-    if (rootContext.length() > 1 && rootContext.endsWith("/")) {
-      rootContext = rootContext.substring(0, rootContext.length() - 1);
-    }
-    handler.setContextPath(rootContext);
+    handler.setContextPath("/");
   }
 
   private static AbstractConnectionFactory[] getConnectionFactories(AccumuloConfiguration conf,
@@ -122,15 +108,6 @@ public class EmbeddedWebServer {
     handler.addServlet(restServlet, where);
   }
 
-  @VisibleForTesting
-  String getContextPath() {
-    return handler.getContextPath();
-  }
-
-  public String getHostName() {
-    return connector.getHost();
-  }
-
   public int getPort() {
     return connector.getLocalPort();
   }
@@ -150,7 +127,7 @@ public class EmbeddedWebServer {
     }
   }
 
-  public void stop() {
+  private void stop() {
     try {
       server.stop();
       server.join();
