@@ -18,20 +18,19 @@
  */
 package org.apache.accumulo.monitor;
 
+import static com.google.common.util.concurrent.Uninterruptibles.sleepUninterruptibly;
 import static java.nio.charset.StandardCharsets.UTF_8;
 import static java.util.concurrent.TimeUnit.HOURS;
-import static java.util.concurrent.TimeUnit.MINUTES;
-import static org.apache.accumulo.core.util.UtilWaitThread.sleepUninterruptibly;
 
 import java.net.InetAddress;
 import java.net.URL;
 import java.net.UnknownHostException;
 import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
+import java.util.Iterator;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
@@ -39,54 +38,49 @@ import java.util.Map.Entry;
 import java.util.Optional;
 import java.util.Set;
 import java.util.UUID;
+import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicLong;
-import java.util.function.Supplier;
 
 import jakarta.inject.Singleton;
 
 import org.apache.accumulo.core.Constants;
+import org.apache.accumulo.core.cli.ConfigOpts;
 import org.apache.accumulo.core.compaction.thrift.CompactionCoordinatorService;
 import org.apache.accumulo.core.compaction.thrift.TExternalCompaction;
 import org.apache.accumulo.core.compaction.thrift.TExternalCompactionList;
 import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.data.TableId;
-import org.apache.accumulo.core.fate.zookeeper.ServiceLock;
-import org.apache.accumulo.core.fate.zookeeper.ServiceLockSupport.HAServiceLockWatcher;
 import org.apache.accumulo.core.fate.zookeeper.ZooReaderWriter;
 import org.apache.accumulo.core.fate.zookeeper.ZooUtil.NodeExistsPolicy;
 import org.apache.accumulo.core.fate.zookeeper.ZooUtil.NodeMissingPolicy;
 import org.apache.accumulo.core.gc.thrift.GCMonitorService;
 import org.apache.accumulo.core.gc.thrift.GCStatus;
+import org.apache.accumulo.core.lock.ServiceLock;
+import org.apache.accumulo.core.lock.ServiceLock.LockLossReason;
+import org.apache.accumulo.core.lock.ServiceLockData;
+import org.apache.accumulo.core.lock.ServiceLockData.ThriftService;
 import org.apache.accumulo.core.manager.thrift.ManagerClientService;
 import org.apache.accumulo.core.manager.thrift.ManagerMonitorInfo;
-import org.apache.accumulo.core.master.thrift.TableInfo;
-import org.apache.accumulo.core.master.thrift.TabletServerStatus;
-import org.apache.accumulo.core.metadata.schema.ExternalCompactionId;
-import org.apache.accumulo.core.metrics.MetricsInfo;
+import org.apache.accumulo.core.manager.thrift.TableInfo;
+import org.apache.accumulo.core.manager.thrift.TabletServerStatus;
 import org.apache.accumulo.core.rpc.ThriftUtil;
 import org.apache.accumulo.core.rpc.clients.ThriftClientTypes;
+import org.apache.accumulo.core.tabletscan.thrift.ActiveScan;
+import org.apache.accumulo.core.tabletscan.thrift.TabletScanClientService;
 import org.apache.accumulo.core.tabletserver.thrift.ActiveCompaction;
-import org.apache.accumulo.core.tabletserver.thrift.ActiveScan;
-import org.apache.accumulo.core.tabletserver.thrift.TabletClientService.Client;
-import org.apache.accumulo.core.tabletserver.thrift.TabletScanClientService;
+import org.apache.accumulo.core.tabletserver.thrift.TabletServerClientService.Client;
 import org.apache.accumulo.core.trace.TraceUtil;
-import org.apache.accumulo.core.util.HostAndPort;
+import org.apache.accumulo.core.util.Halt;
 import org.apache.accumulo.core.util.Pair;
-import org.apache.accumulo.core.util.ServerServices;
-import org.apache.accumulo.core.util.ServerServices.Service;
-import org.apache.accumulo.core.util.Timer;
 import org.apache.accumulo.core.util.compaction.ExternalCompactionUtil;
 import org.apache.accumulo.core.util.threads.Threads;
 import org.apache.accumulo.monitor.rest.compactions.external.ExternalCompactionInfo;
-import org.apache.accumulo.monitor.rest.compactions.external.RunningCompactions;
-import org.apache.accumulo.monitor.rest.compactions.external.RunningCompactorDetails;
 import org.apache.accumulo.monitor.util.logging.RecentLogs;
 import org.apache.accumulo.server.AbstractServer;
 import org.apache.accumulo.server.HighlyAvailableService;
 import org.apache.accumulo.server.ServerContext;
-import org.apache.accumulo.server.ServerOpts;
 import org.apache.accumulo.server.problems.ProblemReports;
 import org.apache.accumulo.server.problems.ProblemType;
 import org.apache.accumulo.server.util.TableInfoUtil;
@@ -105,8 +99,7 @@ import org.glassfish.jersey.servlet.ServletContainer;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.base.Preconditions;
-import com.google.common.base.Suppliers;
+import com.google.common.net.HostAndPort;
 
 /**
  * Serve manager statistics with an embedded web server.
@@ -119,12 +112,12 @@ public class Monitor extends AbstractServer implements HighlyAvailableService {
   private final long START_TIME;
 
   public static void main(String[] args) throws Exception {
-    try (Monitor monitor = new Monitor(new ServerOpts(), args)) {
+    try (Monitor monitor = new Monitor(new ConfigOpts(), args)) {
       monitor.runServer();
     }
   }
 
-  Monitor(ServerOpts opts, String[] args) {
+  Monitor(ConfigOpts opts, String[] args) {
     super("monitor", opts, args);
     START_TIME = System.currentTimeMillis();
   }
@@ -181,7 +174,7 @@ public class Monitor extends AbstractServer implements HighlyAvailableService {
   private Exception problemException;
   private GCStatus gcStatus;
   private Optional<HostAndPort> coordinatorHost = Optional.empty();
-  private Timer coordinatorCheck = null;
+  private long coordinatorCheckNanos = 0L;
   private CompactionCoordinatorService.Client coordinatorClient;
   private final String coordinatorMissingMsg =
       "Error getting the compaction coordinator. Check that it is running. It is not "
@@ -199,11 +192,11 @@ public class Monitor extends AbstractServer implements HighlyAvailableService {
     Map<String,Pair<Long,Long>> samples = new HashMap<>();
     Set<String> serversUpdated = new HashSet<>();
 
-    synchronized void startingUpdates() {
+    void startingUpdates() {
       serversUpdated.clear();
     }
 
-    synchronized void updateTabletServer(String name, long sampleTime, long numEvents) {
+    void updateTabletServer(String name, long sampleTime, long numEvents) {
       Pair<Long,Long> newSample = new Pair<>(sampleTime, numEvents);
       Pair<Long,Long> lastSample = samples.get(name);
 
@@ -216,13 +209,13 @@ public class Monitor extends AbstractServer implements HighlyAvailableService {
       serversUpdated.add(name);
     }
 
-    synchronized void finishedUpdating() {
+    void finishedUpdating() {
       // remove any tablet servers not updated
       samples.keySet().retainAll(serversUpdated);
       prevSamples.keySet().retainAll(serversUpdated);
     }
 
-    synchronized double calculateRate() {
+    double calculateRate() {
       double totalRate = 0;
 
       for (Entry<String,Pair<Long,Long>> entry : prevSamples.entrySet()) {
@@ -236,7 +229,7 @@ public class Monitor extends AbstractServer implements HighlyAvailableService {
       return totalRate;
     }
 
-    synchronized long calculateCount() {
+    long calculateCount() {
       long count = 0;
 
       for (Entry<String,Pair<Long,Long>> entry : prevSamples.entrySet()) {
@@ -391,10 +384,11 @@ public class Monitor extends AbstractServer implements HighlyAvailableService {
       }
 
       // check for compaction coordinator host and only notify its discovery
-      if (coordinatorCheck == null || coordinatorCheck.hasElapsed(expirationTimeMinutes, MINUTES)) {
-        Optional<HostAndPort> previousHost = coordinatorHost;
+      Optional<HostAndPort> previousHost;
+      if (System.nanoTime() - coordinatorCheckNanos > fetchTimeNanos) {
+        previousHost = coordinatorHost;
         coordinatorHost = ExternalCompactionUtil.findCompactionCoordinator(context);
-        coordinatorCheck = Timer.startNew();
+        coordinatorCheckNanos = System.nanoTime();
         if (previousHost.isEmpty() && coordinatorHost.isPresent()) {
           log.info("External Compaction Coordinator found at {}", coordinatorHost.orElseThrow());
         }
@@ -434,8 +428,11 @@ public class Monitor extends AbstractServer implements HighlyAvailableService {
       var path = ServiceLock.path(context.getZooKeeperRoot() + Constants.ZGC_LOCK);
       List<String> locks = ServiceLock.validateAndSort(path, zk.getChildren(path.toString()));
       if (locks != null && !locks.isEmpty()) {
-        address = new ServerServices(new String(zk.getData(path + "/" + locks.get(0)), UTF_8))
-            .getAddress(Service.GC_CLIENT);
+        Optional<ServiceLockData> sld =
+            ServiceLockData.parse(zk.getData(path + "/" + locks.get(0)));
+        if (sld.isPresent()) {
+          address = sld.orElseThrow().getAddress(ThriftService.GC);
+        }
         GCMonitorService.Client client =
             ThriftUtil.getClient(ThriftClientTypes.GC, address, context);
         try {
@@ -454,10 +451,6 @@ public class Monitor extends AbstractServer implements HighlyAvailableService {
   public void run() {
     ServerContext context = getContext();
     int[] ports = getConfiguration().getPort(Property.MONITOR_PORT);
-    String rootContext = getConfiguration().get(Property.MONITOR_ROOT_CONTEXT);
-    // Needs leading slash in order to property create rest endpoint requests
-    Preconditions.checkArgument(rootContext.startsWith("/"),
-        "Root context: \"%s\" does not have a leading '/'", rootContext);
     for (int port : ports) {
       try {
         log.debug("Trying monitor on port {}", port);
@@ -476,7 +469,7 @@ public class Monitor extends AbstractServer implements HighlyAvailableService {
       throw new RuntimeException(
           "Unable to start embedded web server on ports: " + Arrays.toString(ports));
     } else {
-      log.debug("Monitor listening on {}:{}", server.getHostName(), livePort);
+      log.debug("Monitor started on port {}", livePort);
     }
 
     try {
@@ -486,40 +479,18 @@ public class Monitor extends AbstractServer implements HighlyAvailableService {
       throw new RuntimeException(e);
     }
 
-    HostAndPort advertiseAddress = getAdvertiseAddress();
-    if (advertiseAddress == null) {
-      // use the bind address from the connector, unless it's null or 0.0.0.0
-      String advertiseHost = server.getHostName();
-      if (advertiseHost == null || advertiseHost == ServerOpts.BIND_ALL_ADDRESSES) {
-        try {
-          advertiseHost = InetAddress.getLocalHost().getHostName();
-        } catch (UnknownHostException e) {
-          throw new RuntimeException("Unable to get hostname for advertise address", e);
-        }
+    String advertiseHost = getHostname();
+    if (advertiseHost.equals("0.0.0.0")) {
+      try {
+        advertiseHost = InetAddress.getLocalHost().getHostName();
+      } catch (UnknownHostException e) {
+        log.error("Unable to get hostname", e);
       }
-      updateAdvertiseAddress(HostAndPort.fromParts(advertiseHost, livePort));
-    } else {
-      updateAdvertiseAddress(HostAndPort.fromParts(advertiseAddress.getHost(), livePort));
-    }
-    HostAndPort monitorHostAndPort = getAdvertiseAddress();
-    log.debug("Using {} to advertise monitor location in ZooKeeper", monitorHostAndPort);
-    try {
-      monitorLock.replaceLockData(monitorHostAndPort.toString().getBytes(UTF_8));
-    } catch (KeeperException | InterruptedException e) {
-      throw new IllegalStateException("Exception updating monitor lock with host and port", e);
     }
+    log.debug("Using {} to advertise monitor location in ZooKeeper", advertiseHost);
 
-    MetricsInfo metricsInfo = getContext().getMetricsInfo();
-    metricsInfo.init(MetricsInfo.serviceTags(getContext().getInstanceName(), getApplicationName(),
-        monitorHostAndPort, ""));
-
-    // Needed to support the existing zk monitor address format
-    if (!rootContext.endsWith("/")) {
-      rootContext = rootContext + "/";
-    }
     try {
-      URL url = new URL(server.isSecure() ? "https" : "http", monitorHostAndPort.getHost(),
-          server.getPort(), rootContext);
+      URL url = new URL(server.isSecure() ? "https" : "http", advertiseHost, server.getPort(), "/");
       final String path = context.getZooKeeperRoot() + Constants.ZMONITOR_HTTP_ADDR;
       final ZooReaderWriter zoo = context.getZooReaderWriter();
       // Delete before we try to re-create in case the previous session hasn't yet expired
@@ -531,7 +502,7 @@ public class Monitor extends AbstractServer implements HighlyAvailableService {
     }
 
     // need to regularly fetch data so plot data is updated
-    Threads.createCriticalThread("Data fetcher", () -> {
+    Threads.createThread("Data fetcher", () -> {
       while (true) {
         try {
           fetchData();
@@ -543,22 +514,6 @@ public class Monitor extends AbstractServer implements HighlyAvailableService {
     }).start();
 
     monitorInitialized.set(true);
-
-    while (!isShutdownRequested()) {
-      if (Thread.currentThread().isInterrupted()) {
-        LOG.info("Server process thread has been interrupted, shutting down");
-        break;
-      }
-      try {
-        Thread.sleep(1000);
-      } catch (InterruptedException e) {
-        LOG.info("Interrupt Exception received, shutting down");
-        gracefulShutdown(context.rpcCreds());
-      }
-    }
-
-    server.stop();
-    log.info("stop requested. exiting ... ");
   }
 
   private ServletHolder getDefaultServlet() {
@@ -645,82 +600,95 @@ public class Monitor extends AbstractServer implements HighlyAvailableService {
     }
   }
 
-  private final long expirationTimeMinutes = 1;
-
-  // Use Suppliers.memoizeWithExpiration() to cache the results of expensive fetch operations. This
-  // avoids unnecessary repeated fetches within the expiration period and ensures that multiple
-  // requests around the same time use the same cached data.
-  private final Supplier<Map<HostAndPort,ScanStats>> tserverScansSupplier =
-      Suppliers.memoizeWithExpiration(this::fetchTServerScans, expirationTimeMinutes, MINUTES);
-
-  private final Supplier<Map<HostAndPort,ScanStats>> sserverScansSupplier =
-      Suppliers.memoizeWithExpiration(this::fetchSServerScans, expirationTimeMinutes, MINUTES);
-
-  private final Supplier<Map<HostAndPort,CompactionStats>> compactionsSupplier =
-      Suppliers.memoizeWithExpiration(this::fetchCompactions, expirationTimeMinutes, MINUTES);
-
-  private final Supplier<ExternalCompactionInfo> compactorInfoSupplier =
-      Suppliers.memoizeWithExpiration(this::fetchCompactorsInfo, expirationTimeMinutes, MINUTES);
-
-  private final Supplier<ExternalCompactionsSnapshot> externalCompactionsSupplier =
-      Suppliers.memoizeWithExpiration(this::computeExternalCompactionsSnapshot,
-          expirationTimeMinutes, MINUTES);
-
+  private final Map<HostAndPort,ScanStats> tserverScans = new HashMap<>();
+  private final Map<HostAndPort,ScanStats> sserverScans = new HashMap<>();
+  private final Map<HostAndPort,CompactionStats> allCompactions = new HashMap<>();
   private final RecentLogs recentLogs = new RecentLogs();
+  private final ExternalCompactionInfo ecInfo = new ExternalCompactionInfo();
+  private final Map<String,TExternalCompaction> ecRunningMap = new ConcurrentHashMap<>();
+  private long scansFetchedNanos = 0L;
+  private long compactsFetchedNanos = 0L;
+  private long ecInfoFetchedNanos = 0L;
+  private final long fetchTimeNanos = TimeUnit.MINUTES.toNanos(1);
+  private final long ageOffEntriesMillis = TimeUnit.MINUTES.toMillis(15);
 
   /**
-   * @return active tablet server scans. Values are cached and refresh after
-   *         {@link #expirationTimeMinutes}.
+   * Fetch the active scans but only if fetchTimeNanos has elapsed.
    */
-  public Map<HostAndPort,ScanStats> getScans() {
-    return tserverScansSupplier.get();
+  public synchronized Map<HostAndPort,ScanStats> getScans() {
+    if (System.nanoTime() - scansFetchedNanos > fetchTimeNanos) {
+      log.info("User initiated fetch of Active TabletServer Scans");
+      fetchScans();
+    }
+    return Map.copyOf(tserverScans);
+  }
+
+  public synchronized Map<HostAndPort,ScanStats> getScanServerScans() {
+    if (System.nanoTime() - scansFetchedNanos > fetchTimeNanos) {
+      log.info("User initiated fetch of Active ScanServer Scans");
+      fetchScans();
+    }
+    return Map.copyOf(sserverScans);
   }
 
   /**
-   * @return active scan server scans. Values are cached and refresh after
-   *         {@link #expirationTimeMinutes}.
+   * Fetch the active compactions but only if fetchTimeNanos has elapsed.
    */
-  public Map<HostAndPort,ScanStats> getScanServerScans() {
-    return sserverScansSupplier.get();
+  public synchronized Map<HostAndPort,CompactionStats> getCompactions() {
+    if (System.nanoTime() - compactsFetchedNanos > fetchTimeNanos) {
+      log.info("User initiated fetch of Active Compactions");
+      fetchCompactions();
+    }
+    return Map.copyOf(allCompactions);
   }
 
-  /**
-   * @return active compactions. Values are cached and refresh after {@link #expirationTimeMinutes}.
-   */
-  public Map<HostAndPort,CompactionStats> getCompactions() {
-    return compactionsSupplier.get();
-  }
-
-  /**
-   * @return external compaction information. Values are cached and refresh after
-   *         {@link #expirationTimeMinutes}.
-   */
-  public ExternalCompactionInfo getCompactorsInfo() {
+  public synchronized ExternalCompactionInfo getCompactorsInfo() {
     if (coordinatorHost.isEmpty()) {
       throw new IllegalStateException("Tried fetching from compaction coordinator that's missing");
     }
-    return compactorInfoSupplier.get();
-  }
+    if (System.nanoTime() - ecInfoFetchedNanos > fetchTimeNanos) {
+      log.info("User initiated fetch of External Compaction info");
+      Map<String,List<HostAndPort>> compactors =
+          ExternalCompactionUtil.getCompactorAddrs(getContext());
+      log.debug("Found compactors: " + compactors);
+      ecInfo.setFetchedTimeMillis(System.currentTimeMillis());
+      ecInfo.setCompactors(compactors);
+      ecInfo.setCoordinatorHost(coordinatorHost);
 
-  /**
-   * @return running compactions. Values are cached and refresh after
-   *         {@link #expirationTimeMinutes}.
-   */
-  public RunningCompactions getRunningCompactions() {
-    return externalCompactionsSupplier.get().runningCompactions;
-  }
-
-  /**
-   * @return running compactor details. Values are cached and refresh after
-   *         {@link #expirationTimeMinutes}.
-   */
-  public RunningCompactorDetails getRunningCompactorDetails(ExternalCompactionId ecid) {
-    TExternalCompaction extCompaction =
-        externalCompactionsSupplier.get().ecRunningMap.get(ecid.canonical());
-    if (extCompaction == null) {
-      return null;
+      ecInfoFetchedNanos = System.nanoTime();
     }
-    return new RunningCompactorDetails(extCompaction);
+    return ecInfo;
+  }
+
+  /**
+   * Fetch running compactions from Compaction Coordinator. Chose not to restrict the frequency of
+   * user fetches since RPC calls are going to the coordinator. This allows for fine grain updates
+   * of external compaction progress.
+   */
+  public synchronized Map<String,TExternalCompaction> fetchRunningInfo() {
+    if (coordinatorHost.isEmpty()) {
+      throw new IllegalStateException(coordinatorMissingMsg);
+    }
+    var ccHost = coordinatorHost.orElseThrow();
+    log.info("User initiated fetch of running External Compactions from " + ccHost);
+    var client = getCoordinator(ccHost);
+    TExternalCompactionList running;
+    try {
+      running = client.getRunningCompactions(TraceUtil.traceInfo(), getContext().rpcCreds());
+    } catch (Exception e) {
+      throw new IllegalStateException("Unable to get running compactions from " + ccHost, e);
+    }
+
+    ecRunningMap.clear();
+    if (running.getCompactions() != null) {
+      ecRunningMap.putAll(running.getCompactions());
+    }
+
+    return ecRunningMap;
+  }
+
+  public Map<String,TExternalCompaction> getEcRunningMap() {
+    return ecRunningMap;
   }
 
   private CompactionCoordinatorService.Client getCoordinator(HostAndPort address) {
@@ -736,36 +704,61 @@ public class Monitor extends AbstractServer implements HighlyAvailableService {
     return coordinatorClient;
   }
 
-  private Map<HostAndPort,ScanStats> fetchScans(Collection<String> servers) {
+  private void fetchScans() {
     ServerContext context = getContext();
-    Map<HostAndPort,ScanStats> scans = new HashMap<>();
-    for (String server : servers) {
+    for (String server : context.instanceOperations().getTabletServers()) {
       final HostAndPort parsedServer = HostAndPort.fromString(server);
-      TabletScanClientService.Client client = null;
+      TabletScanClientService.Client tserver = null;
       try {
-        client = ThriftUtil.getClient(ThriftClientTypes.TABLET_SCAN, parsedServer, context);
-        List<ActiveScan> activeScans = client.getActiveScans(null, context.rpcCreds());
-        scans.put(parsedServer, new ScanStats(activeScans));
+        tserver = ThriftUtil.getClient(ThriftClientTypes.TABLET_SCAN, parsedServer, context);
+        List<ActiveScan> scans = tserver.getActiveScans(null, context.rpcCreds());
+        tserverScans.put(parsedServer, new ScanStats(scans));
+        scansFetchedNanos = System.nanoTime();
       } catch (Exception ex) {
         log.error("Failed to get active scans from {}", server, ex);
       } finally {
-        ThriftUtil.returnClient(client, context);
+        ThriftUtil.returnClient(tserver, context);
+      }
+    }
+    // Age off old scan information
+    Iterator<Entry<HostAndPort,ScanStats>> tserverIter = tserverScans.entrySet().iterator();
+    // clock time used for fetched for date friendly display
+    long now = System.currentTimeMillis();
+    while (tserverIter.hasNext()) {
+      Entry<HostAndPort,ScanStats> entry = tserverIter.next();
+      if (now - entry.getValue().fetched > ageOffEntriesMillis) {
+        tserverIter.remove();
+      }
+    }
+    // Scan Servers
+    for (String server : context.instanceOperations().getScanServers()) {
+      final HostAndPort parsedServer = HostAndPort.fromString(server);
+      TabletScanClientService.Client sserver = null;
+      try {
+        sserver = ThriftUtil.getClient(ThriftClientTypes.TABLET_SCAN, parsedServer, context);
+        List<ActiveScan> scans = sserver.getActiveScans(null, context.rpcCreds());
+        sserverScans.put(parsedServer, new ScanStats(scans));
+        scansFetchedNanos = System.nanoTime();
+      } catch (Exception ex) {
+        log.error("Failed to get active scans from {}", server, ex);
+      } finally {
+        ThriftUtil.returnClient(sserver, context);
+      }
+    }
+    // Age off old scan information
+    Iterator<Entry<HostAndPort,ScanStats>> sserverIter = sserverScans.entrySet().iterator();
+    // clock time used for fetched for date friendly display
+    now = System.currentTimeMillis();
+    while (sserverIter.hasNext()) {
+      Entry<HostAndPort,ScanStats> entry = sserverIter.next();
+      if (now - entry.getValue().fetched > ageOffEntriesMillis) {
+        sserverIter.remove();
       }
     }
-    return Collections.unmodifiableMap(scans);
   }
 
-  private Map<HostAndPort,ScanStats> fetchTServerScans() {
-    return fetchScans(getContext().instanceOperations().getTabletServers());
-  }
-
-  private Map<HostAndPort,ScanStats> fetchSServerScans() {
-    return fetchScans(getContext().instanceOperations().getScanServers());
-  }
-
-  private Map<HostAndPort,CompactionStats> fetchCompactions() {
+  private void fetchCompactions() {
     ServerContext context = getContext();
-    Map<HostAndPort,CompactionStats> allCompactions = new HashMap<>();
     for (String server : context.instanceOperations().getTabletServers()) {
       final HostAndPort parsedServer = HostAndPort.fromString(server);
       Client tserver = null;
@@ -773,54 +766,25 @@ public class Monitor extends AbstractServer implements HighlyAvailableService {
         tserver = ThriftUtil.getClient(ThriftClientTypes.TABLET_SERVER, parsedServer, context);
         var compacts = tserver.getActiveCompactions(null, context.rpcCreds());
         allCompactions.put(parsedServer, new CompactionStats(compacts));
+        compactsFetchedNanos = System.nanoTime();
       } catch (Exception ex) {
         log.debug("Failed to get active compactions from {}", server, ex);
       } finally {
         ThriftUtil.returnClient(tserver, context);
       }
     }
-    return Collections.unmodifiableMap(allCompactions);
-  }
-
-  private ExternalCompactionInfo fetchCompactorsInfo() {
-    ServerContext context = getContext();
-    Map<String,List<HostAndPort>> compactors = ExternalCompactionUtil.getCompactorAddrs(context);
-    log.debug("Found compactors: {}", compactors);
-    ExternalCompactionInfo ecInfo = new ExternalCompactionInfo();
-    ecInfo.setFetchedTimeMillis(System.currentTimeMillis());
-    ecInfo.setCompactors(compactors);
-    ecInfo.setCoordinatorHost(coordinatorHost);
-    return ecInfo;
-  }
-
-  private static class ExternalCompactionsSnapshot {
-    public final RunningCompactions runningCompactions;
-    public final Map<String,TExternalCompaction> ecRunningMap;
-
-    private ExternalCompactionsSnapshot(Optional<Map<String,TExternalCompaction>> ecRunningMapOpt) {
-      this.ecRunningMap =
-          ecRunningMapOpt.map(Collections::unmodifiableMap).orElse(Collections.emptyMap());
-      this.runningCompactions = new RunningCompactions(this.ecRunningMap);
+    // Age off old compaction information
+    var entryIter = allCompactions.entrySet().iterator();
+    // clock time used for fetched for date friendly display
+    long now = System.currentTimeMillis();
+    while (entryIter.hasNext()) {
+      var entry = entryIter.next();
+      if (now - entry.getValue().fetched > ageOffEntriesMillis) {
+        entryIter.remove();
+      }
     }
   }
 
-  private ExternalCompactionsSnapshot computeExternalCompactionsSnapshot() {
-    if (coordinatorHost.isEmpty()) {
-      throw new IllegalStateException(coordinatorMissingMsg);
-    }
-    var ccHost = coordinatorHost.orElseThrow();
-    log.info("User initiated fetch of running External Compactions from " + ccHost);
-    var client = getCoordinator(ccHost);
-    TExternalCompactionList running;
-    try {
-      running = client.getRunningCompactions(TraceUtil.traceInfo(), getContext().rpcCreds());
-    } catch (Exception e) {
-      throw new IllegalStateException("Unable to get running compactions from " + ccHost, e);
-    }
-
-    return new ExternalCompactionsSnapshot(Optional.ofNullable(running.getCompactions()));
-  }
-
   /**
    * Get the monitor lock in ZooKeeper
    */
@@ -858,20 +822,19 @@ public class Monitor extends AbstractServer implements HighlyAvailableService {
 
     // Get a ZooLock for the monitor
     UUID zooLockUUID = UUID.randomUUID();
-    monitorLock = new ServiceLock(zoo.getZooKeeper(), monitorLockPath, zooLockUUID);
-    HAServiceLockWatcher monitorLockWatcher =
-        new HAServiceLockWatcher("monitor", () -> isShutdownRequested());
-
     while (true) {
-      monitorLock.lock(monitorLockWatcher, new byte[0]);
+      MoniterLockWatcher monitorLockWatcher = new MoniterLockWatcher();
+      monitorLock = new ServiceLock(zoo.getZooKeeper(), monitorLockPath, zooLockUUID);
+      monitorLock.lock(monitorLockWatcher,
+          new ServiceLockData(zooLockUUID, getHostname(), ThriftService.NONE));
 
       monitorLockWatcher.waitForChange();
 
-      if (monitorLockWatcher.isLockAcquired()) {
+      if (monitorLockWatcher.acquiredLock) {
         break;
       }
 
-      if (!monitorLockWatcher.isFailedToAcquireLock()) {
+      if (!monitorLockWatcher.failedToAcquireLock) {
         throw new IllegalStateException("monitor lock in unknown state");
       }
 
@@ -885,6 +848,57 @@ public class Monitor extends AbstractServer implements HighlyAvailableService {
     log.info("Got Monitor lock.");
   }
 
+  /**
+   * Async Watcher for monitor lock
+   */
+  private static class MoniterLockWatcher implements ServiceLock.AccumuloLockWatcher {
+
+    boolean acquiredLock = false;
+    boolean failedToAcquireLock = false;
+
+    @Override
+    public void lostLock(LockLossReason reason) {
+      Halt.halt("Monitor lock in zookeeper lost (reason = " + reason + "), exiting!", -1);
+    }
+
+    @Override
+    public void unableToMonitorLockNode(final Exception e) {
+      Halt.halt(-1, () -> log.error("No longer able to monitor Monitor lock node", e));
+
+    }
+
+    @Override
+    public synchronized void acquiredLock() {
+      if (acquiredLock || failedToAcquireLock) {
+        Halt.halt("Zoolock in unexpected state AL " + acquiredLock + " " + failedToAcquireLock, -1);
+      }
+
+      acquiredLock = true;
+      notifyAll();
+    }
+
+    @Override
+    public synchronized void failedToAcquireLock(Exception e) {
+      log.warn("Failed to get monitor lock " + e);
+
+      if (acquiredLock) {
+        Halt.halt("Zoolock in unexpected state FAL " + acquiredLock + " " + failedToAcquireLock,
+            -1);
+      }
+
+      failedToAcquireLock = true;
+      notifyAll();
+    }
+
+    public synchronized void waitForChange() {
+      while (!acquiredLock && !failedToAcquireLock) {
+        try {
+          wait();
+        } catch (InterruptedException e) {}
+      }
+    }
+  }
+
   public ManagerMonitorInfo getMmi() {
     return mmi;
   }
@@ -1001,9 +1015,4 @@ public class Monitor extends AbstractServer implements HighlyAvailableService {
   public int getLivePort() {
     return livePort;
   }
-
-  @Override
-  public ServiceLock getLock() {
-    return monitorLock;
-  }
 }
