@@ -29,6 +29,7 @@ public class StatusInformation {
   public String managerStatus = null;
   public String gcStatus = null;
   public String tServerStatus = null;
+  public String coordinatorStatus = null;
 
   public Integer logNumber = 0;
   public boolean logsHaveError = false;
@@ -39,24 +40,20 @@ public class StatusInformation {
   /**
    * Generate the status report for the services
    *
-   * @param managerStatus
-   *          Status for the manager
-   * @param gcStatus
-   *          Status for the GC
-   * @param tServerStatus
-   *          Status for the tserver
-   * @param logNumber
-   *          Number of log reports
-   * @param logsHaveError
-   *          Check if log reports include errors
-   * @param problemNumber
-   *          Number of problems per table
+   * @param managerStatus Status for the manager
+   * @param gcStatus Status for the GC
+   * @param tServerStatus Status for the tserver
+   * @param coordinatorStatus Status for the Compaction Coordinator
+   * @param logNumber Number of log reports
+   * @param logsHaveError Check if log reports include errors
+   * @param problemNumber Number of problems per table
    */
   public StatusInformation(String managerStatus, String gcStatus, String tServerStatus,
-      Integer logNumber, boolean logsHaveError, Integer problemNumber) {
+      String coordinatorStatus, Integer logNumber, boolean logsHaveError, Integer problemNumber) {
     this.managerStatus = managerStatus;
     this.gcStatus = gcStatus;
     this.tServerStatus = tServerStatus;
+    this.coordinatorStatus = coordinatorStatus;
     this.logNumber = logNumber;
     this.logsHaveError = logsHaveError;
     this.problemNumber = problemNumber;
