@@ -27,7 +27,7 @@ $(document).ready(function () {
   // Create a table for scans list
   scansList = $('#scansList').DataTable({
     "ajax": {
-      "url": contextPath + 'rest/scans',
+      "url": '/rest/scans',
       "dataSrc": "scans"
     },
     "stateSave": true,
@@ -52,7 +52,7 @@ $(document).ready(function () {
         "type": "html",
         "render": function (data, type, row, meta) {
           if (type === 'display') {
-            data = '<a href="tservers?s=' + row.server + '">' + row.server + '</a>';
+            data = '<a href="/tservers?s=' + row.server + '">' + row.server + '</a>';
           }
           return data;
         }
