@@ -18,7 +18,7 @@
  */
 package org.apache.accumulo.tserver;
 
-import static org.apache.accumulo.core.util.UtilWaitThread.sleepUninterruptibly;
+import static com.google.common.util.concurrent.Uninterruptibles.sleepUninterruptibly;
 
 import java.io.IOException;
 import java.util.ArrayList;
@@ -63,6 +63,7 @@ import org.apache.accumulo.core.iteratorsImpl.system.LocalityGroupIterator.Local
 import org.apache.accumulo.core.iteratorsImpl.system.SortedMapIterator;
 import org.apache.accumulo.core.iteratorsImpl.system.SourceSwitchingIterator;
 import org.apache.accumulo.core.iteratorsImpl.system.SourceSwitchingIterator.DataSource;
+import org.apache.accumulo.core.metadata.UnreferencedTabletFile;
 import org.apache.accumulo.core.sample.impl.SamplerConfigurationImpl;
 import org.apache.accumulo.core.sample.impl.SamplerFactory;
 import org.apache.accumulo.core.util.LocalityGroupUtil;
@@ -89,7 +90,7 @@ public class InMemoryMap {
   private final String mapType;
   private final TableId tableId;
 
-  private final Map<String,Set<ByteSequence>> lggroups;
+  private Map<String,Set<ByteSequence>> lggroups;
 
   private static Pair<SamplerConfigurationImpl,Sampler> getSampler(AccumuloConfiguration config) {
     try {
@@ -109,10 +110,10 @@ public class InMemoryMap {
   public static final String TYPE_LOCALITY_GROUP_MAP = "LocalityGroupMap";
   public static final String TYPE_LOCALITY_GROUP_MAP_NATIVE = "LocalityGroupMap with native";
 
-  private final AtomicReference<Pair<SamplerConfigurationImpl,Sampler>> samplerRef =
+  private AtomicReference<Pair<SamplerConfigurationImpl,Sampler>> samplerRef =
       new AtomicReference<>(null);
 
-  private final AccumuloConfiguration config;
+  private AccumuloConfiguration config;
 
   // defer creating sampler until first write. This was done because an empty sample map configured
   // with no sampler will not flush after a user changes sample
@@ -197,8 +198,8 @@ public class InMemoryMap {
 
   private class SampleMap implements SimpleMap {
 
-    private final SimpleMap map;
-    private final SimpleMap sample;
+    private SimpleMap map;
+    private SimpleMap sample;
 
     public SampleMap(SimpleMap map, SimpleMap sampleMap) {
       this.map = map;
@@ -279,12 +280,12 @@ public class InMemoryMap {
 
   private static class LocalityGroupMap implements SimpleMap {
 
-    private final PreAllocatedArray<Map<ByteSequence,MutableLong>> groupFams;
+    private PreAllocatedArray<Map<ByteSequence,MutableLong>> groupFams;
 
     // the last map in the array is the default locality group
-    private final SimpleMap[] maps;
-    private final Partitioner partitioner;
-    private final PreAllocatedArray<List<Mutation>> partitioned;
+    private SimpleMap[] maps;
+    private Partitioner partitioner;
+    private PreAllocatedArray<List<Mutation>> partitioned;
 
     LocalityGroupMap(Map<String,Set<ByteSequence>> groups, boolean useNativeMap) {
       this.groupFams = new PreAllocatedArray<>(groups.size());
@@ -384,8 +385,8 @@ public class InMemoryMap {
   private static class DefaultMap implements SimpleMap {
     private ConcurrentSkipListMap<Key,Value> map =
         new ConcurrentSkipListMap<>(new MemKeyComparator());
-    private final AtomicLong bytesInMemory = new AtomicLong();
-    private final AtomicInteger size = new AtomicInteger();
+    private AtomicLong bytesInMemory = new AtomicLong();
+    private AtomicInteger size = new AtomicInteger();
 
     public void put(Key key, Value value) {
       // Always a MemKey, so account for the kvCount int
@@ -447,7 +448,7 @@ public class InMemoryMap {
   }
 
   private static class NativeMapWrapper implements SimpleMap {
-    private final NativeMap nativeMap;
+    private NativeMap nativeMap;
 
     NativeMapWrapper() {
       nativeMap = new NativeMap();
@@ -482,10 +483,10 @@ public class InMemoryMap {
     }
   }
 
-  private final AtomicInteger nextKVCount = new AtomicInteger(1);
-  private final AtomicInteger kvCount = new AtomicInteger(0);
+  private AtomicInteger nextKVCount = new AtomicInteger(1);
+  private AtomicInteger kvCount = new AtomicInteger(0);
 
-  private final Object writeSerializer = new Object();
+  private Object writeSerializer = new Object();
 
   /**
    * Applies changes to a row in the InMemoryMap
@@ -536,10 +537,10 @@ public class InMemoryMap {
     private boolean switched = false;
     private InterruptibleIterator iter;
     private FileSKVIterator reader;
-    private final MemoryDataSource parent;
-    private final IteratorEnvironment env;
+    private MemoryDataSource parent;
+    private IteratorEnvironment env;
     private AtomicBoolean iflag;
-    private final SamplerConfigurationImpl iteratorSamplerConfig;
+    private SamplerConfigurationImpl iteratorSamplerConfig;
 
     private SamplerConfigurationImpl getSamplerConfig() {
       if (env != null) {
@@ -602,7 +603,8 @@ public class InMemoryMap {
 
         TableConfiguration tableConf = context.getTableConfiguration(tableId);
         reader = new RFileOperations().newReaderBuilder()
-            .forFile(memDumpFile, fs, conf, tableConf.getCryptoService())
+            .forFile(UnreferencedTabletFile.of(fs, new Path(memDumpFile)), fs, conf,
+                tableConf.getCryptoService())
             .withTableConfiguration(tableConf).seekToBeginning().build();
         if (iflag != null) {
           reader.setInterruptFlag(iflag);
@@ -657,7 +659,7 @@ public class InMemoryMap {
 
   public class MemoryIterator extends WrappingIterator implements InterruptibleIterator {
 
-    private final AtomicBoolean closed;
+    private AtomicBoolean closed;
     private SourceSwitchingIterator ssi;
     private MemoryDataSource mds;
 
@@ -783,7 +785,8 @@ public class InMemoryMap {
 
         TableConfiguration tableConf = context.getTableConfiguration(tableId);
         FileSKVWriter out = new RFileOperations().newWriterBuilder()
-            .forFile(tmpFile, fs, newConf, tableConf.getCryptoService())
+            .forFile(UnreferencedTabletFile.of(fs, new Path(tmpFile)), fs, newConf,
+                tableConf.getCryptoService())
             .withTableConfiguration(aconf).build();
 
         InterruptibleIterator iter = map.skvIterator(null);
