@@ -50,7 +50,6 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import com.google.common.annotations.VisibleForTesting;
-import com.google.common.base.Preconditions;
 
 /**
  * This class stores data in a C++ map. Doing this allows us to store more in memory and avoid
@@ -285,8 +284,8 @@ public class NativeMap implements Iterable<Map.Entry<Key,Value>> {
 
     private final AtomicLong nmiPtr = new AtomicLong(0);
     private boolean hasNext;
-    private final int expectedModCount;
-    private final int[] fieldsLens = new int[7];
+    private int expectedModCount;
+    private int[] fieldsLens = new int[7];
     private byte[] lastRow;
     private final Cleanable cleanableNMI;
 
@@ -305,8 +304,7 @@ public class NativeMap implements Iterable<Map.Entry<Key,Value>> {
       hasNext = nmiPointer != 0;
 
       nmiPtr.set(nmiPointer);
-      // avoid registering a cleanable if there's nothing to delete
-      cleanableNMI = hasNext ? NativeMapCleanerUtil.deleteNMIterator(this, nmiPtr) : null;
+      cleanableNMI = NativeMapCleanerUtil.deleteNMIterator(this, nmiPtr);
     }
 
     // delete is synchronized on a per iterator basis want to ensure only one
@@ -539,16 +537,21 @@ public class NativeMap implements Iterable<Map.Entry<Key,Value>> {
     private ConcurrentIterator iter;
     private Entry<Key,Value> entry;
 
-    private final NativeMap map;
+    private NativeMap map;
     private Range range;
     private AtomicBoolean interruptFlag;
     private int interruptCheckCount = 0;
-    private boolean seeked = false;
 
     private NMSKVIter(NativeMap map, AtomicBoolean interruptFlag) {
       this.map = map;
-      this.iter = null;
-      this.entry = null;
+      this.range = new Range();
+      iter = map.new ConcurrentIterator();
+      if (iter.hasNext()) {
+        entry = iter.next();
+      } else {
+        entry = null;
+      }
+
       this.interruptFlag = interruptFlag;
     }
 
@@ -568,12 +571,12 @@ public class NativeMap implements Iterable<Map.Entry<Key,Value>> {
 
     @Override
     public boolean hasTop() {
-      Preconditions.checkState(seeked, "seek() was never called");
       return entry != null;
     }
 
     @Override
     public void next() {
+
       if (entry == null) {
         throw new NoSuchElementException();
       }
@@ -592,6 +595,7 @@ public class NativeMap implements Iterable<Map.Entry<Key,Value>> {
       } else {
         entry = null;
       }
+
     }
 
     @Override
@@ -601,11 +605,7 @@ public class NativeMap implements Iterable<Map.Entry<Key,Value>> {
         throw new IterationInterruptedException();
       }
 
-      if (iter != null) {
-        iter.delete();
-      } else {
-        Preconditions.checkState(!seeked);
-      }
+      iter.delete();
 
       this.range = range;
 
@@ -624,7 +624,6 @@ public class NativeMap implements Iterable<Map.Entry<Key,Value>> {
         entry = null;
       }
 
-      seeked = true;
       while (hasTop() && range.beforeStartKey(getTopKey())) {
         next();
       }
