@@ -18,15 +18,13 @@
  */
 package org.apache.accumulo.tserver;
 
-import static java.nio.charset.StandardCharsets.UTF_8;
-import static org.apache.accumulo.core.util.UtilWaitThread.sleepUninterruptibly;
-import static org.apache.accumulo.core.util.threads.ThreadPoolNames.SCAN_SERVER_TABLET_METADATA_CACHE_POOL;
+import static com.google.common.util.concurrent.Uninterruptibles.sleepUninterruptibly;
 
 import java.io.IOException;
 import java.io.UncheckedIOException;
+import java.lang.reflect.InvocationTargetException;
 import java.net.UnknownHostException;
 import java.nio.ByteBuffer;
-import java.time.Duration;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
@@ -36,11 +34,11 @@ import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
 import java.util.Objects;
+import java.util.Optional;
 import java.util.Set;
 import java.util.UUID;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentSkipListSet;
-import java.util.concurrent.ThreadPoolExecutor;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicLong;
 import java.util.concurrent.locks.Condition;
@@ -49,11 +47,12 @@ import java.util.stream.Collectors;
 import java.util.stream.Stream;
 
 import org.apache.accumulo.core.Constants;
+import org.apache.accumulo.core.cli.ConfigOpts;
 import org.apache.accumulo.core.client.AccumuloException;
+import org.apache.accumulo.core.clientImpl.thrift.TInfo;
 import org.apache.accumulo.core.clientImpl.thrift.ThriftSecurityException;
 import org.apache.accumulo.core.conf.AccumuloConfiguration;
 import org.apache.accumulo.core.conf.Property;
-import org.apache.accumulo.core.conf.cluster.ClusterConfigParser;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.dataImpl.thrift.InitialMultiScan;
 import org.apache.accumulo.core.dataImpl.thrift.InitialScan;
@@ -63,37 +62,34 @@ import org.apache.accumulo.core.dataImpl.thrift.ScanResult;
 import org.apache.accumulo.core.dataImpl.thrift.TColumn;
 import org.apache.accumulo.core.dataImpl.thrift.TKeyExtent;
 import org.apache.accumulo.core.dataImpl.thrift.TRange;
-import org.apache.accumulo.core.fate.zookeeper.ServiceLock;
-import org.apache.accumulo.core.fate.zookeeper.ServiceLock.LockWatcher;
-import org.apache.accumulo.core.fate.zookeeper.ServiceLockSupport.ServiceLockWatcher;
 import org.apache.accumulo.core.fate.zookeeper.ZooCache;
 import org.apache.accumulo.core.fate.zookeeper.ZooReaderWriter;
 import org.apache.accumulo.core.fate.zookeeper.ZooUtil.NodeExistsPolicy;
 import org.apache.accumulo.core.file.blockfile.cache.impl.BlockCacheConfiguration;
+import org.apache.accumulo.core.lock.ServiceLock;
+import org.apache.accumulo.core.lock.ServiceLock.LockLossReason;
+import org.apache.accumulo.core.lock.ServiceLock.LockWatcher;
+import org.apache.accumulo.core.lock.ServiceLockData;
+import org.apache.accumulo.core.lock.ServiceLockData.ThriftService;
 import org.apache.accumulo.core.metadata.ScanServerRefTabletFile;
 import org.apache.accumulo.core.metadata.StoredTabletFile;
 import org.apache.accumulo.core.metadata.schema.Ample;
 import org.apache.accumulo.core.metadata.schema.TabletMetadata;
-import org.apache.accumulo.core.metrics.MetricsInfo;
-import org.apache.accumulo.core.process.thrift.ServerProcessService;
+import org.apache.accumulo.core.metrics.MetricsUtil;
 import org.apache.accumulo.core.securityImpl.thrift.TCredentials;
-import org.apache.accumulo.core.spi.scan.ScanServerSelector;
-import org.apache.accumulo.core.tabletserver.thrift.ActiveScan;
+import org.apache.accumulo.core.tabletscan.thrift.ActiveScan;
+import org.apache.accumulo.core.tabletscan.thrift.TSampleNotPresentException;
+import org.apache.accumulo.core.tabletscan.thrift.TSamplerConfiguration;
+import org.apache.accumulo.core.tabletscan.thrift.TabletScanClientService;
+import org.apache.accumulo.core.tabletscan.thrift.TooManyFilesException;
 import org.apache.accumulo.core.tabletserver.thrift.NoSuchScanIDException;
 import org.apache.accumulo.core.tabletserver.thrift.NotServingTabletException;
-import org.apache.accumulo.core.tabletserver.thrift.ScanServerBusyException;
-import org.apache.accumulo.core.tabletserver.thrift.TSampleNotPresentException;
-import org.apache.accumulo.core.tabletserver.thrift.TSamplerConfiguration;
-import org.apache.accumulo.core.tabletserver.thrift.TabletScanClientService;
-import org.apache.accumulo.core.tabletserver.thrift.TooManyFilesException;
-import org.apache.accumulo.core.trace.thrift.TInfo;
-import org.apache.accumulo.core.util.HostAndPort;
+import org.apache.accumulo.core.util.Halt;
 import org.apache.accumulo.core.util.UtilWaitThread;
 import org.apache.accumulo.core.util.threads.ThreadPools;
 import org.apache.accumulo.server.AbstractServer;
-import org.apache.accumulo.server.GarbageCollectionLogger;
 import org.apache.accumulo.server.ServerContext;
-import org.apache.accumulo.server.ServerOpts;
+import org.apache.accumulo.server.compaction.PausedCompactionMetrics;
 import org.apache.accumulo.server.conf.TableConfiguration;
 import org.apache.accumulo.server.fs.VolumeManager;
 import org.apache.accumulo.server.rpc.ServerAddress;
@@ -118,7 +114,6 @@ import org.checkerframework.checker.nullness.qual.Nullable;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.beust.jcommander.Parameter;
 import com.github.benmanes.caffeine.cache.CacheLoader;
 import com.github.benmanes.caffeine.cache.Caffeine;
 import com.github.benmanes.caffeine.cache.LoadingCache;
@@ -126,23 +121,10 @@ import com.github.benmanes.caffeine.cache.Scheduler;
 import com.google.common.annotations.VisibleForTesting;
 import com.google.common.base.Preconditions;
 import com.google.common.collect.Sets;
-
-import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
+import com.google.common.net.HostAndPort;
 
 public class ScanServer extends AbstractServer
-    implements TabletScanClientService.Iface, TabletHostingServer, ServerProcessService.Iface {
-
-  public static class ScanServerOpts extends ServerOpts {
-    @Parameter(required = false, names = {"-g", "--group"},
-        description = "Optional group name that will be made available to the ScanServerSelector client plugin.  If not specified will be set to '"
-            + ScanServerSelector.DEFAULT_SCAN_SERVER_GROUP_NAME
-            + "'.  Groups support at least two use cases : dedicating resources to scans and/or using different hardware for scans.")
-    private String groupName = ScanServerSelector.DEFAULT_SCAN_SERVER_GROUP_NAME;
-
-    public String getGroupName() {
-      return groupName;
-    }
-  }
+    implements TabletScanClientService.Iface, TabletHostingServer {
 
   private static final Logger log = LoggerFactory.getLogger(ScanServer.class);
 
@@ -168,8 +150,8 @@ public class ScanServer extends AbstractServer
         loadAll(Set<? extends KeyExtent> keys) {
       long t1 = System.currentTimeMillis();
       @SuppressWarnings("unchecked")
-      var tms = ample.readTablets().forTablets((Collection<KeyExtent>) keys).build().stream()
-          .collect(Collectors.toMap(tm -> tm.getExtent(), tm -> tm));
+      var tms = ample.readTablets().forTablets((Collection<KeyExtent>) keys, Optional.empty())
+          .build().stream().collect(Collectors.toMap(tm -> tm.getExtent(), tm -> tm));
       long t2 = System.currentTimeMillis();
       LOG.trace("Read metadata for {} tablets in {} ms", keys.size(), t2 - t1);
       return tms;
@@ -182,7 +164,6 @@ public class ScanServer extends AbstractServer
   private UUID serverLockUUID;
   private final TabletMetadataLoader tabletMetadataLoader;
   private final LoadingCache<KeyExtent,TabletMetadata> tabletMetadataCache;
-  private final ThreadPoolExecutor tmCacheExecutor;
   // tracks file reservations that are in the process of being added or removed from the metadata
   // table
   private final Set<StoredTabletFile> influxFiles = new HashSet<>();
@@ -202,18 +183,16 @@ public class ScanServer extends AbstractServer
   private final SessionManager sessionManager;
   private final TabletServerResourceManager resourceManager;
   HostAndPort clientAddress;
-  private final GarbageCollectionLogger gcLogger = new GarbageCollectionLogger();
 
+  private volatile boolean serverStopRequested = false;
   private ServiceLock scanServerLock;
   protected TabletServerScanMetrics scanMetrics;
-  private ScanServerMetrics scanServerMetrics;
-  private BlockCacheMetrics blockCacheMetrics;
 
-  private final ZooCache managerLockCache;
+  private ZooCache managerLockCache;
 
   private final String groupName;
 
-  public ScanServer(ScanServerOpts opts, String[] args) {
+  public ScanServer(ConfigOpts opts, String[] args) {
     super("sserver", opts, args);
 
     context = super.getContext();
@@ -238,51 +217,26 @@ public class ScanServer extends AbstractServer
         getConfiguration().getTimeInMillis(Property.SSERV_CACHED_TABLET_METADATA_EXPIRATION);
 
     long scanServerReservationExpiration =
-        getConfiguration().getTimeInMillis(Property.SSERV_SCAN_REFERENCE_EXPIRATION_TIME);
+        getConfiguration().getTimeInMillis(Property.SSERVER_SCAN_REFERENCE_EXPIRATION_TIME);
 
     tabletMetadataLoader = new TabletMetadataLoader(getContext().getAmple());
 
     if (cacheExpiration == 0L) {
       LOG.warn("Tablet metadata caching disabled, may cause excessive scans on metadata table.");
       tabletMetadataCache = null;
-      tmCacheExecutor = null;
     } else {
       if (cacheExpiration < 60000) {
         LOG.warn(
             "Tablet metadata caching less than one minute, may cause excessive scans on metadata table.");
       }
-
-      // Get the cache refresh percentage property
-      // Value must be less than 100% as 100 or over would effectively disable it
-      double cacheRefreshPercentage =
-          getConfiguration().getFraction(Property.SSERV_CACHED_TABLET_METADATA_REFRESH_PERCENT);
-      Preconditions.checkArgument(cacheRefreshPercentage < cacheExpiration,
-          "Tablet metadata cache refresh percentage is '%s' but must be less than 1",
-          cacheRefreshPercentage);
-
-      tmCacheExecutor = context.threadPools().getPoolBuilder(SCAN_SERVER_TABLET_METADATA_CACHE_POOL)
-          .numCoreThreads(8).enableThreadPoolMetrics().build();
-      var builder = Caffeine.newBuilder().expireAfterWrite(cacheExpiration, TimeUnit.MILLISECONDS)
-          .scheduler(Scheduler.systemScheduler()).executor(tmCacheExecutor).recordStats();
-      if (cacheRefreshPercentage > 0) {
-        // Compute the refresh time as a percentage of the expiration time
-        // Cache hits after this time, but before expiration, will trigger a background
-        // non-blocking refresh of the entry so future cache hits get an updated entry
-        // without having to block for a refresh
-        long cacheRefresh = (long) (cacheExpiration * cacheRefreshPercentage);
-        LOG.debug("Tablet metadata refresh percentage set to {}, refresh time set to {} ms",
-            cacheRefreshPercentage, cacheRefresh);
-        builder.refreshAfterWrite(cacheRefresh, TimeUnit.MILLISECONDS);
-      } else {
-        LOG.warn("Tablet metadata cache refresh disabled, may cause blocking on cache expiration.");
-      }
-      tabletMetadataCache = builder.build(tabletMetadataLoader);
+      tabletMetadataCache =
+          Caffeine.newBuilder().expireAfterWrite(cacheExpiration, TimeUnit.MILLISECONDS)
+              .scheduler(Scheduler.systemScheduler()).build(tabletMetadataLoader);
     }
 
     delegate = newThriftScanClientHandler(new WriteTracker());
 
-    this.groupName = Objects.requireNonNull(opts.getGroupName());
-    ClusterConfigParser.validateGroupNames(Set.of(groupName));
+    this.groupName = getConfiguration().get(Property.SSERV_GROUP_NAME);
 
     ThreadPools.watchCriticalScheduledTask(getContext().getScheduledExecutor()
         .scheduleWithFixedDelay(() -> cleanUpReservedFiles(scanServerReservationExpiration),
@@ -306,12 +260,12 @@ public class ScanServer extends AbstractServer
 
     // This class implements TabletClientService.Iface and then delegates calls. Be sure
     // to set up the ThriftProcessor using this class, not the delegate.
-    TProcessor processor = ThriftProcessorTypes.getScanServerTProcessor(this, this, getContext());
+    TProcessor processor = ThriftProcessorTypes.getScanServerTProcessor(this, getContext());
 
-    @SuppressWarnings("deprecation")
-    var maxMessageSizeProperty = getConfiguration().resolve(Property.RPC_MAX_MESSAGE_SIZE,
-        Property.GENERAL_MAX_MESSAGE_SIZE);
-    ServerAddress sp = TServerUtils.startServer(getContext(), getBindAddress(),
+    Property maxMessageSizeProperty =
+        (getConfiguration().get(Property.SSERV_MAX_MESSAGE_SIZE) != null
+            ? Property.SSERV_MAX_MESSAGE_SIZE : Property.GENERAL_MAX_MESSAGE_SIZE);
+    ServerAddress sp = TServerUtils.startServer(getContext(), getHostname(),
         Property.SSERV_CLIENTPORT, processor, this.getClass().getSimpleName(),
         "Thrift Client Server", Property.SSERV_PORTSEARCH, Property.SSERV_MINTHREADS,
         Property.SSERV_MINTHREADS_TIMEOUT, Property.SSERV_THREADCHECK, maxMessageSizeProperty);
@@ -350,17 +304,30 @@ public class ScanServer extends AbstractServer
 
       serverLockUUID = UUID.randomUUID();
       scanServerLock = new ServiceLock(zoo.getZooKeeper(), zLockPath, serverLockUUID);
-      LockWatcher lw = new ServiceLockWatcher("scan server", () -> getShutdownComplete().get(),
-          (name) -> gcLogger.logGCInfo(getConfiguration()));
 
-      // Don't use the normal ServerServices lock content, instead put the server UUID here.
-      byte[] lockContent = (serverLockUUID.toString() + "," + groupName).getBytes(UTF_8);
+      LockWatcher lw = new LockWatcher() {
+
+        @Override
+        public void lostLock(final LockLossReason reason) {
+          Halt.halt(serverStopRequested ? 0 : 1, () -> {
+            if (!serverStopRequested) {
+              LOG.error("Lost tablet server lock (reason = {}), exiting.", reason);
+            }
+            context.getLowMemoryDetector().logGCInfo(getConfiguration());
+          });
+        }
+
+        @Override
+        public void unableToMonitorLockNode(final Exception e) {
+          Halt.halt(1, () -> LOG.error("Lost ability to monitor scan server lock, exiting.", e));
+        }
+      };
 
-      // wait for 120 seconds with 5 second delay
       for (int i = 0; i < 120 / 5; i++) {
         zoo.putPersistentData(zLockPath.toString(), new byte[0], NodeExistsPolicy.SKIP);
 
-        if (scanServerLock.tryLock(lw, lockContent)) {
+        if (scanServerLock.tryLock(lw, new ServiceLockData(serverLockUUID, getClientAddressString(),
+            ThriftService.TABLET_SCAN, this.groupName))) {
           LOG.debug("Obtained scan server lock {}", scanServerLock.getLockPath());
           return scanServerLock;
         }
@@ -377,75 +344,43 @@ public class ScanServer extends AbstractServer
   }
 
   @Override
-  @SuppressFBWarnings(value = "DM_EXIT", justification = "main class can call System.exit")
   public void run() {
-
-    try {
-      waitForUpgrade();
-    } catch (InterruptedException e) {
-      LOG.error("Interrupted while waiting for upgrade to complete, exiting...");
-      System.exit(1);
-    }
-
     SecurityUtil.serverLogin(getConfiguration());
 
     ServerAddress address = null;
     try {
       address = startScanServerClientService();
-      updateAdvertiseAddress(address.getAddress());
-      clientAddress = getAdvertiseAddress();
+      clientAddress = address.getAddress();
     } catch (UnknownHostException e1) {
-      throw new RuntimeException("Failed to start the scan server client service", e1);
+      throw new RuntimeException("Failed to start the compactor client service", e1);
     }
 
-    MetricsInfo metricsInfo = getContext().getMetricsInfo();
+    try {
+      MetricsUtil.initializeMetrics(getContext().getConfiguration(), this.applicationName,
+          clientAddress);
+      scanMetrics = new TabletServerScanMetrics();
+      MetricsUtil.initializeProducers(this, scanMetrics);
+    } catch (ClassNotFoundException | InstantiationException | IllegalAccessException
+        | IllegalArgumentException | InvocationTargetException | NoSuchMethodException
+        | SecurityException e1) {
+      LOG.error("Error initializing metrics, metrics will not be emitted.", e1);
+    }
 
-    scanMetrics = new TabletServerScanMetrics(resourceManager::getOpenFiles);
-    sessionManager.setZombieCountConsumer(scanMetrics::setZombieScanThreads);
-    scanServerMetrics = new ScanServerMetrics(tabletMetadataCache);
-    blockCacheMetrics = new BlockCacheMetrics(resourceManager.getIndexCache(),
-        resourceManager.getDataCache(), resourceManager.getSummaryCache());
-
-    metricsInfo.addMetricsProducers(this, scanMetrics, scanServerMetrics, blockCacheMetrics);
-    metricsInfo.init(MetricsInfo.serviceTags(getContext().getInstanceName(), getApplicationName(),
-        clientAddress, groupName));
     // We need to set the compaction manager so that we don't get an NPE in CompactableImpl.close
 
     ServiceLock lock = announceExistence();
 
     try {
-      while (!isShutdownRequested()) {
-        if (Thread.currentThread().isInterrupted()) {
-          LOG.info("Server process thread has been interrupted, shutting down");
-          break;
-        }
-        try {
-          Thread.sleep(1000);
-          updateIdleStatus(sessionManager.getActiveScans().isEmpty()
-              && tabletMetadataCache.estimatedSize() == 0);
-        } catch (InterruptedException e) {
-          LOG.info("Interrupt Exception received, shutting down");
-          gracefulShutdown(getContext().rpcCreds());
-        }
-      }
-    } finally {
-      // Wait for scans to got to zero
-      while (!sessionManager.getActiveScans().isEmpty()) {
-        LOG.debug("Waiting on {} active scans to complete.",
-            sessionManager.getActiveScans().size());
+      while (!serverStopRequested) {
         UtilWaitThread.sleep(1000);
       }
-
-      LOG.debug("Stopping Thrift Servers");
+    } finally {
+      LOG.info("Stopping Thrift Servers");
       address.server.stop();
 
-      try {
-        LOG.debug("Removing server scan references");
-        this.getContext().getAmple().deleteScanServerFileReferences(clientAddress.toString(),
-            serverLockUUID);
-      } catch (Exception e) {
-        LOG.warn("Failed to remove scan server refs from metadata location", e);
-      }
+      LOG.info("Removing server scan references");
+      this.getContext().getAmple().deleteScanServerFileReferences(clientAddress.toString(),
+          serverLockUUID);
 
       try {
         LOG.debug("Closing filesystems");
@@ -457,14 +392,7 @@ public class ScanServer extends AbstractServer
         LOG.warn("Failed to close filesystem : {}", e.getMessage(), e);
       }
 
-      if (tmCacheExecutor != null) {
-        LOG.debug("Shutting down TabletMetadataCache executor");
-        tmCacheExecutor.shutdownNow();
-      }
-
-      gcLogger.logGCInfo(getConfiguration());
-      super.close();
-      getShutdownComplete().set(true);
+      context.getLowMemoryDetector().logGCInfo(getConfiguration());
       LOG.info("stop requested. exiting ... ");
       try {
         if (null != lock) {
@@ -571,10 +499,6 @@ public class ScanServer extends AbstractServer
         extents);
 
     Map<KeyExtent,TabletMetadata> tabletsMetadata = getTabletMetadata(extents);
-    if (!(tabletsMetadata instanceof HashMap)) {
-      // the map returned by getTabletMetadata may not be mutable
-      tabletsMetadata = new HashMap<>(tabletsMetadata);
-    }
 
     for (KeyExtent extent : extents) {
       var tabletMetadata = tabletsMetadata.get(extent);
@@ -587,6 +511,10 @@ public class ScanServer extends AbstractServer
         LOG.info("RFFS {} extent unable to load {} as AssignmentHandler returned false",
             myReservationId, extent);
         failures.add(extent);
+        if (!(tabletsMetadata instanceof HashMap)) {
+          // the map returned by getTabletMetadata may not be mutable
+          tabletsMetadata = new HashMap<>(tabletsMetadata);
+        }
         tabletsMetadata.remove(extent);
       }
     }
@@ -645,7 +573,8 @@ public class ScanServer extends AbstractServer
 
       for (StoredTabletFile file : allFiles.keySet()) {
         if (!reservedFiles.containsKey(file)) {
-          refs.add(new ScanServerRefTabletFile(serverLockUUID, serverAddress, file.getPathStr()));
+          refs.add(new ScanServerRefTabletFile(file.getNormalizedPathStr(), serverAddress,
+              serverLockUUID));
           filesToReserve.add(file);
           tabletsToCheck.add(Objects.requireNonNull(allFiles.get(file)));
           LOG.trace("RFFS {} need to add scan ref for file {}", myReservationId, file);
@@ -653,8 +582,7 @@ public class ScanServer extends AbstractServer
       }
 
       if (!filesToReserve.isEmpty()) {
-        scanServerMetrics.recordWriteOutReservationTime(
-            () -> getContext().getAmple().putScanServerFileReferences(refs));
+        getContext().getAmple().putScanServerFileReferences(refs);
 
         // After we insert the scan server refs we need to check and see if the tablet is still
         // using the file. As long as the tablet is still using the files then the Accumulo GC
@@ -671,9 +599,14 @@ public class ScanServer extends AbstractServer
         for (KeyExtent extent : tabletsToCheck) {
           TabletMetadata metadataAfter = tabletsToCheckMetadata.get(extent);
           if (metadataAfter == null) {
+            getContext().getAmple().deleteScanServerFileReferences(refs);
             LOG.info("RFFS {} extent unable to load {} as metadata no longer referencing files",
                 myReservationId, extent);
             failures.add(extent);
+            if (!(tabletsMetadata instanceof HashMap)) {
+              // the map returned by getTabletMetadata may not be mutable
+              tabletsMetadata = new HashMap<>(tabletsMetadata);
+            }
             tabletsMetadata.remove(extent);
           } else {
             // remove files that are still referenced
@@ -688,7 +621,6 @@ public class ScanServer extends AbstractServer
           LOG.info("RFFS {} tablet files changed while attempting to reference files {}",
               myReservationId, filesToReserve);
           getContext().getAmple().deleteScanServerFileReferences(refs);
-          scanServerMetrics.incrementReservationConflictCount();
           return null;
         }
       }
@@ -716,18 +648,6 @@ public class ScanServer extends AbstractServer
     }
   }
 
-  @VisibleForTesting
-  ScanReservation reserveFilesInstrumented(Map<KeyExtent,List<TRange>> extents)
-      throws AccumuloException {
-    long start = System.nanoTime();
-    try {
-      return reserveFiles(extents);
-    } finally {
-      scanServerMetrics.recordTotalReservationTime(Duration.ofNanos(System.nanoTime() - start));
-    }
-
-  }
-
   protected ScanReservation reserveFiles(Map<KeyExtent,List<TRange>> extents)
       throws AccumuloException {
 
@@ -758,18 +678,8 @@ public class ScanServer extends AbstractServer
     return new ScanReservation(tabletsMetadata, myReservationId, failures);
   }
 
-  @VisibleForTesting
-  ScanReservation reserveFilesInstrumented(long scanId) throws NoSuchScanIDException {
-    long start = System.nanoTime();
-    try {
-      return reserveFiles(scanId);
-    } finally {
-      scanServerMetrics.recordTotalReservationTime(Duration.ofNanos(System.nanoTime() - start));
-    }
-  }
-
   protected ScanReservation reserveFiles(long scanId) throws NoSuchScanIDException {
-    var session = (ScanSession<?>) sessionManager.getSession(scanId);
+    var session = (ScanSession) sessionManager.getSession(scanId);
     if (session == null) {
       throw new NoSuchScanIDException();
     }
@@ -806,7 +716,7 @@ public class ScanServer extends AbstractServer
     return new ScanReservation(scanSessionFiles, myReservationId);
   }
 
-  private static Set<StoredTabletFile> getScanSessionFiles(ScanSession<?> session) {
+  private static Set<StoredTabletFile> getScanSessionFiles(ScanSession session) {
     if (session instanceof SingleScanSession) {
       var sss = (SingleScanSession) session;
       return Set.copyOf(session.getTabletResolver().getTablet(sss.extent).getDatafiles().keySet());
@@ -848,8 +758,8 @@ public class ScanServer extends AbstractServer
             // then adding the file to influxFiles will make it wait until we finish
             influxFiles.add(file);
             confirmed.add(file);
-            refsToDelete
-                .add(new ScanServerRefTabletFile(serverLockUUID, serverAddress, file.getPathStr()));
+            refsToDelete.add(new ScanServerRefTabletFile(file.getNormalizedPathStr(), serverAddress,
+                serverLockUUID));
 
             // remove the entry from the map while holding the write lock ensuring no new
             // reservations are added to the map values while the metadata operation to delete is
@@ -945,11 +855,6 @@ public class ScanServer extends AbstractServer
     };
   }
 
-  /* Exposed for testing */
-  protected boolean isSystemUser(TCredentials creds) {
-    return context.getSecurityOperation().isSystemUser(creds);
-  }
-
   @Override
   public InitialScan startScan(TInfo tinfo, TCredentials credentials, TKeyExtent textent,
       TRange range, List<TColumn> columns, int batchSize, List<IterInfo> ssiList,
@@ -959,20 +864,9 @@ public class ScanServer extends AbstractServer
       long busyTimeout) throws ThriftSecurityException, NotServingTabletException,
       TooManyFilesException, TSampleNotPresentException, TException {
 
-    if (isShutdownRequested()) {
-      // Prevent scans from starting if shutting down
-      throw new ScanServerBusyException();
-    }
-
     KeyExtent extent = getKeyExtent(textent);
-
-    if (extent.isMeta() && !isSystemUser(credentials)) {
-      throw new TException(
-          "Only the system user can perform eventual consistency scans on the root and metadata tables");
-    }
-
     try (ScanReservation reservation =
-        reserveFilesInstrumented(Map.of(extent, Collections.singletonList(range)))) {
+        reserveFiles(Map.of(extent, Collections.singletonList(range)))) {
 
       if (reservation.getFailures().containsKey(textent)) {
         throw new NotServingTabletException(extent.toThrift());
@@ -986,9 +880,7 @@ public class ScanServer extends AbstractServer
           busyTimeout);
 
       return is;
-    } catch (ScanServerBusyException be) {
-      scanServerMetrics.incrementBusy();
-      throw be;
+
     } catch (AccumuloException | IOException e) {
       LOG.error("Error starting scan", e);
       throw new RuntimeException(e);
@@ -999,20 +891,17 @@ public class ScanServer extends AbstractServer
   public ScanResult continueScan(TInfo tinfo, long scanID, long busyTimeout)
       throws NoSuchScanIDException, NotServingTabletException, TooManyFilesException,
       TSampleNotPresentException, TException {
-    LOG.trace("continue scan: {}", scanID);
+    LOG.debug("continue scan: {}", scanID);
 
-    try (ScanReservation reservation = reserveFilesInstrumented(scanID)) {
+    try (ScanReservation reservation = reserveFiles(scanID)) {
       Preconditions.checkState(reservation.getFailures().isEmpty());
       return delegate.continueScan(tinfo, scanID, busyTimeout);
-    } catch (ScanServerBusyException be) {
-      scanServerMetrics.incrementBusy();
-      throw be;
     }
   }
 
   @Override
   public void closeScan(TInfo tinfo, long scanID) throws TException {
-    LOG.trace("close scan: {}", scanID);
+    LOG.debug("close scan: {}", scanID);
     delegate.closeScan(tinfo, scanID);
   }
 
@@ -1024,11 +913,6 @@ public class ScanServer extends AbstractServer
       Map<String,String> executionHints, long busyTimeout)
       throws ThriftSecurityException, TSampleNotPresentException, TException {
 
-    if (isShutdownRequested()) {
-      // Prevent scans from starting if shutting down
-      throw new ScanServerBusyException();
-    }
-
     if (tbatch.size() == 0) {
       throw new TException("Scan Server batch must include at least one extent");
     }
@@ -1037,16 +921,10 @@ public class ScanServer extends AbstractServer
 
     for (Entry<TKeyExtent,List<TRange>> entry : tbatch.entrySet()) {
       KeyExtent extent = getKeyExtent(entry.getKey());
-
-      if (extent.isMeta() && !context.getSecurityOperation().isSystemUser(credentials)) {
-        throw new TException(
-            "Only the system user can perform eventual consistency scans on the root and metadata tables");
-      }
-
       batch.put(extent, entry.getValue());
     }
 
-    try (ScanReservation reservation = reserveFilesInstrumented(batch)) {
+    try (ScanReservation reservation = reserveFiles(batch)) {
 
       HashMap<KeyExtent,TabletBase> tablets = new HashMap<>();
       reservation.getTabletMetadataExtents().forEach(extent -> {
@@ -1061,11 +939,8 @@ public class ScanServer extends AbstractServer
           ssio, authorizations, waitForWrites, tSamplerConfig, batchTimeOut, contextArg,
           executionHints, getBatchScanTabletResolver(tablets), busyTimeout);
 
-      LOG.trace("started scan: {}", ims.getScanID());
+      LOG.debug("started scan: {}", ims.getScanID());
       return ims;
-    } catch (ScanServerBusyException be) {
-      scanServerMetrics.incrementBusy();
-      throw be;
     } catch (TException e) {
       LOG.error("Error starting scan", e);
       throw e;
@@ -1078,20 +953,17 @@ public class ScanServer extends AbstractServer
   @Override
   public MultiScanResult continueMultiScan(TInfo tinfo, long scanID, long busyTimeout)
       throws NoSuchScanIDException, TSampleNotPresentException, TException {
-    LOG.trace("continue multi scan: {}", scanID);
+    LOG.debug("continue multi scan: {}", scanID);
 
-    try (ScanReservation reservation = reserveFilesInstrumented(scanID)) {
+    try (ScanReservation reservation = reserveFiles(scanID)) {
       Preconditions.checkState(reservation.getFailures().isEmpty());
       return delegate.continueMultiScan(tinfo, scanID, busyTimeout);
-    } catch (ScanServerBusyException be) {
-      scanServerMetrics.incrementBusy();
-      throw be;
     }
   }
 
   @Override
   public void closeMultiScan(TInfo tinfo, long scanID) throws NoSuchScanIDException, TException {
-    LOG.trace("close multi scan: {}", scanID);
+    LOG.debug("close multi scan: {}", scanID);
     delegate.closeMultiScan(tinfo, scanID);
   }
 
@@ -1121,6 +993,12 @@ public class ScanServer extends AbstractServer
     return scanMetrics;
   }
 
+  @Override
+  public PausedCompactionMetrics getPausedCompactionMetrics() {
+    // ScanServer does not perform compactions
+    return null;
+  }
+
   @Override
   public Session getSession(long scanID) {
     return sessionManager.getSession(scanID);
@@ -1141,18 +1019,13 @@ public class ScanServer extends AbstractServer
     return managerLockCache;
   }
 
-  @Override
-  public GarbageCollectionLogger getGcLogger() {
-    return gcLogger;
-  }
-
   @Override
   public BlockCacheConfiguration getBlockCacheConfiguration(AccumuloConfiguration acuConf) {
     return BlockCacheConfiguration.forScanServer(acuConf);
   }
 
   public static void main(String[] args) throws Exception {
-    try (ScanServer tserver = new ScanServer(new ScanServerOpts(), args)) {
+    try (ScanServer tserver = new ScanServer(new ConfigOpts(), args)) {
       tserver.runServer();
     }
   }
