@@ -50,6 +50,7 @@ import org.apache.accumulo.core.clientImpl.CompressedIterators;
 import org.apache.accumulo.core.clientImpl.DurabilityImpl;
 import org.apache.accumulo.core.clientImpl.TabletType;
 import org.apache.accumulo.core.clientImpl.thrift.SecurityErrorCode;
+import org.apache.accumulo.core.clientImpl.thrift.TInfo;
 import org.apache.accumulo.core.clientImpl.thrift.TableOperationExceptionType;
 import org.apache.accumulo.core.clientImpl.thrift.ThriftSecurityException;
 import org.apache.accumulo.core.clientImpl.thrift.ThriftTableOperationException;
@@ -59,7 +60,6 @@ import org.apache.accumulo.core.data.Mutation;
 import org.apache.accumulo.core.data.NamespaceId;
 import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
-import org.apache.accumulo.core.dataImpl.thrift.MapFileInfo;
 import org.apache.accumulo.core.dataImpl.thrift.TCMResult;
 import org.apache.accumulo.core.dataImpl.thrift.TCMStatus;
 import org.apache.accumulo.core.dataImpl.thrift.TConditionalMutation;
@@ -70,15 +70,15 @@ import org.apache.accumulo.core.dataImpl.thrift.TRowRange;
 import org.apache.accumulo.core.dataImpl.thrift.TSummaries;
 import org.apache.accumulo.core.dataImpl.thrift.TSummaryRequest;
 import org.apache.accumulo.core.dataImpl.thrift.UpdateErrors;
-import org.apache.accumulo.core.fate.zookeeper.ServiceLock;
 import org.apache.accumulo.core.fate.zookeeper.ZooUtil;
 import org.apache.accumulo.core.iteratorsImpl.system.IterationInterruptedException;
+import org.apache.accumulo.core.lock.ServiceLock;
 import org.apache.accumulo.core.logging.TabletLogger;
-import org.apache.accumulo.core.master.thrift.BulkImportState;
-import org.apache.accumulo.core.master.thrift.TabletServerStatus;
+import org.apache.accumulo.core.manager.thrift.BulkImportState;
+import org.apache.accumulo.core.manager.thrift.TabletServerStatus;
 import org.apache.accumulo.core.metadata.MetadataTable;
+import org.apache.accumulo.core.metadata.ReferencedTabletFile;
 import org.apache.accumulo.core.metadata.RootTable;
-import org.apache.accumulo.core.metadata.TabletFile;
 import org.apache.accumulo.core.metadata.schema.ExternalCompactionId;
 import org.apache.accumulo.core.security.Authorizations;
 import org.apache.accumulo.core.securityImpl.thrift.TCredentials;
@@ -86,18 +86,20 @@ import org.apache.accumulo.core.spi.cache.BlockCache;
 import org.apache.accumulo.core.summary.Gatherer;
 import org.apache.accumulo.core.summary.Gatherer.FileSystemResolver;
 import org.apache.accumulo.core.summary.SummaryCollection;
+import org.apache.accumulo.core.tablet.thrift.TUnloadTabletGoal;
+import org.apache.accumulo.core.tablet.thrift.TabletManagementClientService;
+import org.apache.accumulo.core.tabletingest.thrift.ConstraintViolationException;
+import org.apache.accumulo.core.tabletingest.thrift.DataFileInfo;
+import org.apache.accumulo.core.tabletingest.thrift.TDurability;
+import org.apache.accumulo.core.tabletingest.thrift.TabletIngestClientService;
 import org.apache.accumulo.core.tabletserver.thrift.ActiveCompaction;
-import org.apache.accumulo.core.tabletserver.thrift.ConstraintViolationException;
 import org.apache.accumulo.core.tabletserver.thrift.NoSuchScanIDException;
 import org.apache.accumulo.core.tabletserver.thrift.NotServingTabletException;
 import org.apache.accumulo.core.tabletserver.thrift.TCompactionQueueSummary;
-import org.apache.accumulo.core.tabletserver.thrift.TDurability;
 import org.apache.accumulo.core.tabletserver.thrift.TExternalCompactionJob;
-import org.apache.accumulo.core.tabletserver.thrift.TUnloadTabletGoal;
-import org.apache.accumulo.core.tabletserver.thrift.TabletClientService;
+import org.apache.accumulo.core.tabletserver.thrift.TabletServerClientService;
 import org.apache.accumulo.core.tabletserver.thrift.TabletStats;
 import org.apache.accumulo.core.trace.TraceUtil;
-import org.apache.accumulo.core.trace.thrift.TInfo;
 import org.apache.accumulo.core.util.ByteBufferUtil;
 import org.apache.accumulo.core.util.Halt;
 import org.apache.accumulo.core.util.Pair;
@@ -110,7 +112,7 @@ import org.apache.accumulo.server.data.ServerMutation;
 import org.apache.accumulo.server.fs.TooManyFilesException;
 import org.apache.accumulo.server.fs.VolumeManager;
 import org.apache.accumulo.server.rpc.TServerUtils;
-import org.apache.accumulo.server.security.AuditedSecurityOperation;
+import org.apache.accumulo.server.security.SecurityOperation;
 import org.apache.accumulo.server.zookeeper.TransactionWatcher;
 import org.apache.accumulo.tserver.ConditionCheckerContext.ConditionChecker;
 import org.apache.accumulo.tserver.RowLocks.RowLock;
@@ -131,12 +133,13 @@ import org.apache.zookeeper.KeeperException.NoNodeException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.cache.Cache;
+import com.github.benmanes.caffeine.cache.Cache;
 
 import io.opentelemetry.api.trace.Span;
 import io.opentelemetry.context.Scope;
 
-public class TabletClientHandler implements TabletClientService.Iface {
+public class TabletClientHandler implements TabletServerClientService.Iface,
+    TabletIngestClientService.Iface, TabletManagementClientService.Iface {
 
   private static final Logger log = LoggerFactory.getLogger(TabletClientHandler.class);
   private final long MAX_TIME_TO_WAIT_FOR_SCAN_RESULT_MILLIS;
@@ -144,7 +147,7 @@ public class TabletClientHandler implements TabletClientService.Iface {
   private final TabletServer server;
   protected final TransactionWatcher watcher;
   protected final ServerContext context;
-  protected final AuditedSecurityOperation security;
+  protected final SecurityOperation security;
   private final WriteTracker writeTracker;
   private final RowLocks rowLocks = new RowLocks();
 
@@ -160,57 +163,9 @@ public class TabletClientHandler implements TabletClientService.Iface {
     log.debug("{} created", TabletClientHandler.class.getName());
   }
 
-  @Override
-  public List<TKeyExtent> bulkImport(TInfo tinfo, TCredentials credentials, final long tid,
-      final Map<TKeyExtent,Map<String,MapFileInfo>> files, final boolean setTime)
-      throws ThriftSecurityException {
-
-    if (!security.canPerformSystemActions(credentials)) {
-      throw new ThriftSecurityException(credentials.getPrincipal(),
-          SecurityErrorCode.PERMISSION_DENIED);
-    }
-
-    try {
-      return watcher.run(Constants.BULK_ARBITRATOR_TYPE, tid, () -> {
-        List<TKeyExtent> failures = new ArrayList<>();
-
-        for (Entry<TKeyExtent,Map<String,MapFileInfo>> entry : files.entrySet()) {
-          TKeyExtent tke = entry.getKey();
-          Map<String,MapFileInfo> fileMap = entry.getValue();
-          Map<TabletFile,MapFileInfo> fileRefMap = new HashMap<>();
-          for (Entry<String,MapFileInfo> mapping : fileMap.entrySet()) {
-            Path path = new Path(mapping.getKey());
-            FileSystem ns = context.getVolumeManager().getFileSystemByPath(path);
-            path = ns.makeQualified(path);
-            fileRefMap.put(new TabletFile(path), mapping.getValue());
-          }
-
-          Tablet importTablet = server.getOnlineTablet(KeyExtent.fromThrift(tke));
-
-          if (importTablet == null) {
-            failures.add(tke);
-          } else {
-            try {
-              importTablet.importMapFiles(tid, fileRefMap, setTime);
-            } catch (IOException ioe) {
-              log.info("files {} not imported to {}: {}", fileMap.keySet(),
-                  KeyExtent.fromThrift(tke), ioe.getMessage());
-              failures.add(tke);
-            }
-          }
-        }
-        return failures;
-      });
-    } catch (RuntimeException e) {
-      throw e;
-    } catch (Exception e) {
-      throw new RuntimeException(e);
-    }
-  }
-
   @Override
   public void loadFiles(TInfo tinfo, TCredentials credentials, long tid, String dir,
-      Map<TKeyExtent,Map<String,MapFileInfo>> tabletImports, boolean setTime)
+      Map<TKeyExtent,Map<String,DataFileInfo>> tabletImports, boolean setTime)
       throws ThriftSecurityException {
     if (!security.canPerformSystemActions(credentials)) {
       throw new ThriftSecurityException(credentials.getPrincipal(),
@@ -219,15 +174,16 @@ public class TabletClientHandler implements TabletClientService.Iface {
 
     watcher.runQuietly(Constants.BULK_ARBITRATOR_TYPE, tid, () -> {
       tabletImports.forEach((tke, fileMap) -> {
-        Map<TabletFile,MapFileInfo> newFileMap = new HashMap<>();
+        Map<ReferencedTabletFile,DataFileInfo> newFileMap = new HashMap<>();
 
-        for (Entry<String,MapFileInfo> mapping : fileMap.entrySet()) {
+        for (Entry<String,DataFileInfo> mapping : fileMap.entrySet()) {
           Path path = new Path(dir, mapping.getKey());
           FileSystem ns = context.getVolumeManager().getFileSystemByPath(path);
           path = ns.makeQualified(path);
-          newFileMap.put(new TabletFile(path), mapping.getValue());
+          newFileMap.put(new ReferencedTabletFile(path), mapping.getValue());
         }
-        var files = newFileMap.keySet().stream().map(TabletFile::getPathStr).collect(toList());
+        var files = newFileMap.keySet().stream().map(ReferencedTabletFile::getNormalizedPathStr)
+            .collect(toList());
         server.updateBulkImportState(files, BulkImportState.INITIAL);
 
         Tablet importTablet = server.getOnlineTablet(KeyExtent.fromThrift(tke));
@@ -235,7 +191,7 @@ public class TabletClientHandler implements TabletClientService.Iface {
         if (importTablet != null) {
           try {
             server.updateBulkImportState(files, BulkImportState.PROCESSING);
-            importTablet.importMapFiles(tid, newFileMap, setTime);
+            importTablet.importDataFiles(tid, newFileMap, setTime);
           } catch (IOException ioe) {
             log.debug("files {} not imported to {}: {}", fileMap.keySet(),
                 KeyExtent.fromThrift(tke), ioe.getMessage());
@@ -248,13 +204,6 @@ public class TabletClientHandler implements TabletClientService.Iface {
 
   }
 
-  @Override
-  public void loadFilesV2(TInfo tinfo, TCredentials credentials, long tid, String dir,
-      Map<TKeyExtent,Map<String,MapFileInfo>> tabletImports, boolean setTime)
-      throws ThriftSecurityException {
-    loadFiles(tinfo, credentials, tid, dir, tabletImports, setTime);
-  }
-
   @Override
   public long startUpdate(TInfo tinfo, TCredentials credentials, TDurability tdurabilty)
       throws ThriftSecurityException {
@@ -263,22 +212,9 @@ public class TabletClientHandler implements TabletClientService.Iface {
     security.authenticateUser(credentials, credentials);
     server.updateMetrics.addPermissionErrors(0);
 
-    UpdateSession us = new UpdateSession(new TservConstraintEnv(server.getContext(), credentials),
-        credentials, durability) {
-      @Override
-      public boolean cleanup() {
-        // This is called when a client abandons a session. When this happens need to decrement
-        // any queued mutations.
-        if (queuedMutationSize > 0) {
-          log.trace(
-              "cleaning up abandoned update session, decrementing totalQueuedMutationSize by {}",
-              queuedMutationSize);
-          server.updateTotalQueuedMutationSize(-queuedMutationSize);
-          queuedMutationSize = 0;
-        }
-        return true;
-      }
-    };
+    UpdateSession us =
+        new UpdateSession(new TservConstraintEnv(server.getContext(), security, credentials),
+            credentials, durability);
     return server.sessionManager.createSession(us, false);
   }
 
@@ -287,8 +223,8 @@ public class TabletClientHandler implements TabletClientService.Iface {
     if (us.currentTablet != null && us.currentTablet.getExtent().equals(keyExtent)) {
       return;
     }
-    if (us.currentTablet == null && (us.failures.containsKey(keyExtent)
-        || us.authFailures.containsKey(keyExtent) || us.unhandledException != null)) {
+    if (us.currentTablet == null
+        && (us.failures.containsKey(keyExtent) || us.authFailures.containsKey(keyExtent))) {
       // if there were previous failures, then do not accept additional writes
       return;
     }
@@ -311,7 +247,7 @@ public class TabletClientHandler implements TabletClientService.Iface {
           // not serving tablet, so report all mutations as
           // failures
           us.failures.put(keyExtent, 0L);
-          server.updateMetrics.addUnknownTabletErrors(1);
+          server.updateMetrics.addUnknownTabletErrors(0);
         }
       } else {
         log.warn("Denying access to table {} for user {}", keyExtent.tableId(), us.getUser());
@@ -319,7 +255,7 @@ public class TabletClientHandler implements TabletClientService.Iface {
         us.authTimes.addStat(t2 - t1);
         us.currentTablet = null;
         us.authFailures.put(keyExtent, SecurityErrorCode.PERMISSION_DENIED);
-        server.updateMetrics.addPermissionErrors(1);
+        server.updateMetrics.addPermissionErrors(0);
       }
     } catch (TableNotFoundException tnfe) {
       log.error("Table " + tableId + " not found ", tnfe);
@@ -327,7 +263,7 @@ public class TabletClientHandler implements TabletClientService.Iface {
       us.authTimes.addStat(t2 - t1);
       us.currentTablet = null;
       us.authFailures.put(keyExtent, SecurityErrorCode.TABLE_DOESNT_EXIST);
-      server.updateMetrics.addUnknownTabletErrors(1);
+      server.updateMetrics.addUnknownTabletErrors(0);
       return;
     } catch (ThriftSecurityException e) {
       log.error("Denying permission to check user " + us.getUser() + " with user " + e.getUser(),
@@ -336,7 +272,7 @@ public class TabletClientHandler implements TabletClientService.Iface {
       us.authTimes.addStat(t2 - t1);
       us.currentTablet = null;
       us.authFailures.put(keyExtent, e.getCode());
-      server.updateMetrics.addPermissionErrors(1);
+      server.updateMetrics.addPermissionErrors(0);
       return;
     }
   }
@@ -359,11 +295,6 @@ public class TabletClientHandler implements TabletClientService.Iface {
         List<Mutation> mutations = us.queuedMutations.get(us.currentTablet);
         for (TMutation tmutation : tmutations) {
           Mutation mutation = new ServerMutation(tmutation);
-          // Deserialize the mutation in an attempt to check for data corruption that happened on
-          // the network. This will avoid writing a corrupt mutation to the write ahead log and
-          // failing after its written to the write ahead log when it is deserialized to update the
-          // in memory map.
-          mutation.getUpdates();
           mutations.add(mutation);
           additionalMutationSize += mutation.numBytes();
         }
@@ -383,15 +314,6 @@ public class TabletClientHandler implements TabletClientService.Iface {
           }
         }
       }
-    } catch (RuntimeException e) {
-      // This method is a thrift oneway method so an exception from it will not make it back to the
-      // client. Need to record the exception and set the session such that any future updates to
-      // the session are ignored.
-      us.unhandledException = e;
-      us.currentTablet = null;
-
-      // Rethrowing it will cause logging from thrift, so not adding logging here.
-      throw e;
     } finally {
       if (reserved) {
         server.sessionManager.unreserveSession(us);
@@ -450,7 +372,7 @@ public class TabletClientHandler implements TabletClientService.Iface {
 
               if (!prepared.getViolations().isEmpty()) {
                 us.violations.add(prepared.getViolations());
-                server.updateMetrics.addConstraintViolations(1);
+                server.updateMetrics.addConstraintViolations(0);
               }
               // Use the size of the original mutation list, regardless of how many mutations
               // did not violate constraints.
@@ -503,7 +425,6 @@ public class TabletClientHandler implements TabletClientService.Iface {
         }
       } catch (Exception e) {
         TraceUtil.setException(span2, e, true);
-        log.error("Error logging mutations sent from {}", TServerUtils.clientAddress.get(), e);
         throw e;
       } finally {
         span2.end();
@@ -531,10 +452,6 @@ public class TabletClientHandler implements TabletClientService.Iface {
         us.commitTimes.addStat(t2 - t1);
 
         updateAvgCommitTime(t2 - t1, sendables.size());
-      } catch (Exception e) {
-        TraceUtil.setException(span3, e, true);
-        log.error("Error committing mutations sent from {}", TServerUtils.clientAddress.get(), e);
-        throw e;
       } finally {
         span3.end();
       }
@@ -567,85 +484,57 @@ public class TabletClientHandler implements TabletClientService.Iface {
 
   @Override
   public UpdateErrors closeUpdate(TInfo tinfo, long updateID) throws NoSuchScanIDException {
-    // Reserve the session and wait for any write that may currently have it reserved. Once reserved
-    // no write stragglers can start against this session id.
-    final UpdateSession us = (UpdateSession) server.sessionManager.reserveSession(updateID, true);
+    final UpdateSession us = (UpdateSession) server.sessionManager.removeSession(updateID);
     if (us == null) {
       throw new NoSuchScanIDException();
     }
 
+    // clients may or may not see data from an update session while
+    // it is in progress, however when the update session is closed
+    // want to ensure that reads wait for the write to finish
+    long opid = writeTracker.startWrite(us.queuedMutations.keySet());
+
     try {
-      if (us.unhandledException != null) {
-        // Since flush() is not being called, any memory added to the global queued mutations
-        // counter will not be decremented. So do that here before throwing an exception.
-        server.updateTotalQueuedMutationSize(-us.queuedMutationSize);
-        us.queuedMutationSize = 0;
-        // make this memory available for GC
-        us.queuedMutations.clear();
-
-        // Something unexpected happened during this write session, so throw an exception here to
-        // cause a TApplicationException on the client side.
-        throw new IllegalStateException(
-            "Write session " + updateID + " saw an unexpected exception", us.unhandledException);
-      }
-
-      // clients may or may not see data from an update session while
-      // it is in progress, however when the update session is closed
-      // want to ensure that reads wait for the write to finish
-      long opid = writeTracker.startWrite(us.queuedMutations.keySet());
-
-      try {
-        flush(us);
-      } catch (HoldTimeoutException e) {
-        // Assumption is that the client has timed out and is gone. If that's not the case throw an
-        // exception that will cause it to retry.
-        log.debug("HoldTimeoutException during closeUpdate, reporting no such session");
-        throw new NoSuchScanIDException();
-      } finally {
-        writeTracker.finishWrite(opid);
-      }
-
-      if (log.isTraceEnabled()) {
-        log.trace(
-            String.format("UpSess %s %,d in %.3fs, at=[%s] ft=%.3fs(pt=%.3fs lt=%.3fs ct=%.3fs)",
-                TServerUtils.clientAddress.get(), us.totalUpdates,
-                (System.currentTimeMillis() - us.startTime) / 1000.0, us.authTimes,
-                us.flushTime / 1000.0, us.prepareTimes.sum() / 1000.0, us.walogTimes.sum() / 1000.0,
-                us.commitTimes.sum() / 1000.0));
-      }
-      if (!us.failures.isEmpty()) {
-        Entry<KeyExtent,Long> first = us.failures.entrySet().iterator().next();
-        log.debug(String.format("Failures: %d, first extent %s successful commits: %d",
-            us.failures.size(), first.getKey().toString(), first.getValue()));
-      }
-      List<ConstraintViolationSummary> violations = us.violations.asList();
-      if (!violations.isEmpty()) {
-        ConstraintViolationSummary first = us.violations.asList().iterator().next();
-        log.debug(String.format("Violations: %d, first %s occurs %d", violations.size(),
-            first.violationDescription, first.numberOfViolatingMutations));
-      }
-      if (!us.authFailures.isEmpty()) {
-        KeyExtent first = us.authFailures.keySet().iterator().next();
-        log.debug(String.format("Authentication Failures: %d, first %s", us.authFailures.size(),
-            first.toString()));
-      }
-      return new UpdateErrors(
-          us.failures.entrySet().stream()
-              .collect(Collectors.toMap(e -> e.getKey().toThrift(), Entry::getValue)),
-          violations.stream().map(ConstraintViolationSummary::toThrift)
-              .collect(Collectors.toList()),
-          us.authFailures.entrySet().stream()
-              .collect(Collectors.toMap(e -> e.getKey().toThrift(), Entry::getValue)));
+      flush(us);
+    } catch (HoldTimeoutException e) {
+      // Assumption is that the client has timed out and is gone. If that's not the case throw an
+      // exception that will cause it to retry.
+      log.debug("HoldTimeoutException during closeUpdate, reporting no such session");
+      throw new NoSuchScanIDException();
     } finally {
-      // Atomically unreserve and delete the session. If there any write stragglers, they will fail
-      // after this point.
-      server.sessionManager.removeSession(updateID, true);
+      writeTracker.finishWrite(opid);
     }
-  }
 
-  @Override
-  public boolean cancelUpdate(TInfo tinfo, long updateID) throws TException {
-    return server.sessionManager.removeIfNotReserved(updateID);
+    if (log.isTraceEnabled()) {
+      log.trace(
+          String.format("UpSess %s %,d in %.3fs, at=[%s] ft=%.3fs(pt=%.3fs lt=%.3fs ct=%.3fs)",
+              TServerUtils.clientAddress.get(), us.totalUpdates,
+              (System.currentTimeMillis() - us.startTime) / 1000.0, us.authTimes,
+              us.flushTime / 1000.0, us.prepareTimes.sum() / 1000.0, us.walogTimes.sum() / 1000.0,
+              us.commitTimes.sum() / 1000.0));
+    }
+    if (!us.failures.isEmpty()) {
+      Entry<KeyExtent,Long> first = us.failures.entrySet().iterator().next();
+      log.debug(String.format("Failures: %d, first extent %s successful commits: %d",
+          us.failures.size(), first.getKey().toString(), first.getValue()));
+    }
+    List<ConstraintViolationSummary> violations = us.violations.asList();
+    if (!violations.isEmpty()) {
+      ConstraintViolationSummary first = us.violations.asList().iterator().next();
+      log.debug(String.format("Violations: %d, first %s occurs %d", violations.size(),
+          first.violationDescription, first.numberOfViolatingMutations));
+    }
+    if (!us.authFailures.isEmpty()) {
+      KeyExtent first = us.authFailures.keySet().iterator().next();
+      log.debug(String.format("Authentication Failures: %d, first %s", us.authFailures.size(),
+          first.toString()));
+    }
+    return new UpdateErrors(
+        us.failures.entrySet().stream()
+            .collect(Collectors.toMap(e -> e.getKey().toThrift(), Entry::getValue)),
+        violations.stream().map(ConstraintViolationSummary::toThrift).collect(Collectors.toList()),
+        us.authFailures.entrySet().stream()
+            .collect(Collectors.toMap(e -> e.getKey().toThrift(), Entry::getValue)));
   }
 
   @Override
@@ -687,7 +576,7 @@ public class TabletClientHandler implements TabletClientService.Iface {
       Span span = TraceUtil.startSpan(this.getClass(), "update::prep");
       try (Scope scope = span.makeCurrent()) {
         prepared = tablet.prepareMutationsForCommit(
-            new TservConstraintEnv(server.getContext(), credentials), mutations);
+            new TservConstraintEnv(server.getContext(), security, credentials), mutations);
       } catch (Exception e) {
         TraceUtil.setException(span, e, true);
         throw e;
@@ -728,7 +617,6 @@ public class TabletClientHandler implements TabletClientService.Iface {
           session.commit(mutations);
         } catch (Exception e) {
           TraceUtil.setException(span3, e, true);
-          log.error("Error committing mutations sent from {}", TServerUtils.clientAddress.get(), e);
           throw e;
         } finally {
           span3.end();
@@ -751,7 +639,7 @@ public class TabletClientHandler implements TabletClientService.Iface {
 
   private void checkConditions(Map<KeyExtent,List<ServerConditionalMutation>> updates,
       ArrayList<TCMResult> results, ConditionalSession cs, List<String> symbols)
-      throws IOException, ReflectiveOperationException {
+      throws IOException {
     Iterator<Entry<KeyExtent,List<ServerConditionalMutation>>> iter = updates.entrySet().iterator();
 
     final CompressedIterators compressedIters = new CompressedIterators(symbols);
@@ -819,7 +707,7 @@ public class TabletClientHandler implements TabletClientService.Iface {
           if (!mutations.isEmpty()) {
 
             PreparedMutations prepared = tablet.prepareMutationsForCommit(
-                new TservConstraintEnv(server.getContext(), sess.credentials), mutations);
+                new TservConstraintEnv(server.getContext(), security, sess.credentials), mutations);
 
             if (prepared.tabletClosed()) {
               addMutationsAsTCMResults(results, mutations, TCMStatus.IGNORED);
@@ -885,7 +773,6 @@ public class TabletClientHandler implements TabletClientService.Iface {
       updateAvgCommitTime(t2 - t1, sendables.size());
     } catch (Exception e) {
       TraceUtil.setException(span3, e, true);
-      log.error("Error committing mutations sent from {}", TServerUtils.clientAddress.get(), e);
       throw e;
     } finally {
       span3.end();
@@ -905,7 +792,7 @@ public class TabletClientHandler implements TabletClientService.Iface {
 
   private Map<KeyExtent,List<ServerConditionalMutation>> conditionalUpdate(ConditionalSession cs,
       Map<KeyExtent,List<ServerConditionalMutation>> updates, ArrayList<TCMResult> results,
-      List<String> symbols) throws IOException, ReflectiveOperationException {
+      List<String> symbols) throws IOException {
     // sort each list of mutations, this is done to avoid deadlock and doing seeks in order is
     // more efficient and detect duplicate rows.
     ConditionalMutationSet.sortConditionalMutations(updates);
@@ -978,29 +865,27 @@ public class TabletClientHandler implements TabletClientService.Iface {
       Map<TKeyExtent,List<TConditionalMutation>> mutations, List<String> symbols)
       throws NoSuchScanIDException, TException {
 
-    ConditionalSession cs = null;
-    Long opid = null;
+    ConditionalSession cs = (ConditionalSession) server.sessionManager.reserveSession(sessID);
 
-    try {
-      cs = (ConditionalSession) server.sessionManager.reserveSession(sessID);
-      if (cs == null || cs.interruptFlag.get()) {
+    if (cs == null || cs.interruptFlag.get()) {
+      throw new NoSuchScanIDException();
+    }
+
+    if (!cs.tableId.equals(MetadataTable.ID) && !cs.tableId.equals(RootTable.ID)) {
+      try {
+        server.resourceManager.waitUntilCommitsAreEnabled();
+      } catch (HoldTimeoutException hte) {
+        // Assumption is that the client has timed out and is gone. If that's not the case throw
+        // an exception that will cause it to retry.
+        log.debug("HoldTimeoutException during conditionalUpdate, reporting no such session");
         throw new NoSuchScanIDException();
       }
+    }
 
-      if (!cs.tableId.equals(MetadataTable.ID) && !cs.tableId.equals(RootTable.ID)) {
-        try {
-          server.resourceManager.waitUntilCommitsAreEnabled();
-        } catch (HoldTimeoutException hte) {
-          // Assumption is that the client has timed out and is gone. If that's not the case throw
-          // an exception that will cause it to retry.
-          log.debug("HoldTimeoutException during conditionalUpdate, reporting no such session");
-          throw new NoSuchScanIDException();
-        }
-      }
-
-      TableId tid = cs.tableId;
-      opid = writeTracker.startWrite(TabletType.type(new KeyExtent(tid, null, null)));
+    TableId tid = cs.tableId;
+    long opid = writeTracker.startWrite(TabletType.type(new KeyExtent(tid, null, null)));
 
+    try {
       // @formatter:off
       Map<KeyExtent, List<ServerConditionalMutation>> updates = mutations.entrySet().stream().collect(Collectors.toMap(
                       entry -> KeyExtent.fromThrift(entry.getKey()),
@@ -1023,36 +908,24 @@ public class TabletClientHandler implements TabletClientService.Iface {
       }
 
       return results;
-    } catch (IOException | ReflectiveOperationException ioe) {
+    } catch (IOException ioe) {
       throw new TException(ioe);
-    } catch (Exception e) {
-      log.warn("Exception returned for conditionalUpdate {}", e);
-      throw e;
     } finally {
-      if (opid != null) {
-        writeTracker.finishWrite(opid);
-      }
-      if (cs != null) {
-        server.sessionManager.unreserveSession(sessID);
-      }
+      writeTracker.finishWrite(opid);
+      server.sessionManager.unreserveSession(sessID);
     }
   }
 
   @Override
   public void invalidateConditionalUpdate(TInfo tinfo, long sessID) {
-    // For the given session, this method should wait for any running conditional update to
-    // complete. After this method returns a conditional update should not be able to start against
-    // this session and nothing should be running.
+    // this method should wait for any running conditional update to complete
+    // after this method returns a conditional update should not be able to start
 
     ConditionalSession cs = (ConditionalSession) server.sessionManager.getSession(sessID);
     if (cs != null) {
-      // Setting this may cause anything running to fail. Setting this will prevent anything from
-      // starting.
       cs.interruptFlag.set(true);
     }
 
-    // If a thread is currently running and working on the update, then this should block until it
-    // un-reserves the session.
     cs = (ConditionalSession) server.sessionManager.reserveSession(sessID, true);
     if (cs != null) {
       server.sessionManager.removeSession(sessID, true);
@@ -1068,7 +941,7 @@ public class TabletClientHandler implements TabletClientService.Iface {
   public void splitTablet(TInfo tinfo, TCredentials credentials, TKeyExtent tkeyExtent,
       ByteBuffer splitPoint) throws NotServingTabletException, ThriftSecurityException {
 
-    TableId tableId = TableId.of(new String(ByteBufferUtil.toBytes(tkeyExtent.table), UTF_8));
+    TableId tableId = TableId.of(new String(ByteBufferUtil.toBytes(tkeyExtent.table)));
     NamespaceId namespaceId = getNamespaceId(credentials, tableId);
 
     if (!security.canSplitTablet(credentials, tableId, namespaceId)) {
@@ -1125,11 +998,16 @@ public class TabletClientHandler implements TabletClientService.Iface {
     return result;
   }
 
-  static void checkPermission(ServerContext context, TabletHostingServer server,
-      TCredentials credentials, String lock, final String request) throws ThriftSecurityException {
-    boolean canPerformSystemActions = false;
+  static void checkPermission(SecurityOperation security, ServerContext context,
+      TabletHostingServer server, TCredentials credentials, String lock, final String request)
+      throws ThriftSecurityException {
     try {
-      canPerformSystemActions = context.getSecurityOperation().canPerformSystemActions(credentials);
+      log.trace("Got {} message from user: {}", request, credentials.getPrincipal());
+      if (!security.canPerformSystemActions(credentials)) {
+        log.warn("Got {} message from user: {}", request, credentials.getPrincipal());
+        throw new ThriftSecurityException(credentials.getPrincipal(),
+            SecurityErrorCode.PERMISSION_DENIED);
+      }
     } catch (ThriftSecurityException e) {
       log.warn("Got {} message from unauthenticatable user: {}", request, e.getUser());
       if (context.getCredentials().getToken().getClass().getName()
@@ -1140,24 +1018,18 @@ public class TabletClientHandler implements TabletClientService.Iface {
       throw e;
     }
 
-    if (!canPerformSystemActions) {
-      log.warn("Denied {} request from user: {}", request, credentials.getPrincipal());
-      throw new ThriftSecurityException(credentials.getPrincipal(),
-          SecurityErrorCode.PERMISSION_DENIED);
-    }
-
     if (server.getLock() == null || !server.getLock().wasLockAcquired()) {
-      log.debug("Got {} message from user {} before my lock was acquired, ignoring...", request,
-          credentials.getPrincipal());
+      log.debug("Got {} message before my lock was acquired, ignoring...", request);
       throw new RuntimeException("Lock not acquired");
     }
 
-    log.trace("Got {} message from user: {}", request, credentials.getPrincipal());
     if (server.getLock() != null && server.getLock().wasLockAcquired()
         && !server.getLock().isLocked()) {
-      Halt.halt(1,
-          "Tablet server no longer holds lock during checkPermission() : " + request + ", exiting",
-          () -> server.getGcLogger().logGCInfo(server.getConfiguration()));
+      Halt.halt(1, () -> {
+        log.info("Tablet server no longer holds lock during checkPermission() : {}, exiting",
+            request);
+        context.getLowMemoryDetector().logGCInfo(server.getConfiguration());
+      });
     }
 
     if (lock != null) {
@@ -1186,7 +1058,7 @@ public class TabletClientHandler implements TabletClientService.Iface {
       final TKeyExtent textent) {
 
     try {
-      checkPermission(context, server, credentials, lock, "loadTablet");
+      checkPermission(security, context, server, credentials, lock, "loadTablet");
     } catch (ThriftSecurityException e) {
       log.error("Caller doesn't have permission to load a tablet", e);
       throw new RuntimeException(e);
@@ -1244,10 +1116,11 @@ public class TabletClientHandler implements TabletClientService.Iface {
     TabletLogger.loading(extent, server.getTabletSession());
 
     final AssignmentHandler ah = new AssignmentHandler(server, extent);
+    // final Runnable ah = new LoggingRunnable(log, );
     // Root tablet assignment must take place immediately
 
     if (extent.isRootTablet()) {
-      Threads.createNonCriticalThread("Root Tablet Assignment", () -> {
+      Threads.createThread("Root Tablet Assignment", () -> {
         ah.run();
         if (server.getOnlineTablets().containsKey(extent)) {
           log.info("Root tablet loaded: {}", extent);
@@ -1255,10 +1128,12 @@ public class TabletClientHandler implements TabletClientService.Iface {
           log.info("Root tablet failed to load");
         }
       }).start();
-    } else if (extent.isMeta()) {
-      server.resourceManager.addMetaDataAssignment(extent, log, ah);
     } else {
-      server.resourceManager.addAssignment(extent, log, ah);
+      if (extent.isMeta()) {
+        server.resourceManager.addMetaDataAssignment(extent, log, ah);
+      } else {
+        server.resourceManager.addAssignment(extent, log, ah);
+      }
     }
   }
 
@@ -1266,7 +1141,7 @@ public class TabletClientHandler implements TabletClientService.Iface {
   public void unloadTablet(TInfo tinfo, TCredentials credentials, String lock, TKeyExtent textent,
       TUnloadTabletGoal goal, long requestTime) {
     try {
-      checkPermission(context, server, credentials, lock, "unloadTablet");
+      checkPermission(security, context, server, credentials, lock, "unloadTablet");
     } catch (ThriftSecurityException e) {
       log.error("Caller doesn't have permission to unload a tablet", e);
       throw new RuntimeException(e);
@@ -1282,7 +1157,7 @@ public class TabletClientHandler implements TabletClientService.Iface {
   public void flush(TInfo tinfo, TCredentials credentials, String lock, String tableId,
       ByteBuffer startRow, ByteBuffer endRow) {
     try {
-      checkPermission(context, server, credentials, lock, "flush");
+      checkPermission(security, context, server, credentials, lock, "flush");
     } catch (ThriftSecurityException e) {
       log.error("Caller doesn't have permission to flush a table", e);
       throw new RuntimeException(e);
@@ -1315,7 +1190,7 @@ public class TabletClientHandler implements TabletClientService.Iface {
   @Override
   public void flushTablet(TInfo tinfo, TCredentials credentials, String lock, TKeyExtent textent) {
     try {
-      checkPermission(context, server, credentials, lock, "flushTablet");
+      checkPermission(security, context, server, credentials, lock, "flushTablet");
     } catch (ThriftSecurityException e) {
       log.error("Caller doesn't have permission to flush a tablet", e);
       throw new RuntimeException(e);
@@ -1337,10 +1212,11 @@ public class TabletClientHandler implements TabletClientService.Iface {
   public void halt(TInfo tinfo, TCredentials credentials, String lock)
       throws ThriftSecurityException {
 
-    checkPermission(context, server, credentials, lock, "halt");
+    checkPermission(security, context, server, credentials, lock, "halt");
 
-    Halt.halt(0, "Manager requested tablet server halt", () -> {
-      server.gcLogger.logGCInfo(server.getConfiguration());
+    Halt.halt(0, () -> {
+      log.info("Manager requested tablet server halt");
+      context.getLowMemoryDetector().logGCInfo(server.getConfiguration());
       server.requestStop();
       try {
         server.getLock().unlock();
@@ -1367,7 +1243,7 @@ public class TabletClientHandler implements TabletClientService.Iface {
   @Override
   public void chop(TInfo tinfo, TCredentials credentials, String lock, TKeyExtent textent) {
     try {
-      checkPermission(context, server, credentials, lock, "chop");
+      checkPermission(security, context, server, credentials, lock, "chop");
     } catch (ThriftSecurityException e) {
       log.error("Caller doesn't have permission to chop extent", e);
       throw new RuntimeException(e);
@@ -1385,7 +1261,7 @@ public class TabletClientHandler implements TabletClientService.Iface {
   public void compact(TInfo tinfo, TCredentials credentials, String lock, String tableId,
       ByteBuffer startRow, ByteBuffer endRow) {
     try {
-      checkPermission(context, server, credentials, lock, "compact");
+      checkPermission(security, context, server, credentials, lock, "compact");
     } catch (ThriftSecurityException e) {
       log.error("Caller doesn't have permission to compact a table", e);
       throw new RuntimeException(e);
@@ -1417,7 +1293,7 @@ public class TabletClientHandler implements TabletClientService.Iface {
   public List<ActiveCompaction> getActiveCompactions(TInfo tinfo, TCredentials credentials)
       throws ThriftSecurityException, TException {
     try {
-      checkPermission(context, server, credentials, null, "getActiveCompactions");
+      checkPermission(security, context, server, credentials, null, "getActiveCompactions");
     } catch (ThriftSecurityException e) {
       log.error("Caller doesn't have permission to get active compactions", e);
       throw e;
