@@ -18,20 +18,20 @@
  */
 package org.apache.accumulo.tserver;
 
-import static java.nio.charset.StandardCharsets.UTF_8;
+import static com.google.common.util.concurrent.Uninterruptibles.sleepUninterruptibly;
 import static org.apache.accumulo.core.metadata.schema.TabletMetadata.ColumnType.ECOMP;
 import static org.apache.accumulo.core.metadata.schema.TabletMetadata.ColumnType.FILES;
 import static org.apache.accumulo.core.metadata.schema.TabletMetadata.ColumnType.LOGS;
 import static org.apache.accumulo.core.metadata.schema.TabletMetadata.ColumnType.PREV_ROW;
-import static org.apache.accumulo.core.util.UtilWaitThread.sleepUninterruptibly;
+import static org.apache.accumulo.core.util.LazySingletons.RANDOM;
 import static org.apache.accumulo.core.util.threads.ThreadPools.watchCriticalFixedDelay;
 import static org.apache.accumulo.core.util.threads.ThreadPools.watchCriticalScheduledTask;
 import static org.apache.accumulo.core.util.threads.ThreadPools.watchNonCriticalScheduledTask;
 
 import java.io.IOException;
 import java.lang.management.ManagementFactory;
+import java.lang.reflect.InvocationTargetException;
 import java.net.UnknownHostException;
-import java.security.SecureRandom;
 import java.time.Duration;
 import java.time.Instant;
 import java.util.ArrayList;
@@ -46,6 +46,7 @@ import java.util.LinkedHashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
+import java.util.Optional;
 import java.util.Set;
 import java.util.SortedMap;
 import java.util.SortedSet;
@@ -62,9 +63,9 @@ import java.util.concurrent.atomic.AtomicInteger;
 import java.util.concurrent.atomic.AtomicLong;
 import java.util.concurrent.locks.ReentrantLock;
 import java.util.function.Consumer;
-import java.util.function.Supplier;
 
 import org.apache.accumulo.core.Constants;
+import org.apache.accumulo.core.cli.ConfigOpts;
 import org.apache.accumulo.core.client.Durability;
 import org.apache.accumulo.core.clientImpl.DurabilityImpl;
 import org.apache.accumulo.core.clientImpl.TabletLocator;
@@ -73,24 +74,27 @@ import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.data.InstanceId;
 import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
-import org.apache.accumulo.core.fate.zookeeper.ServiceLock;
-import org.apache.accumulo.core.fate.zookeeper.ServiceLock.LockWatcher;
-import org.apache.accumulo.core.fate.zookeeper.ServiceLockSupport.ServiceLockWatcher;
 import org.apache.accumulo.core.fate.zookeeper.ZooCache;
 import org.apache.accumulo.core.fate.zookeeper.ZooReaderWriter;
 import org.apache.accumulo.core.fate.zookeeper.ZooUtil.NodeExistsPolicy;
 import org.apache.accumulo.core.file.blockfile.cache.impl.BlockCacheConfiguration;
+import org.apache.accumulo.core.lock.ServiceLock;
+import org.apache.accumulo.core.lock.ServiceLock.LockLossReason;
+import org.apache.accumulo.core.lock.ServiceLock.LockWatcher;
+import org.apache.accumulo.core.lock.ServiceLockData;
+import org.apache.accumulo.core.lock.ServiceLockData.ServiceDescriptor;
+import org.apache.accumulo.core.lock.ServiceLockData.ServiceDescriptors;
+import org.apache.accumulo.core.lock.ServiceLockData.ThriftService;
+import org.apache.accumulo.core.manager.thrift.BulkImportState;
+import org.apache.accumulo.core.manager.thrift.Compacting;
 import org.apache.accumulo.core.manager.thrift.ManagerClientService;
-import org.apache.accumulo.core.master.thrift.BulkImportState;
-import org.apache.accumulo.core.master.thrift.Compacting;
-import org.apache.accumulo.core.master.thrift.TableInfo;
-import org.apache.accumulo.core.master.thrift.TabletServerStatus;
+import org.apache.accumulo.core.manager.thrift.TableInfo;
+import org.apache.accumulo.core.manager.thrift.TabletServerStatus;
 import org.apache.accumulo.core.metadata.MetadataTable;
 import org.apache.accumulo.core.metadata.RootTable;
 import org.apache.accumulo.core.metadata.TServerInstance;
 import org.apache.accumulo.core.metadata.schema.TabletsMetadata;
-import org.apache.accumulo.core.metrics.MetricsInfo;
-import org.apache.accumulo.core.process.thrift.ServerProcessService;
+import org.apache.accumulo.core.metrics.MetricsUtil;
 import org.apache.accumulo.core.rpc.ThriftUtil;
 import org.apache.accumulo.core.rpc.clients.ThriftClientTypes;
 import org.apache.accumulo.core.spi.fs.VolumeChooserEnvironment;
@@ -98,23 +102,19 @@ import org.apache.accumulo.core.tabletserver.log.LogEntry;
 import org.apache.accumulo.core.trace.TraceUtil;
 import org.apache.accumulo.core.util.ComparablePair;
 import org.apache.accumulo.core.util.Halt;
-import org.apache.accumulo.core.util.HostAndPort;
 import org.apache.accumulo.core.util.MapCounter;
 import org.apache.accumulo.core.util.Pair;
 import org.apache.accumulo.core.util.Retry;
 import org.apache.accumulo.core.util.Retry.RetryFactory;
-import org.apache.accumulo.core.util.ServerServices;
-import org.apache.accumulo.core.util.ServerServices.Service;
 import org.apache.accumulo.core.util.UtilWaitThread;
 import org.apache.accumulo.core.util.threads.ThreadPools;
 import org.apache.accumulo.core.util.threads.Threads;
 import org.apache.accumulo.server.AbstractServer;
-import org.apache.accumulo.server.GarbageCollectionLogger;
 import org.apache.accumulo.server.ServerContext;
-import org.apache.accumulo.server.ServerOpts;
 import org.apache.accumulo.server.TabletLevel;
 import org.apache.accumulo.server.client.ClientServiceHandler;
 import org.apache.accumulo.server.compaction.CompactionWatcher;
+import org.apache.accumulo.server.compaction.PausedCompactionMetrics;
 import org.apache.accumulo.server.conf.TableConfiguration;
 import org.apache.accumulo.server.fs.VolumeChooserEnvironmentImpl;
 import org.apache.accumulo.server.fs.VolumeManager;
@@ -125,9 +125,9 @@ import org.apache.accumulo.server.manager.recovery.RecoveryPath;
 import org.apache.accumulo.server.rpc.ServerAddress;
 import org.apache.accumulo.server.rpc.TServerUtils;
 import org.apache.accumulo.server.rpc.ThriftProcessorTypes;
+import org.apache.accumulo.server.security.SecurityOperation;
 import org.apache.accumulo.server.security.SecurityUtil;
 import org.apache.accumulo.server.security.delegation.ZooAuthenticationKeyWatcher;
-import org.apache.accumulo.server.util.FileSystemMonitor;
 import org.apache.accumulo.server.util.ServerBulkImportStatus;
 import org.apache.accumulo.server.util.time.RelativeTime;
 import org.apache.accumulo.server.zookeeper.DistributedWorkQueue;
@@ -166,19 +166,17 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import com.google.common.annotations.VisibleForTesting;
+import com.google.common.collect.Iterators;
+import com.google.common.net.HostAndPort;
 
 import io.opentelemetry.api.trace.Span;
 import io.opentelemetry.context.Scope;
 
-public class TabletServer extends AbstractServer
-    implements TabletHostingServer, ServerProcessService.Iface {
+public class TabletServer extends AbstractServer implements TabletHostingServer {
 
-  private static final SecureRandom random = new SecureRandom();
   private static final Logger log = LoggerFactory.getLogger(TabletServer.class);
-  private static final long TIME_BETWEEN_GC_CHECKS = TimeUnit.SECONDS.toMillis(5);
   private static final long TIME_BETWEEN_LOCATOR_CACHE_CLEARS = TimeUnit.HOURS.toMillis(1);
 
-  final GarbageCollectionLogger gcLogger = new GarbageCollectionLogger();
   final ZooCache managerLockCache;
 
   final TabletServerLogger logger;
@@ -188,7 +186,7 @@ public class TabletServer extends AbstractServer
   TabletServerScanMetrics scanMetrics;
   TabletServerMinCMetrics mincMetrics;
   CompactionExecutorsMetrics ceMetrics;
-  BlockCacheMetrics blockCacheMetrics;
+  PausedCompactionMetrics pausedMetrics;
 
   @Override
   public TabletServerScanMetrics getScanMetrics() {
@@ -199,9 +197,12 @@ public class TabletServer extends AbstractServer
     return mincMetrics;
   }
 
+  @Override
+  public PausedCompactionMetrics getPausedCompactionMetrics() {
+    return pausedMetrics;
+  }
+
   private final LogSorter logSorter;
-  @SuppressWarnings("deprecation")
-  private org.apache.accumulo.tserver.replication.ReplicationWorker replWorker = null;
   final TabletStatsKeeper statsKeeper;
   private final AtomicInteger logIdGenerator = new AtomicInteger();
 
@@ -214,15 +215,20 @@ public class TabletServer extends AbstractServer
   final Map<KeyExtent,Long> recentlyUnloadedCache = Collections.synchronizedMap(new LRUMap<>(1000));
 
   final TabletServerResourceManager resourceManager;
+  private final SecurityOperation security;
 
   private final BlockingDeque<ManagerMessage> managerMessages = new LinkedBlockingDeque<>();
 
   volatile HostAndPort clientAddress;
 
+  private volatile boolean serverStopRequested = false;
+  private volatile boolean shutdownComplete = false;
+
   private ServiceLock tabletServerLock;
 
   private TServer server;
-  private volatile TServer replServer;
+
+  private DistributedWorkQueue bulkFailedCopyQ;
 
   private String lockID;
   private volatile long lockSessionId = -1;
@@ -236,12 +242,12 @@ public class TabletServer extends AbstractServer
   private final ServerContext context;
 
   public static void main(String[] args) throws Exception {
-    try (TabletServer tserver = new TabletServer(new ServerOpts(), args)) {
+    try (TabletServer tserver = new TabletServer(new ConfigOpts(), args)) {
       tserver.runServer();
     }
   }
 
-  protected TabletServer(ServerOpts opts, String[] args) {
+  protected TabletServer(ConfigOpts opts, String[] args) {
     super("tserver", opts, args);
     context = super.getContext();
     this.managerLockCache = new ZooCache(context.getZooReader(), null);
@@ -250,9 +256,6 @@ public class TabletServer extends AbstractServer
     log.info("Instance " + getInstanceID());
     this.sessionManager = new SessionManager(context);
     this.logSorter = new LogSorter(context, aconf);
-    @SuppressWarnings("deprecation")
-    var replWorker = new org.apache.accumulo.tserver.replication.ReplicationWorker(this);
-    this.replWorker = replWorker;
     this.statsKeeper = new TabletStatsKeeper();
     final int numBusyTabletsToLog = aconf.getCount(Property.TSERV_LOG_BUSY_TABLETS_COUNT);
     final long logBusyTabletsDelay =
@@ -267,9 +270,9 @@ public class TabletServer extends AbstractServer
     if (numBusyTabletsToLog > 0) {
       ScheduledFuture<?> future = context.getScheduledExecutor()
           .scheduleWithFixedDelay(Threads.createNamedRunnable("BusyTabletLogger", new Runnable() {
-            private final BusiestTracker ingestTracker =
+            private BusiestTracker ingestTracker =
                 BusiestTracker.newBusiestIngestTracker(numBusyTabletsToLog);
-            private final BusiestTracker queryTracker =
+            private BusiestTracker queryTracker =
                 BusiestTracker.newBusiestQueryTracker(numBusyTabletsToLog);
 
             @Override
@@ -306,24 +309,8 @@ public class TabletServer extends AbstractServer
         }), 5, 5, TimeUnit.SECONDS);
     watchNonCriticalScheduledTask(future);
 
-    ScheduledFuture<?> cleanupTask =
-        context.getScheduledExecutor().scheduleWithFixedDelay(Threads.createNamedRunnable(
-            "ScanRefCleanupTask", () -> getOnlineTablets().values().forEach(tablet -> {
-              try {
-                tablet.removeBatchedScanRefs();
-              } catch (Exception e) {
-                log.error("Error cleaning up stale scan references for tablet {}",
-                    tablet.getExtent(), e);
-              }
-            })), 5, 5, TimeUnit.MINUTES);
-    watchNonCriticalScheduledTask(cleanupTask);
-
-    @SuppressWarnings("deprecation")
-    final long walMaxSize =
-        aconf.getAsBytes(aconf.resolve(Property.TSERV_WAL_MAX_SIZE, Property.TSERV_WALOG_MAX_SIZE));
-    @SuppressWarnings("deprecation")
-    final long walMaxAge = aconf
-        .getTimeInMillis(aconf.resolve(Property.TSERV_WAL_MAX_AGE, Property.TSERV_WALOG_MAX_AGE));
+    final long walMaxSize = aconf.getAsBytes(Property.TSERV_WAL_MAX_SIZE);
+    final long walMaxAge = aconf.getTimeInMillis(Property.TSERV_WAL_MAX_AGE);
     final long minBlockSize =
         context.getHadoopConf().getLong("dfs.namenode.fs-limits.min-block-size", 0);
     if (minBlockSize != 0 && minBlockSize > walMaxSize) {
@@ -333,18 +320,12 @@ public class TabletServer extends AbstractServer
           + " or decrease dfs.namenode.fs-limits.min-block-size in hdfs-site.xml.");
     }
 
-    @SuppressWarnings("deprecation")
     final long toleratedWalCreationFailures =
-        aconf.getCount(aconf.resolve(Property.TSERV_WAL_TOLERATED_CREATION_FAILURES,
-            Property.TSERV_WALOG_TOLERATED_CREATION_FAILURES));
-    @SuppressWarnings("deprecation")
+        aconf.getCount(Property.TSERV_WAL_TOLERATED_CREATION_FAILURES);
     final long walFailureRetryIncrement =
-        aconf.getTimeInMillis(aconf.resolve(Property.TSERV_WAL_TOLERATED_WAIT_INCREMENT,
-            Property.TSERV_WALOG_TOLERATED_WAIT_INCREMENT));
-    @SuppressWarnings("deprecation")
+        aconf.getTimeInMillis(Property.TSERV_WAL_TOLERATED_WAIT_INCREMENT);
     final long walFailureRetryMax =
-        aconf.getTimeInMillis(aconf.resolve(Property.TSERV_WAL_TOLERATED_MAXIMUM_WAIT_DURATION,
-            Property.TSERV_WALOG_TOLERATED_MAXIMUM_WAIT_DURATION));
+        aconf.getTimeInMillis(Property.TSERV_WAL_TOLERATED_MAXIMUM_WAIT_DURATION);
     final RetryFactory walCreationRetryFactory =
         Retry.builder().maxRetries(toleratedWalCreationFailures)
             .retryAfter(walFailureRetryIncrement, TimeUnit.MILLISECONDS)
@@ -362,6 +343,7 @@ public class TabletServer extends AbstractServer
     logger = new TabletServerLogger(this, walMaxSize, syncCounter, flushCounter,
         walCreationRetryFactory, walWritingRetryFactory, walMaxAge);
     this.resourceManager = new TabletServerResourceManager(context, this);
+    this.security = context.getSecurityOperation();
 
     watchCriticalScheduledTask(context.getScheduledExecutor().scheduleWithFixedDelay(
         TabletLocator::clearLocators, jitter(), jitter(), TimeUnit.MILLISECONDS));
@@ -389,7 +371,7 @@ public class TabletServer extends AbstractServer
 
   private static long jitter() {
     // add a random 10% wait
-    return (long) ((1. + (random.nextDouble() / 10))
+    return (long) ((1. + (RANDOM.get().nextDouble() / 10))
         * TabletServer.TIME_BETWEEN_LOCATOR_CACHE_CLEARS);
   }
 
@@ -409,7 +391,7 @@ public class TabletServer extends AbstractServer
 
   void requestStop() {
     log.info("Stop requested.");
-    gracefulShutdown(getContext().rpcCreds());
+    serverStopRequested = true;
   }
 
   private class SplitRunner implements Runnable {
@@ -426,12 +408,7 @@ public class TabletServer extends AbstractServer
   }
 
   public long updateTotalQueuedMutationSize(long additionalMutationSize) {
-    var newTotal = totalQueuedMutationSize.addAndGet(additionalMutationSize);
-    if (log.isTraceEnabled()) {
-      log.trace("totalQueuedMutationSize is now {} after adding {}", newTotal,
-          additionalMutationSize);
-    }
-    return newTotal;
+    return totalQueuedMutationSize.addAndGet(additionalMutationSize);
   }
 
   @Override
@@ -496,8 +473,7 @@ public class TabletServer extends AbstractServer
     }
   }
 
-  protected TreeMap<KeyExtent,TabletData> splitTablet(Tablet tablet, byte[] splitPoint)
-      throws IOException {
+  TreeMap<KeyExtent,TabletData> splitTablet(Tablet tablet, byte[] splitPoint) throws IOException {
     long t1 = System.currentTimeMillis();
 
     TreeMap<KeyExtent,TabletData> tabletInfo = tablet.split(splitPoint);
@@ -558,17 +534,16 @@ public class TabletServer extends AbstractServer
     }
   }
 
-  private ServerAddress startServer(String address, TProcessor processor)
+  private HostAndPort startServer(AccumuloConfiguration conf, String address, TProcessor processor)
       throws UnknownHostException {
-    @SuppressWarnings("deprecation")
-    var maxMessageSizeProperty = getConfiguration().resolve(Property.RPC_MAX_MESSAGE_SIZE,
-        Property.TSERV_MAX_MESSAGE_SIZE, Property.GENERAL_MAX_MESSAGE_SIZE);
+    Property maxMessageSizeProperty = (conf.get(Property.TSERV_MAX_MESSAGE_SIZE) != null
+        ? Property.TSERV_MAX_MESSAGE_SIZE : Property.GENERAL_MAX_MESSAGE_SIZE);
     ServerAddress sp = TServerUtils.startServer(getContext(), address, Property.TSERV_CLIENTPORT,
         processor, this.getClass().getSimpleName(), "Thrift Client Server",
         Property.TSERV_PORTSEARCH, Property.TSERV_MINTHREADS, Property.TSERV_MINTHREADS_TIMEOUT,
         Property.TSERV_THREADCHECK, maxMessageSizeProperty);
     this.server = sp.server;
-    return sp;
+    return sp.address;
   }
 
   private HostAndPort getManagerAddress() {
@@ -617,7 +592,7 @@ public class TabletServer extends AbstractServer
     ThriftUtil.returnClient(client, context);
   }
 
-  private ServerAddress startTabletClientService() throws UnknownHostException {
+  private HostAndPort startTabletClientService() throws UnknownHostException {
     // start listening for client connection last
     TransactionWatcher watcher = new TransactionWatcher(context);
     WriteTracker writeTracker = new WriteTracker();
@@ -625,38 +600,12 @@ public class TabletServer extends AbstractServer
     thriftClientHandler = newTabletClientHandler(watcher, writeTracker);
     scanClientHandler = newThriftScanClientHandler(writeTracker);
 
-    TProcessor processor = ThriftProcessorTypes.getTabletServerTProcessor(this, clientHandler,
-        thriftClientHandler, scanClientHandler, getContext());
-    ServerAddress sp = startServer(getBindAddress(), processor);
-    log.info("address = {}", sp.address);
-    return sp;
-  }
-
-  @Deprecated
-  private void startReplicationService() throws UnknownHostException {
-    final var handler =
-        new org.apache.accumulo.tserver.replication.ReplicationServicerHandler(this);
-    var processor = ThriftProcessorTypes.getReplicationClientTProcessor(handler, getContext());
-    var maxMessageSizeProperty = getConfiguration().resolve(Property.RPC_MAX_MESSAGE_SIZE,
-        Property.TSERV_MAX_MESSAGE_SIZE, Property.GENERAL_MAX_MESSAGE_SIZE);
-    ServerAddress sp = TServerUtils.startServer(getContext(), clientAddress.getHost(),
-        Property.REPLICATION_RECEIPT_SERVICE_PORT, processor, "ReplicationServicerHandler",
-        "Replication Servicer", Property.TSERV_PORTSEARCH, Property.REPLICATION_MIN_THREADS, null,
-        Property.REPLICATION_THREADCHECK, maxMessageSizeProperty);
-    this.replServer = sp.server;
-    log.info("Started replication service on {}", sp.address);
-
-    try {
-      // The replication service is unique to the thrift service for a tserver, not just a host.
-      // Advertise the host and port for replication service given the host and port for the
-      // tserver.
-      getContext().getZooReaderWriter().putPersistentData(getContext().getZooKeeperRoot()
-          + org.apache.accumulo.core.replication.ReplicationConstants.ZOO_TSERVERS + "/"
-          + clientAddress, sp.address.toString().getBytes(UTF_8), NodeExistsPolicy.OVERWRITE);
-    } catch (Exception e) {
-      log.error("Could not advertise replication service port", e);
-      throw new RuntimeException(e);
-    }
+    TProcessor processor =
+        ThriftProcessorTypes.getTabletServerTProcessor(clientHandler, thriftClientHandler,
+            scanClientHandler, thriftClientHandler, thriftClientHandler, getContext());
+    HostAndPort address = startServer(getConfiguration(), clientAddress.getHost(), processor);
+    log.info("address = {}", address);
+    return address;
   }
 
   @Override
@@ -669,11 +618,6 @@ public class TabletServer extends AbstractServer
     return managerLockCache;
   }
 
-  @Override
-  public GarbageCollectionLogger getGcLogger() {
-    return gcLogger;
-  }
-
   private void announceExistence() {
     ZooReaderWriter zoo = getContext().getZooReaderWriter();
     try {
@@ -690,23 +634,45 @@ public class TabletServer extends AbstractServer
         throw e;
       }
 
-      tabletServerLock = new ServiceLock(zoo.getZooKeeper(), zLockPath, UUID.randomUUID());
+      UUID tabletServerUUID = UUID.randomUUID();
+      tabletServerLock = new ServiceLock(zoo.getZooKeeper(), zLockPath, tabletServerUUID);
 
-      LockWatcher lw = new ServiceLockWatcher("tablet server", () -> getShutdownComplete().get(),
-          (name) -> gcLogger.logGCInfo(getConfiguration()));
+      LockWatcher lw = new LockWatcher() {
+
+        @Override
+        public void lostLock(final LockLossReason reason) {
+          Halt.halt(serverStopRequested ? 0 : 1, () -> {
+            if (!serverStopRequested) {
+              log.error("Lost tablet server lock (reason = {}), exiting.", reason);
+            }
+            context.getLowMemoryDetector().logGCInfo(getConfiguration());
+          });
+        }
+
+        @Override
+        public void unableToMonitorLockNode(final Exception e) {
+          Halt.halt(1, () -> log.error("Lost ability to monitor tablet server lock, exiting.", e));
+
+        }
+      };
 
-      byte[] lockContent = new ServerServices(getClientAddressString(), Service.TSERV_CLIENT)
-          .toString().getBytes(UTF_8);
       for (int i = 0; i < 120 / 5; i++) {
         zoo.putPersistentData(zLockPath.toString(), new byte[0], NodeExistsPolicy.SKIP);
 
-        if (tabletServerLock.tryLock(lw, lockContent)) {
+        ServiceDescriptors descriptors = new ServiceDescriptors();
+        for (ThriftService svc : new ThriftService[] {ThriftService.CLIENT,
+            ThriftService.TABLET_INGEST, ThriftService.TABLET_MANAGEMENT, ThriftService.TABLET_SCAN,
+            ThriftService.TSERV}) {
+          descriptors
+              .addService(new ServiceDescriptor(tabletServerUUID, svc, getClientAddressString()));
+        }
+
+        if (tabletServerLock.tryLock(lw, new ServiceLockData(descriptors))) {
           lockID = tabletServerLock.getLockID()
               .serialize(getContext().getZooKeeperRoot() + Constants.ZTSERVERS + "/");
           lockSessionId = tabletServerLock.getSessionId();
           log.debug("Obtained tablet server lock {} {}", tabletServerLock.getLockPath(),
               getTabletSession());
-          startServiceLockVerificationThread();
           return;
         }
         log.info("Waiting for tablet server lock");
@@ -721,25 +687,11 @@ public class TabletServer extends AbstractServer
     }
   }
 
-  @Deprecated
-  private void initializeZkForReplication() {
-    try {
-      org.apache.accumulo.server.replication.ZooKeeperInitialization.ensureZooKeeperInitialized(
-          getContext().getZooReaderWriter(), getContext().getZooKeeperRoot());
-    } catch (KeeperException | InterruptedException e) {
-      throw new IllegalStateException("Exception while ensuring ZooKeeper is initialized", e);
-    }
-  }
-
   // main loop listens for client requests
   @Override
   public void run() {
     SecurityUtil.serverLogin(getConfiguration());
 
-    // To make things easier on users/devs, and to avoid creating an upgrade path to 1.7
-    // We can just make the zookeeper paths before we try to use.
-    initializeZkForReplication();
-
     if (authKeyWatcher != null) {
       log.info("Seeding ZooKeeper watcher for authentication keys");
       try {
@@ -753,43 +705,34 @@ public class TabletServer extends AbstractServer
             + " ZooKeeper. Delegation token authentication will be unavailable.", e);
       }
     }
-    ServerAddress address = null;
     try {
-      address = startTabletClientService();
-      updateAdvertiseAddress(address.getAddress());
-      clientAddress = getAdvertiseAddress();
+      clientAddress = startTabletClientService();
     } catch (UnknownHostException e1) {
       throw new RuntimeException("Failed to start the tablet client service", e1);
     }
 
-    MetricsInfo metricsInfo = context.getMetricsInfo();
+    try {
+      MetricsUtil.initializeMetrics(context.getConfiguration(), this.applicationName,
+          clientAddress);
 
-    metrics = new TabletServerMetrics(this);
-    updateMetrics = new TabletServerUpdateMetrics();
-    scanMetrics = new TabletServerScanMetrics(this.resourceManager::getOpenFiles);
-    sessionManager.setZombieCountConsumer(scanMetrics::setZombieScanThreads);
-    mincMetrics = new TabletServerMinCMetrics();
-    ceMetrics = new CompactionExecutorsMetrics();
-    blockCacheMetrics = new BlockCacheMetrics(this.resourceManager.getIndexCache(),
-        this.resourceManager.getDataCache(), this.resourceManager.getSummaryCache());
+      metrics = new TabletServerMetrics(this);
+      updateMetrics = new TabletServerUpdateMetrics();
+      scanMetrics = new TabletServerScanMetrics();
+      mincMetrics = new TabletServerMinCMetrics();
+      ceMetrics = new CompactionExecutorsMetrics();
+      pausedMetrics = new PausedCompactionMetrics();
+      MetricsUtil.initializeProducers(this, metrics, updateMetrics, scanMetrics, mincMetrics,
+          ceMetrics, pausedMetrics);
 
-    metricsInfo.addMetricsProducers(this, metrics, updateMetrics, scanMetrics, mincMetrics,
-        ceMetrics, blockCacheMetrics);
-    metricsInfo.init(MetricsInfo.serviceTags(context.getInstanceName(), getApplicationName(),
-        clientAddress, ""));
+    } catch (ClassNotFoundException | InstantiationException | IllegalAccessException
+        | IllegalArgumentException | InvocationTargetException | NoSuchMethodException
+        | SecurityException e1) {
+      log.error("Error initializing metrics, metrics will not be emitted.", e1);
+    }
 
-    Supplier<OpeningAndOnlineCompactables> compactables = () -> {
-      // synchronize on both sets to get a consistent snapshot across both sets, this avoids missing
-      // any tablets that are moving between sets
-      synchronized (openingTablets) {
-        synchronized (onlineTablets) {
-          return new OpeningAndOnlineCompactables(Set.copyOf(openingTablets),
-              onlineTablets.snapshot());
-        }
-      }
-    };
-
-    this.compactionManager = new CompactionManager(compactables, getContext(), ceMetrics);
+    this.compactionManager = new CompactionManager(() -> Iterators
+        .transform(onlineTablets.snapshot().values().iterator(), Tablet::asCompactable),
+        getContext(), ceMetrics);
     compactionManager.start();
 
     announceExistence();
@@ -801,13 +744,12 @@ public class TabletServer extends AbstractServer
       throw new RuntimeException(e);
     }
 
-    @SuppressWarnings("deprecation")
     ThreadPoolExecutor distWorkQThreadPool = ThreadPools.getServerThreadPools()
         .createExecutorService(getConfiguration(), Property.TSERV_WORKQ_THREADS, true);
 
-    // TODO: Remove when Property.TSERV_WORKQ_THREADS is removed
-    DistributedWorkQueue bulkFailedCopyQ = new DistributedWorkQueue(
-        getContext().getZooKeeperRoot() + Constants.ZBULK_FAILED_COPYQ, getConfiguration(), this);
+    bulkFailedCopyQ =
+        new DistributedWorkQueue(getContext().getZooKeeperRoot() + Constants.ZBULK_FAILED_COPYQ,
+            getConfiguration(), getContext());
     try {
       bulkFailedCopyQ.startProcessing(new BulkFailedCopyProcessor(getContext()),
           distWorkQThreadPool);
@@ -816,24 +758,12 @@ public class TabletServer extends AbstractServer
     }
 
     try {
-      logSorter.startWatchingForRecoveryLogs(this);
+      logSorter.startWatchingForRecoveryLogs(distWorkQThreadPool);
     } catch (Exception ex) {
       log.error("Error setting watches for recoveries");
       throw new RuntimeException(ex);
     }
     final AccumuloConfiguration aconf = getConfiguration();
-    // if the replication name is ever set, then start replication services
-    @SuppressWarnings("deprecation")
-    Property p = Property.REPLICATION_NAME;
-    ScheduledFuture<?> future = context.getScheduledExecutor().scheduleWithFixedDelay(() -> {
-      if (this.replServer == null) {
-        if (!getConfiguration().get(p).isEmpty()) {
-          log.info(p.getKey() + " was set, starting repl services.");
-          setupReplication(aconf);
-        }
-      }
-    }, 0, 5, TimeUnit.SECONDS);
-    watchNonCriticalScheduledTask(future);
 
     long tabletCheckFrequency = aconf.getTimeInMillis(Property.TSERV_HEALTH_CHECK_FREQ);
     // Periodically check that metadata of tablets matches what is held in memory
@@ -851,10 +781,11 @@ public class TabletServer extends AbstractServer
       Duration duration;
       Span mdScanSpan = TraceUtil.startSpan(this.getClass(), "metadataScan");
       try (Scope scope = mdScanSpan.makeCurrent()) {
+        List<KeyExtent> missingTablets = new ArrayList<>();
         // gather metadata for all tablets readTablets()
-        try (TabletsMetadata tabletsMetadata =
-            getContext().getAmple().readTablets().forTablets(onlineTabletsSnapshot.keySet())
-                .fetch(FILES, LOGS, ECOMP, PREV_ROW).build()) {
+        try (TabletsMetadata tabletsMetadata = getContext().getAmple().readTablets()
+            .forTablets(onlineTabletsSnapshot.keySet(), Optional.of(missingTablets::add))
+            .fetch(FILES, LOGS, ECOMP, PREV_ROW).build()) {
           duration = Duration.between(start, Instant.now());
           log.debug("Metadata scan took {}ms for {} tablets read.", duration.toMillis(),
               onlineTabletsSnapshot.keySet().size());
@@ -866,6 +797,13 @@ public class TabletServer extends AbstractServer
             MetadataUpdateCount counter = updateCounts.get(extent);
             tablet.compareTabletInfo(counter, tabletMetadata);
           }
+
+          for (var extent : missingTablets) {
+            Tablet tablet = onlineTabletsSnapshot.get(extent);
+            if (!tablet.isClosed()) {
+              log.error("Tablet {} is open but does not exist in metadata table.", extent);
+            }
+          }
         }
       } catch (Exception e) {
         log.error("Unable to complete verification of tablet metadata", e);
@@ -881,25 +819,17 @@ public class TabletServer extends AbstractServer
         CLEANUP_BULK_LOADED_CACHE_MILLIS, TimeUnit.MILLISECONDS));
 
     HostAndPort managerHost;
-    while (!isShutdownRequested()) {
-      if (Thread.currentThread().isInterrupted()) {
-        LOG.info("Server process thread has been interrupted, shutting down");
-        break;
-      }
-
-      updateIdleStatus(getOnlineTablets().isEmpty());
-
+    while (!serverStopRequested) {
       // send all of the pending messages
       try {
         ManagerMessage mm = null;
         ManagerClientService.Client iface = null;
 
         try {
-          // wait until a message is ready to send, or a server stop
+          // wait until a message is ready to send, or a sever stop
           // was requested
-          while (mm == null && !isShutdownRequested() && !Thread.currentThread().isInterrupted()) {
+          while (mm == null && !serverStopRequested) {
             mm = managerMessages.poll(1, TimeUnit.SECONDS);
-            updateIdleStatus(getOnlineTablets().isEmpty());
           }
 
           // have a message to send to the manager, so grab a
@@ -910,8 +840,8 @@ public class TabletServer extends AbstractServer
 
           // if while loop does not execute at all and mm != null,
           // then finally block should place mm back on queue
-          while (!Thread.currentThread().isInterrupted() && !isShutdownRequested() && mm != null
-              && client != null && client.getOutputProtocol() != null
+          while (!serverStopRequested && mm != null && client != null
+              && client.getOutputProtocol() != null
               && client.getOutputProtocol().getTransport() != null
               && client.getOutputProtocol().getTransport().isOpen()) {
             try {
@@ -927,7 +857,6 @@ public class TabletServer extends AbstractServer
             // if any messages are immediately available grab em and
             // send them
             mm = managerMessages.poll();
-            updateIdleStatus(getOnlineTablets().isEmpty());
           }
 
         } finally {
@@ -941,7 +870,7 @@ public class TabletServer extends AbstractServer
         }
       } catch (InterruptedException e) {
         log.info("Interrupt Exception received, shutting down");
-        gracefulShutdown(getContext().rpcCreds());
+        serverStopRequested = true;
       } catch (Exception e) {
         // may have lost connection with manager
         // loop back to the beginning and wait for a new one
@@ -950,37 +879,20 @@ public class TabletServer extends AbstractServer
       }
     }
 
-    ManagerClientService.Client iface = managerConnection(getManagerAddress());
-    try {
-      // Ask the manager to unload our tablets and stop loading new tablets
-      if (iface == null) {
-        Halt.halt(-1, "Error informing Manager that we are shutting down, exiting!");
-      } else {
-        iface.tabletServerStopping(TraceUtil.traceInfo(), getContext().rpcCreds(),
-            getTabletSession().getHostPortSession());
+    // wait for shutdown
+    // if the main thread exits oldServer the manager listener, the JVM will
+    // kill the other threads and finalize objects. We want the shutdown that is
+    // running in the manager listener thread to complete oldServer this happens.
+    // consider making other threads daemon threads so that objects don't
+    // get prematurely finalized
+    synchronized (this) {
+      while (!shutdownComplete) {
+        try {
+          this.wait(1000);
+        } catch (InterruptedException e) {
+          log.error(e.toString());
+        }
       }
-
-      boolean managerDown = false;
-      while (!getOnlineTablets().isEmpty()) {
-        log.info("Shutdown requested, waiting for manager to unload {} tablets",
-            getOnlineTablets().size());
-
-        managerDown = sendManagerMessages(managerDown, iface);
-
-        UtilWaitThread.sleep(1000);
-      }
-
-      sendManagerMessages(managerDown, iface);
-
-    } catch (TException | RuntimeException e) {
-      Halt.halt(-1, "Error informing Manager that we are shutting down, exiting!", e);
-    } finally {
-      returnManagerConnection(iface);
-    }
-
-    log.debug("Stopping Replication Server");
-    if (this.replServer != null) {
-      this.replServer.stop();
     }
 
     log.debug("Stopping Thrift Servers");
@@ -995,10 +907,10 @@ public class TabletServer extends AbstractServer
       log.warn("Failed to close filesystem : {}", e.getMessage(), e);
     }
 
-    gcLogger.logGCInfo(getConfiguration());
-    super.close();
-    getShutdownComplete().set(true);
+    context.getLowMemoryDetector().logGCInfo(getConfiguration());
+
     log.info("TServerInfo: stop requested. exiting ... ");
+
     try {
       tabletServerLock.unlock();
     } catch (Exception e) {
@@ -1006,45 +918,6 @@ public class TabletServer extends AbstractServer
     }
   }
 
-  private boolean sendManagerMessages(boolean managerDown, ManagerClientService.Client iface) {
-    ManagerMessage mm = managerMessages.poll();
-    while (mm != null && !managerDown) {
-      try {
-        mm.send(getContext().rpcCreds(), getClientAddressString(), iface);
-        mm = managerMessages.poll();
-      } catch (TException e) {
-        managerDown = true;
-        LOG.debug("Error sending message to Manager during tablet unloading, msg: {}",
-            e.getMessage());
-      }
-    }
-    return managerDown;
-  }
-
-  @SuppressWarnings("deprecation")
-  private void setupReplication(AccumuloConfiguration aconf) {
-    // Start the thrift service listening for incoming replication requests
-    try {
-      startReplicationService();
-    } catch (UnknownHostException e) {
-      throw new RuntimeException("Failed to start replication service", e);
-    }
-
-    // Start the pool to handle outgoing replications
-    final ThreadPoolExecutor replicationThreadPool = ThreadPools.getServerThreadPools()
-        .createExecutorService(getConfiguration(), Property.REPLICATION_WORKER_THREADS);
-    replWorker.setExecutor(replicationThreadPool);
-    replWorker.run();
-
-    // Check the configuration value for the size of the pool and, if changed, resize the pool
-    Runnable replicationWorkThreadPoolResizer = () -> {
-      ThreadPools.resizePool(replicationThreadPool, aconf, Property.REPLICATION_WORKER_THREADS);
-    };
-    ScheduledFuture<?> future = context.getScheduledExecutor()
-        .scheduleWithFixedDelay(replicationWorkThreadPoolResizer, 10, 30, TimeUnit.SECONDS);
-    watchNonCriticalScheduledTask(future);
-  }
-
   public String getClientAddressString() {
     if (clientAddress == null) {
       return null;
@@ -1099,25 +972,10 @@ public class TabletServer extends AbstractServer
   }
 
   private void config() {
-    log.info("Tablet server starting on {}", getBindAddress());
-    Threads.createCriticalThread("Split/MajC initiator", new MajorCompactor(context)).start();
+    log.info("Tablet server starting on {}", getHostname());
+    Threads.createThread("Split/MajC initiator", new MajorCompactor(context)).start();
 
-    clientAddress = HostAndPort.fromParts(getBindAddress(), 0);
-
-    final AccumuloConfiguration aconf = getConfiguration();
-
-    @SuppressWarnings("removal")
-    Property TSERV_MONITOR_FS = Property.TSERV_MONITOR_FS;
-    if (aconf.getBoolean(TSERV_MONITOR_FS)) {
-      log.warn("{} is deprecated and marked for removal.", TSERV_MONITOR_FS.getKey());
-      FileSystemMonitor.start(aconf);
-    }
-
-    Runnable gcDebugTask = () -> gcLogger.logGCInfo(getConfiguration());
-
-    ScheduledFuture<?> future = context.getScheduledExecutor().scheduleWithFixedDelay(gcDebugTask,
-        0, TIME_BETWEEN_GC_CHECKS, TimeUnit.MILLISECONDS);
-    watchNonCriticalScheduledTask(future);
+    clientAddress = HostAndPort.fromParts(getHostname(), 0);
   }
 
   public TabletServerStatus getStats(Map<TableId,MapCounter<ScanRunState>> scanCounts) {
@@ -1235,9 +1093,9 @@ public class TabletServer extends AbstractServer
   }
 
   public void minorCompactionStarted(CommitSession tablet, long lastUpdateSequence,
-      String newMapfileLocation) throws IOException {
+      String newDataFileLocation) throws IOException {
     Durability durability = getMincEventDurability(tablet.getExtent());
-    logger.minorCompactionStarted(tablet, lastUpdateSequence, newMapfileLocation, durability);
+    logger.minorCompactionStarted(tablet, lastUpdateSequence, newDataFileLocation, durability);
   }
 
   public void recover(VolumeManager fs, KeyExtent extent, List<LogEntry> logEntries,
@@ -1329,6 +1187,10 @@ public class TabletServer extends AbstractServer
     return resourceManager.holdTime();
   }
 
+  public SecurityOperation getSecurityOperation() {
+    return security;
+  }
+
   // avoid unnecessary redundant markings to meta
   final ConcurrentHashMap<DfsLogger,EnumSet<TabletLevel>> metadataTableLogs =
       new ConcurrentHashMap<>();
