@@ -18,9 +18,7 @@
  */
 package org.apache.accumulo.tserver;
 
-import static java.util.stream.Collectors.toList;
-import static java.util.stream.Collectors.toMap;
-import static org.apache.accumulo.core.util.UtilWaitThread.sleepUninterruptibly;
+import static com.google.common.util.concurrent.Uninterruptibles.sleepUninterruptibly;
 
 import java.io.IOException;
 import java.nio.ByteBuffer;
@@ -29,17 +27,18 @@ import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
-import java.util.Map.Entry;
 import java.util.Set;
 import java.util.concurrent.CancellationException;
 import java.util.concurrent.ExecutionException;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.TimeoutException;
+import java.util.stream.Collectors;
 
 import org.apache.accumulo.core.client.SampleNotPresentException;
 import org.apache.accumulo.core.client.TableNotFoundException;
 import org.apache.accumulo.core.clientImpl.TabletType;
 import org.apache.accumulo.core.clientImpl.thrift.SecurityErrorCode;
+import org.apache.accumulo.core.clientImpl.thrift.TInfo;
 import org.apache.accumulo.core.clientImpl.thrift.ThriftSecurityException;
 import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.data.Column;
@@ -61,18 +60,17 @@ import org.apache.accumulo.core.sample.impl.SamplerConfigurationImpl;
 import org.apache.accumulo.core.security.Authorizations;
 import org.apache.accumulo.core.securityImpl.thrift.TCredentials;
 import org.apache.accumulo.core.spi.scan.ScanDispatcher;
-import org.apache.accumulo.core.tabletserver.thrift.ActiveScan;
+import org.apache.accumulo.core.tabletscan.thrift.ActiveScan;
+import org.apache.accumulo.core.tabletscan.thrift.ScanServerBusyException;
+import org.apache.accumulo.core.tabletscan.thrift.TSampleNotPresentException;
+import org.apache.accumulo.core.tabletscan.thrift.TSamplerConfiguration;
+import org.apache.accumulo.core.tabletscan.thrift.TabletScanClientService;
 import org.apache.accumulo.core.tabletserver.thrift.NoSuchScanIDException;
 import org.apache.accumulo.core.tabletserver.thrift.NotServingTabletException;
-import org.apache.accumulo.core.tabletserver.thrift.ScanServerBusyException;
-import org.apache.accumulo.core.tabletserver.thrift.TSampleNotPresentException;
-import org.apache.accumulo.core.tabletserver.thrift.TSamplerConfiguration;
-import org.apache.accumulo.core.tabletserver.thrift.TabletScanClientService;
-import org.apache.accumulo.core.trace.thrift.TInfo;
 import org.apache.accumulo.server.ServerContext;
 import org.apache.accumulo.server.fs.TooManyFilesException;
 import org.apache.accumulo.server.rpc.TServerUtils;
-import org.apache.accumulo.server.security.AuditedSecurityOperation;
+import org.apache.accumulo.server.security.SecurityOperation;
 import org.apache.accumulo.tserver.scan.LookupTask;
 import org.apache.accumulo.tserver.scan.NextBatchTask;
 import org.apache.accumulo.tserver.scan.ScanParameters;
@@ -96,7 +94,7 @@ public class ThriftScanClientHandler implements TabletScanClientService.Iface {
 
   private final TabletHostingServer server;
   protected final ServerContext context;
-  protected final AuditedSecurityOperation security;
+  protected final SecurityOperation security;
   private final WriteTracker writeTracker;
   private final long MAX_TIME_TO_WAIT_FOR_SCAN_RESULT_MILLIS;
 
@@ -135,8 +133,8 @@ public class ThriftScanClientHandler implements TabletScanClientService.Iface {
       boolean isolated, long readaheadThreshold, TSamplerConfiguration tSamplerConfig,
       long batchTimeOut, String contextArg, Map<String,String> executionHints, long busyTimeout)
       throws NotServingTabletException, ThriftSecurityException,
-      org.apache.accumulo.core.tabletserver.thrift.TooManyFilesException,
-      TSampleNotPresentException, ScanServerBusyException {
+      org.apache.accumulo.core.tabletscan.thrift.TooManyFilesException, TSampleNotPresentException,
+      ScanServerBusyException {
     final KeyExtent extent = KeyExtent.fromThrift(textent);
     TabletResolver resolver = new TabletResolver() {
       @Override
@@ -158,7 +156,7 @@ public class ThriftScanClientHandler implements TabletScanClientService.Iface {
       boolean isolated, long readaheadThreshold, TSamplerConfiguration tSamplerConfig,
       long batchTimeOut, String contextArg, Map<String,String> executionHints,
       ScanSession.TabletResolver tabletResolver, long busyTimeout) throws NotServingTabletException,
-      ThriftSecurityException, org.apache.accumulo.core.tabletserver.thrift.TooManyFilesException,
+      ThriftSecurityException, org.apache.accumulo.core.tabletscan.thrift.TooManyFilesException,
       TSampleNotPresentException, ScanServerBusyException {
 
     server.getScanMetrics().incrementStartScan(1.0D);
@@ -216,8 +214,6 @@ public class ThriftScanClientHandler implements TabletScanClientService.Iface {
 
     long sid = server.getSessionManager().createSession(scanSession, true);
 
-    scanParams.setScanSessionId(sid);
-
     ScanResult scanResult;
     try {
       scanResult = continueScan(tinfo, sid, scanSession, busyTimeout);
@@ -234,8 +230,8 @@ public class ThriftScanClientHandler implements TabletScanClientService.Iface {
   @Override
   public ScanResult continueScan(TInfo tinfo, long scanID, long busyTimeout)
       throws NoSuchScanIDException, NotServingTabletException,
-      org.apache.accumulo.core.tabletserver.thrift.TooManyFilesException,
-      TSampleNotPresentException, ScanServerBusyException {
+      org.apache.accumulo.core.tabletscan.thrift.TooManyFilesException, TSampleNotPresentException,
+      ScanServerBusyException {
     SingleScanSession scanSession =
         (SingleScanSession) server.getSessionManager().reserveSession(scanID);
     if (scanSession == null) {
@@ -251,28 +247,28 @@ public class ThriftScanClientHandler implements TabletScanClientService.Iface {
 
   protected ScanResult continueScan(TInfo tinfo, long scanID, SingleScanSession scanSession,
       long busyTimeout) throws NoSuchScanIDException, NotServingTabletException,
-      org.apache.accumulo.core.tabletserver.thrift.TooManyFilesException,
-      TSampleNotPresentException, ScanServerBusyException {
+      org.apache.accumulo.core.tabletscan.thrift.TooManyFilesException, TSampleNotPresentException,
+      ScanServerBusyException {
 
     server.getScanMetrics().incrementContinueScan(1.0D);
 
-    if (scanSession.getScanTask() == null) {
-      scanSession.setScanTask(new NextBatchTask(server, scanID, scanSession.interruptFlag));
+    if (scanSession.nextBatchTask == null) {
+      scanSession.nextBatchTask = new NextBatchTask(server, scanID, scanSession.interruptFlag);
       server.getResourceManager().executeReadAhead(scanSession.extent,
-          getScanDispatcher(scanSession.extent), scanSession, scanSession.getScanTask());
+          getScanDispatcher(scanSession.extent), scanSession, scanSession.nextBatchTask);
     }
 
     ScanBatch bresult;
     try {
-      bresult = scanSession.getScanTask().get(busyTimeout, MAX_TIME_TO_WAIT_FOR_SCAN_RESULT_MILLIS,
+      bresult = scanSession.nextBatchTask.get(busyTimeout, MAX_TIME_TO_WAIT_FOR_SCAN_RESULT_MILLIS,
           TimeUnit.MILLISECONDS);
-      scanSession.clearScanTask();
+      scanSession.nextBatchTask = null;
     } catch (ExecutionException e) {
       server.getSessionManager().removeSession(scanID);
       if (e.getCause() instanceof NotServingTabletException) {
         throw (NotServingTabletException) e.getCause();
       } else if (e.getCause() instanceof TooManyFilesException) {
-        throw new org.apache.accumulo.core.tabletserver.thrift.TooManyFilesException(
+        throw new org.apache.accumulo.core.tabletscan.thrift.TooManyFilesException(
             scanSession.extent.toThrift());
       } else if (e.getCause() instanceof SampleNotPresentException) {
         throw new TSampleNotPresentException(scanSession.extent.toThrift());
@@ -280,7 +276,7 @@ public class ThriftScanClientHandler implements TabletScanClientService.Iface {
         sleepUninterruptibly(MAX_TIME_TO_WAIT_FOR_SCAN_RESULT_MILLIS, TimeUnit.MILLISECONDS);
         List<KVEntry> empty = Collections.emptyList();
         bresult = new ScanBatch(empty, true);
-        scanSession.clearScanTask();
+        scanSession.nextBatchTask = null;
       } else {
         throw new RuntimeException(e);
       }
@@ -288,7 +284,7 @@ public class ThriftScanClientHandler implements TabletScanClientService.Iface {
       server.getSessionManager().removeSession(scanID);
       TabletBase tablet = scanSession.getTabletResolver().getTablet(scanSession.extent);
       if (busyTimeout > 0) {
-        server.getScanMetrics().incrementBusy(1.0D);
+        server.getScanMetrics().incrementScanBusyTimeout(1.0D);
         throw new ScanServerBusyException();
       } else if (tablet == null || tablet.isClosed()) {
         throw new NotServingTabletException(scanSession.extent.toThrift());
@@ -315,9 +311,9 @@ public class ThriftScanClientHandler implements TabletScanClientService.Iface {
     if (scanResult.more && scanSession.batchCount > scanSession.readaheadThreshold) {
       // start reading next batch while current batch is transmitted
       // to client
-      scanSession.setScanTask(new NextBatchTask(server, scanID, scanSession.interruptFlag));
+      scanSession.nextBatchTask = new NextBatchTask(server, scanID, scanSession.interruptFlag);
       server.getResourceManager().executeReadAhead(scanSession.extent,
-          getScanDispatcher(scanSession.extent), scanSession, scanSession.getScanTask());
+          getScanDispatcher(scanSession.extent), scanSession, scanSession.nextBatchTask);
     }
 
     if (!scanResult.more) {
@@ -397,22 +393,26 @@ public class ThriftScanClientHandler implements TabletScanClientService.Iface {
     // check if user has permission to the tables
     for (TableId tableId : tables) {
       NamespaceId namespaceId = getNamespaceId(credentials, tableId);
-      if (!security.canScan(credentials, tableId, namespaceId, tbatch, tcolumns, ssiList, ssio,
-          authorizations)) {
+      if (!security.canScan(credentials, tableId, namespaceId)) {
         throw new ThriftSecurityException(credentials.getPrincipal(),
             SecurityErrorCode.PERMISSION_DENIED);
       }
     }
 
-    if (!security.authenticatedUserHasAuthorizations(credentials, authorizations)) {
-      throw new ThriftSecurityException(credentials.getPrincipal(),
-          SecurityErrorCode.BAD_AUTHORIZATIONS);
+    try {
+      if (!security.authenticatedUserHasAuthorizations(credentials, authorizations)) {
+        throw new ThriftSecurityException(credentials.getPrincipal(),
+            SecurityErrorCode.BAD_AUTHORIZATIONS);
+      }
+    } catch (ThriftSecurityException tse) {
+      log.error("{} is not authorized", credentials.getPrincipal(), tse);
+      throw tse;
     }
 
     // @formatter:off
-    Map<KeyExtent,List<Range>> batch = tbatch.entrySet().stream().collect(toMap(
-        Entry::getKey,
-        entry -> entry.getValue().stream().map(Range::new).collect(toList())
+    Map<KeyExtent, List<Range>> batch = tbatch.entrySet().stream().collect(Collectors.toMap(
+                    entry -> entry.getKey(),
+                    entry -> entry.getValue().stream().map(Range::new).collect(Collectors.toList())
     ));
     // @formatter:on
 
@@ -440,8 +440,6 @@ public class ThriftScanClientHandler implements TabletScanClientService.Iface {
 
     long sid = server.getSessionManager().createSession(mss, true);
 
-    scanParams.setScanSessionId(sid);
-
     MultiScanResult result;
     try {
       result = continueMultiScan(sid, mss, busyTimeout);
@@ -474,17 +472,17 @@ public class ThriftScanClientHandler implements TabletScanClientService.Iface {
 
     server.getScanMetrics().incrementContinueScan(1.0D);
 
-    if (session.getScanTask() == null) {
-      session.setScanTask(new LookupTask(server, scanID));
+    if (session.lookupTask == null) {
+      session.lookupTask = new LookupTask(server, scanID);
       server.getResourceManager().executeReadAhead(session.threadPoolExtent,
-          getScanDispatcher(session.threadPoolExtent), session, session.getScanTask());
+          getScanDispatcher(session.threadPoolExtent), session, session.lookupTask);
     }
 
     try {
 
-      MultiScanResult scanResult = session.getScanTask().get(busyTimeout,
+      MultiScanResult scanResult = session.lookupTask.get(busyTimeout,
           MAX_TIME_TO_WAIT_FOR_SCAN_RESULT_MILLIS, TimeUnit.MILLISECONDS);
-      session.clearScanTask();
+      session.lookupTask = null;
       return scanResult;
     } catch (ExecutionException e) {
       server.getSessionManager().removeSession(scanID);
@@ -497,7 +495,7 @@ public class ThriftScanClientHandler implements TabletScanClientService.Iface {
     } catch (CancellationException ce) {
       server.getSessionManager().removeSession(scanID);
       if (busyTimeout > 0) {
-        server.getScanMetrics().incrementBusy(1.0D);
+        server.getScanMetrics().incrementScanBusyTimeout(1.0D);
         throw new ScanServerBusyException();
       } else {
         log.warn("Failed to get multiscan result", ce);
@@ -541,7 +539,13 @@ public class ThriftScanClientHandler implements TabletScanClientService.Iface {
   @Override
   public List<ActiveScan> getActiveScans(TInfo tinfo, TCredentials credentials)
       throws ThriftSecurityException, TException {
-    TabletClientHandler.checkPermission(context, server, credentials, null, "getScans");
+    try {
+      TabletClientHandler.checkPermission(security, context, server, credentials, null, "getScans");
+    } catch (ThriftSecurityException e) {
+      log.error("Caller doesn't have permission to get active scans", e);
+      throw e;
+    }
+
     return server.getSessionManager().getActiveScans();
   }
 
