@@ -21,6 +21,7 @@ package org.apache.accumulo.tserver.compactions;
 import static java.util.concurrent.TimeUnit.MILLISECONDS;
 import static java.util.concurrent.TimeUnit.MINUTES;
 import static java.util.concurrent.TimeUnit.NANOSECONDS;
+import static org.apache.accumulo.core.util.compaction.CompactionServicesConfig.DEFAULT_SERVICE;
 
 import java.util.Collection;
 import java.util.HashMap;
@@ -31,11 +32,9 @@ import java.util.Objects;
 import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.LinkedBlockingQueue;
-import java.util.function.Supplier;
 import java.util.stream.Collectors;
 
 import org.apache.accumulo.core.conf.Property;
-import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.metadata.schema.ExternalCompactionId;
 import org.apache.accumulo.core.spi.compaction.CompactionExecutorId;
@@ -43,13 +42,11 @@ import org.apache.accumulo.core.spi.compaction.CompactionKind;
 import org.apache.accumulo.core.spi.compaction.CompactionServiceId;
 import org.apache.accumulo.core.spi.compaction.CompactionServices;
 import org.apache.accumulo.core.tabletserver.thrift.TCompactionQueueSummary;
-import org.apache.accumulo.core.util.Pair;
 import org.apache.accumulo.core.util.Retry;
 import org.apache.accumulo.core.util.compaction.CompactionExecutorIdImpl;
 import org.apache.accumulo.core.util.compaction.CompactionServicesConfig;
 import org.apache.accumulo.core.util.threads.Threads;
 import org.apache.accumulo.server.ServerContext;
-import org.apache.accumulo.tserver.OpeningAndOnlineCompactables;
 import org.apache.accumulo.tserver.compactions.CompactionExecutor.CType;
 import org.apache.accumulo.tserver.metrics.CompactionExecutorsMetrics;
 import org.apache.accumulo.tserver.tablet.Tablet;
@@ -57,37 +54,30 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import com.google.common.base.Preconditions;
-import com.google.common.cache.Cache;
-import com.google.common.cache.CacheBuilder;
 import com.google.common.collect.Sets;
 
 public class CompactionManager {
 
   private static final Logger log = LoggerFactory.getLogger(CompactionManager.class);
 
-  private final Supplier<OpeningAndOnlineCompactables> compactables;
+  private Iterable<Compactable> compactables;
   private volatile Map<CompactionServiceId,CompactionService> services;
 
-  private final LinkedBlockingQueue<Compactable> compactablesToCheck = new LinkedBlockingQueue<>();
+  private LinkedBlockingQueue<Compactable> compactablesToCheck = new LinkedBlockingQueue<>();
 
-  private final long maxTimeBetweenChecks;
+  private long maxTimeBetweenChecks;
 
-  private final ServerContext context;
+  private ServerContext context;
 
   private CompactionServicesConfig currentCfg;
 
   private long lastConfigCheckTime = System.nanoTime();
 
-  private final CompactionExecutorsMetrics ceMetrics;
+  private CompactionExecutorsMetrics ceMetrics;
 
-  private String lastDeprecationWarning = "";
+  private Map<CompactionExecutorId,ExternalCompactionExecutor> externalExecutors;
 
-  private final Map<CompactionExecutorId,ExternalCompactionExecutor> externalExecutors;
-
-  private final Map<ExternalCompactionId,ExtCompInfo> runningExternalCompactions;
-
-  // use to limit logging of unknown compaction services
-  private final Cache<Pair<TableId,CompactionServiceId>,Long> unknownCompactionServiceErrorCache;
+  private Map<ExternalCompactionId,ExtCompInfo> runningExternalCompactions;
 
   static class ExtCompInfo {
     final KeyExtent extent;
@@ -99,13 +89,6 @@ public class CompactionManager {
     }
   }
 
-  private void warnAboutDeprecation(String warning) {
-    if (!warning.equals(lastDeprecationWarning)) {
-      log.warn(warning);
-      lastDeprecationWarning = warning;
-    }
-  }
-
   private void mainLoop() {
     long lastCheckAllTime = System.nanoTime();
 
@@ -122,33 +105,18 @@ public class CompactionManager {
         long passed = NANOSECONDS.toMillis(System.nanoTime() - lastCheckAllTime);
         if (passed >= maxTimeBetweenChecks) {
           // take a snapshot of what is currently running
-          HashMap<ExternalCompactionId,ExtCompInfo> runningEcids =
-              new HashMap<>(runningExternalCompactions);
-          // Get a snapshot of the tablets that are online and opening, this must be obtained after
-          // getting the runningExternalCompactions snapshot above. If it were obtained before then
-          // an opening tablet could add itself to runningExternalCompactions after this code
-          // obtained the snapshot of opening and online tablets and this code would remove it.
-          var compactablesSnapshot = compactables.get();
-          for (Tablet tablet : compactablesSnapshot.online.values()) {
-            Compactable compactable = tablet.asCompactable();
+          HashSet<ExternalCompactionId> runningEcids =
+              new HashSet<>(runningExternalCompactions.keySet());
+          for (Compactable compactable : compactables) {
             last = compactable;
             submitCompaction(compactable);
             // remove anything from snapshot that tablets know are running
             compactable.getExternalCompactionIds(runningEcids::remove);
           }
           lastCheckAllTime = System.nanoTime();
-
-          // remove any tablets that are currently opening, these may have been added to
-          // runningExternalCompactions while in the process of opening
-          runningEcids.values()
-              .removeIf(extCompInfo -> compactablesSnapshot.opening.contains(extCompInfo.extent));
-
           // anything left in the snapshot is unknown to any tablet and should be removed if it
           // still exists
-          runningEcids.forEach((ecid, info) -> log.debug(
-              "Removing unknown external compaction {} {} from runningExternalCompactions", ecid,
-              info.extent));
-          runningExternalCompactions.keySet().removeAll(runningEcids.keySet());
+          runningExternalCompactions.keySet().removeAll(runningEcids);
         } else {
           var compactable = compactablesToCheck.poll(maxTimeBetweenChecks - passed, MILLISECONDS);
           if (compactable != null) {
@@ -188,18 +156,12 @@ public class CompactionManager {
         checkForConfigChanges(true);
         service = services.get(csid);
         if (service == null) {
-          var cacheKey = new Pair<>(compactable.getTableId(), csid);
-          var last = unknownCompactionServiceErrorCache.getIfPresent(cacheKey);
-          if (last == null) {
-            // have not logged an error recently for this, so lets log one
-            log.error(
-                "Tablet {} returned non-existent compaction service {} for compaction type {}.  Check"
-                    + " the table compaction dispatcher configuration. No compactions will happen"
-                    + " until the configuration is fixed. This log message is temporarily suppressed for the"
-                    + " entire table.",
-                compactable.getExtent(), csid, ctype);
-            unknownCompactionServiceErrorCache.put(cacheKey, System.currentTimeMillis());
-          }
+          log.error(
+              "Tablet {} returned non-existent compaction service {} for compaction type {}.  Check"
+                  + " the table compaction dispatcher configuration. Attempting to fall back to "
+                  + "{} service.",
+              compactable.getExtent(), csid, ctype, DEFAULT_SERVICE);
+          service = services.get(DEFAULT_SERVICE);
         }
       }
 
@@ -209,12 +171,11 @@ public class CompactionManager {
     }
   }
 
-  public CompactionManager(Supplier<OpeningAndOnlineCompactables> compactables,
-      ServerContext context, CompactionExecutorsMetrics ceMetrics) {
+  public CompactionManager(Iterable<Compactable> compactables, ServerContext context,
+      CompactionExecutorsMetrics ceMetrics) {
     this.compactables = compactables;
 
-    this.currentCfg =
-        new CompactionServicesConfig(context.getConfiguration(), this::warnAboutDeprecation);
+    this.currentCfg = new CompactionServicesConfig(context.getConfiguration());
 
     this.context = context;
 
@@ -226,9 +187,6 @@ public class CompactionManager {
 
     Map<CompactionServiceId,CompactionService> tmpServices = new HashMap<>();
 
-    unknownCompactionServiceErrorCache =
-        CacheBuilder.newBuilder().expireAfterWrite(5, MINUTES).build();
-
     currentCfg.getPlanners().forEach((serviceName, plannerClassName) -> {
       try {
         tmpServices.put(CompactionServiceId.of(serviceName),
@@ -264,8 +222,7 @@ public class CompactionManager {
 
       lastConfigCheckTime = System.nanoTime();
 
-      var tmpCfg =
-          new CompactionServicesConfig(context.getConfiguration(), this::warnAboutDeprecation);
+      var tmpCfg = new CompactionServicesConfig(context.getConfiguration());
 
       if (!currentCfg.equals(tmpCfg)) {
         Map<CompactionServiceId,CompactionService> tmpServices = new HashMap<>();
@@ -293,13 +250,13 @@ public class CompactionManager {
           }
         });
 
-        var deletedServices = Sets.difference(services.keySet(), tmpServices.keySet());
+        var deletedServices =
+            Sets.difference(currentCfg.getPlanners().keySet(), tmpCfg.getPlanners().keySet());
 
-        for (var dcsid : deletedServices) {
-          services.get(dcsid).stop();
+        for (String serviceName : deletedServices) {
+          services.get(CompactionServiceId.of(serviceName)).stop();
         }
 
-        this.currentCfg = tmpCfg;
         this.services = Map.copyOf(tmpServices);
 
         HashSet<CompactionExecutorId> activeExternalExecs = new HashSet<>();
@@ -315,7 +272,7 @@ public class CompactionManager {
 
   public void start() {
     log.debug("Started compaction manager");
-    Threads.createCriticalThread("Compaction Manager", () -> mainLoop()).start();
+    Threads.createThread("Compaction Manager", () -> mainLoop()).start();
   }
 
   public CompactionServices getServices() {
@@ -355,8 +312,7 @@ public class CompactionManager {
     if (ecJob != null) {
       runningExternalCompactions.put(ecJob.getExternalCompactionId(),
           new ExtCompInfo(ecJob.getExtent(), extCE.getId()));
-      log.debug("Reserved external compaction {} {}", ecJob.getExternalCompactionId(),
-          ecJob.getExtent());
+      log.debug("Reserved external compaction {}", ecJob.getExternalCompactionId());
     }
     return ecJob;
   }
@@ -372,7 +328,6 @@ public class CompactionManager {
   public void registerExternalCompaction(ExternalCompactionId ecid, KeyExtent extent,
       CompactionExecutorId ceid) {
     runningExternalCompactions.put(ecid, new ExtCompInfo(extent, ceid));
-    log.trace("registered external compaction {} {}", ecid, extent);
   }
 
   public void commitExternalCompaction(ExternalCompactionId extCompactionId,
@@ -384,19 +339,10 @@ public class CompactionManager {
           "Unexpected extent seen on compaction commit %s %s", ecInfo.extent, extentCompacted);
       Tablet tablet = currentTablets.get(ecInfo.extent);
       if (tablet != null) {
-        log.debug("Attempting to commit external compaction {} {}", extCompactionId,
-            tablet.getExtent());
         tablet.asCompactable().commitExternalCompaction(extCompactionId, fileSize, entries);
         compactablesToCheck.add(tablet.asCompactable());
-        runningExternalCompactions.remove(extCompactionId);
-        log.trace("Committed external compaction {} {}", extCompactionId, tablet.getExtent());
-      } else {
-        log.debug("Ignoring request to commit {} {} because its not in set of known tablets",
-            extCompactionId, ecInfo.extent);
       }
-    } else {
-      log.debug("Ignoring request to commit {} because its not in runningExternalCompactions",
-          extCompactionId);
+      runningExternalCompactions.remove(extCompactionId);
     }
   }
 
@@ -408,17 +354,10 @@ public class CompactionManager {
           "Unexpected extent seen on compaction commit %s %s", ecInfo.extent, extentCompacted);
       Tablet tablet = currentTablets.get(ecInfo.extent);
       if (tablet != null) {
-        log.debug("Attempting to fail external compaction {} {}", ecid, tablet.getExtent());
         tablet.asCompactable().externalCompactionFailed(ecid);
         compactablesToCheck.add(tablet.asCompactable());
-        runningExternalCompactions.remove(ecid);
-        log.trace("Failed external compaction {} {}", ecid, tablet.getExtent());
-      } else {
-        log.debug("Ignoring request to fail {} {} because its not in set of known tablets", ecid,
-            ecInfo.extent);
       }
-    } else {
-      log.debug("Ignoring request to fail {} because its not in runningExternalCompactions", ecid);
+      runningExternalCompactions.remove(ecid);
     }
   }
 
@@ -431,6 +370,7 @@ public class CompactionManager {
     public CompactionExecutorId ceid;
     public int running;
     public int queued;
+    public int paused;
   }
 
   public Collection<ExtCompMetric> getExternalMetrics() {
@@ -459,10 +399,6 @@ public class CompactionManager {
   public void compactableClosed(KeyExtent extent, Set<CompactionServiceId> servicesUsed,
       Set<ExternalCompactionId> ecids) {
     runningExternalCompactions.keySet().removeAll(ecids);
-    if (log.isTraceEnabled()) {
-      ecids.forEach(ecid -> log.trace(
-          "Removed {} from runningExternalCompactions for {} as part of close", ecid, extent));
-    }
     servicesUsed.stream().map(services::get).filter(Objects::nonNull)
         .forEach(compService -> compService.compactableClosed(extent));
   }
