@@ -18,10 +18,6 @@
  */
 package org.apache.accumulo.tserver.compactions;
 
-import static java.util.concurrent.TimeUnit.MILLISECONDS;
-import static java.util.concurrent.TimeUnit.MINUTES;
-import static org.apache.accumulo.core.util.threads.ThreadPoolNames.COMPACTION_SERVICE_COMPACTION_PLANNER_POOL;
-
 import java.util.Collection;
 import java.util.Collections;
 import java.util.EnumMap;
@@ -37,19 +33,15 @@ import java.util.concurrent.ConcurrentLinkedQueue;
 import java.util.concurrent.ConcurrentMap;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.RejectedExecutionException;
+import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicLong;
 import java.util.function.Consumer;
 import java.util.function.Function;
 
-import org.apache.accumulo.core.client.TableNotFoundException;
 import org.apache.accumulo.core.client.admin.compaction.CompactableFile;
 import org.apache.accumulo.core.conf.ConfigurationTypeHelper;
-import org.apache.accumulo.core.conf.Property;
-import org.apache.accumulo.core.data.NamespaceId;
 import org.apache.accumulo.core.data.TableId;
-import org.apache.accumulo.core.data.TabletId;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
-import org.apache.accumulo.core.dataImpl.TabletIdImpl;
 import org.apache.accumulo.core.spi.common.ServiceEnvironment;
 import org.apache.accumulo.core.spi.compaction.CompactionExecutorId;
 import org.apache.accumulo.core.spi.compaction.CompactionJob;
@@ -73,29 +65,24 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import com.google.common.base.Preconditions;
-import com.google.common.cache.Cache;
-import com.google.common.cache.CacheBuilder;
 import com.google.common.collect.Sets;
 
 public class CompactionService {
   private CompactionPlanner planner;
   private Map<CompactionExecutorId,CompactionExecutor> executors;
   private final CompactionServiceId myId;
-  private final Map<KeyExtent,Collection<SubmittedJob>> submittedJobs = new ConcurrentHashMap<>();
-  private final ServerContext context;
+  private Map<KeyExtent,Collection<SubmittedJob>> submittedJobs = new ConcurrentHashMap<>();
+  private ServerContext context;
   private String plannerClassName;
   private Map<String,String> plannerOpts;
-  private final CompactionExecutorsMetrics ceMetrics;
-  private final ExecutorService planningExecutor;
-  private final Map<CompactionKind,ConcurrentMap<KeyExtent,Compactable>> queuedForPlanning;
+  private CompactionExecutorsMetrics ceMetrics;
+  private ExecutorService planningExecutor;
+  private Map<CompactionKind,ConcurrentMap<KeyExtent,Compactable>> queuedForPlanning;
 
-  private final RateLimiter readLimiter;
-  private final RateLimiter writeLimiter;
-  private final AtomicLong rateLimit = new AtomicLong(0);
-  private final Function<CompactionExecutorId,ExternalCompactionExecutor> externExecutorSupplier;
-
-  // use to limit logging of max scan files exceeded
-  private final Cache<TableId,Long> maxScanFilesExceededErrorCache;
+  private RateLimiter readLimiter;
+  private RateLimiter writeLimiter;
+  private AtomicLong rateLimit = new AtomicLong(0);
+  private Function<CompactionExecutorId,ExternalCompactionExecutor> externExecutorSupplier;
 
   private static final Logger log = LoggerFactory.getLogger(CompactionService.class);
 
@@ -115,15 +102,16 @@ public class CompactionService {
 
     var initParams =
         new CompactionPlannerInitParams(myId, plannerOpts, new ServiceEnvironmentImpl(context));
-    planner = createPlanner(myId, plannerClass, plannerOptions, initParams);
+    planner = createPlanner(plannerClass);
+    planner.init(initParams);
 
     Map<CompactionExecutorId,CompactionExecutor> tmpExecutors = new HashMap<>();
 
     this.rateLimit.set(maxRate);
 
-    this.readLimiter = SharedRateLimiterFactory.getInstance(this.context.getScheduledExecutor())
+    this.readLimiter = SharedRateLimiterFactory.getInstance(this.context.getConfiguration())
         .create("CS_" + serviceName + "_read", () -> rateLimit.get());
-    this.writeLimiter = SharedRateLimiterFactory.getInstance(this.context.getScheduledExecutor())
+    this.writeLimiter = SharedRateLimiterFactory.getInstance(this.context.getConfiguration())
         .create("CS_" + serviceName + "_write", () -> rateLimit.get());
 
     initParams.getRequestedExecutors().forEach((ceid, numThreads) -> {
@@ -131,39 +119,29 @@ public class CompactionService {
           new InternalCompactionExecutor(ceid, numThreads, ceMetrics, readLimiter, writeLimiter));
     });
 
-    initParams.getRequestedExternalExecutors().forEach((ceid) -> {
+    initParams.getRequestedExternalExecutors().forEach(ceid -> {
       tmpExecutors.put(ceid, externExecutorSupplier.apply(ceid));
     });
 
     this.executors = Map.copyOf(tmpExecutors);
 
-    this.planningExecutor = ThreadPools.getServerThreadPools()
-        .getPoolBuilder(COMPACTION_SERVICE_COMPACTION_PLANNER_POOL).numCoreThreads(1)
-        .numMaxThreads(1).withTimeOut(0L, MILLISECONDS).build();
+    this.planningExecutor = ThreadPools.getServerThreadPools().createThreadPool(1, 1, 0L,
+        TimeUnit.MILLISECONDS, "CompactionPlanner", false);
 
     this.queuedForPlanning = new EnumMap<>(CompactionKind.class);
     for (CompactionKind kind : CompactionKind.values()) {
       queuedForPlanning.put(kind, new ConcurrentHashMap<KeyExtent,Compactable>());
     }
 
-    maxScanFilesExceededErrorCache = CacheBuilder.newBuilder().expireAfterWrite(5, MINUTES).build();
-
     log.debug("Created new compaction service id:{} rate limit:{} planner:{} planner options:{}",
         myId, maxRate, plannerClass, plannerOptions);
   }
 
-  private static CompactionPlanner createPlanner(CompactionServiceId myId, String plannerClass,
-      Map<String,String> options, CompactionPlannerInitParams initParams) {
+  private CompactionPlanner createPlanner(String plannerClass) {
     try {
-      var planner =
-          ConfigurationTypeHelper.getClassInstance(null, plannerClass, CompactionPlanner.class);
-      planner.init(initParams);
-      return planner;
-    } catch (Exception e) {
-      log.error(
-          "Failed to create compaction planner for {} using class:{} options:{}.  Compaction service will not start any new compactions until its configuration is fixed.",
-          myId, plannerClass, options, e);
-      return new ProvisionalCompactionPlanner(myId);
+      return ConfigurationTypeHelper.getClassInstance(null, plannerClass, CompactionPlanner.class);
+    } catch (ReflectiveOperationException e) {
+      throw new IllegalArgumentException(e);
     }
   }
 
@@ -209,8 +187,7 @@ public class CompactionService {
           try {
             Optional<Compactable.Files> files = compactable.getFiles(myId, kind);
             if (files.isEmpty() || files.orElseThrow().candidates.isEmpty()) {
-              log.trace("Compactable returned no files {} {} {}", myId, compactable.getExtent(),
-                  kind);
+              log.trace("Compactable returned no files {} {}", compactable.getExtent(), kind);
             } else {
               CompactionPlan plan = getCompactionPlan(kind, files.orElseThrow(), compactable);
               submitCompactionJob(plan, files.orElseThrow(), compactable, completionCallback);
@@ -239,21 +216,11 @@ public class CompactionService {
 
     private final ServiceEnvironment senv = new ServiceEnvironmentImpl(context);
 
-    @Override
-    public NamespaceId getNamespaceId() throws TableNotFoundException {
-      return context.getNamespaceId(comp.getTableId());
-    }
-
     @Override
     public TableId getTableId() {
       return comp.getTableId();
     }
 
-    @Override
-    public TabletId getTabletId() {
-      return new TabletIdImpl(comp.getExtent());
-    }
-
     @Override
     public ServiceEnvironment getServiceEnvironment() {
       return senv;
@@ -303,36 +270,15 @@ public class CompactionService {
       Compactable compactable) {
     PlanningParameters params = new CpPlanParams(kind, compactable, files);
 
-    log.trace("Planning compactions {} {} {} {} {}", myId, planner.getClass().getName(),
+    log.trace("Planning compactions {} {} {} {}", planner.getClass().getName(),
         compactable.getExtent(), kind, files);
 
     CompactionPlan plan;
     try {
       plan = planner.makePlan(params);
-      var tableId = compactable.getTableId();
-
-      if (plan.getJobs().isEmpty()) {
-        int maxScanFiles =
-            context.getTableConfiguration(tableId).getCount(Property.TSERV_SCAN_MAX_OPENFILES);
-
-        if (files.allFiles.size() >= maxScanFiles && files.compacting.isEmpty()) {
-          var last = maxScanFilesExceededErrorCache.getIfPresent(tableId);
-
-          if (last == null) {
-            log.warn(
-                "The tablet {} has {} files and the max files for scan is {}.  No compactions are "
-                    + "running and none were planned for this tablet by {}, so the files will "
-                    + "not be reduced by compaction which could cause scans to fail.  Please "
-                    + "check your compaction configuration. This log message is temporarily suppressed for the entire table.",
-                compactable.getExtent(), files.allFiles.size(), maxScanFiles, myId);
-            maxScanFilesExceededErrorCache.put(tableId, System.currentTimeMillis());
-          }
-        }
-      }
-
     } catch (RuntimeException e) {
-      log.debug("Planner failed {} {} {} {} {}", myId, planner.getClass().getName(),
-          compactable.getExtent(), kind, files, e);
+      log.debug("Planner failed {} {} {} {}", planner.getClass().getName(), compactable.getExtent(),
+          kind, files, e);
       throw e;
     }
 
@@ -343,7 +289,8 @@ public class CompactionService {
       Compactable compactable, Consumer<Compactable> completionCallback) {
     // log error if tablet is metadata and compaction is external
     var execIds = plan.getJobs().stream().map(cj -> (CompactionExecutorIdImpl) cj.getExecutor());
-    if (compactable.getExtent().isMeta() && execIds.anyMatch(ceid -> ceid.isExternalId())) {
+    if (compactable.getExtent().isMeta()
+        && execIds.anyMatch(CompactionExecutorIdImpl::isExternalId)) {
       log.error(
           "Compacting metadata tablets on external compactors is not supported, please change "
               + "config for compaction service ({}) and/or table ASAP.  {} is not compacting, "
@@ -421,7 +368,8 @@ public class CompactionService {
 
     var initParams =
         new CompactionPlannerInitParams(myId, plannerOptions, new ServiceEnvironmentImpl(context));
-    var tmpPlanner = createPlanner(myId, plannerClassName, plannerOptions, initParams);
+    var tmpPlanner = createPlanner(plannerClassName);
+    tmpPlanner.init(initParams);
 
     Map<CompactionExecutorId,CompactionExecutor> tmpExecutors = new HashMap<>();
 
@@ -460,7 +408,6 @@ public class CompactionService {
 
   public void stop() {
     executors.values().forEach(CompactionExecutor::stop);
-    log.debug("Stopped compaction service {}", myId);
   }
 
   int getCompactionsRunning(CType ctype) {
