@@ -26,8 +26,8 @@ import org.apache.accumulo.server.data.ServerMutation;
 
 public class ServerConditionalMutation extends ServerMutation {
 
-  private final long cmid;
-  private final List<TCondition> conditions;
+  private long cmid;
+  private List<TCondition> conditions;
 
   public ServerConditionalMutation(TConditionalMutation input) {
     super(input.mutation);
