@@ -56,6 +56,7 @@ import org.apache.accumulo.core.spi.crypto.CryptoEnvironment.Scope;
 import org.apache.accumulo.core.spi.crypto.CryptoService;
 import org.apache.accumulo.core.spi.crypto.FileDecrypter;
 import org.apache.accumulo.core.spi.crypto.FileEncrypter;
+import org.apache.accumulo.core.spi.crypto.NoCryptoService;
 import org.apache.accumulo.core.util.Pair;
 import org.apache.accumulo.core.util.threads.Threads;
 import org.apache.accumulo.server.ServerContext;
@@ -361,9 +362,8 @@ public class DfsLogger implements Comparable<DfsLogger> {
         FileDecrypter decrypter =
             CryptoUtils.getFileDecrypter(cryptoService, Scope.WAL, null, input);
         log.debug("Using {} for decrypting WAL", cryptoService.getClass().getSimpleName());
-        var stream = decrypter.decryptStream(input);
-        decryptingInput = stream instanceof DataInputStream ? (DataInputStream) stream
-            : new DataInputStream(stream);
+        decryptingInput = cryptoService instanceof NoCryptoService ? input
+            : new DataInputStream(decrypter.decryptStream(input));
       } else if (Arrays.equals(magicBuffer, magic3)) {
         // Read logs files from Accumulo 1.9 and throw an error if they are encrypted
         String cryptoModuleClassname = input.readUTF();
@@ -376,7 +376,7 @@ public class DfsLogger implements Comparable<DfsLogger> {
         decryptingInput = input;
       } else {
         throw new IllegalArgumentException(
-            "Unsupported write ahead log version " + new String(magicBuffer, UTF_8));
+            "Unsupported write ahead log version " + new String(magicBuffer));
       }
     } catch (EOFException e) {
       // Explicitly catch any exceptions that should be converted to LogHeaderIncompleteException
@@ -462,9 +462,9 @@ public class DfsLogger implements Comparable<DfsLogger> {
       }
 
       LogFileKey key = new LogFileKey();
-      key.setEvent(OPEN);
-      key.setTserverSession(filename);
-      key.setFilename(filename);
+      key.event = OPEN;
+      key.tserverSession = filename;
+      key.filename = filename;
       op = logKeyData(key, Durability.SYNC);
     } catch (Exception ex) {
       if (logFile != null) {
@@ -475,8 +475,7 @@ public class DfsLogger implements Comparable<DfsLogger> {
       throw new IOException(ex);
     }
 
-    syncThread =
-        Threads.createCriticalThread("Accumulo WALog thread " + this, new LogSyncingTask());
+    syncThread = Threads.createThread("Accumulo WALog thread " + this, new LogSyncingTask());
     syncThread.start();
     op.await();
     log.debug("Got new write-ahead log: {}", this);
@@ -485,9 +484,7 @@ public class DfsLogger implements Comparable<DfsLogger> {
   static long getWalBlockSize(AccumuloConfiguration conf) {
     long blockSize = conf.getAsBytes(Property.TSERV_WAL_BLOCKSIZE);
     if (blockSize == 0) {
-      @SuppressWarnings("deprecation")
-      Property prop = conf.resolve(Property.TSERV_WAL_MAX_SIZE, Property.TSERV_WALOG_MAX_SIZE);
-      blockSize = (long) (conf.getAsBytes(prop) * 1.1);
+      blockSize = (long) (conf.getAsBytes(Property.TSERV_WAL_MAX_SIZE) * 1.1);
     }
     return blockSize;
   }
@@ -567,10 +564,10 @@ public class DfsLogger implements Comparable<DfsLogger> {
   public LoggerOperation defineTablet(CommitSession cs) throws IOException {
     // write this log to the METADATA table
     final LogFileKey key = new LogFileKey();
-    key.setEvent(DEFINE_TABLET);
-    key.setSeq(cs.getWALogSeq());
-    key.setTabletId(cs.getLogId());
-    key.setTablet(cs.getExtent());
+    key.event = DEFINE_TABLET;
+    key.seq = cs.getWALogSeq();
+    key.tabletId = cs.getLogId();
+    key.tablet = cs.getExtent();
     return logKeyData(key, Durability.LOG);
   }
 
@@ -622,11 +619,11 @@ public class DfsLogger implements Comparable<DfsLogger> {
     List<Pair<LogFileKey,LogFileValue>> data = new ArrayList<>();
     for (TabletMutations tabletMutations : mutations) {
       LogFileKey key = new LogFileKey();
-      key.setEvent(MANY_MUTATIONS);
-      key.setSeq(tabletMutations.getSeq());
-      key.setTabletId(tabletMutations.getTid());
+      key.event = MANY_MUTATIONS;
+      key.seq = tabletMutations.getSeq();
+      key.tabletId = tabletMutations.getTid();
       LogFileValue value = new LogFileValue();
-      value.setMutations(tabletMutations.getMutations());
+      value.mutations = tabletMutations.getMutations();
       data.add(new Pair<>(key, value));
       durability = maxDurability(tabletMutations.getDurability(), durability);
     }
@@ -635,11 +632,11 @@ public class DfsLogger implements Comparable<DfsLogger> {
 
   public LoggerOperation log(CommitSession cs, Mutation m, Durability d) throws IOException {
     LogFileKey key = new LogFileKey();
-    key.setEvent(MUTATION);
-    key.setSeq(cs.getWALogSeq());
-    key.setTabletId(cs.getLogId());
+    key.event = MUTATION;
+    key.seq = cs.getWALogSeq();
+    key.tabletId = cs.getLogId();
     LogFileValue value = new LogFileValue();
-    value.setMutations(singletonList(m));
+    value.mutations = singletonList(m);
     return logFileData(singletonList(new Pair<>(key, value)), d);
   }
 
@@ -657,19 +654,19 @@ public class DfsLogger implements Comparable<DfsLogger> {
   public LoggerOperation minorCompactionFinished(long seq, int tid, Durability durability)
       throws IOException {
     LogFileKey key = new LogFileKey();
-    key.setEvent(COMPACTION_FINISH);
-    key.setSeq(seq);
-    key.setTabletId(tid);
+    key.event = COMPACTION_FINISH;
+    key.seq = seq;
+    key.tabletId = tid;
     return logKeyData(key, durability);
   }
 
   public LoggerOperation minorCompactionStarted(long seq, int tid, String fqfn,
       Durability durability) throws IOException {
     LogFileKey key = new LogFileKey();
-    key.setEvent(COMPACTION_START);
-    key.setSeq(seq);
-    key.setTabletId(tid);
-    key.setFilename(fqfn);
+    key.event = COMPACTION_START;
+    key.seq = seq;
+    key.tabletId = tid;
+    key.filename = fqfn;
     return logKeyData(key, durability);
   }
 
