@@ -18,9 +18,6 @@
  */
 package org.apache.accumulo.tserver.log;
 
-import static java.nio.charset.StandardCharsets.UTF_8;
-import static org.apache.accumulo.core.util.threads.ThreadPoolNames.TSERVER_WAL_SORT_CONCURRENT_POOL;
-
 import java.io.DataInputStream;
 import java.io.EOFException;
 import java.io.IOException;
@@ -41,12 +38,12 @@ import org.apache.accumulo.core.crypto.CryptoEnvironmentImpl;
 import org.apache.accumulo.core.data.Key;
 import org.apache.accumulo.core.data.Mutation;
 import org.apache.accumulo.core.file.FileOperations;
-import org.apache.accumulo.core.master.thrift.RecoveryStatus;
+import org.apache.accumulo.core.manager.thrift.RecoveryStatus;
+import org.apache.accumulo.core.metadata.UnreferencedTabletFile;
 import org.apache.accumulo.core.spi.crypto.CryptoEnvironment;
 import org.apache.accumulo.core.spi.crypto.CryptoService;
 import org.apache.accumulo.core.util.Pair;
 import org.apache.accumulo.core.util.threads.ThreadPools;
-import org.apache.accumulo.server.AbstractServer;
 import org.apache.accumulo.server.ServerContext;
 import org.apache.accumulo.server.fs.VolumeManager;
 import org.apache.accumulo.server.log.SortedLogState;
@@ -67,6 +64,7 @@ import com.google.common.annotations.VisibleForTesting;
 public class LogSorter {
 
   private static final Logger log = LoggerFactory.getLogger(LogSorter.class);
+  AccumuloConfiguration sortedLogConf;
 
   private final Map<String,LogProcessor> currentWork = Collections.synchronizedMap(new HashMap<>());
 
@@ -85,7 +83,7 @@ public class LogSorter {
 
     @Override
     public void process(String child, byte[] data) {
-      String work = new String(data, UTF_8);
+      String work = new String(data);
       String[] parts = work.split("\\|");
       String src = parts[0];
       String dest = parts[1];
@@ -168,10 +166,7 @@ public class LogSorter {
         return;
       }
 
-      @SuppressWarnings("deprecation")
-      Property prop = sortedLogConf.resolve(Property.TSERV_WAL_SORT_BUFFER_SIZE,
-          Property.TSERV_SORT_BUFFER_SIZE);
-      final long bufferSize = sortedLogConf.getAsBytes(prop);
+      final long bufferSize = sortedLogConf.getAsBytes(Property.TSERV_WAL_SORT_BUFFER_SIZE);
       Thread.currentThread().setName("Sorting " + name + " for recovery");
       while (true) {
         final ArrayList<Pair<LogFileKey,LogFileValue>> buffer = new ArrayList<>();
@@ -224,20 +219,21 @@ public class LogSorter {
     }
   }
 
+  ThreadPoolExecutor threadPool;
   private final ServerContext context;
-  private final AccumuloConfiguration conf;
   private final double walBlockSize;
   private final CryptoService cryptoService;
-  private final AccumuloConfiguration sortedLogConf;
 
   public LogSorter(ServerContext context, AccumuloConfiguration conf) {
     this.context = context;
-    this.conf = conf;
-    this.sortedLogConf = extractSortedLogConfig(this.conf);
-    this.walBlockSize = DfsLogger.getWalBlockSize(this.conf);
+    this.sortedLogConf = extractSortedLogConfig(conf);
+
+    int threadPoolSize = conf.getCount(Property.TSERV_WAL_SORT_MAX_CONCURRENT);
+    this.threadPool = ThreadPools.getServerThreadPools().createFixedThreadPool(threadPoolSize,
+        this.getClass().getName(), true);
+    this.walBlockSize = DfsLogger.getWalBlockSize(conf);
     CryptoEnvironment env = new CryptoEnvironmentImpl(CryptoEnvironment.Scope.RECOVERY);
-    this.cryptoService =
-        context.getCryptoFactory().getService(env, this.conf.getAllCryptoProperties());
+    this.cryptoService = context.getCryptoFactory().getService(env, conf.getAllCryptoProperties());
   }
 
   /**
@@ -274,31 +270,31 @@ public class LogSorter {
       var logFileKey = pair.getFirst();
       var logFileValue = pair.getSecond();
       Key k = logFileKey.toKey();
-      keyListMap.computeIfAbsent(k, (key) -> new ArrayList<>()).addAll(logFileValue.getMutations());
+      var list = keyListMap.putIfAbsent(k, logFileValue.mutations);
+      if (list != null) {
+        var muts = new ArrayList<>(list);
+        muts.addAll(logFileValue.mutations);
+        keyListMap.put(logFileKey.toKey(), muts);
+      }
     }
 
     try (var writer = FileOperations.getInstance().newWriterBuilder()
-        .forFile(fullPath.toString(), fs, fs.getConf(), cryptoService)
+        .forFile(UnreferencedTabletFile.of(fs, fullPath), fs, fs.getConf(), cryptoService)
         .withTableConfiguration(sortedLogConf).build()) {
       writer.startDefaultLocalityGroup();
       for (var entry : keyListMap.entrySet()) {
         LogFileValue val = new LogFileValue();
-        val.setMutations(entry.getValue());
+        val.mutations = entry.getValue();
         writer.append(entry.getKey(), val.toValue());
       }
     }
   }
 
-  public void startWatchingForRecoveryLogs(AbstractServer server)
+  public void startWatchingForRecoveryLogs(ThreadPoolExecutor distWorkQThreadPool)
       throws KeeperException, InterruptedException {
-    @SuppressWarnings("deprecation")
-    int threadPoolSize = this.conf.getCount(this.conf
-        .resolve(Property.TSERV_WAL_SORT_MAX_CONCURRENT, Property.TSERV_RECOVERY_MAX_CONCURRENT));
-    ThreadPoolExecutor threadPool =
-        ThreadPools.getServerThreadPools().getPoolBuilder(TSERVER_WAL_SORT_CONCURRENT_POOL)
-            .numCoreThreads(threadPoolSize).enableThreadPoolMetrics().build();
+    this.threadPool = distWorkQThreadPool;
     new DistributedWorkQueue(context.getZooKeeperRoot() + Constants.ZRECOVERY, sortedLogConf,
-        server).startProcessing(new LogProcessor(), threadPool);
+        context).startProcessing(new LogProcessor(), this.threadPool);
   }
 
   public List<RecoveryStatus> getLogSorts() {
