@@ -19,7 +19,6 @@
 package org.apache.accumulo.tserver.log;
 
 import static java.util.Collections.singletonList;
-import static org.apache.accumulo.core.util.threads.ThreadPoolNames.TSERVER_WAL_CREATOR_POOL;
 
 import java.io.IOException;
 import java.nio.channels.ClosedChannelException;
@@ -39,16 +38,12 @@ import java.util.concurrent.locks.ReentrantReadWriteLock;
 import org.apache.accumulo.core.client.Durability;
 import org.apache.accumulo.core.data.Mutation;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
-import org.apache.accumulo.core.fate.zookeeper.ServiceLock;
-import org.apache.accumulo.core.protobuf.ProtobufUtil;
 import org.apache.accumulo.core.util.Halt;
 import org.apache.accumulo.core.util.Retry;
 import org.apache.accumulo.core.util.Retry.RetryFactory;
 import org.apache.accumulo.core.util.threads.ThreadPools;
 import org.apache.accumulo.server.ServerContext;
 import org.apache.accumulo.server.fs.VolumeManager;
-import org.apache.accumulo.server.replication.proto.Replication.Status;
-import org.apache.accumulo.server.util.ReplicationTableUtil;
 import org.apache.accumulo.tserver.TabletMutations;
 import org.apache.accumulo.tserver.TabletServer;
 import org.apache.accumulo.tserver.log.DfsLogger.LoggerOperation;
@@ -228,7 +223,6 @@ public class TabletServerLogger {
         }
 
         this.createTime = System.currentTimeMillis();
-        return;
       } else {
         throw new RuntimeException("Error: unexpected type seen: " + next);
       }
@@ -250,8 +244,9 @@ public class TabletServerLogger {
           throw new RuntimeException(e);
         }
       } else {
+        log.error("Repeatedly failed to create WAL. Going to exit tabletserver.", t);
         // We didn't have retries or we failed too many times.
-        Halt.halt(1, "Experienced too many errors creating WALs, giving up", t);
+        Halt.halt("Experienced too many errors creating WALs, giving up", 1);
       }
 
       // The exception will trigger the log creation to be re-attempted.
@@ -263,98 +258,89 @@ public class TabletServerLogger {
     if (nextLogMaker != null) {
       return;
     }
-    nextLogMaker = ThreadPools.getServerThreadPools().getPoolBuilder(TSERVER_WAL_CREATOR_POOL)
-        .numCoreThreads(1).build();
-    nextLogMaker.execute(new Runnable() {
-      @Override
-      public void run() {
-        final ServerResources conf = tserver.getServerConfig();
-        final VolumeManager fs = conf.getVolumeManager();
-        while (!nextLogMaker.isShutdown()) {
-          log.debug("Creating next WAL");
-          DfsLogger alog = null;
-
-          try {
-            alog = new DfsLogger(tserver.getContext(), conf, syncCounter, flushCounter);
-            alog.open(tserver.getClientAddressString());
-          } catch (Exception t) {
-            log.error("Failed to open WAL", t);
-            // the log is not advertised in ZK yet, so we can just delete it if it exists
-            if (alog != null) {
-              try {
-                alog.close();
-              } catch (Exception e) {
-                log.error("Failed to close WAL after it failed to open", e);
-              }
-
-              try {
-                Path path = alog.getPath();
-                if (fs.exists(path)) {
-                  fs.delete(path);
-                }
-              } catch (Exception e) {
-                log.warn("Failed to delete a WAL that failed to open", e);
-              }
-            }
+    nextLogMaker =
+        ThreadPools.getServerThreadPools().createFixedThreadPool(1, "WALog creator", true);
+    nextLogMaker.execute(() -> {
+      final ServerResources conf = tserver.getServerConfig();
+      final VolumeManager fs = conf.getVolumeManager();
+      while (!nextLogMaker.isShutdown()) {
+        log.debug("Creating next WAL");
+        DfsLogger alog = null;
 
+        try {
+          alog = new DfsLogger(tserver.getContext(), conf, syncCounter, flushCounter);
+          alog.open(tserver.getClientAddressString());
+        } catch (Exception t) {
+          log.error("Failed to open WAL", t);
+          // the log is not advertised in ZK yet, so we can just delete it if it exists
+          if (alog != null) {
             try {
-              nextLog.offer(t, 12, TimeUnit.HOURS);
-            } catch (InterruptedException ex) {
-              // Throw an Error, not an Exception, so the AccumuloUncaughtExceptionHandler
-              // will log this then halt the VM.
-              throw new Error("Next log maker thread interrupted", ex);
-            }
-
-            continue;
-          }
-
-          String fileName = alog.getFileName();
-          log.debug("Created next WAL {}", fileName);
-
-          try {
-            tserver.addNewLogMarker(alog);
-          } catch (Exception t) {
-            log.error("Failed to add new WAL marker for " + fileName, t);
-
-            try {
-              // Intentionally not deleting walog because it may have been advertised in ZK. See
-              // #949
               alog.close();
             } catch (Exception e) {
               log.error("Failed to close WAL after it failed to open", e);
             }
 
-            // it's possible the log was advertised in ZK even though we got an
-            // exception. If there's a chance the WAL marker may have been created,
-            // this will ensure it's closed. Either the close will be written and
-            // the GC will clean it up, or the tserver is about to die due to sesson
-            // expiration and the GC will also clean it up.
             try {
-              tserver.walogClosed(alog);
+              Path path = alog.getPath();
+              if (fs.exists(path)) {
+                fs.delete(path);
+              }
             } catch (Exception e) {
-              log.error("Failed to close WAL that failed to open: " + fileName, e);
+              log.warn("Failed to delete a WAL that failed to open", e);
             }
-
-            try {
-              nextLog.offer(t, 12, TimeUnit.HOURS);
-            } catch (InterruptedException ex) {
-              // Throw an Error, not an Exception, so the AccumuloUncaughtExceptionHandler
-              // will log this then halt the VM.
-              throw new Error("Next log maker thread interrupted", ex);
-            }
-
-            continue;
           }
 
           try {
-            while (!nextLog.offer(alog, 12, TimeUnit.HOURS)) {
-              log.info("Our WAL was not used for 12 hours: {}", fileName);
-            }
-          } catch (InterruptedException e) {
-            // Throw an Error, not an Exception, so the AccumuloUncaughtExceptionHandler
-            // will log this then halt the VM.
-            throw new Error("Next log maker thread interrupted", e);
+            nextLog.offer(t, 12, TimeUnit.HOURS);
+          } catch (InterruptedException ex) {
+            // ignore
           }
+
+          continue;
+        }
+
+        String fileName = alog.getFileName();
+        log.debug("Created next WAL {}", fileName);
+
+        try {
+          tserver.addNewLogMarker(alog);
+        } catch (Exception t) {
+          log.error("Failed to add new WAL marker for " + fileName, t);
+
+          try {
+            // Intentionally not deleting walog because it may have been advertised in ZK. See
+            // #949
+            alog.close();
+          } catch (Exception e) {
+            log.error("Failed to close WAL after it failed to open", e);
+          }
+
+          // it's possible the log was advertised in ZK even though we got an
+          // exception. If there's a chance the WAL marker may have been created,
+          // this will ensure it's closed. Either the close will be written and
+          // the GC will clean it up, or the tserver is about to die due to sesson
+          // expiration and the GC will also clean it up.
+          try {
+            tserver.walogClosed(alog);
+          } catch (Exception e) {
+            log.error("Failed to close WAL that failed to open: " + fileName, e);
+          }
+
+          try {
+            nextLog.offer(t, 12, TimeUnit.HOURS);
+          } catch (InterruptedException ex) {
+            // ignore
+          }
+
+          continue;
+        }
+
+        try {
+          while (!nextLog.offer(alog, 12, TimeUnit.HOURS)) {
+            log.info("Our WAL was not used for 12 hours: {}", fileName);
+          }
+        } catch (InterruptedException e) {
+          // ignore - server is shutting down
         }
       }
     });
@@ -394,7 +380,6 @@ public class TabletServerLogger {
 
     boolean success = false;
     while (!success) {
-      Throwable sawWriteFailure = null;
       try {
         // get a reference to the loggers that no other thread can touch
         AtomicInteger currentId = new AtomicInteger(-1);
@@ -414,23 +399,6 @@ public class TabletServerLogger {
               } finally {
                 commitSession.finishUpdatingLogsUsed();
               }
-
-              // Need to release
-              KeyExtent extent = commitSession.getExtent();
-              @SuppressWarnings("deprecation")
-              boolean replicationEnabled =
-                  org.apache.accumulo.core.replication.ReplicationConfigurationUtil
-                      .isEnabled(extent, tserver.getTableConfiguration(extent));
-              if (replicationEnabled) {
-                @SuppressWarnings("deprecation")
-                Status status = org.apache.accumulo.server.replication.StatusUtil
-                    .openWithUnknownLength(System.currentTimeMillis());
-                log.debug("Writing " + ProtobufUtil.toString(status) + " to metadata table for "
-                    + copy.getFileName());
-                // Got some new WALs, note this in the metadata table
-                ReplicationTableUtil.updateFiles(tserver.getContext(), commitSession.getExtent(),
-                    copy.getFileName(), status);
-              }
             }
           }
         }
@@ -449,7 +417,7 @@ public class TabletServerLogger {
         writeRetry.logRetry(log, "Logs closed while writing", ex);
       } catch (Exception t) {
         writeRetry.logRetry(log, "Failed to write to WAL", t);
-        sawWriteFailure = t;
+
         try {
           // Backoff
           writeRetry.waitForNextAttempt(log, "write to WAL");
@@ -465,15 +433,6 @@ public class TabletServerLogger {
       // the logs haven't changed.
       final int finalCurrent = currentLogId;
       if (!success) {
-        final ServiceLock tabletServerLock = tserver.getLock();
-        if (sawWriteFailure != null) {
-          log.info("WAL write failure, validating server lock in ZooKeeper", sawWriteFailure);
-          if (tabletServerLock == null || !tabletServerLock.verifyLockAtSource()) {
-            Halt.halt(-1, "Writing to WAL has failed and TabletServer lock does not exist",
-                sawWriteFailure);
-          }
-        }
-
         testLockAndRun(logIdLock, new TestCallWithWriteLock() {
 
           @Override
