@@ -45,62 +45,13 @@ import com.google.common.base.Preconditions;
 public class LogFileKey implements WritableComparable<LogFileKey> {
   private static final Logger log = LoggerFactory.getLogger(LogFileKey.class);
 
+  public LogEvents event;
+  public String filename = null;
+  public KeyExtent tablet = null;
+  public long seq = -1;
+  public int tabletId = -1;
   public static final int VERSION = 2;
-
-  private LogEvents event;
-  private String filename = null;
-  private KeyExtent tablet = null;
-  private long seq = -1;
-  private int tabletId = -1;
-  private String tserverSession;
-
-  public LogEvents getEvent() {
-    return event;
-  }
-
-  public String getFilename() {
-    return filename;
-  }
-
-  public KeyExtent getTablet() {
-    return tablet;
-  }
-
-  public long getSeq() {
-    return seq;
-  }
-
-  public int getTabletId() {
-    return tabletId;
-  }
-
-  public String getTserverSession() {
-    return tserverSession;
-  }
-
-  public void setEvent(LogEvents event) {
-    this.event = event;
-  }
-
-  public void setFilename(String filename) {
-    this.filename = filename;
-  }
-
-  public void setTablet(KeyExtent tablet) {
-    this.tablet = tablet;
-  }
-
-  public void setSeq(long seq) {
-    this.seq = seq;
-  }
-
-  public void setTabletId(int tabletId) {
-    this.tabletId = tabletId;
-  }
-
-  public void setTserverSession(String tserverSession) {
-    this.tserverSession = tserverSession;
-  }
+  public String tserverSession;
 
   @Override
   public void readFields(DataInput in) throws IOException {
@@ -342,9 +293,7 @@ public class LogFileKey implements WritableComparable<LogFileKey> {
     row[11] = (byte) ((seq >>> 8) & mask);
     row[12] = (byte) (seq & mask);
 
-    if (log.isTraceEnabled()) {
-      log.trace("Convert {} {} {} to row {}", event, tabletId, seq, Arrays.toString(row));
-    }
+    log.trace("Convert {} {} {} to row {}", event, tabletId, seq, Arrays.toString(row));
     return row;
   }
 
@@ -398,10 +347,8 @@ public class LogFileKey implements WritableComparable<LogFileKey> {
     if (eventType(logFileKey.event) != rowParts[0]) {
       throw new AssertionError("Event in row differs from column family. Key: " + key);
     }
-    if (log.isTraceEnabled()) {
-      log.trace("From row {} get {} {} {}", Arrays.toString(rowParts), logFileKey.event,
-          logFileKey.tabletId, logFileKey.seq);
-    }
+    log.trace("From row {} get {} {} {}", Arrays.toString(rowParts), logFileKey.event,
+        logFileKey.tabletId, logFileKey.seq);
 
     // handle special cases of what is stored in the qualifier
     switch (logFileKey.event) {
