@@ -42,15 +42,7 @@ public class LogFileValue implements Writable {
 
   private static final List<Mutation> empty = Collections.emptyList();
 
-  private List<Mutation> mutations = empty;
-
-  public List<Mutation> getMutations() {
-    return mutations;
-  }
-
-  public void setMutations(List<Mutation> mutations) {
-    this.mutations = mutations;
-  }
+  public List<Mutation> mutations = empty;
 
   @Override
   public void readFields(DataInput in) throws IOException {
@@ -92,7 +84,7 @@ public class LogFileValue implements Writable {
       }
       builder.append("  ").append(new String(m.getRow(), UTF_8)).append("\n");
       for (ColumnUpdate update : m.getUpdates()) {
-        String value = new String(update.getValue(), UTF_8);
+        String value = new String(update.getValue());
         builder.append("      ").append(new String(update.getColumnFamily(), UTF_8)).append(":")
             .append(new String(update.getColumnQualifier(), UTF_8)).append(" ")
             .append(update.hasTimestamp() ? "[user]:" : "[system]:").append(update.getTimestamp())
