@@ -217,7 +217,7 @@ public class LogReader implements KeywordExecutable {
         }
       } else {
         throw new IllegalArgumentException(
-            "Unsupported write ahead log version " + new String(magicBuffer, UTF_8));
+            "Unsupported write ahead log version " + new String(magicBuffer));
       }
     } catch (EOFException e) {
       log.warn("Could not read header for {} . Ignoring...", path);
@@ -230,21 +230,21 @@ public class LogReader implements KeywordExecutable {
       KeyExtent ke, Set<Integer> tabletIds, int maxMutations) {
 
     if (ke != null) {
-      if (key.getEvent() == LogEvents.DEFINE_TABLET) {
-        if (key.getTablet().equals(ke)) {
-          tabletIds.add(key.getTabletId());
+      if (key.event == LogEvents.DEFINE_TABLET) {
+        if (key.tablet.equals(ke)) {
+          tabletIds.add(key.tabletId);
         } else {
           return;
         }
-      } else if (!tabletIds.contains(key.getTabletId())) {
+      } else if (!tabletIds.contains(key.tabletId)) {
         return;
       }
     }
 
     if (row != null || rowMatcher != null) {
-      if (key.getEvent() == LogEvents.MUTATION || key.getEvent() == LogEvents.MANY_MUTATIONS) {
+      if (key.event == LogEvents.MUTATION || key.event == LogEvents.MANY_MUTATIONS) {
         boolean found = false;
-        for (Mutation m : value.getMutations()) {
+        for (Mutation m : value.mutations) {
           if (row != null && new Text(m.getRow()).equals(row)) {
             found = true;
             break;
