@@ -47,29 +47,16 @@ public class CompactionExecutorsMetrics implements MetricsProducer {
   private volatile List<CeMetrics> ceMetricsList = List.of();
   private final Map<CompactionExecutorId,CeMetrics> ceMetricsMap = new HashMap<>();
   private final Map<CompactionExecutorId,ExMetrics> exCeMetricsMap = new HashMap<>();
-  private volatile MeterRegistry registry = null;
+  private MeterRegistry registry = null;
 
   // public so it can be closed by outside callers
-  public class CeMetrics implements AutoCloseable {
-    private final AtomicInteger queued;
-    private final AtomicInteger running;
+  public static class CeMetrics implements AutoCloseable {
+    private AtomicInteger queued;
+    private AtomicInteger running;
 
     private IntSupplier runningSupplier;
     private IntSupplier queuedSupplier;
 
-    private CeMetrics(CompactionExecutorId ceid) {
-      if (registry != null) {
-        this.queued = registry.gauge(METRICS_MAJC_QUEUED, Tags.of("id", ceid.canonical()),
-            new AtomicInteger(0));
-        this.running = registry.gauge(METRICS_MAJC_RUNNING, Tags.of("id", ceid.canonical()),
-            new AtomicInteger(0));
-      } else {
-        // these vars have no effect on metrics in this case - just avoids NPEs
-        this.queued = new AtomicInteger(0);
-        this.running = new AtomicInteger(0);
-      }
-    }
-
     @Override
     public void close() {
       runningSupplier = () -> 0;
@@ -79,31 +66,14 @@ public class CompactionExecutorsMetrics implements MetricsProducer {
     }
   }
 
-  private class ExMetrics {
-    private final AtomicInteger queued;
-    private final AtomicInteger running;
-
-    private ExMetrics(CompactionExecutorId ceid) {
-      if (registry != null) {
-        this.queued = registry.gauge(METRICS_MAJC_QUEUED, Tags.of("id", ceid.canonical()),
-            new AtomicInteger(0));
-        this.running = registry.gauge(METRICS_MAJC_RUNNING, Tags.of("id", ceid.canonical()),
-            new AtomicInteger(0));
-      } else {
-        // these vars have no effect on metrics in this case - just avoids NPEs
-        this.queued = new AtomicInteger(0);
-        this.running = new AtomicInteger(0);
-      }
-    }
+  private static class ExMetrics {
+    AtomicInteger queued;
+    AtomicInteger running;
   }
 
   public CompactionExecutorsMetrics() {
-    startUpdateThread();
-  }
-
-  protected void startUpdateThread() {
     ScheduledExecutorService scheduler = ThreadPools.getServerThreadPools()
-        .createScheduledExecutorService(1, "compactionExecutorsMetricsPoller");
+        .createScheduledExecutorService(1, "compactionExecutorsMetricsPoller", false);
     Runtime.getRuntime().addShutdownHook(new Thread(scheduler::shutdownNow));
     long minimumRefreshDelay = TimeUnit.SECONDS.toMillis(5);
     ThreadPools.watchNonCriticalScheduledTask(scheduler.scheduleAtFixedRate(this::update,
@@ -115,7 +85,16 @@ public class CompactionExecutorsMetrics implements MetricsProducer {
 
     synchronized (ceMetricsMap) {
 
-      CeMetrics cem = ceMetricsMap.computeIfAbsent(ceid, id -> new CeMetrics(ceid));
+      CeMetrics cem = ceMetricsMap.computeIfAbsent(ceid, id -> {
+        CeMetrics m = new CeMetrics();
+        if (registry != null) {
+          m.queued = registry.gauge(METRICS_MAJC_QUEUED, Tags.of("id", ceid.canonical()),
+              new AtomicInteger(0));
+          m.running = registry.gauge(METRICS_MAJC_RUNNING, Tags.of("id", ceid.canonical()),
+              new AtomicInteger(0));
+        }
+        return m;
+      });
 
       cem.runningSupplier = runningSupplier;
       cem.queuedSupplier = queuedSupplier;
@@ -137,7 +116,16 @@ public class CompactionExecutorsMetrics implements MetricsProducer {
         externalMetricsSupplier.get().forEach(ecm -> {
           seenIds.add(ecm.ceid);
 
-          ExMetrics exm = exCeMetricsMap.computeIfAbsent(ecm.ceid, id -> new ExMetrics(ecm.ceid));
+          ExMetrics exm = exCeMetricsMap.computeIfAbsent(ecm.ceid, id -> {
+            ExMetrics m = new ExMetrics();
+            if (registry != null) {
+              m.queued = registry.gauge(METRICS_MAJC_QUEUED, Tags.of("id", ecm.ceid.canonical()),
+                  new AtomicInteger(0));
+              m.running = registry.gauge(METRICS_MAJC_RUNNING, Tags.of("id", ecm.ceid.canonical()),
+                  new AtomicInteger(0));
+            }
+            return m;
+          });
 
           exm.queued.set(ecm.queued);
           exm.running.set(ecm.running);
