@@ -64,16 +64,15 @@ public class LookupTask extends ScanTask<MultiScanResult> {
     MultiScanSession session = (MultiScanSession) server.getSession(scanID);
     String oldThreadName = Thread.currentThread().getName();
 
-    if (!transitionToRunning()) {
-      return;
-    }
-    // Do not add any code here. Need to ensure that transitionFromRunning() runs in the finally
-    // block when transitionToRunning() returns true.
     try {
       if (isCancelled() || session == null) {
         return;
       }
 
+      if (!transitionToRunning()) {
+        return;
+      }
+
       TableConfiguration acuTableConf = server.getTableConfiguration(session.threadPoolExtent);
       long maxResultsSize = acuTableConf.getAsBytes(Property.TABLE_SCAN_MAXMEM);
 
@@ -184,8 +183,8 @@ public class LookupTask extends ScanTask<MultiScanResult> {
       log.warn("exception while doing multi-scan ", e);
       addResult(e);
     } finally {
-      transitionFromRunning();
       Thread.currentThread().setName(oldThreadName);
+      runState.set(ScanRunState.FINISHED);
     }
   }
 
