@@ -43,7 +43,6 @@ public final class ScanParameters {
   private final SamplerConfiguration samplerConfig;
   private final long batchTimeOut;
   private final String classLoaderContext;
-  private volatile Long scanSessionId = null;
   private volatile ScanDispatch dispatch;
 
   public ScanParameters(int maxEntries, Authorizations authorizations, Set<Column> columnSet,
@@ -107,14 +106,6 @@ public final class ScanParameters {
     return dispatch;
   }
 
-  public void setScanSessionId(long scanSessionId) {
-    this.scanSessionId = scanSessionId;
-  }
-
-  public Long getScanSessionId() {
-    return scanSessionId;
-  }
-
   @Override
   public String toString() {
     StringBuilder buf = new StringBuilder();
@@ -127,7 +118,6 @@ public final class ScanParameters {
     buf.append(", maxEntries=").append(this.maxEntries);
     buf.append(", num=").append(this.maxEntries);
     buf.append(", samplerConfig=").append(this.samplerConfig);
-    buf.append(", scanSessionId=").append(this.scanSessionId);
     buf.append("]");
     return buf.toString();
   }
