@@ -28,8 +28,9 @@ import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.dataImpl.thrift.MultiScanResult;
 import org.apache.accumulo.core.securityImpl.thrift.TCredentials;
 import org.apache.accumulo.tserver.scan.ScanParameters;
+import org.apache.accumulo.tserver.scan.ScanTask;
 
-public class MultiScanSession extends ScanSession<MultiScanResult> {
+public class MultiScanSession extends ScanSession {
   public final KeyExtent threadPoolExtent;
   public final Map<KeyExtent,List<Range>> queries;
   public final Set<KeyExtent> exents;
@@ -40,6 +41,8 @@ public class MultiScanSession extends ScanSession<MultiScanResult> {
   public int numEntries;
   public long totalLookupTime;
 
+  public volatile ScanTask<MultiScanResult> lookupTask;
+
   public MultiScanSession(TCredentials credentials, KeyExtent threadPoolExtent,
       Map<KeyExtent,List<Range>> queries, ScanParameters scanParams,
       Map<String,String> executionHints, TabletResolver tabletResolver) {
@@ -61,10 +64,8 @@ public class MultiScanSession extends ScanSession<MultiScanResult> {
 
   @Override
   public boolean cleanup() {
-    // read volatile once to avoid race conditions
-    var localScanTask = getScanTask();
-    if (localScanTask != null) {
-      localScanTask.cancel(true);
+    if (lookupTask != null) {
+      lookupTask.cancel(true);
     }
     // the cancellation should provide us the safety to return true here
     return super.cleanup();
