@@ -18,10 +18,7 @@
  */
 package org.apache.accumulo.tserver.session;
 
-import java.util.concurrent.TimeUnit;
-
 import org.apache.accumulo.core.securityImpl.thrift.TCredentials;
-import org.apache.accumulo.core.util.Timer;
 import org.apache.accumulo.server.rpc.TServerUtils;
 
 public class Session {
@@ -33,9 +30,7 @@ public class Session {
   public final String client;
   public long lastAccessTime;
   public long startTime;
-  private State state = State.NEW;
-  boolean allowReservation = true;
-  private final Timer stateChangeTimer = Timer.startNew();
+  State state = State.NEW;
   private final TCredentials credentials;
 
   Session(TCredentials credentials) {
@@ -55,21 +50,6 @@ public class Session {
     return true;
   }
 
-  public void setState(State state) {
-    if (this.state != state) {
-      this.state = state;
-      stateChangeTimer.restart();
-    }
-  }
-
-  public State getState() {
-    return state;
-  }
-
-  public long elaspedSinceStateChange(TimeUnit unit) {
-    return stateChangeTimer.elapsed(unit);
-  }
-
   @Override
   public String toString() {
     return getClass().getSimpleName() + " " + state + " startTime:" + startTime + " lastAccessTime:"
