@@ -38,9 +38,7 @@ import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentSkipListSet;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicLong;
-import java.util.function.BooleanSupplier;
 import java.util.function.Consumer;
-import java.util.function.Predicate;
 import java.util.function.Supplier;
 import java.util.stream.Collectors;
 
@@ -54,8 +52,8 @@ import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.logging.TabletLogger;
 import org.apache.accumulo.core.manager.thrift.TabletLoadState;
 import org.apache.accumulo.core.metadata.CompactableFileImpl;
+import org.apache.accumulo.core.metadata.ReferencedTabletFile;
 import org.apache.accumulo.core.metadata.StoredTabletFile;
-import org.apache.accumulo.core.metadata.TabletFile;
 import org.apache.accumulo.core.metadata.schema.DataFileValue;
 import org.apache.accumulo.core.metadata.schema.ExternalCompactionId;
 import org.apache.accumulo.core.metadata.schema.ExternalCompactionMetadata;
@@ -82,7 +80,6 @@ import org.apache.zookeeper.KeeperException.NoNodeException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.annotations.VisibleForTesting;
 import com.google.common.base.Preconditions;
 import com.google.common.base.Suppliers;
 import com.google.common.collect.Collections2;
@@ -107,12 +104,12 @@ public class CompactableImpl implements Compactable {
 
   private final FileManager fileMgr;
 
-  private final Set<CompactionJob> runningJobs = new HashSet<>();
+  private Set<CompactionJob> runningJobs = new HashSet<>();
   private volatile boolean compactionRunning = false;
 
-  private final Supplier<Set<CompactionServiceId>> servicesInUse;
+  private Supplier<Set<CompactionServiceId>> servicesInUse;
 
-  private final Set<CompactionServiceId> servicesUsed = new ConcurrentSkipListSet<>();
+  private Set<CompactionServiceId> servicesUsed = new ConcurrentSkipListSet<>();
 
   enum ChopSelectionStatus {
     SELECTING, SELECTED, NOT_ACTIVE, MARKING
@@ -127,16 +124,16 @@ public class CompactableImpl implements Compactable {
   private Long compactionId;
   private CompactionConfig compactionConfig;
 
-  private final CompactionManager manager;
+  private CompactionManager manager;
 
   AtomicLong lastSeenCompactionCancelId = new AtomicLong(Long.MIN_VALUE);
 
   private volatile boolean closed = false;
 
-  private final Map<ExternalCompactionId,ExternalCompactionInfo> externalCompactions =
+  private Map<ExternalCompactionId,ExternalCompactionInfo> externalCompactions =
       new ConcurrentHashMap<>();
 
-  private final Set<ExternalCompactionId> externalCompactionsCommitting = new HashSet<>();
+  private Set<ExternalCompactionId> externalCompactionsCommitting = new HashSet<>();
 
   // This interface exists for two purposes. First it allows abstraction of new and old
   // implementations for user pluggable file selection code. Second it facilitates placing code
@@ -144,9 +141,7 @@ public class CompactableImpl implements Compactable {
   public interface CompactionHelper {
     Set<StoredTabletFile> selectFiles(SortedMap<StoredTabletFile,DataFileValue> allFiles);
 
-    Set<StoredTabletFile> getFilesToDrop();
-
-    Map<String,String> getConfigOverrides(Set<CompactableFile> files, TabletFile tmpFile);
+    Map<String,String> getConfigOverrides(Set<CompactableFile> files);
 
   }
 
@@ -196,17 +191,17 @@ public class CompactableImpl implements Compactable {
     // important to track this in order to know if the last compaction is a full compaction and
     // should not propagate deletes.
     private boolean initiallySelectedAll = false;
-    private final Set<StoredTabletFile> selectedFiles = new HashSet<>();
+    private Set<StoredTabletFile> selectedFiles = new HashSet<>();
 
     protected Set<StoredTabletFile> allCompactingFiles = new HashSet<>();
 
     // track files produced by compactions of this tablet, those are considered chopped
-    private final Set<StoredTabletFile> choppedFiles = new HashSet<>();
+    private Set<StoredTabletFile> choppedFiles = new HashSet<>();
     private ChopSelectionStatus chopStatus = ChopSelectionStatus.NOT_ACTIVE;
-    private final Set<StoredTabletFile> allFilesWhenChopStarted = new HashSet<>();
+    private Set<StoredTabletFile> allFilesWhenChopStarted = new HashSet<>();
 
     private final KeyExtent extent;
-    private final Deriver<Duration> selectionExpirationDeriver;
+    private Deriver<Duration> selectionExpirationDeriver;
 
     public FileManager(KeyExtent extent, Collection<StoredTabletFile> extCompactingFiles,
         Optional<SelectedInfo> extSelInfo, Deriver<Duration> selectionExpirationDeriver) {
@@ -233,11 +228,6 @@ public class CompactableImpl implements Compactable {
       return selectKind;
     }
 
-    @VisibleForTesting
-    Set<StoredTabletFile> getSelectedFiles() {
-      return Set.copyOf(selectedFiles);
-    }
-
     SelectedInfo getReservedInfo() {
       Preconditions.checkState(selectStatus == FileSelectionStatus.RESERVED);
       return new SelectedInfo(initiallySelectedAll, selectedFiles, selectKind);
@@ -247,32 +237,12 @@ public class CompactableImpl implements Compactable {
 
     protected abstract long getNanoTime();
 
-    /**
-     * @return the last id of the last successful user compaction
-     */
-    protected abstract long getLastCompactId();
+    boolean initiateSelection(CompactionKind kind) {
 
-    boolean initiateSelection(CompactionKind kind, Long compactionId) {
-
-      Preconditions.checkArgument(
-          kind == CompactionKind.SELECTOR && compactionId == null
-              || kind == CompactionKind.USER && compactionId != null,
-          "Unexpected kind and/or compaction id: %s %s", kind, compactionId);
+      Preconditions.checkArgument(kind == CompactionKind.SELECTOR || kind == CompactionKind.USER);
 
       if (selectStatus == FileSelectionStatus.NOT_ACTIVE || (kind == CompactionKind.USER
-          && selectKind == CompactionKind.SELECTOR && noneRunning(CompactionKind.SELECTOR)
-          && selectStatus != FileSelectionStatus.SELECTING)) {
-
-        // Check compaction id when a lock is held and no other user compactions have files
-        // selected, at this point the results of any previous user compactions should be seen. If
-        // user compaction is currently running, then will not get this far because of the checks a
-        // few lines up.
-        if (kind == CompactionKind.USER && getLastCompactId() >= compactionId) {
-          // This user compaction has already completed, so no need to initiate selection of files
-          // for user compaction.
-          return false;
-        }
-
+          && selectKind == CompactionKind.SELECTOR && noneRunning(CompactionKind.SELECTOR))) {
         selectStatus = FileSelectionStatus.NEW;
         selectKind = kind;
         selectedFiles.clear();
@@ -334,8 +304,8 @@ public class CompactableImpl implements Compactable {
     }
 
     class ChopSelector {
-      private final Set<StoredTabletFile> allFiles;
-      private final Set<StoredTabletFile> filesToExamine;
+      private Set<StoredTabletFile> allFiles;
+      private Set<StoredTabletFile> filesToExamine;
 
       private ChopSelector(Set<StoredTabletFile> allFiles, Set<StoredTabletFile> filesToExamine) {
         this.allFiles = allFiles;
@@ -408,8 +378,7 @@ public class CompactableImpl implements Compactable {
     /**
      * @return The set of tablet files that are candidates for compaction
      */
-    Set<StoredTabletFile> getCandidates(Set<StoredTabletFile> currFiles, CompactionKind kind,
-        boolean isCompactionStratConfigured) {
+    Set<StoredTabletFile> getCandidates(Set<StoredTabletFile> currFiles, CompactionKind kind) {
 
       if (!currFiles.containsAll(allCompactingFiles)) {
         log.trace("Ignoring because compacting not a subset {}", getExtent());
@@ -421,10 +390,6 @@ public class CompactableImpl implements Compactable {
 
       switch (kind) {
         case SYSTEM: {
-          if (isCompactionStratConfigured) {
-            return Set.of();
-          }
-
           return handleSystemCompaction(currFiles);
         }
         case SELECTOR:
@@ -747,11 +712,6 @@ public class CompactableImpl implements Compactable {
       protected long getNanoTime() {
         return System.nanoTime();
       }
-
-      @Override
-      protected long getLastCompactId() {
-        return tablet.getLastCompactId();
-      }
     };
   }
 
@@ -1050,25 +1010,16 @@ public class CompactableImpl implements Compactable {
 
     synchronized (this) {
       if (closed) {
-        log.trace("Selection of files was not initiated {} because closed", getExtent());
         return;
       }
 
-      if (fileMgr.initiateSelection(kind, compactionId)) {
+      if (fileMgr.initiateSelection(kind)) {
         this.chelper = localHelper;
         this.compactionId = compactionId;
         this.compactionConfig = compactionConfig;
         log.trace("Selected compaction status changed {} {} {} {}", getExtent(),
             fileMgr.getSelectionStatus(), compactionId, compactionConfig);
       } else {
-        if (kind == CompactionKind.USER) {
-          // Only log for user compaction because this code is only called when one is initiated via
-          // the API call. For other compaction kinds the tserver will keep periodically attempting
-          // to initiate which would result in lots of logs.
-          log.trace(
-              "Selection of files was not initiated {} compactionId:{} selectStatus:{} selectedFiles:{}",
-              getExtent(), this.compactionId, fileMgr.selectStatus, fileMgr.selectedFiles.size());
-        }
         return;
       }
     }
@@ -1098,14 +1049,14 @@ public class CompactableImpl implements Compactable {
           fileMgr.cancelSelection();
         }
       } else {
-        var allSelected =
-            allFiles.keySet().equals(Sets.union(selectingFiles, localHelper.getFilesToDrop()));
+        var allSelected = allFiles.keySet().equals(selectingFiles);
         synchronized (this) {
           fileMgr.finishSelection(selectingFiles, allSelected);
         }
 
         manager.compactableChanged(this);
       }
+
     } catch (Exception e) {
       log.error("Failed to select user compaction files {}", getExtent(), e);
     } finally {
@@ -1115,6 +1066,7 @@ public class CompactableImpl implements Compactable {
         }
       }
     }
+
   }
 
   static Collection<String> asFileNames(Set<StoredTabletFile> files) {
@@ -1131,13 +1083,6 @@ public class CompactableImpl implements Compactable {
     return tablet.getExtent();
   }
 
-  @SuppressWarnings("removal")
-  private boolean isCompactionStratConfigured() {
-    var strategyClass = tablet.getTableConfiguration().get(Property.TABLE_COMPACTION_STRATEGY);
-    return tablet.getTableConfiguration().isPropertySet(Property.TABLE_COMPACTION_STRATEGY)
-        && strategyClass != null && !strategyClass.isBlank();
-  }
-
   @Override
   public Optional<Files> getFiles(CompactionServiceId service, CompactionKind kind) {
 
@@ -1164,8 +1109,8 @@ public class CompactableImpl implements Compactable {
 
       var runningJobsCopy = Set.copyOf(runningJobs);
 
-      Set<StoredTabletFile> candidates = fileMgr.getCandidates(
-          Collections.unmodifiableSet(files.keySet()), kind, isCompactionStratConfigured());
+      Set<StoredTabletFile> candidates =
+          fileMgr.getCandidates(Collections.unmodifiableSet(files.keySet()), kind);
 
       if (candidates.isEmpty()) {
         return Optional.empty();
@@ -1182,11 +1127,10 @@ public class CompactableImpl implements Compactable {
     private final Supplier<Boolean> expensiveCheck;
     private final Supplier<Boolean> inexpensiveCheck;
 
-    public CompactionCheck(CompactionServiceId service, CompactionKind kind,
-        BooleanSupplier keepRunning, Long compactionId) {
-      this.expensiveCheck = Suppliers.memoizeWithExpiration(
-          () -> service.equals(getConfiguredService(kind)) && keepRunning.getAsBoolean(), 3,
-          TimeUnit.SECONDS);
+    public CompactionCheck(CompactionServiceId service, CompactionKind kind, Long compactionId) {
+      this.expensiveCheck = Suppliers.memoizeWithExpiration(() -> {
+        return service.equals(getConfiguredService(kind));
+      }, 3, TimeUnit.SECONDS);
       this.inexpensiveCheck = Suppliers.memoizeWithExpiration(() -> {
         if (closed
             || (kind == CompactionKind.USER && lastSeenCompactionCancelId.get() >= compactionId)) {
@@ -1277,10 +1221,10 @@ public class CompactableImpl implements Compactable {
       if (job.getKind() == CompactionKind.USER) {
         cInfo.iters = compactionConfig.getIterators();
         cInfo.checkCompactionId = this.compactionId;
-        cInfo.localCompactionCfg = this.compactionConfig;
       }
 
       cInfo.localHelper = this.chelper;
+      cInfo.localCompactionCfg = this.compactionConfig;
     }
 
     // Check to ensure the tablet actually has these files now that they are reserved. Compaction
@@ -1314,8 +1258,8 @@ public class CompactableImpl implements Compactable {
   }
 
   @Override
-  public void compact(CompactionServiceId service, CompactionJob job, BooleanSupplier keepRunning,
-      RateLimiter readLimiter, RateLimiter writeLimiter, long queuedTime) {
+  public void compact(CompactionServiceId service, CompactionJob job, RateLimiter readLimiter,
+      RateLimiter writeLimiter, long queuedTime) {
 
     Optional<CompactionInfo> ocInfo = reserveFilesForCompaction(service, job);
     if (ocInfo.isEmpty()) {
@@ -1333,8 +1277,8 @@ public class CompactableImpl implements Compactable {
     try {
       TabletLogger.compacting(getExtent(), job, cInfo.localCompactionCfg);
       tablet.incrementStatusMajor();
-      var check = new CompactionCheck(service, kind, keepRunning, cInfo.checkCompactionId);
-      TabletFile tmpFileName = tablet.getNextMapFilenameForMajc(cInfo.propagateDeletes);
+      var check = new CompactionCheck(service, kind, cInfo.checkCompactionId);
+      ReferencedTabletFile tmpFileName = tablet.getNextDataFilenameForMajc(cInfo.propagateDeletes);
       var compactEnv = new MajCEnv(kind, check, readLimiter, writeLimiter, cInfo.propagateDeletes);
 
       SortedMap<StoredTabletFile,DataFileValue> allFiles = tablet.getDatafiles();
@@ -1344,7 +1288,7 @@ public class CompactableImpl implements Compactable {
       stats = CompactableUtils.compact(tablet, job, cInfo, compactEnv, compactFiles, tmpFileName);
 
       newFile = CompactableUtils.bringOnline(tablet.getDatafileManager(), cInfo, stats,
-          compactFiles, allFiles, kind, tmpFileName);
+          compactFiles, tmpFileName);
 
       TabletLogger.compacted(getExtent(), job, newFile.orElse(null));
       successful = true;
@@ -1373,10 +1317,11 @@ public class CompactableImpl implements Compactable {
     var cInfo = ocInfo.orElseThrow();
 
     try {
-      TabletFile compactTmpName = tablet.getNextMapFilenameForMajc(cInfo.propagateDeletes);
+      Map<String,String> overrides =
+          CompactableUtils.getOverrides(job.getKind(), tablet, cInfo.localHelper, job.getFiles());
 
-      Map<String,String> overrides = CompactableUtils.getOverrides(job.getKind(), tablet,
-          cInfo.localHelper, job.getFiles(), compactTmpName);
+      ReferencedTabletFile compactTmpName =
+          tablet.getNextDataFilenameForMajc(cInfo.propagateDeletes);
 
       ExternalCompactionInfo ecInfo = new ExternalCompactionInfo();
 
@@ -1429,6 +1374,7 @@ public class CompactableImpl implements Compactable {
       ExternalCompactionInfo ecInfo = externalCompactions.get(extCompactionId);
 
       if (ecInfo != null) {
+        log.debug("Attempting to commit external compaction {}", extCompactionId);
         Optional<StoredTabletFile> metaFile = Optional.empty();
         boolean successful = false;
         try {
@@ -1441,17 +1387,16 @@ public class CompactableImpl implements Compactable {
           successful = true;
         } catch (Exception e) {
           metaFile = Optional.empty();
-          log.error("Error committing external compaction: id: {}, extent: {}", extCompactionId,
-              getExtent(), e);
+          log.error("Error committing external compaction {}", extCompactionId, e);
           throw new RuntimeException(e);
         } finally {
           completeCompaction(ecInfo.job, ecInfo.meta.getJobFiles(), metaFile, successful);
           externalCompactions.remove(extCompactionId);
-          log.debug("Completed commit of external compaction {} {}", extCompactionId, getExtent());
+          log.debug("Completed commit of external compaction {}", extCompactionId);
         }
       } else {
-        log.debug("Ignoring request to commit external compaction that is unknown {} {}",
-            extCompactionId, getExtent());
+        log.debug("Ignoring request to commit external compaction that is unknown {}",
+            extCompactionId);
       }
 
       tablet.getContext().getAmple().deleteExternalCompactionFinalStates(List.of(extCompactionId));
@@ -1484,10 +1429,9 @@ public class CompactableImpl implements Compactable {
             .mutate();
         completeCompaction(ecInfo.job, ecInfo.meta.getJobFiles(), Optional.empty(), false);
         externalCompactions.remove(ecid);
-        log.debug("Processed external compaction failure: id: {}, extent: {}", ecid, getExtent());
+        log.debug("Processed external compaction failure {}", ecid);
       } else {
-        log.debug("Ignoring request to fail external compaction that is unknown {} {}", ecid,
-            getExtent());
+        log.debug("Ignoring request to fail external compaction that is unknown {}", ecid);
       }
 
       tablet.getContext().getAmple().deleteExternalCompactionFinalStates(List.of(ecid));
@@ -1519,7 +1463,7 @@ public class CompactableImpl implements Compactable {
 
       if (dispatcher == null) {
         log.error(
-            "Failed to dispatch compaction, no dispatcher. extent:{} kind:{} hints:{}, falling back to {} service. Unable to instantiate dispatcher plugin. Check server log.",
+            "Failed to dispatch compaction {} kind:{} hints:{}, falling back to {} service. Unable to instantiate dispatcher plugin. Check server log.",
             getExtent(), kind, debugHints, CompactionServicesConfig.DEFAULT_SERVICE);
         return CompactionServicesConfig.DEFAULT_SERVICE;
       }
@@ -1566,8 +1510,7 @@ public class CompactableImpl implements Compactable {
 
       return dispatch.getService();
     } catch (RuntimeException e) {
-      log.error(
-          "Failed to dispatch compaction due to exception. extent:{} kind:{} hints:{}, falling back to {} service.",
+      log.error("Failed to dispatch compaction {} kind:{} hints:{}, falling back to {} service.",
           getExtent(), kind, debugHints, CompactionServicesConfig.DEFAULT_SERVICE, e);
       return CompactionServicesConfig.DEFAULT_SERVICE;
     }
@@ -1591,7 +1534,7 @@ public class CompactableImpl implements Compactable {
    * Interrupts and waits for any running compactions. After this method returns, no compactions
    * should be running and none should be able to start.
    */
-  public void close() {
+  public synchronized void close() {
     synchronized (this) {
       if (closed) {
         return;
@@ -1602,19 +1545,11 @@ public class CompactableImpl implements Compactable {
       // Wait while internal jobs are running or external compactions are committing. When
       // chopStatus is MARKING or selectStatus is SELECTING, there may be metadata table writes so
       // wait on those. Do not wait on external compactions that are running.
-      Predicate<CompactionJob> jobsToWaitFor =
-          job -> !((CompactionExecutorIdImpl) job.getExecutor()).isExternalId();
-      while (runningJobs.stream().anyMatch(jobsToWaitFor)
+      while (runningJobs.stream()
+          .anyMatch(job -> !((CompactionExecutorIdImpl) job.getExecutor()).isExternalId())
           || !externalCompactionsCommitting.isEmpty()
           || fileMgr.chopStatus == ChopSelectionStatus.MARKING
           || fileMgr.selectStatus == FileSelectionStatus.SELECTING) {
-
-        log.debug(
-            "Closing {} is waiting on {} running compactions, {} committing external compactions, chop marking {}, file selection {}",
-            getExtent(), runningJobs.stream().filter(jobsToWaitFor).count(),
-            externalCompactionsCommitting.size(), fileMgr.chopStatus == ChopSelectionStatus.MARKING,
-            fileMgr.selectStatus == FileSelectionStatus.SELECTING);
-
         try {
           wait(50);
         } catch (InterruptedException e) {
@@ -1623,6 +1558,7 @@ public class CompactableImpl implements Compactable {
         }
       }
     }
+
     manager.compactableClosed(getExtent(), servicesUsed, externalCompactions.keySet());
   }
 }
