@@ -18,7 +18,7 @@
  */
 package org.apache.accumulo.tserver.tablet;
 
-import static org.apache.accumulo.core.util.UtilWaitThread.sleepUninterruptibly;
+import static com.google.common.util.concurrent.Uninterruptibles.sleepUninterruptibly;
 
 import java.io.IOException;
 import java.util.Collection;
@@ -38,8 +38,8 @@ import java.util.concurrent.atomic.AtomicReference;
 import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.logging.TabletLogger;
+import org.apache.accumulo.core.metadata.ReferencedTabletFile;
 import org.apache.accumulo.core.metadata.StoredTabletFile;
-import org.apache.accumulo.core.metadata.TabletFile;
 import org.apache.accumulo.core.metadata.schema.DataFileValue;
 import org.apache.accumulo.core.metadata.schema.ExternalCompactionId;
 import org.apache.accumulo.core.metadata.schema.TabletMetadata.Location;
@@ -47,10 +47,8 @@ import org.apache.accumulo.core.trace.TraceUtil;
 import org.apache.accumulo.core.util.MapCounter;
 import org.apache.accumulo.core.util.Pair;
 import org.apache.accumulo.server.fs.VolumeManager;
-import org.apache.accumulo.server.replication.proto.Replication.Status;
 import org.apache.accumulo.server.util.ManagerMetadataUtil;
 import org.apache.accumulo.server.util.MetadataTableUtil;
-import org.apache.accumulo.server.util.ReplicationTableUtil;
 import org.apache.hadoop.fs.Path;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -97,7 +95,7 @@ class DatafileManager {
     }
   }
 
-  Pair<Long,Map<TabletFile,DataFileValue>> reserveFilesForScan() {
+  Pair<Long,Map<StoredTabletFile,DataFileValue>> reserveFilesForScan() {
     synchronized (tablet) {
 
       Set<StoredTabletFile> absFilePaths = new HashSet<>(datafileSizes.keySet());
@@ -106,7 +104,7 @@ class DatafileManager {
 
       scanFileReservations.put(rid, absFilePaths);
 
-      Map<TabletFile,DataFileValue> ret = new HashMap<>();
+      Map<StoredTabletFile,DataFileValue> ret = new HashMap<>();
 
       for (StoredTabletFile path : absFilePaths) {
         fileScanReferenceCounts.increment(path, 1);
@@ -119,6 +117,8 @@ class DatafileManager {
 
   void returnFilesForScan(Long reservationId) {
 
+    final Set<StoredTabletFile> filesToDelete = new HashSet<>();
+
     synchronized (tablet) {
       Set<StoredTabletFile> absFilePaths = scanFileReservations.remove(reservationId);
 
@@ -127,20 +127,27 @@ class DatafileManager {
       }
 
       boolean notify = false;
-      try {
-        for (StoredTabletFile path : absFilePaths) {
-          long refCount = fileScanReferenceCounts.decrement(path, 1);
-          if (refCount == 0) {
-            notify = true;
-          } else if (refCount < 0) {
-            throw new IllegalStateException("Scan ref count for " + path + " is " + refCount);
+      for (StoredTabletFile path : absFilePaths) {
+        long refCount = fileScanReferenceCounts.decrement(path, 1);
+        if (refCount == 0) {
+          if (filesToDeleteAfterScan.remove(path)) {
+            filesToDelete.add(path);
           }
-        }
-      } finally {
-        if (notify) {
-          tablet.notifyAll();
+          notify = true;
+        } else if (refCount < 0) {
+          throw new IllegalStateException("Scan ref count for " + path + " is " + refCount);
         }
       }
+
+      if (notify) {
+        tablet.notifyAll();
+      }
+    }
+
+    if (!filesToDelete.isEmpty()) {
+      log.debug("Removing scan refs from metadata {} {}", tablet.getExtent(), filesToDelete);
+      MetadataTableUtil.removeScanFiles(tablet.getExtent(), filesToDelete, tablet.getContext(),
+          tablet.getTabletServer().getLock());
     }
   }
 
@@ -168,33 +175,6 @@ class DatafileManager {
     }
   }
 
-  /**
-   * This method will remove any scan references that have been added to filesToDeleteAfterScan.
-   * This is meant to be called periodically as to batch the removal of scan references.
-   */
-  public void removeBatchedScanRefs() {
-    Set<StoredTabletFile> snapshot;
-    synchronized (tablet) {
-      snapshot = new HashSet<>(filesToDeleteAfterScan);
-      filesToDeleteAfterScan.clear();
-    }
-    removeFilesAfterScan(snapshot);
-  }
-
-  /**
-   * @return true if any file is no longer in use by a scan and can be removed, false otherwise.
-   */
-  boolean canScanRefsBeRemoved() {
-    synchronized (tablet) {
-      for (var path : filesToDeleteAfterScan) {
-        if (fileScanReferenceCounts.get(path) == 0) {
-          return true;
-        }
-      }
-      return false;
-    }
-  }
-
   private TreeSet<StoredTabletFile> waitForScansToFinish(Set<StoredTabletFile> pathsToWaitFor) {
     long maxWait = 10000L;
     long startTime = System.currentTimeMillis();
@@ -229,14 +209,14 @@ class DatafileManager {
     return inUse;
   }
 
-  public Collection<StoredTabletFile> importMapFiles(long tid, Map<TabletFile,DataFileValue> paths,
-      boolean setTime) throws IOException {
+  public Collection<StoredTabletFile> importDataFiles(long tid,
+      Map<ReferencedTabletFile,DataFileValue> paths, boolean setTime) throws IOException {
 
     String bulkDir = null;
     // once tablet files are inserted into the metadata they will become StoredTabletFiles
     Map<StoredTabletFile,DataFileValue> newFiles = new HashMap<>(paths.size());
 
-    for (TabletFile tpath : paths.keySet()) {
+    for (ReferencedTabletFile tpath : paths.keySet()) {
       boolean inTheRightDirectory = false;
       Path parent = tpath.getPath().getParent().getParent();
       for (String tablesDir : tablet.getContext().getTablesDirs()) {
@@ -292,7 +272,7 @@ class DatafileManager {
           datafileSizes.put(tpath.getKey(), tpath.getValue());
         }
 
-        tablet.getTabletResources().importedMapFiles();
+        tablet.getTabletResources().importedDataFiles();
 
         tablet.computeNumEntries();
       }
@@ -300,12 +280,6 @@ class DatafileManager {
       for (Entry<StoredTabletFile,DataFileValue> entry : newFiles.entrySet()) {
         TabletLogger.bulkImported(tablet.getExtent(), entry.getKey());
       }
-    } catch (Exception e) {
-      // Any exception in this code is prone to leaving the persisted tablet metadata and the
-      // tablets in memory data structs out of sync. Log the extent and exact files involved as this
-      // may be useful for debugging.
-      log.error("Failure adding bulk import files {} {}", tablet.getExtent(), paths.keySet(), e);
-      throw e;
     } finally {
       // increment finish count after metadata update AND updating in memory map of files
       metadataUpdateCount.updateAndGet(MetadataUpdateCount::incrementFinish);
@@ -319,8 +293,9 @@ class DatafileManager {
    * entries so was not inserted into the metadata. In this case empty is returned. If the file was
    * stored in the metadata table, then StoredTableFile will be returned.
    */
-  Optional<StoredTabletFile> bringMinorCompactionOnline(TabletFile tmpDatafile,
-      TabletFile newDatafile, DataFileValue dfv, CommitSession commitSession, long flushId) {
+  Optional<StoredTabletFile> bringMinorCompactionOnline(ReferencedTabletFile tmpDatafile,
+      ReferencedTabletFile newDatafile, DataFileValue dfv, CommitSession commitSession,
+      long flushId) {
     Optional<StoredTabletFile> newFile;
     // rename before putting in metadata table, so files in metadata table should
     // always exist
@@ -333,7 +308,7 @@ class DatafileManager {
           vm.deleteRecursively(tmpDatafile.getPath());
         } else {
           if (!attemptedRename && vm.exists(newDatafile.getPath())) {
-            log.warn("Target map file already exist {}", newDatafile);
+            log.warn("Target data file already exist {}", newDatafile);
             throw new RuntimeException("File unexpectedly exists " + newDatafile.getPath());
           }
           // the following checks for spurious rename failures that succeeded but gave an IoE
@@ -357,66 +332,18 @@ class DatafileManager {
 
     // increment start count before metadata update AND updating in memory map of files
     metadataUpdateCount.updateAndGet(MetadataUpdateCount::incrementStart);
-    // do not place any code here between above stmt and following try{}finally
+    // do not place any code here between above stmt and try{}finally
     try {
-      // Should not hold the tablet lock while trying to acquire the log lock because this could
-      // lead to deadlock. However there is a path in the code that does this. See #3759
-      tablet.getLogLock().lock();
-      // do not place any code here between lock and try
+      Set<String> unusedWalLogs = tablet.beginClearingUnusedLogs();
       try {
-        // The following call pairs with tablet.finishClearingUnusedLogs() later in this block. If
-        // moving where the following method is called, examine it and finishClearingUnusedLogs()
-        // before moving.
-        Set<String> unusedWalLogs = tablet.beginClearingUnusedLogs();
-
         // the order of writing to metadata and walog is important in the face of machine/process
         // failures need to write to metadata before writing to walog, when things are done in the
         // reverse order data could be lost... the minor compaction start even should be written
         // before the following metadata write is made
         newFile = tablet.updateTabletDataFile(commitSession.getMaxCommittedTime(), newDatafile, dfv,
             unusedWalLogs, flushId);
-
-        // Mark that we have data we want to replicate
-        // This WAL could still be in use by other Tablets *from the same table*, so we can only
-        // mark
-        // that there is data to replicate,
-        // but it is *not* closed. We know it is not closed by the fact that this MinC triggered. A
-        // MinC cannot happen unless the
-        // tablet is online and thus these WALs are referenced by that tablet. Therefore, the WAL
-        // replication status cannot be 'closed'.
-        @SuppressWarnings("deprecation")
-        boolean replicate = org.apache.accumulo.core.replication.ReplicationConfigurationUtil
-            .isEnabled(tablet.getExtent(), tablet.getTableConfiguration());
-        if (replicate) {
-          // unusedWalLogs is of the form host/fileURI, need to strip off the host portion
-          Set<String> logFileOnly = new HashSet<>();
-          for (String unusedWalLog : unusedWalLogs) {
-            int index = unusedWalLog.indexOf('/');
-            if (index == -1) {
-              log.warn(
-                  "Could not find host component to strip from DFSLogger representation of WAL");
-            } else {
-              unusedWalLog = unusedWalLog.substring(index + 1);
-            }
-            logFileOnly.add(unusedWalLog);
-          }
-
-          if (log.isDebugEnabled()) {
-            log.debug("Recording that data has been ingested into {} using {}", tablet.getExtent(),
-                logFileOnly);
-          }
-          for (String logFile : logFileOnly) {
-            @SuppressWarnings("deprecation")
-            Status status =
-                org.apache.accumulo.server.replication.StatusUtil.openWithUnknownLength();
-            ReplicationTableUtil.updateFiles(tablet.getContext(), tablet.getExtent(), logFile,
-                status);
-          }
-        }
-
-        tablet.finishClearingUnusedLogs();
       } finally {
-        tablet.getLogLock().unlock();
+        tablet.finishClearingUnusedLogs();
       }
 
       do {
@@ -448,12 +375,6 @@ class DatafileManager {
 
         t2 = System.currentTimeMillis();
       }
-    } catch (Exception e) {
-      // Any exception in this code is prone to leaving the persisted tablet metadata and the
-      // tablets in memory data structs out of sync. Log the extent and exact file involved as this
-      // may be useful for debugging.
-      log.error("Failure adding minor compacted file {} {}", tablet.getExtent(), newDatafile, e);
-      throw e;
     } finally {
       // increment finish count after metadata update AND updating in memory map of files
       metadataUpdateCount.updateAndGet(MetadataUpdateCount::incrementFinish);
@@ -475,17 +396,17 @@ class DatafileManager {
   }
 
   Optional<StoredTabletFile> bringMajorCompactionOnline(Set<StoredTabletFile> oldDatafiles,
-      TabletFile tmpDatafile, Long compactionId, Set<StoredTabletFile> selectedFiles,
+      ReferencedTabletFile tmpDatafile, Long compactionId, Set<StoredTabletFile> selectedFiles,
       DataFileValue dfv, Optional<ExternalCompactionId> ecid) throws IOException {
     final KeyExtent extent = tablet.getExtent();
     VolumeManager vm = tablet.getTabletServer().getContext().getVolumeManager();
     long t1, t2;
 
-    TabletFile newDatafile = CompactableUtils.computeCompactionFileDest(tmpDatafile);
+    ReferencedTabletFile newDatafile = CompactableUtils.computeCompactionFileDest(tmpDatafile);
 
     if (vm.exists(newDatafile.getPath())) {
-      log.error("Target map file already exist " + newDatafile, new Exception());
-      throw new IllegalStateException("Target map file already exist " + newDatafile);
+      log.error("Target data file already exist " + newDatafile, new Exception());
+      throw new IllegalStateException("Target data file already exist " + newDatafile);
     }
 
     if (dfv.getNumEntries() == 0) {
@@ -556,13 +477,6 @@ class DatafileManager {
       tablet.setLastCompactionID(compactionIdToWrite);
       removeFilesAfterScan(filesInUseByScans);
 
-    } catch (Exception e) {
-      // Any exception in this code is prone to leaving the persisted tablet metadata and the
-      // tablets in memory data structs out of sync. Log the extent and exact files involved as this
-      // may be useful for debugging.
-      log.error("Failure updating files after major compaction {} {} {}", tablet.getExtent(),
-          newFile, oldDatafiles, e);
-      throw e;
     } finally {
       // increment finish count after metadata update AND updating in memory map of files
       metadataUpdateCount.updateAndGet(MetadataUpdateCount::incrementFinish);
@@ -582,9 +496,9 @@ class DatafileManager {
     }
   }
 
-  public Set<TabletFile> getFiles() {
+  public Set<StoredTabletFile> getFiles() {
     synchronized (tablet) {
-      HashSet<TabletFile> files = new HashSet<>(datafileSizes.keySet());
+      HashSet<StoredTabletFile> files = new HashSet<>(datafileSizes.keySet());
       return Collections.unmodifiableSet(files);
     }
   }
