@@ -27,7 +27,6 @@ import java.util.TreeMap;
 import java.util.concurrent.atomic.AtomicLong;
 
 import org.apache.accumulo.core.metadata.StoredTabletFile;
-import org.apache.accumulo.core.metadata.TabletFile;
 import org.apache.accumulo.core.metadata.schema.DataFileValue;
 import org.apache.accumulo.core.metadata.schema.TabletMetadata;
 import org.apache.accumulo.core.sample.impl.SamplerConfigurationImpl;
@@ -36,6 +35,8 @@ import org.apache.accumulo.tserver.InMemoryMap;
 import org.apache.accumulo.tserver.TabletHostingServer;
 import org.apache.accumulo.tserver.TabletServerResourceManager;
 import org.apache.accumulo.tserver.metrics.TabletServerScanMetrics;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 /**
  * A tablet that can not be written to and operates off of a snapshot of tablet metadata for its
@@ -44,6 +45,8 @@ import org.apache.accumulo.tserver.metrics.TabletServerScanMetrics;
  */
 public class SnapshotTablet extends TabletBase {
 
+  private static final Logger log = LoggerFactory.getLogger(SnapshotTablet.class);
+
   private final TabletHostingServer server;
   private final SortedMap<StoredTabletFile,DataFileValue> files;
   private final TabletServerResourceManager.TabletResourceManager tabletResources;
@@ -93,10 +96,9 @@ public class SnapshotTablet extends TabletBase {
 
   }
 
-  @SuppressWarnings({"rawtypes", "unchecked"})
   @Override
-  public Pair<Long,Map<TabletFile,DataFileValue>> reserveFilesForScan() {
-    return new Pair(0L, getDatafiles());
+  public Pair<Long,Map<StoredTabletFile,DataFileValue>> reserveFilesForScan() {
+    return new Pair<>(0L, getDatafiles());
   }
 
   @Override
@@ -123,11 +125,16 @@ public class SnapshotTablet extends TabletBase {
 
     for (ScanDataSource activeScan : activeScans) {
       activeScan.interrupt();
-      // The tablet server will wait for this to return true because it wants to be sure no scans
-      // will run after the tablet is unloaded to ensure immediate consistency. Scans running in the
-      // scan server are eventually consistent, so there is no need to wait here. Disallow future
-      // activity on the scan session so it can be cleaned up eventually, but do not need to wait.
-      disallowNewReservations(activeScan.getScanParameters());
+    }
+
+    // wait for reads and writes to complete
+    while (!activeScans.isEmpty()) {
+      try {
+        log.debug("Closing tablet {} waiting for {} scans", extent, activeScans.size());
+        this.wait(50);
+      } catch (InterruptedException e) {
+        log.error(e.toString());
+      }
     }
   }
 }
