@@ -18,16 +18,15 @@
  */
 package org.apache.accumulo.tserver.tablet;
 
+import static com.google.common.util.concurrent.Uninterruptibles.sleepUninterruptibly;
 import static java.nio.charset.StandardCharsets.UTF_8;
 import static java.util.stream.Collectors.toList;
-import static org.apache.accumulo.core.util.UtilWaitThread.sleepUninterruptibly;
 
 import java.io.ByteArrayInputStream;
 import java.io.DataInputStream;
 import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.lang.ref.SoftReference;
-import java.time.Duration;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
@@ -64,19 +63,16 @@ import org.apache.accumulo.core.data.Mutation;
 import org.apache.accumulo.core.data.Range;
 import org.apache.accumulo.core.data.Value;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
-import org.apache.accumulo.core.dataImpl.thrift.MapFileInfo;
-import org.apache.accumulo.core.fate.zookeeper.ServiceLock;
 import org.apache.accumulo.core.file.FileOperations;
 import org.apache.accumulo.core.file.FilePrefix;
 import org.apache.accumulo.core.iterators.SortedKeyValueIterator;
 import org.apache.accumulo.core.iteratorsImpl.system.SourceSwitchingIterator;
-import org.apache.accumulo.core.logging.ConditionalLogger.DeduplicatingLogger;
 import org.apache.accumulo.core.logging.TabletLogger;
 import org.apache.accumulo.core.manager.state.tables.TableState;
-import org.apache.accumulo.core.master.thrift.BulkImportState;
+import org.apache.accumulo.core.manager.thrift.BulkImportState;
 import org.apache.accumulo.core.metadata.MetadataTable;
+import org.apache.accumulo.core.metadata.ReferencedTabletFile;
 import org.apache.accumulo.core.metadata.StoredTabletFile;
-import org.apache.accumulo.core.metadata.TabletFile;
 import org.apache.accumulo.core.metadata.schema.DataFileValue;
 import org.apache.accumulo.core.metadata.schema.ExternalCompactionId;
 import org.apache.accumulo.core.metadata.schema.ExternalCompactionMetadata;
@@ -85,32 +81,30 @@ import org.apache.accumulo.core.metadata.schema.MetadataTime;
 import org.apache.accumulo.core.metadata.schema.TabletMetadata;
 import org.apache.accumulo.core.metadata.schema.TabletMetadata.ColumnType;
 import org.apache.accumulo.core.metadata.schema.TabletMetadata.Location;
-import org.apache.accumulo.core.protobuf.ProtobufUtil;
 import org.apache.accumulo.core.sample.impl.SamplerConfigurationImpl;
 import org.apache.accumulo.core.security.Authorizations;
 import org.apache.accumulo.core.spi.fs.VolumeChooserEnvironment;
 import org.apache.accumulo.core.spi.scan.ScanDispatch;
+import org.apache.accumulo.core.tabletingest.thrift.DataFileInfo;
 import org.apache.accumulo.core.tabletserver.log.LogEntry;
 import org.apache.accumulo.core.tabletserver.thrift.TabletStats;
 import org.apache.accumulo.core.trace.TraceUtil;
-import org.apache.accumulo.core.util.Halt;
 import org.apache.accumulo.core.util.Pair;
 import org.apache.accumulo.core.volume.Volume;
 import org.apache.accumulo.server.ServerContext;
 import org.apache.accumulo.server.compaction.CompactionStats;
+import org.apache.accumulo.server.compaction.PausedCompactionMetrics;
 import org.apache.accumulo.server.fs.VolumeChooserEnvironmentImpl;
 import org.apache.accumulo.server.fs.VolumeUtil;
 import org.apache.accumulo.server.fs.VolumeUtil.TabletFiles;
 import org.apache.accumulo.server.problems.ProblemReport;
 import org.apache.accumulo.server.problems.ProblemReports;
 import org.apache.accumulo.server.problems.ProblemType;
-import org.apache.accumulo.server.replication.proto.Replication.Status;
 import org.apache.accumulo.server.tablets.TabletTime;
 import org.apache.accumulo.server.tablets.UniqueNameAllocator;
 import org.apache.accumulo.server.util.FileUtil;
 import org.apache.accumulo.server.util.ManagerMetadataUtil;
 import org.apache.accumulo.server.util.MetadataTableUtil;
-import org.apache.accumulo.server.util.ReplicationTableUtil;
 import org.apache.accumulo.tserver.ConditionCheckerContext.ConditionChecker;
 import org.apache.accumulo.tserver.InMemoryMap;
 import org.apache.accumulo.tserver.MinorCompactionReason;
@@ -146,8 +140,6 @@ import io.opentelemetry.context.Scope;
  */
 public class Tablet extends TabletBase {
   private static final Logger log = LoggerFactory.getLogger(Tablet.class);
-  private static final Logger CLOSING_STUCK_LOGGER =
-      new DeduplicatingLogger(log, Duration.ofMinutes(5), 1000);
 
   private final TabletServer tabletServer;
   private final TabletResourceManager tabletResources;
@@ -161,7 +153,7 @@ public class Tablet extends TabletBase {
   private long persistedTime;
 
   private Location lastLocation = null;
-  private final Set<Path> checkedTabletDirs = new ConcurrentSkipListSet<>();
+  private volatile Set<Path> checkedTabletDirs = new ConcurrentSkipListSet<>();
 
   private final AtomicLong dataSourceDeletions = new AtomicLong(0);
 
@@ -171,20 +163,15 @@ public class Tablet extends TabletBase {
   }
 
   private enum CloseState {
-    OPEN, REQUESTED, CLOSING, CLOSED, COMPLETE
+    OPEN, CLOSING, CLOSED, COMPLETE
   }
 
-  private long closeRequestTime = 0;
   private volatile CloseState closeState = CloseState.OPEN;
 
   private boolean updatingFlushID = false;
 
-  private final AtomicLong lastFlushID = new AtomicLong(-1);
-  private final AtomicLong lastCompactID = new AtomicLong(-1);
-
-  public long getLastCompactId() {
-    return lastCompactID.get();
-  }
+  private AtomicLong lastFlushID = new AtomicLong(-1);
+  private AtomicLong lastCompactID = new AtomicLong(-1);
 
   private static class CompactionWaitInfo {
     long flushID = -1;
@@ -199,7 +186,7 @@ public class Tablet extends TabletBase {
     WAITING_TO_START, IN_PROGRESS
   }
 
-  private final CompactableImpl compactable;
+  private CompactableImpl compactable;
 
   private volatile CompactionState minorCompactionState = null;
 
@@ -227,21 +214,22 @@ public class Tablet extends TabletBase {
   private final Rate scannedRate = new Rate(0.95);
 
   private long lastMinorCompactionFinishTime = 0;
-  private long lastMapFileImportTime = 0;
+  private long lastDataFileImportTime = 0;
 
   private volatile long numEntries = 0;
   private volatile long numEntriesInMemory = 0;
 
   // Files that are currently in the process of bulk importing. Access to this is protected by the
   // tablet lock.
-  private final Set<TabletFile> bulkImporting = new HashSet<>();
+  private final Set<ReferencedTabletFile> bulkImporting = new HashSet<>();
 
   // Files that were successfully bulk imported. Using a concurrent map supports non-locking
   // operations on the key set which is useful for the periodic task that cleans up completed bulk
   // imports for all tablets. However the values of this map are ArrayList which do not support
   // concurrency. This is ok because all operations on the values are done while the tablet lock is
   // held.
-  private final ConcurrentHashMap<Long,List<TabletFile>> bulkImported = new ConcurrentHashMap<>();
+  private final ConcurrentHashMap<Long,List<ReferencedTabletFile>> bulkImported =
+      new ConcurrentHashMap<>();
 
   private final int logId;
 
@@ -265,16 +253,17 @@ public class Tablet extends TabletBase {
     return dirUri;
   }
 
-  TabletFile getNextMapFilename(FilePrefix prefix) throws IOException {
+  ReferencedTabletFile getNextDataFilename(FilePrefix prefix) throws IOException {
     String extension = FileOperations.getNewFileExtension(tableConfiguration);
-    return new TabletFile(new Path(chooseTabletDir() + "/"
-        + prefix.createFileName(context.getUniqueNameAllocator().getNextName() + "." + extension)));
+    return new ReferencedTabletFile(new Path(chooseTabletDir() + "/" + prefix.toPrefix()
+        + context.getUniqueNameAllocator().getNextName() + "." + extension));
   }
 
-  TabletFile getNextMapFilenameForMajc(boolean propagateDeletes) throws IOException {
-    FilePrefix prefix = !propagateDeletes ? FilePrefix.FULL_COMPACTION : FilePrefix.COMPACTION;
-    String tmpFileName = getNextMapFilename(prefix).getMetaInsert() + "_tmp";
-    return new TabletFile(new Path(tmpFileName));
+  ReferencedTabletFile getNextDataFilenameForMajc(boolean propagateDeletes) throws IOException {
+    String tmpFileName = getNextDataFilename(
+        !propagateDeletes ? FilePrefix.MAJOR_COMPACTION_ALL_FILES : FilePrefix.MAJOR_COMPACTION)
+        .getMetaInsert() + "_tmp";
+    return new ReferencedTabletFile(new Path(tmpFileName));
   }
 
   private void checkTabletDir(Path path) throws IOException {
@@ -312,17 +301,14 @@ public class Tablet extends TabletBase {
     this.logId = tabletServer.createLogId();
 
     // translate any volume changes
-    @SuppressWarnings("deprecation")
-    boolean replicationEnabled = org.apache.accumulo.core.replication.ReplicationConfigurationUtil
-        .isEnabled(extent, this.tableConfiguration);
     TabletFiles tabletPaths =
         new TabletFiles(data.getDirectoryName(), data.getLogEntries(), data.getDataFiles());
     tabletPaths = VolumeUtil.updateTabletVolumes(tabletServer.getContext(), tabletServer.getLock(),
-        extent, tabletPaths, replicationEnabled);
+        extent, tabletPaths);
 
     this.dirName = data.getDirectoryName();
 
-    for (Entry<Long,List<TabletFile>> entry : data.getBulkImported().entrySet()) {
+    for (Entry<Long,List<ReferencedTabletFile>> entry : data.getBulkImported().entrySet()) {
       this.bulkImported.put(entry.getKey(), new ArrayList<>(entry.getValue()));
     }
 
@@ -342,8 +328,8 @@ public class Tablet extends TabletBase {
       final CommitSession commitSession = getTabletMemory().getCommitSession();
       try {
         Set<String> absPaths = new HashSet<>();
-        for (TabletFile ref : datafiles.keySet()) {
-          absPaths.add(ref.getPathStr());
+        for (StoredTabletFile ref : datafiles.keySet()) {
+          absPaths.add(ref.getNormalizedPathStr());
         }
 
         tabletServer.recover(this.getTabletServer().getVolumeManager(), extent, logEntries,
@@ -365,25 +351,11 @@ public class Tablet extends TabletBase {
         }
         commitSession.updateMaxCommittedTime(tabletTime.getTime());
 
-        @SuppressWarnings("deprecation")
-        boolean replicationEnabledForTable =
-            org.apache.accumulo.core.replication.ReplicationConfigurationUtil.isEnabled(extent,
-                tabletServer.getTableConfiguration(extent));
         if (entriesUsedOnTablet.get() == 0) {
           log.debug("No replayed mutations applied, removing unused entries for {}", extent);
           MetadataTableUtil.removeUnusedWALEntries(getTabletServer().getContext(), extent,
               logEntries, tabletServer.getLock());
           logEntries.clear();
-        } else if (replicationEnabledForTable) {
-          // record that logs may have data for this extent
-          @SuppressWarnings("deprecation")
-          Status status = org.apache.accumulo.server.replication.StatusUtil.openWithUnknownLength();
-          for (LogEntry logEntry : logEntries) {
-            log.debug("Writing updated status to metadata table for {} {}", logEntry.filename,
-                ProtobufUtil.toString(status));
-            ReplicationTableUtil.updateFiles(tabletServer.getContext(), extent, logEntry.filename,
-                status);
-          }
         }
 
       } catch (Exception t) {
@@ -457,7 +429,7 @@ public class Tablet extends TabletBase {
   }
 
   public void checkConditions(ConditionChecker checker, Authorizations authorizations,
-      AtomicBoolean iFlag) throws IOException, ReflectiveOperationException {
+      AtomicBoolean iFlag) throws IOException {
 
     ScanParameters scanParams = new ScanParameters(-1, authorizations, Collections.emptySet(), null,
         null, false, null, -1, null);
@@ -469,18 +441,19 @@ public class Tablet extends TabletBase {
     try {
       SortedKeyValueIterator<Key,Value> iter = new SourceSwitchingIterator(dataSource);
       checker.check(iter);
-    } catch (IOException | RuntimeException | ReflectiveOperationException e) {
+    } catch (IOException | RuntimeException e) {
       sawException = true;
       throw e;
     } finally {
       // code in finally block because always want
-      // to return mapfiles, even when exception is thrown
+      // to return data files, even when exception is thrown
       dataSource.close(sawException);
     }
   }
 
-  DataFileValue minorCompact(InMemoryMap memTable, TabletFile tmpDatafile, TabletFile newDatafile,
-      long queued, CommitSession commitSession, long flushId, MinorCompactionReason mincReason) {
+  DataFileValue minorCompact(InMemoryMap memTable, ReferencedTabletFile tmpDatafile,
+      ReferencedTabletFile newDatafile, long queued, CommitSession commitSession, long flushId,
+      MinorCompactionReason mincReason) {
     boolean failed = false;
     long start = System.currentTimeMillis();
     timer.incrementStatusMinor();
@@ -512,15 +485,8 @@ public class Tablet extends TabletBase {
             flushId);
         storedFile.ifPresent(stf -> compactable.filesAdded(true, List.of(stf)));
       } catch (Exception e) {
-        final ServiceLock tserverLock = tabletServer.getLock();
-        if (tserverLock == null || !tserverLock.verifyLockAtSource()) {
-          log.error("Minor compaction of {} has failed and TabletServer lock does not exist."
-              + " Halting...", getExtent(), e);
-          Halt.halt(-1, "TabletServer lock does not exist", e);
-        } else {
-          TraceUtil.setException(span2, e, true);
-          throw e;
-        }
+        TraceUtil.setException(span2, e, true);
+        throw e;
       } finally {
         span2.end();
       }
@@ -888,26 +854,27 @@ public class Tablet extends TabletBase {
       totalBytes += mutation.numBytes();
     }
 
-    try {
-      getTabletMemory().mutate(commitSession, mutations, totalCount);
-      synchronized (this) {
-        getTabletMemory().updateMemoryUsageStats();
-        if (isCloseComplete()) {
-          throw new IllegalStateException(
-              "Tablet " + extent + " closed with outstanding messages to the logger");
-        }
-        numEntries += totalCount;
-        numEntriesInMemory += totalCount;
-        ingestCount += totalCount;
-        ingestBytes += totalBytes;
+    getTabletMemory().mutate(commitSession, mutations, totalCount);
+
+    synchronized (this) {
+      if (isCloseComplete()) {
+        throw new IllegalStateException(
+            "Tablet " + extent + " closed with outstanding messages to the logger");
       }
-    } finally {
+      // decrement here in case an exception is thrown below
       decrementWritesInProgress(commitSession);
+
+      getTabletMemory().updateMemoryUsageStats();
+
+      numEntries += totalCount;
+      numEntriesInMemory += totalCount;
+      ingestCount += totalCount;
+      ingestBytes += totalBytes;
     }
   }
 
   /**
-   * Closes the mapfiles associated with a Tablet. If saveState is true, a minor compaction is
+   * Closes the data files associated with a Tablet. If saveState is true, a minor compaction is
    * performed.
    */
   @Override
@@ -920,21 +887,6 @@ public class Tablet extends TabletBase {
   void initiateClose(boolean saveState) {
     log.trace("initiateClose(saveState={}) {}", saveState, getExtent());
 
-    synchronized (this) {
-      if (closeState == CloseState.OPEN) {
-        closeRequestTime = System.nanoTime();
-        closeState = CloseState.REQUESTED;
-      } else {
-        Preconditions.checkState(closeRequestTime != 0);
-        long runningTime = Duration.ofNanos(System.nanoTime() - closeRequestTime).toMinutes();
-        if (runningTime >= 15) {
-          CLOSING_STUCK_LOGGER.info(
-              "Tablet {} close requested again, but has been closing for {} minutes", this.extent,
-              runningTime);
-        }
-      }
-    }
-
     MinorCompactionTask mct = null;
     if (saveState) {
       try {
@@ -1048,31 +1000,13 @@ public class Tablet extends TabletBase {
       activeScan.interrupt();
     }
 
-    // create a copy so that it can be whittled down as client sessions are disabled
-    List<ScanDataSource> runningScans = new ArrayList<>(this.activeScans);
-
-    runningScans.removeIf(scanDataSource -> {
-      boolean currentlyUnreserved = disallowNewReservations(scanDataSource.getScanParameters());
-      if (currentlyUnreserved) {
-        log.debug("Disabled scan session in tablet close {} {}", extent, scanDataSource);
-      }
-      return currentlyUnreserved;
-    });
-
     long lastLogTime = System.nanoTime();
 
     // wait for reads and writes to complete
-    while (writesInProgress > 0 || !runningScans.isEmpty()) {
-      runningScans.removeIf(scanDataSource -> {
-        boolean currentlyUnreserved = disallowNewReservations(scanDataSource.getScanParameters());
-        if (currentlyUnreserved) {
-          log.debug("Disabled scan session in tablet close {} {}", extent, scanDataSource);
-        }
-        return currentlyUnreserved;
-      });
+    while (writesInProgress > 0 || !activeScans.isEmpty()) {
 
       if (log.isDebugEnabled() && System.nanoTime() - lastLogTime > TimeUnit.SECONDS.toNanos(60)) {
-        for (ScanDataSource activeScan : runningScans) {
+        for (ScanDataSource activeScan : activeScans) {
           log.debug("Waiting on scan in completeClose {} {}", extent, activeScan);
         }
 
@@ -1081,19 +1015,13 @@ public class Tablet extends TabletBase {
 
       try {
         log.debug("Waiting to completeClose for {}. {} writes {} scans", extent, writesInProgress,
-            runningScans.size());
+            activeScans.size());
         this.wait(50);
       } catch (InterruptedException e) {
         log.error("Interrupted waiting to completeClose for extent {}", extent, e);
       }
     }
 
-    // It is assumed that nothing new would have been added to activeScans since it was copied, so
-    // check that assumption. At this point activeScans should be empty or everything in it should
-    // be disabled.
-    Preconditions.checkState(activeScans.stream()
-        .allMatch(scanDataSource -> disallowNewReservations(scanDataSource.getScanParameters())));
-
     getTabletMemory().waitForMinC();
 
     if (saveState && getTabletMemory().getMemTable().getNumEntries() > 0) {
@@ -1133,7 +1061,7 @@ public class Tablet extends TabletBase {
 
     getTabletMemory().close();
 
-    // close map files
+    // close data files
     getTabletResources().close();
 
     if (completeClose) {
@@ -1421,8 +1349,8 @@ public class Tablet extends TabletBase {
   private boolean isFindSplitsSuppressed() {
     if (supressFindSplits) {
       if (timeOfLastMinCWhenFindSplitsWasSupressed != lastMinorCompactionFinishTime
-          || timeOfLastImportWhenFindSplitsWasSupressed != lastMapFileImportTime) {
-        // a minor compaction or map file import has occurred... check again
+          || timeOfLastImportWhenFindSplitsWasSupressed != lastDataFileImportTime) {
+        // a minor compaction or data file import has occurred... check again
         supressFindSplits = false;
       } else {
         // nothing changed, do not split
@@ -1439,7 +1367,7 @@ public class Tablet extends TabletBase {
   private void suppressFindSplits() {
     supressFindSplits = true;
     timeOfLastMinCWhenFindSplitsWasSupressed = lastMinorCompactionFinishTime;
-    timeOfLastImportWhenFindSplitsWasSupressed = lastMapFileImportTime;
+    timeOfLastImportWhenFindSplitsWasSupressed = lastDataFileImportTime;
   }
 
   private static int longestCommonLength(Text text, Text beforeMid) {
@@ -1453,7 +1381,7 @@ public class Tablet extends TabletBase {
 
   // encapsulates results of computations needed to make determinations about splits
   private static class SplitComputations {
-    final Set<TabletFile> inputFiles;
+    final Set<StoredTabletFile> inputFiles;
 
     // cached result of calling FileUtil.findMidpoint
     final SortedMap<Double,Key> midPoint;
@@ -1461,7 +1389,7 @@ public class Tablet extends TabletBase {
     // the last row seen in the files, only set for the default tablet
     final Text lastRowForDefaultTablet;
 
-    private SplitComputations(Set<TabletFile> inputFiles, SortedMap<Double,Key> midPoint,
+    private SplitComputations(Set<StoredTabletFile> inputFiles, SortedMap<Double,Key> midPoint,
         Text lastRowForDefaultTablet) {
       this.inputFiles = inputFiles;
       this.midPoint = midPoint;
@@ -1487,7 +1415,7 @@ public class Tablet extends TabletBase {
       return Optional.empty();
     }
 
-    Set<TabletFile> files = getDatafileManager().getFiles();
+    Set<StoredTabletFile> files = getDatafileManager().getFiles();
     SplitComputations lastComputation = lastSplitComputation.get();
     if (lastComputation != null && lastComputation.inputFiles.equals(files)) {
       // the last computation is still relevant
@@ -1507,9 +1435,8 @@ public class Tablet extends TabletBase {
     // Only want one thread doing this computation at time for a tablet.
     if (splitComputationLock.tryLock()) {
       try {
-        SortedMap<Double,Key> midpoint =
-            FileUtil.findMidPoint(context, tableConfiguration, chooseTabletDir(),
-                extent.prevEndRow(), extent.endRow(), FileUtil.toPathStrings(files), .25, true);
+        SortedMap<Double,Key> midpoint = FileUtil.findMidPoint(context, tableConfiguration,
+            chooseTabletDir(), extent.prevEndRow(), extent.endRow(), files, .25, true);
 
         Text lastRow = null;
 
@@ -1638,12 +1565,11 @@ public class Tablet extends TabletBase {
       }
     } else {
       Text tsp = new Text(sp);
-      var fileStrings = FileUtil.toPathStrings(getDatafileManager().getFiles());
       // This ratio is calculated before that tablet is closed and outside of a lock, so new files
       // could arrive before the tablet is closed and locked. That is okay as the ratio is an
       // estimate.
       var ratio = FileUtil.estimatePercentageLTE(context, tableConfiguration, chooseTabletDir(),
-          extent.prevEndRow(), extent.endRow(), fileStrings, tsp);
+          extent.prevEndRow(), extent.endRow(), getDatafileManager().getFiles(), tsp);
       splitPoint = new SplitRowSpec(ratio, tsp);
     }
 
@@ -1658,12 +1584,12 @@ public class Tablet extends TabletBase {
     }
 
     // obtain this info outside of synch block since it will involve opening
-    // the map files... it is ok if the set of map files changes, because
-    // this info is used for optimization... it is ok if map files are missing
+    // the data files... it is ok if the set of data files changes, because
+    // this info is used for optimization... it is ok if data files are missing
     // from the set... can still query and insert into the tablet while this
-    // map file operation is happening
-    Map<TabletFile,FileUtil.FileInfo> firstAndLastRows = FileUtil.tryToGetFirstAndLastRows(context,
-        tableConfiguration, getDatafileManager().getFiles());
+    // data file operation is happening
+    Map<StoredTabletFile,FileUtil.FileInfo> firstAndLastRows = FileUtil
+        .tryToGetFirstAndLastRows(context, tableConfiguration, getDatafileManager().getFiles());
 
     synchronized (this) {
       // java needs tuples ...
@@ -1790,64 +1716,49 @@ public class Tablet extends TabletBase {
     return splitCreationTime;
   }
 
-  public void importMapFiles(long tid, Map<TabletFile,MapFileInfo> fileMap, boolean setTime)
-      throws IOException {
-    Map<TabletFile,DataFileValue> entries = new HashMap<>(fileMap.size());
+  public void importDataFiles(long tid, Map<ReferencedTabletFile,DataFileInfo> fileMap,
+      boolean setTime) throws IOException {
+    Map<ReferencedTabletFile,DataFileValue> entries = new HashMap<>(fileMap.size());
     List<String> files = new ArrayList<>();
 
-    for (Entry<TabletFile,MapFileInfo> entry : fileMap.entrySet()) {
+    for (Entry<ReferencedTabletFile,DataFileInfo> entry : fileMap.entrySet()) {
       entries.put(entry.getKey(), new DataFileValue(entry.getValue().estimatedSize, 0L));
-      files.add(entry.getKey().getPathStr());
+      files.add(entry.getKey().getNormalizedPathStr());
     }
 
     // Clients timeout and will think that this operation failed.
     // Don't do it if we spent too long waiting for the lock
-    long now = System.nanoTime();
+    long now = System.currentTimeMillis();
     synchronized (this) {
       if (isClosed()) {
         throw new IOException("tablet " + extent + " is closed");
       }
 
-      long rpcTimeoutNanos = TimeUnit.MILLISECONDS.toNanos(
-          (long) (getTabletServer().getConfiguration().getTimeInMillis(Property.GENERAL_RPC_TIMEOUT)
-              * 1.1));
-
-      // wait for any files that are bulk importing up to the RPC timeout limit
-      while (!Collections.disjoint(bulkImporting, fileMap.keySet())) {
-        try {
-          wait(1_000);
-        } catch (InterruptedException e) {
-          Thread.currentThread().interrupt();
-          throw new IllegalStateException(e);
-        }
-
-        long lockWait = System.nanoTime() - now;
-        if (lockWait > rpcTimeoutNanos) {
-          throw new IOException("Timeout waiting " + TimeUnit.NANOSECONDS.toSeconds(lockWait)
-              + " seconds to get tablet lock for " + extent + " " + tid);
-        }
+      // TODO check seems unneeded now - ACCUMULO-1291
+      long lockWait = System.currentTimeMillis() - now;
+      if (lockWait
+          > getTabletServer().getConfiguration().getTimeInMillis(Property.GENERAL_RPC_TIMEOUT)) {
+        throw new IOException(
+            "Timeout waiting " + (lockWait / 1000.) + " seconds to get tablet lock for " + extent);
       }
 
-      // need to check this again because when wait is called above the lock is released.
-      if (isClosed()) {
-        throw new IOException("tablet " + extent + " is closed");
-      }
-
-      long lockWait = System.nanoTime() - now;
-      if (lockWait > rpcTimeoutNanos) {
-        throw new IOException("Timeout waiting " + TimeUnit.NANOSECONDS.toSeconds(lockWait)
-            + " seconds to get tablet lock for " + extent + " " + tid);
-      }
-
-      List<TabletFile> alreadyImported = bulkImported.get(tid);
+      List<ReferencedTabletFile> alreadyImported = bulkImported.get(tid);
       if (alreadyImported != null) {
-        for (TabletFile entry : alreadyImported) {
+        for (ReferencedTabletFile entry : alreadyImported) {
           if (fileMap.remove(entry) != null) {
             log.trace("Ignoring import of bulk file already imported: {}", entry);
           }
         }
       }
 
+      fileMap.keySet().removeIf(file -> {
+        if (bulkImporting.contains(file)) {
+          log.info("Ignoring import of bulk file currently importing: " + file);
+          return true;
+        }
+        return false;
+      });
+
       if (fileMap.isEmpty()) {
         return;
       }
@@ -1860,13 +1771,8 @@ public class Tablet extends TabletBase {
     try {
       tabletServer.updateBulkImportState(files, BulkImportState.LOADING);
 
-      var storedTabletFile = getDatafileManager().importMapFiles(tid, entries, setTime);
-      lastMapFileImportTime = System.currentTimeMillis();
-
-      synchronized (this) {
-        // only mark the bulk import a success if no exception was thrown
-        bulkImported.computeIfAbsent(tid, k -> new ArrayList<>()).addAll(fileMap.keySet());
-      }
+      var storedTabletFile = getDatafileManager().importDataFiles(tid, entries, setTime);
+      lastDataFileImportTime = System.currentTimeMillis();
 
       if (isSplitPossible()) {
         getTabletServer().executeSplit(this);
@@ -1882,6 +1788,11 @@ public class Tablet extends TabletBase {
               "Likely bug in code, always expect to remove something.  Please open an Accumulo issue.");
         }
 
+        try {
+          bulkImported.computeIfAbsent(tid, k -> new ArrayList<>()).addAll(fileMap.keySet());
+        } catch (Exception ex) {
+          log.info(ex.toString(), ex);
+        }
         tabletServer.removeBulkImportState(files);
       }
     }
@@ -1930,10 +1841,7 @@ public class Tablet extends TabletBase {
   public void checkIfMinorCompactionNeededForLogs(List<DfsLogger> closedLogs) {
 
     // grab this outside of tablet lock.
-    @SuppressWarnings("deprecation")
-    Property prop = tableConfiguration.resolve(Property.TSERV_WAL_MAX_REFERENCED,
-        Property.TSERV_WALOG_MAX_REFERENCED, Property.TABLE_MINC_LOGS_MAX);
-    int maxLogs = tableConfiguration.getCount(prop);
+    int maxLogs = tableConfiguration.getCount(Property.TSERV_WAL_MAX_REFERENCED);
 
     String reason = null;
     synchronized (this) {
@@ -1962,17 +1870,15 @@ public class Tablet extends TabletBase {
     }
   }
 
-  ReentrantLock getLogLock() {
-    return logLock;
-  }
-
   Set<String> beginClearingUnusedLogs() {
-    Preconditions.checkState(logLock.isHeldByCurrentThread());
     Set<String> unusedLogs = new HashSet<>();
 
     ArrayList<String> otherLogsCopy = new ArrayList<>();
     ArrayList<String> currentLogsCopy = new ArrayList<>();
 
+    // do not hold tablet lock while acquiring the log lock
+    logLock.lock();
+
     synchronized (this) {
       if (removingLogs) {
         throw new IllegalStateException(
@@ -1989,6 +1895,12 @@ public class Tablet extends TabletBase {
         unusedLogs.remove(logger.getMeta());
       }
 
+      otherLogs = Collections.emptySet();
+      // Intentionally NOT calling rebuildReferencedLogs() here as that could cause GC of in use
+      // walogs(see #539). The clearing of otherLogs is reflected in ReferencedLogs when
+      // finishClearingUnusedLogs() calls rebuildReferencedLogs(). See the comments in
+      // rebuildReferencedLogs() for more info.
+
       if (!unusedLogs.isEmpty()) {
         removingLogs = true;
       }
@@ -2011,10 +1923,9 @@ public class Tablet extends TabletBase {
   }
 
   synchronized void finishClearingUnusedLogs() {
-    Preconditions.checkState(logLock.isHeldByCurrentThread());
     removingLogs = false;
-    otherLogs = Collections.emptySet();
     rebuildReferencedLogs();
+    logLock.unlock();
   }
 
   private boolean removingLogs = false;
@@ -2030,8 +1941,7 @@ public class Tablet extends TabletBase {
 
     boolean releaseLock = true;
 
-    // Should not hold the tablet lock while trying to acquire the log lock because this could lead
-    // to deadlock. However there is a path in the code that does this. See #3759
+    // do not hold tablet lock while acquiring the log lock
     logLock.lock();
 
     try {
@@ -2105,10 +2015,6 @@ public class Tablet extends TabletBase {
   public void compactAll(long compactionId, CompactionConfig compactionConfig) {
 
     synchronized (this) {
-      // This check will quickly ignore stale request from the manager, however its not sufficient
-      // for correctness. This same check is done again later at a point when no compactions could
-      // be running concurrently to avoid race conditions. If the check passes here, it possible a
-      // concurrent compaction could change lastCompactID after the check succeeds.
       if (lastCompactID.get() >= compactionId) {
         return;
       }
@@ -2161,7 +2067,7 @@ public class Tablet extends TabletBase {
   }
 
   public Map<StoredTabletFile,DataFileValue> updatePersistedTime(long bulkTime,
-      Map<TabletFile,DataFileValue> paths, long tid) {
+      Map<ReferencedTabletFile,DataFileValue> paths, long tid) {
     synchronized (timeLock) {
       if (bulkTime > persistedTime) {
         persistedTime = bulkTime;
@@ -2178,7 +2084,8 @@ public class Tablet extends TabletBase {
    * Update tablet file data from flush. Returns a StoredTabletFile if there are data entries.
    */
   public Optional<StoredTabletFile> updateTabletDataFile(long maxCommittedTime,
-      TabletFile newDatafile, DataFileValue dfv, Set<String> unusedWalLogs, long flushId) {
+      ReferencedTabletFile newDatafile, DataFileValue dfv, Set<String> unusedWalLogs,
+      long flushId) {
     synchronized (timeLock) {
       if (maxCommittedTime > persistedTime) {
         persistedTime = maxCommittedTime;
@@ -2202,12 +2109,16 @@ public class Tablet extends TabletBase {
     return getTabletServer().getScanMetrics();
   }
 
+  public PausedCompactionMetrics getPausedCompactionMetrics() {
+    return getTabletServer().getPausedCompactionMetrics();
+  }
+
   DatafileManager getDatafileManager() {
     return datafileManager;
   }
 
   @Override
-  public Pair<Long,Map<TabletFile,DataFileValue>> reserveFilesForScan() {
+  public Pair<Long,Map<StoredTabletFile,DataFileValue>> reserveFilesForScan() {
     return getDatafileManager().reserveFilesForScan();
   }
 
@@ -2220,24 +2131,6 @@ public class Tablet extends TabletBase {
     return getDatafileManager().getUpdateCount();
   }
 
-  public void removeBatchedScanRefs() {
-    synchronized (this) {
-      if (isClosed() || isClosing()) {
-        return;
-      }
-      // return early if there are no scan files to remove
-      if (!getDatafileManager().canScanRefsBeRemoved()) {
-        return;
-      }
-      incrementWritesInProgress();
-    }
-    try {
-      getDatafileManager().removeBatchedScanRefs();
-    } finally {
-      decrementWritesInProgress();
-    }
-  }
-
   TabletMemory getTabletMemory() {
     return tabletMemory;
   }
