@@ -38,6 +38,7 @@ import java.util.concurrent.atomic.AtomicBoolean;
 import org.apache.accumulo.core.client.SampleNotPresentException;
 import org.apache.accumulo.core.client.sample.RowSampler;
 import org.apache.accumulo.core.client.sample.Sampler;
+import org.apache.accumulo.core.client.sample.SamplerConfiguration;
 import org.apache.accumulo.core.conf.ConfigurationCopy;
 import org.apache.accumulo.core.conf.DefaultConfiguration;
 import org.apache.accumulo.core.conf.Property;
@@ -48,7 +49,7 @@ import org.apache.accumulo.core.data.Mutation;
 import org.apache.accumulo.core.data.Range;
 import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.data.Value;
-import org.apache.accumulo.core.iterators.IteratorUtil.IteratorScope;
+import org.apache.accumulo.core.iterators.IteratorEnvironment;
 import org.apache.accumulo.core.iterators.SortedKeyValueIterator;
 import org.apache.accumulo.core.iteratorsImpl.system.ColumnFamilySkippingIterator;
 import org.apache.accumulo.core.iteratorsImpl.system.IterationInterruptedException;
@@ -58,7 +59,6 @@ import org.apache.accumulo.core.spi.crypto.NoCryptoServiceFactory;
 import org.apache.accumulo.core.util.LocalityGroupUtil;
 import org.apache.accumulo.server.ServerContext;
 import org.apache.accumulo.server.conf.TableConfiguration;
-import org.apache.accumulo.server.iterators.SystemIteratorEnvironmentImpl;
 import org.apache.accumulo.tserver.InMemoryMap.MemoryIterator;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.io.Text;
@@ -71,6 +71,29 @@ import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
 @SuppressFBWarnings(value = "PATH_TRAVERSAL_IN", justification = "paths not set by user input")
 public class InMemoryMapTest extends WithTestNames {
 
+  private static class SampleIE implements IteratorEnvironment {
+
+    private final SamplerConfiguration sampleConfig;
+
+    public SampleIE() {
+      this.sampleConfig = null;
+    }
+
+    public SampleIE(SamplerConfigurationImpl sampleConfig) {
+      this.sampleConfig = sampleConfig.toSamplerConfiguration();
+    }
+
+    @Override
+    public boolean isSamplingEnabled() {
+      return sampleConfig != null;
+    }
+
+    @Override
+    public SamplerConfiguration getSamplerConfiguration() {
+      return sampleConfig;
+    }
+  }
+
   public static ServerContext getServerContext() {
     Configuration hadoopConf = new Configuration();
     ServerContext context = EasyMock.createMock(ServerContext.class);
@@ -80,7 +103,6 @@ public class InMemoryMapTest extends WithTestNames {
     EasyMock.expect(context.getTableConfiguration(EasyMock.anyObject())).andReturn(tConf)
         .anyTimes();
     EasyMock.expect(tConf.getCryptoService()).andReturn(NoCryptoServiceFactory.NONE).anyTimes();
-    EasyMock.expect(tConf.get(Property.TABLE_SAMPLER)).andReturn("").anyTimes();
     EasyMock.expect(context.getHadoopConf()).andReturn(hadoopConf).anyTimes();
     EasyMock.replay(context, tConf);
     return context;
@@ -297,9 +319,7 @@ public class InMemoryMapTest extends WithTestNames {
 
     mutate(imm, "r1", "foo:cq5", 3, "bar5");
 
-    SortedKeyValueIterator<Key,Value> dc =
-        ski1.deepCopy(new SystemIteratorEnvironmentImpl.Builder(getServerContext())
-            .withScope(IteratorScope.scan).withTableId(TableId.of("foo")).build());
+    SortedKeyValueIterator<Key,Value> dc = ski1.deepCopy(new SampleIE());
 
     ski1.seek(new Range(newKey("r1", "foo:cq1", 3), null), Set.of(), false);
     testAndCallNext(ski1, "r1", "foo:cq1", 3, "bar1");
@@ -351,9 +371,8 @@ public class InMemoryMapTest extends WithTestNames {
       }
     }
 
-    SortedKeyValueIterator<Key,Value> dc =
-        ski1.deepCopy(new SystemIteratorEnvironmentImpl.Builder(getServerContext())
-            .withScope(IteratorScope.scan).withTableId(TableId.of("foo")).build());
+    SortedKeyValueIterator<Key,Value> dc = ski1.deepCopy(new SampleIE());
+
     if (interleaving == 2) {
       imm.delete(0);
       if (interrupt) {
@@ -504,9 +523,7 @@ public class InMemoryMapTest extends WithTestNames {
     MemoryIterator iter1 = imm.skvIterator(null);
 
     seekLocalityGroups(iter1);
-    SortedKeyValueIterator<Key,Value> dc1 =
-        iter1.deepCopy(new SystemIteratorEnvironmentImpl.Builder(getServerContext())
-            .withScope(IteratorScope.scan).withTableId(TableId.of("foo")).build());
+    SortedKeyValueIterator<Key,Value> dc1 = iter1.deepCopy(new SampleIE());
     seekLocalityGroups(dc1);
 
     assertEquals(10, imm.getNumEntries());
@@ -559,27 +576,12 @@ public class InMemoryMapTest extends WithTestNames {
 
       MemoryIterator iter1 = imm.skvIterator(sampleConfig);
       MemoryIterator iter2 = imm.skvIterator(null);
-      SortedKeyValueIterator<Key,Value> iter0dc1 =
-          iter0.deepCopy(new SystemIteratorEnvironmentImpl.Builder(getServerContext())
-              .withScope(IteratorScope.scan).withTableId(TableId.of("foo")).build());
-      SortedKeyValueIterator<Key,Value> iter0dc2 =
-          iter0.deepCopy(new SystemIteratorEnvironmentImpl.Builder(getServerContext())
-              .withScope(IteratorScope.scan).withTableId(TableId.of("foo")).withSamplingEnabled()
-              .withSamplerConfiguration(sampleConfig.toSamplerConfiguration()).build());
-      SortedKeyValueIterator<Key,Value> iter1dc1 =
-          iter1.deepCopy(new SystemIteratorEnvironmentImpl.Builder(getServerContext())
-              .withScope(IteratorScope.scan).withTableId(TableId.of("foo")).build());
-      SortedKeyValueIterator<Key,Value> iter1dc2 =
-          iter1.deepCopy(new SystemIteratorEnvironmentImpl.Builder(getServerContext())
-              .withScope(IteratorScope.scan).withTableId(TableId.of("foo")).withSamplingEnabled()
-              .withSamplerConfiguration(sampleConfig.toSamplerConfiguration()).build());
-      SortedKeyValueIterator<Key,Value> iter2dc1 =
-          iter2.deepCopy(new SystemIteratorEnvironmentImpl.Builder(getServerContext())
-              .withScope(IteratorScope.scan).withTableId(TableId.of("foo")).build());
-      SortedKeyValueIterator<Key,Value> iter2dc2 =
-          iter2.deepCopy(new SystemIteratorEnvironmentImpl.Builder(getServerContext())
-              .withScope(IteratorScope.scan).withTableId(TableId.of("foo")).withSamplingEnabled()
-              .withSamplerConfiguration(sampleConfig.toSamplerConfiguration()).build());
+      SortedKeyValueIterator<Key,Value> iter0dc1 = iter0.deepCopy(new SampleIE());
+      SortedKeyValueIterator<Key,Value> iter0dc2 = iter0.deepCopy(new SampleIE(sampleConfig));
+      SortedKeyValueIterator<Key,Value> iter1dc1 = iter1.deepCopy(new SampleIE());
+      SortedKeyValueIterator<Key,Value> iter1dc2 = iter1.deepCopy(new SampleIE(sampleConfig));
+      SortedKeyValueIterator<Key,Value> iter2dc1 = iter2.deepCopy(new SampleIE());
+      SortedKeyValueIterator<Key,Value> iter2dc2 = iter2.deepCopy(new SampleIE(sampleConfig));
 
       assertEquals(expectedNone, readAll(iter0));
       assertEquals(expectedNone, readAll(iter0dc1));
@@ -603,27 +605,12 @@ public class InMemoryMapTest extends WithTestNames {
       assertEquals(expectedSample, readAll(iter1dc2));
       assertEquals(expectedSample, readAll(iter2dc2));
 
-      SortedKeyValueIterator<Key,Value> iter0dc3 =
-          iter0.deepCopy(new SystemIteratorEnvironmentImpl.Builder(getServerContext())
-              .withScope(IteratorScope.scan).withTableId(TableId.of("foo")).build());
-      SortedKeyValueIterator<Key,Value> iter0dc4 =
-          iter0.deepCopy(new SystemIteratorEnvironmentImpl.Builder(getServerContext())
-              .withScope(IteratorScope.scan).withTableId(TableId.of("foo")).withSamplingEnabled()
-              .withSamplerConfiguration(sampleConfig.toSamplerConfiguration()).build());
-      SortedKeyValueIterator<Key,Value> iter1dc3 =
-          iter1.deepCopy(new SystemIteratorEnvironmentImpl.Builder(getServerContext())
-              .withScope(IteratorScope.scan).withTableId(TableId.of("foo")).build());
-      SortedKeyValueIterator<Key,Value> iter1dc4 =
-          iter1.deepCopy(new SystemIteratorEnvironmentImpl.Builder(getServerContext())
-              .withScope(IteratorScope.scan).withTableId(TableId.of("foo")).withSamplingEnabled()
-              .withSamplerConfiguration(sampleConfig.toSamplerConfiguration()).build());
-      SortedKeyValueIterator<Key,Value> iter2dc3 =
-          iter2.deepCopy(new SystemIteratorEnvironmentImpl.Builder(getServerContext())
-              .withScope(IteratorScope.scan).withTableId(TableId.of("foo")).build());
-      SortedKeyValueIterator<Key,Value> iter2dc4 =
-          iter2.deepCopy(new SystemIteratorEnvironmentImpl.Builder(getServerContext())
-              .withScope(IteratorScope.scan).withTableId(TableId.of("foo")).withSamplingEnabled()
-              .withSamplerConfiguration(sampleConfig.toSamplerConfiguration()).build());
+      SortedKeyValueIterator<Key,Value> iter0dc3 = iter0.deepCopy(new SampleIE());
+      SortedKeyValueIterator<Key,Value> iter0dc4 = iter0.deepCopy(new SampleIE(sampleConfig));
+      SortedKeyValueIterator<Key,Value> iter1dc3 = iter1.deepCopy(new SampleIE());
+      SortedKeyValueIterator<Key,Value> iter1dc4 = iter1.deepCopy(new SampleIE(sampleConfig));
+      SortedKeyValueIterator<Key,Value> iter2dc3 = iter2.deepCopy(new SampleIE());
+      SortedKeyValueIterator<Key,Value> iter2dc4 = iter2.deepCopy(new SampleIE(sampleConfig));
 
       assertEquals(expectedNone, readAll(iter0dc3));
       assertEquals(expectedNone, readAll(iter0dc4));
@@ -680,9 +667,7 @@ public class InMemoryMapTest extends WithTestNames {
     }
 
     if (deepCopy) {
-      iter = iter.deepCopy(new SystemIteratorEnvironmentImpl.Builder(getServerContext())
-          .withScope(IteratorScope.scan).withTableId(TableId.of("foo")).withSamplingEnabled()
-          .withSamplerConfiguration(sampleConfig1.toSamplerConfiguration()).build());
+      iter = iter.deepCopy(new SampleIE(sampleConfig1));
     }
 
     if (delete && dcAfterDelete) {
@@ -783,10 +768,7 @@ public class InMemoryMapTest extends WithTestNames {
     iter.seek(new Range(), Set.of(), false);
     assertEquals(expectedSample, readAll(iter));
 
-    SortedKeyValueIterator<Key,
-        Value> dc = iter.deepCopy(new SystemIteratorEnvironmentImpl.Builder(getServerContext())
-            .withScope(IteratorScope.scan).withTableId(TableId.of("foo")).withSamplingEnabled()
-            .withSamplerConfiguration(sampleConfig2.toSamplerConfiguration()).build());
+    SortedKeyValueIterator<Key,Value> dc = iter.deepCopy(new SampleIE(sampleConfig2));
     dc.seek(new Range(), Set.of(), false);
     assertEquals(expectedSample, readAll(dc));
 
