@@ -124,26 +124,26 @@ public class SortedLogRecoveryTest extends WithTestNames {
   private static KeyValue createKeyValue(LogEvents type, long seq, int tid,
       Object fileExtentMutation) {
     KeyValue result = new KeyValue();
-    result.key.setEvent(type);
-    result.key.setSeq(seq);
-    result.key.setTabletId(tid);
+    result.key.event = type;
+    result.key.seq = seq;
+    result.key.tabletId = tid;
     switch (type) {
       case OPEN:
-        result.key.setTserverSession((String) fileExtentMutation);
+        result.key.tserverSession = (String) fileExtentMutation;
         break;
       case COMPACTION_FINISH:
         break;
       case COMPACTION_START:
-        result.key.setFilename((String) fileExtentMutation);
+        result.key.filename = (String) fileExtentMutation;
         break;
       case DEFINE_TABLET:
-        result.key.setTablet((KeyExtent) fileExtentMutation);
+        result.key.tablet = (KeyExtent) fileExtentMutation;
         break;
       case MUTATION:
-        result.value.setMutations(List.of((Mutation) fileExtentMutation));
+        result.value.mutations = List.of((Mutation) fileExtentMutation);
         break;
       case MANY_MUTATIONS:
-        result.value.setMutations(Arrays.asList((Mutation[]) fileExtentMutation));
+        result.value.mutations = Arrays.asList((Mutation[]) fileExtentMutation);
     }
     return result;
   }
