@@ -30,10 +30,8 @@ import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.time.Duration;
 import java.util.HashSet;
-import java.util.List;
 import java.util.Optional;
 import java.util.Set;
-import java.util.concurrent.atomic.AtomicLong;
 import java.util.stream.Collectors;
 import java.util.stream.Stream;
 
@@ -62,7 +60,7 @@ public class CompactableImplFileManagerTest {
     var tabletFiles = newFiles("F00000.rf", "F00001.rf", "F00002.rf", "F00003.rf");
 
     assertEquals(newFiles("F00000.rf", "F00001.rf", "F00002.rf", "F00003.rf"),
-        fileMgr.getCandidates(tabletFiles, SYSTEM, false));
+        fileMgr.getCandidates(tabletFiles, SYSTEM));
     assertNoCandidates(fileMgr, tabletFiles, CHOP, USER, SELECTOR);
 
     var job1 = newJob(CompactionKind.SYSTEM, "F00000.rf", "F00001.rf");
@@ -70,8 +68,7 @@ public class CompactableImplFileManagerTest {
     assertTrue(fileMgr.reserveFiles(job1));
     assertEquals(job1.getSTFiles(), fileMgr.getCompactingFiles());
 
-    assertEquals(newFiles("F00002.rf", "F00003.rf"),
-        fileMgr.getCandidates(tabletFiles, SYSTEM, false));
+    assertEquals(newFiles("F00002.rf", "F00003.rf"), fileMgr.getCandidates(tabletFiles, SYSTEM));
     assertNoCandidates(fileMgr, tabletFiles, CHOP, USER, SELECTOR);
 
     var job2 = newJob(CompactionKind.SYSTEM, "F00002.rf", "F00003.rf");
@@ -82,7 +79,7 @@ public class CompactableImplFileManagerTest {
     // try to reserve files reserved by other compactions, should fail
     assertFalse(fileMgr.reserveFiles(newJob(CompactionKind.SYSTEM, "F00001.rf", "F00002.rf")));
 
-    assertEquals(Set.of(), fileMgr.getCandidates(tabletFiles, CompactionKind.SYSTEM, false));
+    assertEquals(Set.of(), fileMgr.getCandidates(tabletFiles, CompactionKind.SYSTEM));
     assertNoCandidates(fileMgr, tabletFiles, SYSTEM, CHOP, USER, SELECTOR);
 
     fileMgr.completed(job2, newFile("C00004.rf"));
@@ -91,7 +88,7 @@ public class CompactableImplFileManagerTest {
     tabletFiles = newFiles("C00004.rf", "C00005.rf");
 
     assertEquals(newFiles("C00004.rf", "C00005.rf"),
-        fileMgr.getCandidates(tabletFiles, CompactionKind.SYSTEM, false));
+        fileMgr.getCandidates(tabletFiles, CompactionKind.SYSTEM));
     assertNoCandidates(fileMgr, tabletFiles, CHOP, USER, SELECTOR);
 
     var job3 = newJob(CompactionKind.SYSTEM, "C00004.rf", "C00005.rf");
@@ -117,10 +114,10 @@ public class CompactableImplFileManagerTest {
     assertFalse(fileMgr.reserveFiles(staleJob));
 
     assertEquals(newFiles("F00000.rf", "F00001.rf", "F00002.rf", "F00003.rf"),
-        fileMgr.getCandidates(tabletFiles, SYSTEM, false));
+        fileMgr.getCandidates(tabletFiles, SYSTEM));
     assertNoCandidates(fileMgr, tabletFiles, CHOP, USER, SELECTOR);
 
-    assertTrue(fileMgr.initiateSelection(USER, 1L));
+    assertTrue(fileMgr.initiateSelection(USER));
 
     assertFalse(fileMgr.reserveFiles(staleJob));
 
@@ -136,9 +133,9 @@ public class CompactableImplFileManagerTest {
 
     assertFalse(fileMgr.reserveFiles(staleJob));
 
-    assertEquals(newFiles("F00003.rf"), fileMgr.getCandidates(tabletFiles, SYSTEM, false));
+    assertEquals(newFiles("F00003.rf"), fileMgr.getCandidates(tabletFiles, SYSTEM));
     assertEquals(newFiles("F00000.rf", "F00001.rf", "F00002.rf"),
-        fileMgr.getCandidates(tabletFiles, USER, false));
+        fileMgr.getCandidates(tabletFiles, USER));
     assertNoCandidates(fileMgr, tabletFiles, CHOP, SELECTOR);
 
     assertFalse(fileMgr.reserveFiles(newJob(SELECTOR, "F00000.rf", "F00001.rf")));
@@ -157,8 +154,8 @@ public class CompactableImplFileManagerTest {
     // reservation was successfully made
     fileMgr.setNanoTime(2 * SELECTION_EXPIRATION.toNanos());
 
-    assertEquals(newFiles("F00003.rf"), fileMgr.getCandidates(tabletFiles, SYSTEM, false));
-    assertEquals(newFiles("F00002.rf"), fileMgr.getCandidates(tabletFiles, USER, false));
+    assertEquals(newFiles("F00003.rf"), fileMgr.getCandidates(tabletFiles, SYSTEM));
+    assertEquals(newFiles("F00002.rf"), fileMgr.getCandidates(tabletFiles, USER));
     assertNoCandidates(fileMgr, tabletFiles, CHOP, SELECTOR);
 
     fileMgr.completed(job1, newFile("C00004.rf"));
@@ -166,9 +163,8 @@ public class CompactableImplFileManagerTest {
 
     tabletFiles = newFiles("C00004.rf", "F00002.rf", "F00003.rf");
 
-    assertEquals(newFiles("F00003.rf"), fileMgr.getCandidates(tabletFiles, SYSTEM, false));
-    assertEquals(newFiles("F00002.rf", "C00004.rf"),
-        fileMgr.getCandidates(tabletFiles, USER, false));
+    assertEquals(newFiles("F00003.rf"), fileMgr.getCandidates(tabletFiles, SYSTEM));
+    assertEquals(newFiles("F00002.rf", "C00004.rf"), fileMgr.getCandidates(tabletFiles, USER));
     assertNoCandidates(fileMgr, tabletFiles, CHOP, SELECTOR);
 
     var job2 = newJob(USER, "F00002.rf", "C00004.rf");
@@ -183,8 +179,7 @@ public class CompactableImplFileManagerTest {
 
     tabletFiles = newFiles("C00005.rf", "F00003.rf");
 
-    assertEquals(newFiles("C00005.rf", "F00003.rf"),
-        fileMgr.getCandidates(tabletFiles, SYSTEM, false));
+    assertEquals(newFiles("C00005.rf", "F00003.rf"), fileMgr.getCandidates(tabletFiles, SYSTEM));
     assertNoCandidates(fileMgr, tabletFiles, USER, CHOP, SELECTOR);
   }
 
@@ -193,7 +188,7 @@ public class CompactableImplFileManagerTest {
     TestFileManager fileMgr = new TestFileManager();
     var tabletFiles = newFiles("F00000.rf", "F00001.rf", "F00002.rf", "F00003.rf");
 
-    assertTrue(fileMgr.initiateSelection(USER, 1L));
+    assertTrue(fileMgr.initiateSelection(USER));
     assertTrue(fileMgr.beginSelection());
     fileMgr.finishSelection(newFiles("F00000.rf", "F00001.rf", "F00002.rf", "F00003.rf"), false);
     assertEquals(FileSelectionStatus.SELECTED, fileMgr.getSelectionStatus());
@@ -202,7 +197,7 @@ public class CompactableImplFileManagerTest {
     assertFalse(fileMgr.reserveFiles(newJob(SYSTEM, "F00001.rf", "F00002.rf")));
 
     assertEquals(newFiles("F00000.rf", "F00001.rf", "F00002.rf", "F00003.rf"),
-        fileMgr.getCandidates(tabletFiles, USER, false));
+        fileMgr.getCandidates(tabletFiles, USER));
     assertNoCandidates(fileMgr, tabletFiles, SYSTEM, CHOP, SELECTOR);
 
     // advance time to a point where the selection is eligible to expire
@@ -211,9 +206,9 @@ public class CompactableImplFileManagerTest {
     // now that the selection is eligible to expire, the selected files should be available as
     // system compaction candidates
     assertEquals(newFiles("F00000.rf", "F00001.rf", "F00002.rf", "F00003.rf"),
-        fileMgr.getCandidates(tabletFiles, USER, false));
+        fileMgr.getCandidates(tabletFiles, USER));
     assertEquals(newFiles("F00000.rf", "F00001.rf", "F00002.rf", "F00003.rf"),
-        fileMgr.getCandidates(tabletFiles, SYSTEM, false));
+        fileMgr.getCandidates(tabletFiles, SYSTEM));
     assertNoCandidates(fileMgr, tabletFiles, CHOP, SELECTOR);
 
     // a system compaction should be able to reserve selected files after expiration which should
@@ -235,7 +230,7 @@ public class CompactableImplFileManagerTest {
   public void testSelectionExpirationDisjoint() {
     TestFileManager fileMgr = new TestFileManager();
 
-    assertTrue(fileMgr.initiateSelection(USER, 1L));
+    assertTrue(fileMgr.initiateSelection(USER));
     assertTrue(fileMgr.beginSelection());
     fileMgr.finishSelection(newFiles("F00000.rf", "F00001.rf"), false);
     assertEquals(FileSelectionStatus.SELECTED, fileMgr.getSelectionStatus());
@@ -270,7 +265,7 @@ public class CompactableImplFileManagerTest {
     var job1 = newJob(SYSTEM, "F00000.rf", "F00001.rf");
     assertTrue(fileMgr.reserveFiles(job1));
 
-    assertTrue(fileMgr.initiateSelection(USER, 1L));
+    assertTrue(fileMgr.initiateSelection(USER));
 
     // selection was initiated, so a new system compaction should not be able to start
     assertFalse(fileMgr.reserveFiles(newJob(SYSTEM, "F00002.rf", "F00003.rf")));
@@ -290,46 +285,12 @@ public class CompactableImplFileManagerTest {
     assertEquals(FileSelectionStatus.SELECTED, fileMgr.getSelectionStatus());
   }
 
-  @Test
-  public void testUserCompactionPreemptsSelectorCompaction() {
-    TestFileManager fileMgr = new TestFileManager();
-
-    assertTrue(fileMgr.initiateSelection(SELECTOR, null));
-    assertEquals(SELECTOR, fileMgr.getSelectionKind());
-    assertTrue(fileMgr.beginSelection());
-    // USER compaction should not be able to preempt while in the middle of selecting files
-    assertFalse(fileMgr.initiateSelection(USER, 1L));
-    assertEquals(SELECTOR, fileMgr.getSelectionKind());
-    fileMgr.finishSelection(newFiles("F00000.rf", "F00001.rf", "F00002.rf"), false);
-    // check state is as expected after finishing selection
-    assertEquals(SELECTOR, fileMgr.getSelectionKind());
-    assertEquals(FileSelectionStatus.SELECTED, fileMgr.getSelectionStatus());
-    assertFalse(fileMgr.getSelectedFiles().isEmpty());
-
-    // USER compaction should not be able to preempt when there are running compactions.
-    fileMgr.running.add(SELECTOR);
-    assertFalse(fileMgr.initiateSelection(USER, 1L));
-    // check state is as expected
-    assertEquals(SELECTOR, fileMgr.getSelectionKind());
-    assertEquals(FileSelectionStatus.SELECTED, fileMgr.getSelectionStatus());
-    assertFalse(fileMgr.getSelectedFiles().isEmpty());
-
-    // after file selection is complete and there are no running compactions, should be able to
-    // preempt
-    fileMgr.running.clear();
-    assertTrue(fileMgr.initiateSelection(USER, 1L));
-    // check that things were properly reset
-    assertEquals(USER, fileMgr.getSelectionKind());
-    assertEquals(FileSelectionStatus.NEW, fileMgr.getSelectionStatus());
-    assertTrue(fileMgr.getSelectedFiles().isEmpty());
-  }
-
   @Test
   public void testUserCompactionCanceled() {
     TestFileManager fileMgr = new TestFileManager();
     var tabletFiles = newFiles("F00000.rf", "F00001.rf", "F00002.rf", "F00003.rf", "F00004.rf");
 
-    assertTrue(fileMgr.initiateSelection(USER, 1L));
+    assertTrue(fileMgr.initiateSelection(USER));
     assertTrue(fileMgr.beginSelection());
     fileMgr.finishSelection(
         newFiles("F00000.rf", "F00001.rf", "F00002.rf", "F00003.rf", "F00004.rf"), false);
@@ -339,7 +300,7 @@ public class CompactableImplFileManagerTest {
     fileMgr.userCompactionCanceled();
     assertEquals(FileSelectionStatus.NOT_ACTIVE, fileMgr.getSelectionStatus());
 
-    assertTrue(fileMgr.initiateSelection(USER, 1L));
+    assertTrue(fileMgr.initiateSelection(USER));
     assertTrue(fileMgr.beginSelection());
     fileMgr.finishSelection(
         newFiles("F00000.rf", "F00001.rf", "F00002.rf", "F00003.rf", "F00004.rf"), false);
@@ -355,14 +316,14 @@ public class CompactableImplFileManagerTest {
     assertEquals(Sets.union(job1.getSTFiles(), job2.getSTFiles()), fileMgr.getCompactingFiles());
 
     // all tablet files are selected, so there are no candidates for system compaction
-    assertEquals(Set.of(), fileMgr.getCandidates(tabletFiles, SYSTEM, false));
+    assertEquals(Set.of(), fileMgr.getCandidates(tabletFiles, SYSTEM));
 
     // this time when the user compaction is canceled jobs are running, so transition to canceled
     fileMgr.userCompactionCanceled();
     assertEquals(FileSelectionStatus.CANCELED, fileMgr.getSelectionStatus());
 
     // files that were selected should now be available as candidates after canceling
-    assertEquals(newFiles("F00004.rf"), fileMgr.getCandidates(tabletFiles, SYSTEM, false));
+    assertEquals(newFiles("F00004.rf"), fileMgr.getCandidates(tabletFiles, SYSTEM));
 
     // when this job completes it should not transition from CANCELED to NOT_ACTIVE because there is
     // still another
@@ -395,7 +356,7 @@ public class CompactableImplFileManagerTest {
     ChopSelector chopSel = fileMgr.initiateChop(tabletFiles);
     assertEquals(ChopSelectionStatus.SELECTING, fileMgr.getChopStatus());
 
-    assertEquals(Set.of(), fileMgr.getCandidates(tabletFiles, CHOP, false));
+    assertEquals(Set.of(), fileMgr.getCandidates(tabletFiles, CHOP));
 
     // this should not include C00005.rf because it was created by a compaction observed by the file
     // manager
@@ -404,8 +365,7 @@ public class CompactableImplFileManagerTest {
     chopSel.selectChopFiles(newFiles("F00002.rf", "F00004.rf"));
     assertEquals(ChopSelectionStatus.SELECTED, fileMgr.getChopStatus());
 
-    assertEquals(newFiles("F00002.rf", "F00004.rf"),
-        fileMgr.getCandidates(tabletFiles, CHOP, false));
+    assertEquals(newFiles("F00002.rf", "F00004.rf"), fileMgr.getCandidates(tabletFiles, CHOP));
 
     // simulate compacting one of the files that needs to be chopped, but this should not finish the
     // chop because more files need to be chopped
@@ -417,7 +377,7 @@ public class CompactableImplFileManagerTest {
     assertEquals(ChopSelectionStatus.SELECTED, fileMgr.getChopStatus());
     assertThrows(IllegalStateException.class, fileMgr::finishMarkingChop);
 
-    assertEquals(newFiles("F00004.rf"), fileMgr.getCandidates(tabletFiles, CHOP, false));
+    assertEquals(newFiles("F00004.rf"), fileMgr.getCandidates(tabletFiles, CHOP));
 
     // simulate compacting the last file to chop. should cause the chop finish
     var job3 = newJob(CHOP, "F00004.rf");
@@ -426,7 +386,7 @@ public class CompactableImplFileManagerTest {
     tabletFiles = newFiles("C00004.rf", "C00006.rf", "F00003.rf", "C00007.rf");
     assertTrue(fileMgr.finishChop(tabletFiles));
 
-    assertEquals(Set.of(), fileMgr.getCandidates(tabletFiles, CHOP, false));
+    assertEquals(Set.of(), fileMgr.getCandidates(tabletFiles, CHOP));
     assertEquals(ChopSelectionStatus.MARKING, fileMgr.getChopStatus());
     assertEquals(Set.of(), fileMgr.getCompactingFiles());
 
@@ -435,45 +395,10 @@ public class CompactableImplFileManagerTest {
 
   }
 
-  @Test
-  public void testComletedUserCompaction() {
-    TestFileManager fileMgr = new TestFileManager();
-
-    fileMgr.lastCompactId.set(2);
-    // should fail to initiate because the last compact id is equal
-    assertFalse(fileMgr.initiateSelection(USER, 2L));
-    assertEquals(FileSelectionStatus.NOT_ACTIVE, fileMgr.selectStatus);
-
-    fileMgr.lastCompactId.set(3);
-    // should fail to initiate because the last compact id is greater than
-    assertFalse(fileMgr.initiateSelection(USER, 2L));
-    assertEquals(FileSelectionStatus.NOT_ACTIVE, fileMgr.selectStatus);
-
-    fileMgr.lastCompactId.set(1);
-    assertTrue(fileMgr.initiateSelection(USER, 2L));
-    assertEquals(FileSelectionStatus.NEW, fileMgr.selectStatus);
-
-    assertTrue(fileMgr.beginSelection());
-    fileMgr.finishSelection(
-        newFiles("F00000.rf", "F00001.rf", "F00002.rf", "F00003.rf", "F00004.rf"), false);
-    assertEquals(FileSelectionStatus.SELECTED, fileMgr.getSelectionStatus());
-  }
-
-  @Test
-  public void testIllegalInitiateArgs() {
-    TestFileManager fileMgr = new TestFileManager();
-    assertThrows(IllegalArgumentException.class, () -> fileMgr.initiateSelection(USER, null));
-    assertThrows(IllegalArgumentException.class, () -> fileMgr.initiateSelection(SELECTOR, 2L));
-    for (var kind : List.of(SYSTEM, CHOP)) {
-      assertThrows(IllegalArgumentException.class, () -> fileMgr.initiateSelection(kind, 2L));
-      assertThrows(IllegalArgumentException.class, () -> fileMgr.initiateSelection(kind, null));
-    }
-  }
-
   private void assertNoCandidates(TestFileManager fileMgr, Set<StoredTabletFile> tabletFiles,
       CompactionKind... kinds) {
     for (CompactionKind kind : kinds) {
-      assertEquals(Set.of(), fileMgr.getCandidates(tabletFiles, kind, false));
+      assertEquals(Set.of(), fileMgr.getCandidates(tabletFiles, kind));
     }
 
   }
@@ -483,7 +408,6 @@ public class CompactableImplFileManagerTest {
     public static final Duration SELECTION_EXPIRATION = Duration.ofMinutes(2);
     private long time = 0;
     public Set<CompactionKind> running = new HashSet<>();
-    public AtomicLong lastCompactId = new AtomicLong(0);
 
     public TestFileManager() {
       super(new KeyExtent(TableId.of("1"), null, null), Set.of(), Optional.empty(),
@@ -508,11 +432,6 @@ public class CompactableImplFileManagerTest {
       return time;
     }
 
-    @Override
-    protected long getLastCompactId() {
-      return lastCompactId.get();
-    }
-
     void setNanoTime(long t) {
       time = t;
     }
