@@ -60,10 +60,6 @@ public class ShellOptionsJC {
       description = "disables tab completion (for less overhead when scripting)")
   private boolean tabCompletionDisabled;
 
-  @Parameter(names = "--debug", description = "enables client debugging"
-      + "; deprecated, configure debugging through your logging configuration file")
-  private boolean debugEnabled;
-
   @Parameter(names = {"-?", "--help"}, help = true, description = "display this help")
   private boolean helpEnabled;
 
@@ -152,10 +148,6 @@ public class ShellOptionsJC {
     return tabCompletionDisabled;
   }
 
-  public boolean isDebugEnabled() {
-    return debugEnabled;
-  }
-
   public boolean isHelpEnabled() {
     return helpEnabled;
   }
@@ -201,7 +193,7 @@ public class ShellOptionsJC {
         File file = new File(path);
         if (file.isFile() && file.canRead()) {
           clientConfigFile = file.getAbsolutePath();
-          Shell.log.info("Loading configuration from {}", clientConfigFile);
+          System.out.println("Loading configuration from " + clientConfigFile);
           break;
         }
       }
