@@ -25,7 +25,6 @@ import java.util.ArrayList;
 import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
-import java.util.Objects;
 import java.util.Set;
 import java.util.TreeMap;
 
@@ -53,19 +52,10 @@ import org.jline.reader.LineReader;
 import com.google.common.collect.ImmutableSortedMap;
 
 public class ConfigCommand extends Command {
-  private Option tableOpt;
-  private Option deleteOpt;
-  private Option setOpt;
-  private Option forceOpt;
-  private Option filterOpt;
-  private Option filterWithValuesOpt;
-  private Option disablePaginationOpt;
-  private Option outputFileOpt;
-  private Option namespaceOpt;
-  private Option showExpOpt;
+  private Option tableOpt, deleteOpt, setOpt, forceOpt, filterOpt, filterWithValuesOpt,
+      disablePaginationOpt, outputFileOpt, namespaceOpt;
 
-  private int COL1 = 10;
-  private int COL2 = 7;
+  private int COL1 = 10, COL2 = 7;
   private LineReader reader;
 
   @Override
@@ -88,9 +78,6 @@ public class ConfigCommand extends Command {
       NamespaceNotFoundException {
     reader = shellState.getReader();
 
-    boolean force = cl.hasOption(forceOpt);
-    boolean showExp = cl.hasOption(showExpOpt);
-
     final String tableName = cl.getOptionValue(tableOpt.getOpt());
     if (tableName != null && !shellState.getAccumuloClient().tableOperations().exists(tableName)) {
       throw new TableNotFoundException(null, tableName, null);
@@ -101,7 +88,7 @@ public class ConfigCommand extends Command {
       throw new NamespaceNotFoundException(null, namespace, null);
     }
     if (cl.hasOption(deleteOpt.getOpt())) {
-      // delete property from table, namespace, or system
+      // delete property from table
       String property = cl.getOptionValue(deleteOpt.getOpt());
       if (property.contains("=")) {
         throw new BadArgumentException("Invalid '=' operator in delete operation.", fullCommand,
@@ -126,12 +113,11 @@ public class ConfigCommand extends Command {
           Shell.log.warn(invalidTablePropFormatString, property);
         }
         shellState.getAccumuloClient().instanceOperations().removeProperty(property);
-        logSysPropChanged(Property.getPropertyByKey(property), "deleted");
+        Shell.log.debug("Successfully deleted system configuration option.");
       }
     } else if (cl.hasOption(setOpt.getOpt())) {
-      // set property on table, namespace, or system
-      String property = cl.getOptionValue(setOpt.getOpt());
-      String value;
+      // set property on table
+      String property = cl.getOptionValue(setOpt.getOpt()), value = null;
       if (!property.contains("=")) {
         throw new BadArgumentException("Missing '=' operator in set operation.", fullCommand,
             fullCommand.indexOf(property));
@@ -143,9 +129,8 @@ public class ConfigCommand extends Command {
       // check for deprecation
       var theProp = Property.getPropertyByKey(property);
       if (theProp != null && theProp.isDeprecated()) {
-        if (!force
-            && !shellState.confirm("Trying to set deprecated property `" + property + "` continue")
-                .orElse(false)) {
+        if (!forceSet(shellState, cl,
+            "Trying to set deprecated property `" + property + "` continue")) {
           throw new BadArgumentException(
               "Tried to set deprecated property and force not specified.", fullCommand,
               fullCommand.indexOf(property));
@@ -178,7 +163,7 @@ public class ConfigCommand extends Command {
               fullCommand.indexOf(property));
         }
         shellState.getAccumuloClient().instanceOperations().setProperty(property, value);
-        logSysPropChanged(theProp, "set");
+        Shell.log.debug("Successfully set system configuration option.");
       }
     } else {
       boolean warned = false;
@@ -224,8 +209,8 @@ public class ConfigCommand extends Command {
         String n = Namespaces.getNamespaceName(shellState.getContext(),
             shellState.getContext().getNamespaceId(shellState.getContext().getTableId(tableName)));
         try {
-          namespaceConfig
-              .putAll(shellState.getAccumuloClient().namespaceOperations().getConfiguration(n));
+          shellState.getAccumuloClient().namespaceOperations().getConfiguration(n)
+              .forEach(namespaceConfig::put);
         } catch (AccumuloSecurityException e) {
           if (e.getSecurityErrorCode() == PERMISSION_DENIED) {
             Shell.log.warn(
@@ -319,8 +304,7 @@ public class ConfigCommand extends Command {
           if (dfault != null && key.toLowerCase().contains("password")) {
             siteVal = sysVal = dfault = curVal = curVal.replaceAll(".", "*");
           }
-          if (defaults.containsKey(key)
-              && (!Property.getPropertyByKey(key).isExperimental() || showExp)) {
+          if (defaults.containsKey(key) && !Property.getPropertyByKey(key).isExperimental()) {
             printConfLine(output, "default", key, dfault);
             printed = true;
           }
@@ -329,7 +313,7 @@ public class ConfigCommand extends Command {
                 siteVal == null ? "" : siteVal);
             printed = true;
           }
-          if (!siteConfig.containsKey(key) || !Objects.equals(siteVal, sysVal)) {
+          if (!siteConfig.containsKey(key) || !siteVal.equals(sysVal)) {
             printConfLine(output, "system", printed ? "   @override" : key, sysVal);
             printed = true;
           }
@@ -338,11 +322,11 @@ public class ConfigCommand extends Command {
           // If the user can't see the system configuration, then print the default
           // configuration value if the current namespace value is different from it.
           if (sysVal == null && dfault != null && !dfault.equals(nspVal)
-              && (!Property.getPropertyByKey(key).isExperimental() || showExp)) {
+              && !Property.getPropertyByKey(key).isExperimental()) {
             printConfLine(output, "default", key, dfault);
             printed = true;
           }
-          if (!systemConfig.containsKey(key) || !Objects.equals(sysVal, nspVal)) {
+          if (!systemConfig.containsKey(key) || !sysVal.equals(nspVal)) {
             printConfLine(output, "namespace", printed ? "   @override" : key, nspVal);
             printed = true;
           }
@@ -353,7 +337,7 @@ public class ConfigCommand extends Command {
           // If the user can't see the system configuration, then print the default
           // configuration value if the current table value is different from it.
           if (nspVal == null && dfault != null && !dfault.equals(curVal)
-              && (!Property.getPropertyByKey(key).isExperimental() || showExp)) {
+              && !Property.getPropertyByKey(key).isExperimental()) {
             printConfLine(output, "default", key, dfault);
             printed = true;
           }
@@ -362,7 +346,7 @@ public class ConfigCommand extends Command {
           // If the user can't see the system configuration, then print the default
           // configuration value if the current namespace value is different from it.
           if (sysVal == null && dfault != null && !dfault.equals(curVal)
-              && (!Property.getPropertyByKey(key).isExperimental() || showExp)) {
+              && !Property.getPropertyByKey(key).isExperimental()) {
             printConfLine(output, "default", key, dfault);
             printed = true;
           }
@@ -411,7 +395,7 @@ public class ConfigCommand extends Command {
 
   @Override
   public String description() {
-    return "prints table specific, namespace specific, and system properties";
+    return "prints system properties and table specific properties";
   }
 
   @Override
@@ -422,12 +406,10 @@ public class ConfigCommand extends Command {
 
     tableOpt = new Option(ShellOptions.tableOption, "table", true,
         "table to display/set/delete properties for");
-    deleteOpt =
-        new Option("d", "delete", true, "delete a per-table, per-namespace, or system property");
-    setOpt = new Option("s", "set", true, "set a per-table, per-namespace, or system property");
+    deleteOpt = new Option("d", "delete", true, "delete a per-table property");
+    setOpt = new Option("s", "set", true, "set a per-table property");
     forceOpt = new Option("force", "force", false,
         "used with set to set a deprecated property without asking");
-    showExpOpt = new Option("show", "show-exp", false, "also show experimental properties");
     filterOpt = new Option("f", "filter", true,
         "show only properties that contain this string in their name.");
     filterWithValuesOpt = new Option("fv", "filter-with-values", true,
@@ -459,7 +441,6 @@ public class ConfigCommand extends Command {
     o.addOption(disablePaginationOpt);
     o.addOption(outputFileOpt);
     o.addOption(forceOpt);
-    o.addOption(showExpOpt);
 
     return o;
   }
@@ -469,13 +450,17 @@ public class ConfigCommand extends Command {
     return 0;
   }
 
-  private void logSysPropChanged(Property prop, String setOrDeleted) {
-    if (Property.isFixedZooPropertyKey(prop)) {
-      Shell.log.warn("Successfully {} a fixed system configuration option. Change will not "
-          + "take effect until related processes are restarted.", setOrDeleted);
-    } else {
-      Shell.log.debug("Successfully {} system configuration option.", setOrDeleted);
+  /**
+   * Determine is force is set as an option or user enters (y | yes) on the shell prompt.
+   *
+   * @return true if force is set as opt or y | yes entered at command line.
+   */
+  private boolean forceSet(final Shell shellState, final CommandLine cl, final String prompt) {
+    if (cl.hasOption(forceOpt)) {
+      return true;
     }
+    shellState.getWriter().flush();
+    String line = shellState.getReader().readLine(prompt + " (yes|no)? ");
+    return line != null && (line.equalsIgnoreCase("y") || line.equalsIgnoreCase("yes"));
   }
-
 }
