@@ -49,24 +49,7 @@ public class GrepCommand extends ScanCommand {
       if (cl.getArgList().isEmpty()) {
         throw new MissingArgumentException("No terms specified");
       }
-      // Configure formatting options
-      final FormatterConfig config = new FormatterConfig();
-      config.setPrintTimestamps(cl.hasOption(timestampOpt.getOpt()));
-      if (cl.hasOption(showFewOpt.getOpt())) {
-        final String showLength = cl.getOptionValue(showFewOpt.getOpt());
-        try {
-          final int length = Integer.parseInt(showLength);
-          config.setShownLength(length);
-        } catch (NumberFormatException nfe) {
-          Shell.log.error("Arg must be an integer.", nfe);
-        } catch (IllegalArgumentException iae) {
-          Shell.log.error("Invalid length argument", iae);
-        }
-      }
       final Class<? extends Formatter> formatter = getFormatter(cl, tableName, shellState);
-      @SuppressWarnings("deprecation")
-      final org.apache.accumulo.core.util.interpret.ScanInterpreter interpreter =
-          getInterpreter(cl, tableName, shellState);
 
       // handle first argument, if present, the authorizations list to
       // scan with
@@ -83,7 +66,7 @@ public class GrepCommand extends ScanCommand {
       final Authorizations auths = getAuths(cl, shellState);
       final BatchScanner scanner =
           shellState.getAccumuloClient().createBatchScanner(tableName, auths, numThreads);
-      scanner.setRanges(Collections.singletonList(getRange(cl, interpreter)));
+      scanner.setRanges(Collections.singletonList(getRange(cl)));
 
       scanner.setTimeout(getTimeout(cl), TimeUnit.MILLISECONDS);
 
@@ -98,9 +81,11 @@ public class GrepCommand extends ScanCommand {
       }
       try {
         // handle columns
-        fetchColumns(cl, scanner, interpreter);
+        fetchColumns(cl, scanner);
 
         // output the records
+        final FormatterConfig config = new FormatterConfig();
+        config.setPrintTimestamps(cl.hasOption(timestampOpt.getOpt()));
         printRecords(cl, shellState, config, scanner, formatter, printFile);
       } finally {
         scanner.close();
@@ -119,15 +104,13 @@ public class GrepCommand extends ScanCommand {
     final IteratorSetting grep = new IteratorSetting(prio, name, GrepIterator.class);
     GrepIterator.setTerm(grep, term);
     GrepIterator.setNegate(grep, negate);
-    GrepIterator.matchColumnVisibility(grep, true); // override GrepIterator default
     scanner.addScanIterator(grep);
   }
 
   @Override
   public String description() {
-    return "searches each row, column family, column qualifier, visibility (since 2.1.3),"
-        + " and value in a table for a substring (not a regular expression), in parallel,"
-        + " on the server side";
+    return "searches each row, column family, column qualifier and value in a"
+        + " table for a substring (not a regular expression), in parallel, on the server side";
   }
 
   @Override
