@@ -22,7 +22,6 @@ import java.util.ArrayList;
 import java.util.Collections;
 import java.util.LinkedList;
 import java.util.List;
-import java.util.Map;
 import java.util.Objects;
 import java.util.Set;
 import java.util.TreeSet;
@@ -48,15 +47,19 @@ import org.apache.commons.cli.CommandLine;
 import org.apache.commons.cli.Option;
 import org.apache.commons.cli.Options;
 import org.apache.hadoop.io.Text;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import com.google.common.annotations.VisibleForTesting;
 
 /**
  * Utility that generates single line tablet info. The output of this could be fed to sort, awk,
- * grep, etc. to answer questions like which tablets have the most files.
+ * grep, etc inorder to answer questions like which tablets have the most files.
  */
 public class ListTabletsCommand extends Command {
 
+  private static final Logger log = LoggerFactory.getLogger(ListTabletsCommand.class);
+
   private Option outputFileOpt;
   private Option optTablePattern;
   private Option optHumanReadable;
@@ -67,7 +70,7 @@ public class ListTabletsCommand extends Command {
   public int execute(String fullCommand, CommandLine cl, Shell shellState) throws Exception {
     final Set<TableInfo> tableInfoSet = populateTables(cl, shellState);
     if (tableInfoSet.isEmpty()) {
-      Shell.log.warn("No tables found that match your criteria");
+      log.warn("No tables found that match your criteria");
       return 0;
     }
     boolean humanReadable = cl.hasOption(optHumanReadable.getOpt());
@@ -121,13 +124,13 @@ public class ListTabletsCommand extends Command {
       throws NamespaceNotFoundException {
 
     final TableOperations tableOps = shellState.getAccumuloClient().tableOperations();
-    final Map<String,String> tableIdMap = tableOps.tableIdMap();
+    var tableIdMap = tableOps.tableIdMap();
 
     Set<TableInfo> tableSet = new TreeSet<>();
 
     if (cl.hasOption(optTablePattern.getOpt())) {
       Pattern tablePattern = Pattern.compile(cl.getOptionValue(optTablePattern.getOpt()));
-      for (String table : tableIdMap.keySet()) {
+      for (String table : tableOps.list()) {
         if (tablePattern.matcher(table).matches()) {
           TableId id = TableId.of(tableIdMap.get(table));
           tableSet.add(new TableInfo(table, id));
@@ -146,7 +149,7 @@ public class ListTabletsCommand extends Command {
           TableId id = TableId.of(tableIdString);
           tableSet.add(new TableInfo(name, id));
         } else {
-          Shell.log.warn("Table not found: {}", name);
+          log.warn("Table not found: {}", name);
         }
       });
       return tableSet;
@@ -159,7 +162,7 @@ public class ListTabletsCommand extends Command {
         TableId id = TableId.of(idString);
         tableSet.add(new TableInfo(table, id));
       } else {
-        Shell.log.warn("Table not found: {}", table);
+        log.warn("Table not found: {}", table);
       }
       return tableSet;
     }
@@ -213,14 +216,14 @@ public class ListTabletsCommand extends Command {
 
   private List<TabletRowInfo> getTabletRowInfo(Shell shellState, TableInfo tableInfo)
       throws Exception {
-    Shell.log.trace("scan metadata for tablet info table name: \'{}\', tableId: \'{}\' ",
-        tableInfo.name, tableInfo.id);
+    log.trace("scan metadata for tablet info table name: \'{}\', tableId: \'{}\' ", tableInfo.name,
+        tableInfo.id);
 
     List<TabletRowInfo> tResults = getMetadataInfo(shellState, tableInfo);
 
-    if (Shell.log.isTraceEnabled()) {
+    if (log.isTraceEnabled()) {
       for (TabletRowInfo tabletRowInfo : tResults) {
-        Shell.log.trace("Tablet info: {}", tabletRowInfo);
+        log.trace("Tablet info: {}", tabletRowInfo);
       }
     }
 
