@@ -46,17 +46,20 @@ public class MergeCommand extends Command {
     if (cl.hasOption(forceOpt.getOpt())) {
       force = true;
     }
-    if (cl.hasOption(allOpt)) {
+    if (cl.hasOption(allOpt.getOpt())) {
       all = true;
     }
     if (cl.hasOption(sizeOpt.getOpt())) {
       size = ConfigurationTypeHelper.getFixedMemoryAsBytes(cl.getOptionValue(sizeOpt.getOpt()));
     }
     if (startRow == null && endRow == null && size < 0 && !all) {
-      if (!shellState
-          .confirm(" Warning!!! Are you REALLY sure you want to merge the entire table { "
-              + tableName + " } into one tablet?!?!?!")
-          .orElse(false)) {
+      shellState.getWriter().flush();
+      String line = shellState.getReader()
+          .readLine("Merge the entire table { " + tableName + " } into one tablet (yes|no)? ");
+      if (line == null) {
+        return 0;
+      }
+      if (!line.equalsIgnoreCase("y") && !line.equalsIgnoreCase("yes")) {
         return 0;
       }
     }
@@ -95,11 +98,9 @@ public class MergeCommand extends Command {
         new Option("s", "size", true, "merge tablets to the given size over the entire table");
     forceOpt = new Option("f", "force", false,
         "merge small tablets to large tablets, even if it goes over the given size");
-    // Using the constructor does not allow for empty option
-    Option.Builder builder = Option.builder().longOpt("all").hasArg(false)
-        .desc("allow an entire table to be merged into one tablet without prompting"
+    allOpt = new Option("", "all", false,
+        "allow an entire table to be merged into one tablet without prompting"
             + " the user for confirmation");
-    allOpt = builder.build();
     o.addOption(OptUtil.startRowOpt());
     o.addOption(OptUtil.endRowOpt());
     o.addOption(OptUtil.tableOpt("table to be merged"));
