@@ -56,7 +56,6 @@ public class QuotedStringTokenizer implements Iterable<String> {
 
   private void createTokens() throws BadArgumentException, UnsupportedEncodingException {
     boolean inQuote = false;
-    boolean inValue = false;
     boolean inEscapeSequence = false;
     String hexChars = null;
     char inQuoteChar = '"';
@@ -67,22 +66,17 @@ public class QuotedStringTokenizer implements Iterable<String> {
     for (int i = 0; i < input.length(); ++i) {
       final char ch = input.charAt(i);
 
+      // if I ended up in an escape sequence, check for valid escapable character, and add it as a
+      // literal
       if (inEscapeSequence) {
         inEscapeSequence = false;
-        // check for a valid escapable character and add it as a literal
-        switch (ch) {
-          case 'x':
-            hexChars = "";
-            break;
-          case ' ':
-          case '\'':
-          case '"':
-          case '\\':
-            token[tokenLength++] = inputBytes[i];
-            break;
-          default:
-            throw new BadArgumentException("can only escape single quotes, double"
-                + " quotes, the space character, the backslash, and hex input", input, i);
+        if (ch == 'x') {
+          hexChars = "";
+        } else if (ch == ' ' || ch == '\'' || ch == '"' || ch == '\\') {
+          token[tokenLength++] = inputBytes[i];
+        } else {
+          throw new BadArgumentException("can only escape single quotes, double"
+              + " quotes, the space character, the backslash, and hex input", input, i);
         }
       } else if (hexChars != null) {
         // in a hex escape sequence
@@ -115,54 +109,22 @@ public class QuotedStringTokenizer implements Iterable<String> {
         } else {
           token[tokenLength++] = inputBytes[i];
         }
-      } else if (inValue) {
-        switch (ch) {
-          case '\\':
-            // start escape sequence
-            inEscapeSequence = true;
-            break;
-          case ' ':
-            // end current token
-            inValue = false;
+      } else {
+        // not in a quote, either enter a quote, end a token, start escape, or continue a token
+        if (ch == '\'' || ch == '"') {
+          if (tokenLength > 0) {
             tokens.add(new String(token, 0, tokenLength, Shell.CHARSET));
             tokenLength = 0;
-            break;
-          default:
-            // continue the current token
-            token[tokenLength++] = inputBytes[i];
-        }
-      } else {
-        switch (ch) {
-          case '=':
-            // entering a value. Include the '=' char in the token
-            inValue = true;
-            token[tokenLength++] = inputBytes[i];
-            break;
-          case '\'':
-            // drop through to quote handling
-          case '"':
-            // entering a quote
-            if (tokenLength > 0) {
-              tokens.add(new String(token, 0, tokenLength, Shell.CHARSET));
-              tokenLength = 0;
-            }
-            inQuote = true;
-            inQuoteChar = ch;
-            break;
-          case ' ':
-            // end a token if more input exists
-            if (tokenLength > 0) {
-              tokens.add(new String(token, 0, tokenLength, Shell.CHARSET));
-              tokenLength = 0;
-            }
-            break;
-          case ('\\'):
-            // start escape sequence
-            inEscapeSequence = true;
-            break;
-          default:
-            // continue the current token
-            token[tokenLength++] = inputBytes[i];
+          }
+          inQuote = true;
+          inQuoteChar = ch;
+        } else if (ch == ' ' && tokenLength > 0) {
+          tokens.add(new String(token, 0, tokenLength, Shell.CHARSET));
+          tokenLength = 0;
+        } else if (ch == '\\') {
+          inEscapeSequence = true;
+        } else if (ch != ' ') {
+          token[tokenLength++] = inputBytes[i];
         }
       }
     }
