@@ -41,7 +41,6 @@ import org.apache.accumulo.core.iterators.user.RegExFilter;
 import org.apache.accumulo.core.iterators.user.ReqVisFilter;
 import org.apache.accumulo.core.iterators.user.VersioningIterator;
 import org.apache.accumulo.core.metadata.MetadataTable;
-import org.apache.accumulo.core.spi.common.ContextClassLoaderFactory.ContextClassLoaderException;
 import org.apache.accumulo.shell.Shell;
 import org.apache.accumulo.shell.Shell.Command;
 import org.apache.accumulo.shell.ShellCommandException;
@@ -61,7 +60,7 @@ public class SetIterCommand extends Command {
   @Override
   public int execute(final String fullCommand, final CommandLine cl, final Shell shellState)
       throws AccumuloException, AccumuloSecurityException, TableNotFoundException, IOException,
-      ShellCommandException, ContextClassLoaderException {
+      ShellCommandException {
 
     boolean tables =
         cl.hasOption(OptUtil.tableOpt().getOpt()) || !shellState.getTableName().isEmpty();
@@ -110,7 +109,7 @@ public class SetIterCommand extends Command {
     }
 
     // Try to get the name provided by the setiter command
-    String name = cl.getOptionValue(nameOpt.getOpt());
+    String name = cl.getOptionValue(nameOpt.getOpt(), null);
 
     // Cannot continue if no name is provided
     if (name == null && configuredName == null) {
