@@ -20,7 +20,6 @@ package org.apache.accumulo.shell.commands;
 
 import java.util.Collections;
 import java.util.Map;
-import java.util.Optional;
 import java.util.Set;
 import java.util.SortedSet;
 import java.util.TreeSet;
@@ -74,21 +73,26 @@ public abstract class TableOperation extends Command {
       Shell.log.warn("No tables found that match your criteria");
     }
 
-    // do op if forced or user answers prompt with yes
+    boolean more = true;
+    // flush the tables
     for (String tableName : tableSet) {
+      if (!more) {
+        break;
+      }
       if (!shellState.getAccumuloClient().tableOperations().exists(tableName)) {
         throw new TableNotFoundException(null, tableName, null);
       }
+      boolean operate = true;
       if (!force) {
-        Optional<Boolean> confirmed = shellState.confirm(getName() + " { " + tableName + " }");
-        if (confirmed.isEmpty()) {
-          break;
-        }
-        if (!confirmed.orElseThrow()) {
-          continue;
-        }
+        shellState.getWriter().flush();
+        String line =
+            shellState.getReader().readLine(getName() + " { " + tableName + " } (yes|no)? ");
+        more = line != null;
+        operate = line != null && (line.equalsIgnoreCase("y") || line.equalsIgnoreCase("yes"));
+      }
+      if (operate) {
+        doTableOp(shellState, tableName);
       }
-      doTableOp(shellState, tableName);
     }
 
     return 0;
