@@ -1,23 +1,25 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.shell;
 
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.File;
 import java.io.FileDescriptor;
@@ -27,14 +29,17 @@ import java.io.OutputStream;
 import java.io.PrintStream;
 import java.nio.file.Files;
 
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Test;
+import org.jline.reader.LineReader;
+import org.jline.reader.LineReaderBuilder;
+import org.jline.terminal.Size;
+import org.jline.terminal.Terminal;
+import org.jline.terminal.impl.DumbTerminal;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import jline.console.ConsoleReader;
-
 public class ShellConfigTest {
 
   public static class TestOutputStream extends OutputStream {
@@ -60,18 +65,20 @@ public class ShellConfigTest {
   File config;
   private static final Logger log = LoggerFactory.getLogger(ShellConfigTest.class);
 
-  @Before
+  @BeforeEach
   public void setUp() throws Exception {
     out = System.out;
     output = new TestOutputStream();
     System.setOut(new PrintStream(output));
     config = Files.createTempFile(null, null).toFile();
-
-    shell = new Shell(new ConsoleReader(new FileInputStream(FileDescriptor.in), output));
+    Terminal terminal = new DumbTerminal(new FileInputStream(FileDescriptor.in), output);
+    terminal.setSize(new Size(80, 24));
+    LineReader reader = LineReaderBuilder.builder().terminal(terminal).build();
+    shell = new Shell(reader);
     shell.setLogErrorsToConsole();
   }
 
-  @After
+  @AfterEach
   public void teardown() throws Exception {
     shell.shutdown();
     output.clear();
@@ -98,15 +105,15 @@ public class ShellConfigTest {
   @Test
   public void testHelp() throws IOException {
     assertFalse(shell.config(args("--help")));
-    assertTrue("Did not print usage", output.get().startsWith("Usage"));
+    assertTrue(output.get().startsWith("Usage"), "Did not print usage");
   }
 
   @Test
   public void testBadArg() throws IOException {
     assertFalse(shell.config(args("--bogus")));
     // JCommander versions after 1.60 will cause the Shell to detect the arg as Unrecognized option
-    assertTrue("Did not print Error", output.get().startsWith("ERROR"));
-    assertTrue("Did not print usage", output.get().contains("Usage"));
+    assertTrue(output.get().startsWith("ERROR"), "Did not print Error");
+    assertTrue(output.get().contains("Usage"), "Did not print usage");
   }
 
 }
