@@ -25,7 +25,6 @@ import static org.easymock.EasyMock.createNiceMock;
 import static org.easymock.EasyMock.expect;
 import static org.easymock.EasyMock.expectLastCall;
 import static org.easymock.EasyMock.replay;
-import static org.easymock.EasyMock.verify;
 import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertNull;
 import static org.junit.jupiter.api.Assertions.assertTrue;
@@ -37,7 +36,6 @@ import java.io.InputStream;
 import java.io.PrintWriter;
 import java.util.Collections;
 import java.util.Map;
-import java.util.Optional;
 import java.util.TreeMap;
 
 import org.apache.accumulo.core.client.BatchWriter;
@@ -52,16 +50,14 @@ import org.jline.reader.LineReaderBuilder;
 import org.jline.terminal.Size;
 import org.jline.terminal.Terminal;
 import org.jline.terminal.impl.DumbTerminal;
-import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 
 public class DeleterFormatterTest {
-  // default timestamp
-  private static final long TIMESTAMP = Long.MAX_VALUE;
   DeleterFormatter formatter;
   Map<Key,Value> data;
   BatchWriter writer;
+  BatchWriter exceptionWriter;
   Shell shellState;
   LineReader reader;
   Terminal terminal;
@@ -85,11 +81,19 @@ public class DeleterFormatterTest {
   }
 
   @BeforeEach
-  public void setUp() throws IOException {
+  public void setUp() throws IOException, MutationsRejectedException {
     input = new SettableInputStream();
     baos = new ByteArrayOutputStream();
 
+    MutationsRejectedException mre = createMock(MutationsRejectedException.class);
+
     writer = createNiceMock(BatchWriter.class);
+    exceptionWriter = createNiceMock(BatchWriter.class);
+    exceptionWriter.close();
+    expectLastCall().andThrow(mre);
+    exceptionWriter.addMutation(anyObject(Mutation.class));
+    expectLastCall().andThrow(mre);
+
     shellState = createNiceMock(Shell.class);
 
     terminal = new DumbTerminal(input, baos);
@@ -100,18 +104,14 @@ public class DeleterFormatterTest {
     expect(shellState.getReader()).andReturn(reader).anyTimes();
     expect(shellState.getWriter()).andReturn(pw).anyTimes();
 
+    replay(writer, exceptionWriter, shellState);
+
     data = new TreeMap<>();
     data.put(new Key("r", "cf", "cq"), new Value("value"));
   }
 
-  @AfterEach
-  public void verifyCommonMocks() {
-    verify(writer, shellState);
-  }
-
   @Test
   public void testEmpty() {
-    replay(writer, shellState);
     formatter = new DeleterFormatter(writer, Collections.<Key,Value>emptyMap().entrySet(),
         new FormatterConfig().setPrintTimestamps(true), shellState, true);
     assertFalse(formatter.hasNext());
@@ -119,23 +119,17 @@ public class DeleterFormatterTest {
 
   @Test
   public void testSingle() throws IOException {
-    replay(writer, shellState);
     formatter = new DeleterFormatter(writer, data.entrySet(),
         new FormatterConfig().setPrintTimestamps(true), shellState, true);
 
     assertTrue(formatter.hasNext());
     assertNull(formatter.next());
 
-    verifyOut("[DELETED]", " r ", "cf", "cq", "value");
+    verify("[DELETED]", " r ", "cf", "cq", "value");
   }
 
   @Test
   public void testNo() throws IOException {
-    expect(shellState.confirm("Delete { r cf:cq [] " + TIMESTAMP + "\tvalue } ? "))
-        .andReturn(Optional.of(false));
-    expectLastCall().once();
-    replay(writer, shellState);
-
     input.set("no\n");
     data.put(new Key("z"), new Value("v2"));
     formatter = new DeleterFormatter(writer, data.entrySet(),
@@ -144,18 +138,13 @@ public class DeleterFormatterTest {
     assertTrue(formatter.hasNext());
     assertNull(formatter.next());
 
-    verifyOut("[SKIPPED]", " r ", "cf", "cq", "value");
+    verify("[SKIPPED]", " r ", "cf", "cq", "value");
 
     assertTrue(formatter.hasNext());
   }
 
   @Test
   public void testNoConfirmation() throws IOException {
-    expect(shellState.confirm("Delete { r cf:cq [] " + TIMESTAMP + "\tvalue } ? "))
-        .andReturn(Optional.empty());
-    expectLastCall().once();
-    replay(writer, shellState);
-
     input.set("");
     data.put(new Key("z"), new Value("v2"));
     formatter = new DeleterFormatter(writer, data.entrySet(),
@@ -164,22 +153,13 @@ public class DeleterFormatterTest {
     assertTrue(formatter.hasNext());
     assertNull(formatter.next());
 
-    verifyOut("[SKIPPED]", " r ", "cf", "cq", "value");
+    verify("[SKIPPED]", " r ", "cf", "cq", "value");
 
     assertFalse(formatter.hasNext());
   }
 
   @Test
   public void testYes() throws IOException {
-    expect(shellState.confirm("Delete { r cf:cq [] " + TIMESTAMP + "\tvalue } ? "))
-        .andReturn(Optional.of(true));
-    expectLastCall().once();
-
-    expect(shellState.confirm("Delete { z : [] " + TIMESTAMP + "\tv2 } ? "))
-        .andReturn(Optional.of(true));
-    expectLastCall().once();
-    replay(writer, shellState);
-
     input.set("y\nyes\n");
     data.put(new Key("z"), new Value("v2"));
     formatter = new DeleterFormatter(writer, data.entrySet(),
@@ -187,38 +167,29 @@ public class DeleterFormatterTest {
 
     assertTrue(formatter.hasNext());
     assertNull(formatter.next());
-    verifyOut("[DELETED]", " r ", "cf", "cq", "value");
+    verify("[DELETED]", " r ", "cf", "cq", "value");
 
     assertTrue(formatter.hasNext());
     assertNull(formatter.next());
-    verifyOut("[DELETED]", " z ", "v2");
+    verify("[DELETED]", " z ", "v2");
   }
 
   @Test
-  public void testMutationException() throws MutationsRejectedException {
-    MutationsRejectedException mre = createMock(MutationsRejectedException.class);
-    BatchWriter exceptionWriter = createNiceMock(BatchWriter.class);
-    exceptionWriter.close();
-    expectLastCall().andThrow(mre);
-    exceptionWriter.addMutation(anyObject(Mutation.class));
-    expectLastCall().andThrow(mre);
-    replay(mre, writer, exceptionWriter, shellState);
+  public void testMutationException() {
     formatter = new DeleterFormatter(exceptionWriter, data.entrySet(),
         new FormatterConfig().setPrintTimestamps(true), shellState, true);
 
     assertTrue(formatter.hasNext());
     assertNull(formatter.next());
     assertFalse(formatter.hasNext());
-    verify(mre, exceptionWriter);
   }
 
-  private void verifyOut(String... chunks) throws IOException {
+  private void verify(String... chunks) throws IOException {
     reader.getTerminal().writer().flush();
 
     String output = baos.toString();
     for (String chunk : chunks) {
-      assertTrue(output.contains(chunk), "Output is missing chunk: " + chunk);
+      assertTrue(output.contains(chunk));
     }
   }
-
 }
