@@ -34,7 +34,7 @@ public class TestMain {
         System.exit(0);
       }
       if (args[0].equals("throw")) {
-        throw new RuntimeException("This is an exception");
+        throw new IllegalStateException("This is an exception");
       }
     }
     System.exit(-1);
