@@ -19,7 +19,9 @@
 package org.apache.accumulo.test;
 
 import static java.nio.charset.StandardCharsets.UTF_8;
-import static org.apache.accumulo.core.util.UtilWaitThread.sleepUninterruptibly;
+import static java.util.concurrent.TimeUnit.MINUTES;
+import static java.util.concurrent.TimeUnit.SECONDS;
+import static org.apache.accumulo.core.util.LazySingletons.RANDOM;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertSame;
@@ -43,7 +45,6 @@ import java.util.TreeSet;
 import java.util.UUID;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
-import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.function.Function;
 import java.util.stream.Collectors;
@@ -58,7 +59,6 @@ import org.apache.accumulo.core.client.ConditionalWriter;
 import org.apache.accumulo.core.client.ConditionalWriter.Result;
 import org.apache.accumulo.core.client.ConditionalWriter.Status;
 import org.apache.accumulo.core.client.ConditionalWriterConfig;
-import org.apache.accumulo.core.client.Durability;
 import org.apache.accumulo.core.client.IsolatedScanner;
 import org.apache.accumulo.core.client.IteratorSetting;
 import org.apache.accumulo.core.client.RowIterator;
@@ -69,8 +69,6 @@ import org.apache.accumulo.core.client.TableNotFoundException;
 import org.apache.accumulo.core.client.TableOfflineException;
 import org.apache.accumulo.core.client.admin.NewTableConfiguration;
 import org.apache.accumulo.core.client.security.tokens.PasswordToken;
-import org.apache.accumulo.core.clientImpl.ConditionalWriterImpl;
-import org.apache.accumulo.core.conf.ClientProperty;
 import org.apache.accumulo.core.data.ArrayByteSequence;
 import org.apache.accumulo.core.data.ByteSequence;
 import org.apache.accumulo.core.data.Condition;
@@ -607,7 +605,7 @@ public class ConditionalWriterIT extends SharedMiniClusterBase {
 
           while (results.hasNext()) {
             Result result = results.next();
-            String k = new String(result.getMutation().getRow(), UTF_8);
+            String k = new String(result.getMutation().getRow());
             assertFalse(actual.containsKey(k),
                 "Did not expect to see multiple results for the row: " + k);
             actual.put(k, result.getStatus());
@@ -743,7 +741,7 @@ public class ConditionalWriterIT extends SharedMiniClusterBase {
 
         while (results.hasNext()) {
           Result result = results.next();
-          String k = new String(result.getMutation().getRow(), UTF_8);
+          String k = new String(result.getMutation().getRow());
           assertFalse(actual.containsKey(k),
               "Did not expect to see multiple results for the row: " + k);
           actual.put(k, result.getStatus());
@@ -846,7 +844,7 @@ public class ConditionalWriterIT extends SharedMiniClusterBase {
         int rejected = 0;
         while (results.hasNext()) {
           Result result = results.next();
-          if (new String(result.getMutation().getRow(), UTF_8).equals("99006")) {
+          if (new String(result.getMutation().getRow()).equals("99006")) {
             assertEquals(Status.ACCEPTED, result.getStatus());
             accepted++;
           } else {
@@ -885,7 +883,7 @@ public class ConditionalWriterIT extends SharedMiniClusterBase {
       NewTableConfiguration ntc = new NewTableConfiguration().withSplits(nss("2", "4", "6"));
       client.tableOperations().create(tableName, ntc);
 
-      sleepUninterruptibly(2, TimeUnit.SECONDS);
+      Thread.sleep(SECONDS.toMillis(2));
 
       int num = 100;
 
@@ -895,7 +893,7 @@ public class ConditionalWriterIT extends SharedMiniClusterBase {
       byte[] e = new byte[0];
 
       for (int i = 0; i < num; i++) {
-        rows.add(FastFormat.toZeroPaddedString(abs(random.nextLong()), 16, 16, e));
+        rows.add(FastFormat.toZeroPaddedString(abs(RANDOM.get().nextLong()), 16, 16, e));
       }
 
       for (int i = 0; i < num; i++) {
@@ -970,7 +968,7 @@ public class ConditionalWriterIT extends SharedMiniClusterBase {
       ColumnVisibility cvaob = new ColumnVisibility("A|B");
       ColumnVisibility cvaab = new ColumnVisibility("A&B");
 
-      switch (random.nextInt(3)) {
+      switch (RANDOM.get().nextInt(3)) {
         case 1:
           client.tableOperations().addSplits(tableName, nss("6"));
           break;
@@ -1017,7 +1015,7 @@ public class ConditionalWriterIT extends SharedMiniClusterBase {
         HashSet<String> rows = new HashSet<>();
         while (results.hasNext()) {
           Result result = results.next();
-          String row = new String(result.getMutation().getRow(), UTF_8);
+          String row = new String(result.getMutation().getRow());
           switch (row) {
             case "19059":
               assertEquals(Status.ACCEPTED, result.getStatus());
@@ -1199,19 +1197,19 @@ public class ConditionalWriterIT extends SharedMiniClusterBase {
           new IsolatedScanner(client.createScanner(tableName, Authorizations.EMPTY))) {
 
         for (int i = 0; i < 20; i++) {
-          int numRows = random.nextInt(10) + 1;
+          int numRows = RANDOM.get().nextInt(10) + 1;
 
           ArrayList<ByteSequence> changes = new ArrayList<>(numRows);
           ArrayList<ConditionalMutation> mutations = new ArrayList<>();
 
           for (int j = 0; j < numRows; j++) {
-            changes.add(rows.get(random.nextInt(rows.size())));
+            changes.add(rows.get(RANDOM.get().nextInt(rows.size())));
           }
 
           for (ByteSequence row : changes) {
             scanner.setRange(new Range(row.toString()));
             Stats stats = new Stats(scanner.iterator());
-            stats.set(random.nextInt(10), random.nextInt(Integer.MAX_VALUE));
+            stats.set(RANDOM.get().nextInt(10), RANDOM.get().nextInt(Integer.MAX_VALUE));
             mutations.add(stats.toMutation());
           }
 
@@ -1243,7 +1241,7 @@ public class ConditionalWriterIT extends SharedMiniClusterBase {
 
       NewTableConfiguration ntc = new NewTableConfiguration();
 
-      switch (random.nextInt(3)) {
+      switch (RANDOM.get().nextInt(3)) {
         case 1:
           ntc = ntc.withSplits(nss("4"));
           break;
@@ -1260,7 +1258,7 @@ public class ConditionalWriterIT extends SharedMiniClusterBase {
 
         for (int i = 0; i < 1000; i++) {
           rows.add(new ArrayByteSequence(
-              FastFormat.toZeroPaddedString(abs(random.nextLong()), 16, 16, new byte[0])));
+              FastFormat.toZeroPaddedString(abs(RANDOM.get().nextLong()), 16, 16, new byte[0])));
         }
 
         ArrayList<ConditionalMutation> mutations = new ArrayList<>();
@@ -1292,7 +1290,7 @@ public class ConditionalWriterIT extends SharedMiniClusterBase {
         tp.shutdown();
 
         while (!tp.isTerminated()) {
-          tp.awaitTermination(1, TimeUnit.MINUTES);
+          tp.awaitTermination(1, MINUTES);
         }
 
         assertFalse(failed.get(), "A MutatorTask failed with an exception");
@@ -1388,7 +1386,7 @@ public class ConditionalWriterIT extends SharedMiniClusterBase {
 
       try (
           ConditionalWriter cw = client.createConditionalWriter(table,
-              new ConditionalWriterConfig().setTimeout(3, TimeUnit.SECONDS));
+              new ConditionalWriterConfig().setTimeout(3, SECONDS));
           Scanner scanner = client.createScanner(table, Authorizations.EMPTY)) {
 
         ConditionalMutation cm1 = new ConditionalMutation("r1", new Condition("tx", "seq"));
@@ -1539,34 +1537,4 @@ public class ConditionalWriterIT extends SharedMiniClusterBase {
     }
   }
 
-  @Test
-  public void testCreateConditionalWriterUsesClientProps() throws Exception {
-    // Tests that creating a conditional writer includes the client properties that were set
-    String tableName = getUniqueNames(1)[0];
-    var clientProps = getClientProps();
-    // Set non-default values for all conditional writer props
-    clientProps.setProperty(ClientProperty.CONDITIONAL_WRITER_TIMEOUT_MAX.getKey(), "99");
-    clientProps.setProperty(ClientProperty.CONDITIONAL_WRITER_THREADS_MAX.getKey(), "101");
-    clientProps.setProperty(ClientProperty.CONDITIONAL_WRITER_DURABILITY.getKey(),
-        Durability.NONE.name());
-    try (AccumuloClient client = Accumulo.newClient().from(clientProps).build()) {
-      client.tableOperations().create(tableName);
-
-      try (
-          ConditionalWriterImpl cw1 =
-              (ConditionalWriterImpl) client.createConditionalWriter(tableName);
-          ConditionalWriterImpl cw2 =
-              (ConditionalWriterImpl) client.createConditionalWriter(tableName,
-                  new ConditionalWriterConfig().setMaxWriteThreads(200))) {
-        // verify we see the non-default prop values
-        assertEquals(99, cw1.getConfig().getTimeout(TimeUnit.SECONDS));
-        assertEquals(101, cw1.getConfig().getMaxWriteThreads());
-        assertEquals(Durability.NONE, cw1.getConfig().getDurability());
-        assertEquals(99, cw2.getConfig().getTimeout(TimeUnit.SECONDS));
-        assertEquals(200, cw2.getConfig().getMaxWriteThreads());
-        assertEquals(Durability.NONE, cw2.getConfig().getDurability());
-      }
-    }
-  }
-
 }
