@@ -19,6 +19,7 @@
 package org.apache.accumulo.test;
 
 import static org.apache.accumulo.core.Constants.IMPORT_MAPPINGS_FILE;
+import static org.apache.accumulo.core.util.LazySingletons.RANDOM;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
@@ -47,7 +48,6 @@ import org.apache.accumulo.core.data.Key;
 import org.apache.accumulo.core.data.Mutation;
 import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.data.Value;
-import org.apache.accumulo.core.manager.state.tables.TableState;
 import org.apache.accumulo.core.metadata.MetadataTable;
 import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection;
 import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection.DataFileColumnFamily;
@@ -85,140 +85,124 @@ public class ImportExportIT extends AccumuloClusterHarness {
   @Test
   public void testExportImportThenScan() throws Exception {
     try (AccumuloClient client = Accumulo.newClient().from(getClientProps()).build()) {
+
       String[] tableNames = getUniqueNames(2);
-      doExportImportThenScan(client, tableNames[0], tableNames[1]);
-    }
-  }
+      String srcTable = tableNames[0], destTable = tableNames[1];
+      client.tableOperations().create(srcTable);
 
-  @Test
-  public void testExportImportSameTableNameThenScan() throws Exception {
-    try (AccumuloClient client = Accumulo.newClient().from(getClientProps()).build()) {
-      String ns1 = "namespace1";
-      client.namespaceOperations().create(ns1);
-      String ns2 = "namespace2";
-      client.namespaceOperations().create(ns2);
-      String tableName = getUniqueNames(1)[0];
-      doExportImportThenScan(client, ns1 + "." + tableName, ns2 + "." + tableName);
-    }
-  }
-
-  public void doExportImportThenScan(AccumuloClient client, String srcTable, String destTable)
-      throws Exception {
-
-    client.tableOperations().create(srcTable);
-
-    try (BatchWriter bw = client.createBatchWriter(srcTable)) {
-      for (int row = 0; row < 1000; row++) {
-        Mutation m = new Mutation(Integer.toString(row));
-        for (int col = 0; col < 100; col++) {
-          m.put(Integer.toString(col), "", Integer.toString(col * 2));
-        }
-        bw.addMutation(m);
-      }
-    }
-
-    client.tableOperations().compact(srcTable, null, null, true, true);
-
-    // Make a directory we can use to throw the export and import directories
-    // Must exist on the filesystem the cluster is running.
-    FileSystem fs = cluster.getFileSystem();
-    log.info("Using FileSystem: " + fs);
-    Path baseDir = new Path(cluster.getTemporaryPath(), getClass().getName());
-    fs.deleteOnExit(baseDir);
-    if (fs.exists(baseDir)) {
-      log.info("{} exists on filesystem, deleting", baseDir);
-      assertTrue(fs.delete(baseDir, true), "Failed to deleted " + baseDir);
-    }
-    log.info("Creating {}", baseDir);
-    assertTrue(fs.mkdirs(baseDir), "Failed to create " + baseDir);
-    Path exportDir = new Path(baseDir, "export");
-    fs.deleteOnExit(exportDir);
-    Path importDirA = new Path(baseDir, "import-a");
-    Path importDirB = new Path(baseDir, "import-b");
-    fs.deleteOnExit(importDirA);
-    fs.deleteOnExit(importDirB);
-    for (Path p : new Path[] {exportDir, importDirA, importDirB}) {
-      assertTrue(fs.mkdirs(p), "Failed to create " + p);
-    }
-
-    Set<String> importDirs = Set.of(importDirA.toString(), importDirB.toString());
-
-    Path[] importDirAry = new Path[] {importDirA, importDirB};
-
-    log.info("Exporting table to {}", exportDir);
-    log.info("Importing table from {}", importDirs);
-
-    // test fast fail offline check
-    assertThrows(IllegalStateException.class,
-        () -> client.tableOperations().exportTable(srcTable, exportDir.toString()));
-
-    // Offline the table
-    client.tableOperations().offline(srcTable, true);
-    // Then export it
-    client.tableOperations().exportTable(srcTable, exportDir.toString());
-
-    // Make sure the distcp.txt file that exporttable creates is available
-    Path distcp = new Path(exportDir, "distcp.txt");
-    fs.deleteOnExit(distcp);
-    assertTrue(fs.exists(distcp), "Distcp file doesn't exist");
-    FSDataInputStream is = fs.open(distcp);
-    BufferedReader reader = new BufferedReader(new InputStreamReader(is));
-
-    // Copy each file that was exported to one of the imports directory
-    String line;
-
-    while ((line = reader.readLine()) != null) {
-      Path p = new Path(line.substring(5));
-      assertTrue(fs.exists(p), "File doesn't exist: " + p);
-      Path importDir = importDirAry[random.nextInt(importDirAry.length)];
-      Path dest = new Path(importDir, p.getName());
-      assertFalse(fs.exists(dest), "Did not expect " + dest + " to exist");
-      FileUtil.copy(fs, p, fs, dest, false, fs.getConf());
-    }
-
-    reader.close();
-
-    log.info("Import dir A: {}", Arrays.toString(fs.listStatus(importDirA)));
-    log.info("Import dir B: {}", Arrays.toString(fs.listStatus(importDirB)));
-
-    // Import the exported data into a new table
-    client.tableOperations().importTable(destTable, importDirs, ImportConfiguration.empty());
-
-    // Get the table ID for the table that the importtable command created
-    final String tableId = client.tableOperations().tableIdMap().get(destTable);
-    assertNotNull(tableId);
-
-    // Get all `file` colfams from the metadata table for the new table
-    log.info("Imported into table with ID: {}", tableId);
-
-    try (Scanner s = client.createScanner(MetadataTable.NAME, Authorizations.EMPTY)) {
-      s.setRange(TabletsSection.getRange(TableId.of(tableId)));
-      s.fetchColumnFamily(DataFileColumnFamily.NAME);
-      ServerColumnFamily.DIRECTORY_COLUMN.fetch(s);
-
-      // Should find a single entry
-      for (Entry<Key,Value> fileEntry : s) {
-        Key k = fileEntry.getKey();
-        String value = fileEntry.getValue().toString();
-        if (k.getColumnFamily().equals(DataFileColumnFamily.NAME)) {
-          // The file should be an absolute URI (file:///...), not a relative path
-          // (/b-000.../I000001.rf)
-          String fileUri = k.getColumnQualifier().toString();
-          assertFalse(looksLikeRelativePath(fileUri),
-              "Imported files should have absolute URIs, not relative: " + fileUri);
-        } else if (k.getColumnFamily().equals(ServerColumnFamily.NAME)) {
-          assertFalse(looksLikeRelativePath(value),
-              "Server directory should have absolute URI, not relative: " + value);
-        } else {
-          fail("Got expected pair: " + k + "=" + fileEntry.getValue());
+      try (BatchWriter bw = client.createBatchWriter(srcTable)) {
+        for (int row = 0; row < 1000; row++) {
+          Mutation m = new Mutation(Integer.toString(row));
+          for (int col = 0; col < 100; col++) {
+            m.put(Integer.toString(col), "", Integer.toString(col * 2));
+          }
+          bw.addMutation(m);
         }
       }
 
-    }
-    // Online the original table before we verify equivalence
-    client.tableOperations().online(srcTable, true);
+      client.tableOperations().compact(srcTable, null, null, true, true);
 
-    verifyTableEquality(client, srcTable, destTable);
+      // Make a directory we can use to throw the export and import directories
+      // Must exist on the filesystem the cluster is running.
+      FileSystem fs = cluster.getFileSystem();
+      log.info("Using FileSystem: " + fs);
+      Path baseDir = new Path(cluster.getTemporaryPath(), getClass().getName());
+      fs.deleteOnExit(baseDir);
+      if (fs.exists(baseDir)) {
+        log.info("{} exists on filesystem, deleting", baseDir);
+        assertTrue(fs.delete(baseDir, true), "Failed to deleted " + baseDir);
+      }
+      log.info("Creating {}", baseDir);
+      assertTrue(fs.mkdirs(baseDir), "Failed to create " + baseDir);
+      Path exportDir = new Path(baseDir, "export");
+      fs.deleteOnExit(exportDir);
+      Path importDirA = new Path(baseDir, "import-a");
+      Path importDirB = new Path(baseDir, "import-b");
+      fs.deleteOnExit(importDirA);
+      fs.deleteOnExit(importDirB);
+      for (Path p : new Path[] {exportDir, importDirA, importDirB}) {
+        assertTrue(fs.mkdirs(p), "Failed to create " + p);
+      }
+
+      Set<String> importDirs = Set.of(importDirA.toString(), importDirB.toString());
+
+      Path[] importDirAry = new Path[] {importDirA, importDirB};
+
+      log.info("Exporting table to {}", exportDir);
+      log.info("Importing table from {}", importDirs);
+
+      // test fast fail offline check
+      assertThrows(IllegalStateException.class,
+          () -> client.tableOperations().exportTable(srcTable, exportDir.toString()));
+
+      // Offline the table
+      client.tableOperations().offline(srcTable, true);
+      // Then export it
+      client.tableOperations().exportTable(srcTable, exportDir.toString());
+
+      // Make sure the distcp.txt file that exporttable creates is available
+      Path distcp = new Path(exportDir, "distcp.txt");
+      fs.deleteOnExit(distcp);
+      assertTrue(fs.exists(distcp), "Distcp file doesn't exist");
+      FSDataInputStream is = fs.open(distcp);
+      BufferedReader reader = new BufferedReader(new InputStreamReader(is));
+
+      // Copy each file that was exported to one of the imports directory
+      String line;
+
+      while ((line = reader.readLine()) != null) {
+        Path p = new Path(line.substring(5));
+        assertTrue(fs.exists(p), "File doesn't exist: " + p);
+        Path importDir = importDirAry[RANDOM.get().nextInt(importDirAry.length)];
+        Path dest = new Path(importDir, p.getName());
+        assertFalse(fs.exists(dest), "Did not expect " + dest + " to exist");
+        FileUtil.copy(fs, p, fs, dest, false, fs.getConf());
+      }
+
+      reader.close();
+
+      log.info("Import dir A: {}", Arrays.toString(fs.listStatus(importDirA)));
+      log.info("Import dir B: {}", Arrays.toString(fs.listStatus(importDirB)));
+
+      // Import the exported data into a new table
+      client.tableOperations().importTable(destTable, importDirs, ImportConfiguration.empty());
+
+      // Get the table ID for the table that the importtable command created
+      final String tableId = client.tableOperations().tableIdMap().get(destTable);
+      assertNotNull(tableId);
+
+      // Get all `file` colfams from the metadata table for the new table
+      log.info("Imported into table with ID: {}", tableId);
+
+      try (Scanner s = client.createScanner(MetadataTable.NAME, Authorizations.EMPTY)) {
+        s.setRange(TabletsSection.getRange(TableId.of(tableId)));
+        s.fetchColumnFamily(DataFileColumnFamily.NAME);
+        ServerColumnFamily.DIRECTORY_COLUMN.fetch(s);
+
+        // Should find a single entry
+        for (Entry<Key,Value> fileEntry : s) {
+          Key k = fileEntry.getKey();
+          String value = fileEntry.getValue().toString();
+          if (k.getColumnFamily().equals(DataFileColumnFamily.NAME)) {
+            // The file should be an absolute URI (file:///...), not a relative path
+            // (/b-000.../I000001.rf)
+            String fileUri = k.getColumnQualifier().toString();
+            assertFalse(looksLikeRelativePath(fileUri),
+                "Imported files should have absolute URIs, not relative: " + fileUri);
+          } else if (k.getColumnFamily().equals(ServerColumnFamily.NAME)) {
+            assertFalse(looksLikeRelativePath(value),
+                "Server directory should have absolute URI, not relative: " + value);
+          } else {
+            fail("Got expected pair: " + k + "=" + fileEntry.getValue());
+          }
+        }
+
+      }
+      // Online the original table before we verify equivalence
+      client.tableOperations().online(srcTable, true);
+
+      verifyTableEquality(client, srcTable, destTable);
+    }
   }
 
   @Test
@@ -287,7 +271,7 @@ public class ImportExportIT extends AccumuloClusterHarness {
       while ((line = reader.readLine()) != null) {
         Path p = new Path(line.substring(5));
         assertTrue(fs.exists(p), "File doesn't exist: " + p);
-        Path importDir = importDirAry[random.nextInt(importDirAry.length)];
+        Path importDir = importDirAry[RANDOM.get().nextInt(importDirAry.length)];
         Path dest = new Path(importDir, p.getName());
         assertFalse(fs.exists(dest), "Did not expect " + dest + " to exist");
         FileUtil.copy(fs, p, fs, dest, false, fs.getConf());
@@ -311,7 +295,6 @@ public class ImportExportIT extends AccumuloClusterHarness {
 
       // verify the new table is offline
       assertFalse(client.tableOperations().isOnline(destTable), "Table should have been offline.");
-      assertEquals(getServerContext().getTableState(TableId.of(tableId)), TableState.OFFLINE);
       client.tableOperations().online(destTable, true);
 
       // Get all `file` colfams from the metadata table for the new table
