@@ -18,7 +18,6 @@
  */
 package org.apache.accumulo.test;
 
-import static java.nio.charset.StandardCharsets.UTF_8;
 import static org.apache.accumulo.harness.AccumuloITBase.SUNNY_DAY;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertTrue;
@@ -376,7 +375,7 @@ public class InMemoryMapIT extends WithTestNames {
         if (value.length() > 0) {
           value.append(",");
         }
-        value.append(new String(bytes.toArray(), UTF_8));
+        value.append(new String(bytes.toArray()));
       }
       configuration.set("table.group." + entry.getKey(), value.toString());
       enabledLGs.append(entry.getKey());
