@@ -18,7 +18,7 @@
  */
 package org.apache.accumulo.test;
 
-import static org.apache.accumulo.core.util.UtilWaitThread.sleepUninterruptibly;
+import static java.util.concurrent.TimeUnit.SECONDS;
 import static org.apache.accumulo.harness.AccumuloITBase.MINI_CLUSTER_ONLY;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
@@ -39,7 +39,6 @@ import java.util.Map.Entry;
 import java.util.Set;
 import java.util.SortedSet;
 import java.util.TreeSet;
-import java.util.concurrent.TimeUnit;
 
 import org.apache.accumulo.cluster.ClusterUser;
 import org.apache.accumulo.core.client.Accumulo;
@@ -136,7 +135,7 @@ public class NamespacesIT extends SharedMiniClusterBase {
         c.tableOperations().delete(t);
       }
     }
-    assertEquals(3, c.tableOperations().list().size());
+    assertEquals(2, c.tableOperations().list().size());
     for (String n : c.namespaceOperations().list()) {
       if (!n.equals(Namespace.ACCUMULO.name()) && !n.equals(Namespace.DEFAULT.name())) {
         c.namespaceOperations().delete(n);
@@ -215,13 +214,6 @@ public class NamespacesIT extends SharedMiniClusterBase {
     assertFalse(nsOps.exists(n2));
   }
 
-  @Test
-  public void createNamespaceWithSystemUser() throws Exception {
-    String testNamespace = "ns_" + getUniqueNames(1)[0];
-    AccumuloClient client = getCluster().getServerContext();
-    client.namespaceOperations().create(testNamespace);
-  }
-
   @Test
   public void createAndDeleteNamespace() throws Exception {
     String t1 = namespace + ".1";
@@ -410,7 +402,7 @@ public class NamespacesIT extends SharedMiniClusterBase {
       c.namespaceOperations().checkIteratorConflicts(namespace, setting,
           EnumSet.allOf(IteratorScope.class));
       c.namespaceOperations().attachIterator(namespace, setting);
-      sleepUninterruptibly(2, TimeUnit.SECONDS);
+      Thread.sleep(SECONDS.toMillis(2));
       var e = assertThrows(AccumuloException.class, () -> c.namespaceOperations()
           .checkIteratorConflicts(namespace, setting, EnumSet.allOf(IteratorScope.class)));
       assertEquals(IllegalArgumentException.class, e.getCause().getClass());
@@ -427,7 +419,7 @@ public class NamespacesIT extends SharedMiniClusterBase {
       // verify can see inserted entry again
       c.namespaceOperations().removeIterator(namespace, setting.getName(),
           EnumSet.allOf(IteratorScope.class));
-      sleepUninterruptibly(2, TimeUnit.SECONDS);
+      Thread.sleep(SECONDS.toMillis(2));
       assertFalse(c.namespaceOperations().listIterators(namespace).containsKey(iterName));
       assertFalse(c.tableOperations().listIterators(t1).containsKey(iterName));
     }
@@ -915,7 +907,7 @@ public class NamespacesIT extends SharedMiniClusterBase {
     // set the filter, verify that accumulo namespace is the only one unaffected
     c.instanceOperations().setProperty(k, v);
     // doesn't take effect immediately, needs time to propagate to tserver's ZooKeeper cache
-    sleepUninterruptibly(250, TimeUnit.MILLISECONDS);
+    Thread.sleep(250);
     assertTrue(c.instanceOperations().getSystemConfiguration().containsValue(v));
     assertEquals(systemNamespaceShouldInherit,
         checkNamespaceHasProp(Namespace.ACCUMULO.name(), k, v));
@@ -929,7 +921,7 @@ public class NamespacesIT extends SharedMiniClusterBase {
     // verify it is no longer inherited
     c.instanceOperations().removeProperty(k);
     // doesn't take effect immediately, needs time to propagate to tserver's ZooKeeper cache
-    sleepUninterruptibly(250, TimeUnit.MILLISECONDS);
+    Thread.sleep(250);
     assertFalse(c.instanceOperations().getSystemConfiguration().containsValue(v));
     assertFalse(checkNamespaceHasProp(Namespace.ACCUMULO.name(), k, v));
     assertFalse(checkTableHasProp(RootTable.NAME, k, v));
