@@ -438,16 +438,13 @@ public class ScanConsistencyIT extends AccumuloClusterHarness {
       this.tctx = testContext;
     }
 
-    @SuppressWarnings("deprecation")
     private long bulkImport(Random random, Collection<Mutation> mutations) throws Exception {
 
       if (mutations.isEmpty()) {
         return 0;
       }
 
-      String name = "/bulkimport_" + nextLongAbs(random);
-      Path bulkDir = new Path(tctx.tmpDir + name);
-      Path failDir = new Path(tctx.tmpDir + name + "_failures");
+      Path bulkDir = new Path(tctx.tmpDir + "/bulkimport_" + nextLongAbs(random));
 
       List<Key> keys = mutations.stream().flatMap(ScanConsistencyIT::toKeys).sorted()
           .collect(Collectors.toList());
@@ -463,22 +460,10 @@ public class ScanConsistencyIT extends AccumuloClusterHarness {
           }
         }
 
-        if (random.nextBoolean()) {
-          // use bulk import v1
-          tctx.fileSystem.mkdirs(failDir);
-          tctx.client.tableOperations().importDirectory(tctx.table, bulkDir.toString(),
-              failDir.toString(), true);
-          assertEquals(0, tctx.fileSystem.listStatus(failDir).length,
-              "Failure dir was not empty " + failDir);
-        } else {
-          // use bulk import v2
-          tctx.client.tableOperations().importDirectory(bulkDir.toString()).to(tctx.table)
-              .tableTime(true).load();
-        }
-
+        tctx.client.tableOperations().importDirectory(bulkDir.toString()).to(tctx.table)
+            .tableTime(true).load();
       } finally {
         tctx.fileSystem.delete(bulkDir, true);
-        tctx.fileSystem.delete(failDir, true);
       }
 
       return keys.size();
@@ -659,24 +644,21 @@ public class ScanConsistencyIT extends AccumuloClusterHarness {
           // 1 in 20 chance of doing a filter compaction. This compaction will delete a data set.
           var deletes = tctx.dataTracker.getDeletes();
 
-          if (!deletes.isEmpty()) {
-            // The row has the format <random long>:<generation>, the following gets the generations
-            // from the rows. Expect the generation to be the same for a set of data to delete.
-            String gen = deletes.stream().map(m -> new String(m.getRow(), UTF_8))
-                .map(row -> row.split(":")[1]).distinct().collect(MoreCollectors.onlyElement());
+          // The row has the format <random long>:<generation>, the following gets the generations
+          // from the rows. Expect the generation to be the same for a set of data to delete.
+          String gen = deletes.stream().map(m -> new String(m.getRow(), UTF_8))
+              .map(row -> row.split(":")[1]).distinct().collect(MoreCollectors.onlyElement());
 
-            IteratorSetting iterSetting =
-                new IteratorSetting(100, "genfilter", GenerationFilter.class);
-            iterSetting.addOptions(Map.of("generation", gen));
+          IteratorSetting iterSetting =
+              new IteratorSetting(100, "genfilter", GenerationFilter.class);
+          iterSetting.addOptions(Map.of("generation", gen));
 
-            // run a compaction that deletes every key with the specified generation. Must wait on
-            // the
-            // compaction because at the end of the test it will try to verify deleted data is not
-            // present. Must flush the table in case data to delete is still in memory.
-            tctx.client.tableOperations().compact(tctx.table, new CompactionConfig().setFlush(true)
-                .setWait(true).setIterators(List.of(iterSetting)));
-            numFilters++;
-          }
+          // run a compaction that deletes every key with the specified generation. Must wait on the
+          // compaction because at the end of the test it will try to verify deleted data is not
+          // present. Must flush the table in case data to delete is still in memory.
+          tctx.client.tableOperations().compact(tctx.table, new CompactionConfig().setFlush(true)
+              .setWait(true).setIterators(List.of(iterSetting)));
+          numFilters++;
         }
       }
 
