@@ -48,12 +48,11 @@ import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.data.Value;
 import org.apache.accumulo.core.fate.zookeeper.ZooReaderWriter;
 import org.apache.accumulo.core.gc.Reference;
+import org.apache.accumulo.core.metadata.MetadataTable;
 import org.apache.accumulo.core.metadata.ScanServerRefTabletFile;
 import org.apache.accumulo.core.metadata.schema.Ample.DataLevel;
-import org.apache.accumulo.core.metadata.schema.MetadataSchema;
 import org.apache.accumulo.core.metadata.schema.MetadataSchema.ScanServerFileReferenceSection;
 import org.apache.accumulo.core.security.Authorizations;
-import org.apache.accumulo.core.util.HostAndPort;
 import org.apache.accumulo.gc.GCRun;
 import org.apache.accumulo.harness.MiniClusterConfigurationCallback;
 import org.apache.accumulo.harness.SharedMiniClusterBase;
@@ -67,6 +66,8 @@ import org.junit.jupiter.api.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import com.google.common.net.HostAndPort;
+
 @Tag(MINI_CLUSTER_ONLY)
 public class ScanServerMetadataEntriesIT extends SharedMiniClusterBase {
 
@@ -80,7 +81,7 @@ public class ScanServerMetadataEntriesIT extends SharedMiniClusterBase {
         org.apache.hadoop.conf.Configuration coreSite) {
       cfg.setNumScanServers(1);
       cfg.setProperty(Property.TSERV_SESSION_MAXIDLE, "3s");
-      cfg.setProperty(Property.SSERV_SCAN_REFERENCE_EXPIRATION_TIME, "5s");
+      cfg.setProperty(Property.SSERVER_SCAN_REFERENCE_EXPIRATION_TIME, "5s");
     }
   }
 
@@ -112,7 +113,7 @@ public class ScanServerMetadataEntriesIT extends SharedMiniClusterBase {
 
     Set<ScanServerRefTabletFile> scanRefs = Stream.of("F0000070.rf", "F0000071.rf")
         .map(f -> "hdfs://localhost:8020/accumulo/tables/2a/default_tablet/" + f)
-        .map(f -> new ScanServerRefTabletFile(serverLockUUID, server.toString(), f))
+        .map(f -> new ScanServerRefTabletFile(f, server.toString(), serverLockUUID))
         .collect(Collectors.toSet());
 
     ServerContext ctx = getCluster().getServerContext();
@@ -233,7 +234,7 @@ public class ScanServerMetadataEntriesIT extends SharedMiniClusterBase {
         assertNotNull(iter.next());
 
         List<Entry<Key,Value>> metadataEntries = null;
-        try (Scanner scanner2 = client.createScanner("accumulo.metadata", Authorizations.EMPTY)) {
+        try (Scanner scanner2 = client.createScanner(MetadataTable.NAME, Authorizations.EMPTY)) {
           scanner2.setRange(ScanServerFileReferenceSection.getRange());
           metadataEntries = scanner2.stream().distinct().collect(Collectors.toList());
         }
@@ -243,8 +244,8 @@ public class ScanServerMetadataEntriesIT extends SharedMiniClusterBase {
         Set<String> metadataScanFileRefs = new HashSet<>();
         metadataEntries.forEach(m -> {
           String row = m.getKey().getRow().toString();
-          assertTrue(row.startsWith(MetadataSchema.ScanServerFileReferenceSection.getRowPrefix()));
-          String file = m.getKey().getColumnQualifier().toString();
+          assertTrue(row.startsWith("~sserv"));
+          String file = row.substring(ScanServerFileReferenceSection.getRowPrefix().length());
           metadataScanFileRefs.add(file);
         });
         assertEquals(fileCount, metadataScanFileRefs.size());
