@@ -18,6 +18,7 @@
  */
 package org.apache.accumulo.test;
 
+import static org.apache.accumulo.core.util.LazySingletons.RANDOM;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertTrue;
@@ -34,6 +35,8 @@ import org.apache.accumulo.core.client.Scanner;
 import org.apache.accumulo.core.client.admin.NewTableConfiguration;
 import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.data.Mutation;
+import org.apache.accumulo.core.metadata.MetadataTable;
+import org.apache.accumulo.core.metadata.RootTable;
 import org.apache.accumulo.core.security.Authorizations;
 import org.apache.accumulo.minicluster.ServerType;
 import org.apache.accumulo.miniclusterImpl.MiniAccumuloClusterImpl.ProcessInfo;
@@ -46,20 +49,16 @@ import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.RawLocalFileSystem;
 import org.apache.hadoop.io.Text;
 import org.junit.jupiter.api.Test;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
 
 public class VerifySerialRecoveryIT extends ConfigurableMacBase {
 
-  private static final Logger log = LoggerFactory.getLogger(VerifySerialRecoveryIT.class);
-
   private static final byte[] HEXCHARS = {0x30, 0x31, 0x32, 0x33, 0x34, 0x35, 0x36, 0x37, 0x38,
       0x39, 0x61, 0x62, 0x63, 0x64, 0x65, 0x66};
 
   public static byte[] randomHex(int n) {
     byte[] binary = new byte[n];
     byte[] hex = new byte[n * 2];
-    random.nextBytes(binary);
+    RANDOM.get().nextBytes(binary);
     int count = 0;
     for (byte x : binary) {
       hex[count++] = HEXCHARS[(x >> 4) & 0xf];
@@ -118,31 +117,33 @@ public class VerifySerialRecoveryIT extends ConfigurableMacBase {
       assertEquals(0, cluster.exec(Admin.class, "stopAll").getProcess().waitFor());
       ts.getProcess().waitFor();
       String result = ts.readStdOut();
-      log.info(result);
-
+      for (String line : result.split("\n")) {
+        System.out.println(line);
+      }
       // walk through the output, verifying that only a single normal recovery was running at one
       // time
-      boolean ongoingRecovery = false;
+      boolean started = false;
       int recoveries = 0;
       var pattern =
           Pattern.compile(".*recovered \\d+ mutations creating \\d+ entries from \\d+ walogs.*");
       for (String line : result.split("\n")) {
-        // ignore metadata and root tables
-        if (line.contains("!0") || line.contains("+r")) {
+        // ignore metadata tables
+        if (line.contains(MetadataTable.ID.canonical())
+            || line.contains(RootTable.ID.canonical())) {
           continue;
         }
         if (line.contains("recovering data from walogs")) {
-          assertFalse(ongoingRecovery, "Saw recovery start before previous recovery finished");
-          ongoingRecovery = true;
+          assertFalse(started);
+          started = true;
           recoveries++;
         }
         if (pattern.matcher(line).matches()) {
-          assertTrue(ongoingRecovery, "Saw recovery end without recovery start");
-          ongoingRecovery = false;
+          assertTrue(started);
+          started = false;
         }
       }
-      assertFalse(ongoingRecovery, "Expected no ongoing recovery at end of test");
-      assertTrue(recoveries > 0, "Expected at least one recovery to have occurred");
+      assertFalse(started);
+      assertTrue(recoveries > 0);
     }
   }
 }
