@@ -18,33 +18,31 @@
  */
 package org.apache.accumulo.test.compaction;
 
+import java.util.List;
+import java.util.concurrent.ScheduledThreadPoolExecutor;
+
 import org.apache.accumulo.coordinator.CompactionCoordinator;
 import org.apache.accumulo.coordinator.CompactionFinalizer;
-import org.apache.accumulo.core.client.BatchWriter;
-import org.apache.accumulo.core.client.MutationsRejectedException;
-import org.apache.accumulo.core.client.TableNotFoundException;
+import org.apache.accumulo.core.cli.ConfigOpts;
 import org.apache.accumulo.core.compaction.thrift.CompactionCoordinatorService;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
-import org.apache.accumulo.core.metadata.schema.Ample;
 import org.apache.accumulo.core.metadata.schema.ExternalCompactionFinalState;
 import org.apache.accumulo.core.metadata.schema.ExternalCompactionFinalState.FinalState;
 import org.apache.accumulo.core.metadata.schema.ExternalCompactionId;
-import org.apache.accumulo.core.process.thrift.ServerProcessService;
 import org.apache.accumulo.server.ServerContext;
-import org.apache.accumulo.server.ServerOpts;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 public class TestCompactionCoordinatorForOfflineTable extends CompactionCoordinator
-    implements CompactionCoordinatorService.Iface, ServerProcessService.Iface {
+    implements CompactionCoordinatorService.Iface {
 
   public static class NonNotifyingCompactionFinalizer extends CompactionFinalizer {
 
     private static final Logger LOG =
         LoggerFactory.getLogger(NonNotifyingCompactionFinalizer.class);
 
-    NonNotifyingCompactionFinalizer(ServerContext context) {
-      super(context, context.getScheduledExecutor());
+    NonNotifyingCompactionFinalizer(ServerContext context, ScheduledThreadPoolExecutor stpe) {
+      super(context, stpe);
     }
 
     @Override
@@ -56,11 +54,7 @@ public class TestCompactionCoordinatorForOfflineTable extends CompactionCoordina
 
       // write metadata entry
       LOG.info("Writing completed external compaction to metadata table: {}", ecfs);
-      try (BatchWriter writer = context.createBatchWriter(Ample.DataLevel.USER.metaTable())) {
-        writer.addMutation(ecfs.toMutation());
-      } catch (MutationsRejectedException | TableNotFoundException e) {
-        throw new RuntimeException(e);
-      }
+      context.getAmple().putExternalCompactionFinalStates(List.of(ecfs));
 
       // queue RPC if queue is not full
       LOG.info("Skipping tserver notification for completed external compaction: {}", ecfs);
@@ -68,18 +62,18 @@ public class TestCompactionCoordinatorForOfflineTable extends CompactionCoordina
 
   }
 
-  protected TestCompactionCoordinatorForOfflineTable(ServerOpts opts, String[] args) {
+  protected TestCompactionCoordinatorForOfflineTable(ConfigOpts opts, String[] args) {
     super(opts, args);
   }
 
   @Override
-  protected CompactionFinalizer createCompactionFinalizer() {
-    return new NonNotifyingCompactionFinalizer(getContext());
+  protected CompactionFinalizer createCompactionFinalizer(ScheduledThreadPoolExecutor stpe) {
+    return new NonNotifyingCompactionFinalizer(getContext(), stpe);
   }
 
   public static void main(String[] args) throws Exception {
     try (TestCompactionCoordinatorForOfflineTable coordinator =
-        new TestCompactionCoordinatorForOfflineTable(new ServerOpts(), args)) {
+        new TestCompactionCoordinatorForOfflineTable(new ConfigOpts(), args)) {
       coordinator.runServer();
     }
   }
