@@ -42,15 +42,12 @@ import org.apache.accumulo.cluster.AccumuloCluster;
 import org.apache.accumulo.core.client.Accumulo;
 import org.apache.accumulo.core.client.AccumuloClient;
 import org.apache.accumulo.core.client.AccumuloException;
-import org.apache.accumulo.core.client.AccumuloSecurityException;
 import org.apache.accumulo.core.client.BatchWriter;
 import org.apache.accumulo.core.client.Scanner;
-import org.apache.accumulo.core.client.TableExistsException;
 import org.apache.accumulo.core.client.TableNotFoundException;
 import org.apache.accumulo.core.client.admin.CloneConfiguration;
 import org.apache.accumulo.core.client.admin.DiskUsage;
 import org.apache.accumulo.core.client.admin.NewTableConfiguration;
-import org.apache.accumulo.core.client.security.tokens.PasswordToken;
 import org.apache.accumulo.core.clientImpl.ClientContext;
 import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.data.Key;
@@ -64,8 +61,6 @@ import org.apache.accumulo.core.metadata.RootTable;
 import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection.DataFileColumnFamily;
 import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection.ServerColumnFamily;
 import org.apache.accumulo.core.security.Authorizations;
-import org.apache.accumulo.core.security.NamespacePermission;
-import org.apache.accumulo.core.security.TablePermission;
 import org.apache.accumulo.harness.AccumuloClusterHarness;
 import org.apache.accumulo.miniclusterImpl.MiniAccumuloClusterImpl;
 import org.apache.hadoop.fs.FileStatus;
@@ -355,131 +350,4 @@ public class CloneTestIT extends AccumuloClusterHarness {
           "mc1", CloneConfiguration.empty()));
     }
   }
-
-  private void baseCloneNamespace(AccumuloClient client, String src, String dest) throws Exception {
-    writeData(src, client).close();
-    // Don't force a flush on the table, let's make sure the
-    // clone operation does this
-    client.tableOperations().clone(src, dest, CloneConfiguration.empty());
-    checkData(dest, client);
-  }
-
-  @Test
-  public void testCloneSameNamespace() throws Exception {
-    try (AccumuloClient client = Accumulo.newClient().from(getClientProps()).build()) {
-      String tableName = getUniqueNames(1)[0];
-      client.namespaceOperations().create("old");
-      client.tableOperations().create("old." + tableName);
-      assertThrows(TableExistsException.class,
-          () -> baseCloneNamespace(client, "old." + tableName, "old." + tableName));
-    }
-  }
-
-  @Test
-  public void testCloneIntoDiffNamespace() throws Exception {
-    try (AccumuloClient client = Accumulo.newClient().from(getClientProps()).build()) {
-      String tableName = getUniqueNames(1)[0];
-      client.namespaceOperations().create("old");
-      client.tableOperations().create("old." + tableName);
-      client.namespaceOperations().create("new");
-      baseCloneNamespace(client, "old." + tableName, "new." + tableName);
-    }
-  }
-
-  @Test
-  public void testCloneIntoDiffNamespaceTableExists() throws Exception {
-    try (AccumuloClient client = Accumulo.newClient().from(getClientProps()).build()) {
-      String tableName = getUniqueNames(1)[0];
-      client.namespaceOperations().create("old");
-      client.tableOperations().create("old." + tableName);
-      client.namespaceOperations().create("new");
-      client.tableOperations().create("new." + tableName);
-      assertThrows(TableExistsException.class,
-          () -> baseCloneNamespace(client, "old." + tableName, "new." + tableName));
-    }
-  }
-
-  @Test
-  public void testCloneIntoDiffNamespaceDoesntExist() throws Exception {
-    try (AccumuloClient client = Accumulo.newClient().from(getClientProps()).build()) {
-      String tableName = getUniqueNames(1)[0];
-      client.namespaceOperations().create("old");
-      client.tableOperations().create("old." + tableName);
-      assertThrows(AccumuloException.class,
-          () -> baseCloneNamespace(client, "old." + tableName, "missing." + tableName));
-    }
-  }
-
-  @Test
-  public void testCloneIntoAccumuloNamespace() throws Exception {
-    try (AccumuloClient client = Accumulo.newClient().from(getClientProps()).build()) {
-      String tableName = getUniqueNames(1)[0];
-      client.namespaceOperations().create("old");
-      client.tableOperations().create("old." + tableName);
-      assertThrows(AccumuloException.class,
-          () -> baseCloneNamespace(client, "old." + tableName, "accumulo." + tableName));
-    }
-  }
-
-  @Test
-  public void testCloneNamespaceIncorrectPermissions() throws Exception {
-    final String tableName = getUniqueNames(1)[0];
-    final String newUserName = "NEW_USER";
-    final String srcNs = "src";
-    final String srcTableName = srcNs + "." + tableName;
-    final String destNs = "dst";
-    final String dstTableName = destNs + "." + tableName;
-
-    try (AccumuloClient client = Accumulo.newClient().from(getClientProps()).build()) {
-      client.namespaceOperations().create(srcNs);
-      client.tableOperations().create(srcTableName);
-      client.namespaceOperations().create(destNs);
-      client.securityOperations().createLocalUser(newUserName, new PasswordToken(newUserName));
-      // User needs WRITE or ALTER_TABLE on the src table to flush it as part of the clone operation
-      client.securityOperations().grantTablePermission(newUserName, srcTableName,
-          TablePermission.ALTER_TABLE);
-      client.securityOperations().grantNamespacePermission(newUserName, destNs,
-          NamespacePermission.READ);
-      client.securityOperations().grantNamespacePermission(newUserName, destNs,
-          NamespacePermission.CREATE_TABLE);
-    }
-
-    try (AccumuloClient client =
-        Accumulo.newClient().to(getCluster().getInstanceName(), getCluster().getZooKeepers())
-            .as(newUserName, newUserName).build()) {
-      // READ permission is needed on the src table, not the dst namespace
-      assertThrows(AccumuloSecurityException.class, () -> client.tableOperations()
-          .clone(srcTableName, dstTableName, CloneConfiguration.empty()));
-    }
-  }
-
-  @Test
-  public void testCloneNamespacePermissions() throws Exception {
-    final String tableName = getUniqueNames(1)[0];
-    final String newUserName = "NEW_USER";
-    final String srcNs = "src";
-    final String srcTableName = srcNs + "." + tableName;
-    final String destNs = "dst";
-    final String dstTableName = destNs + "." + tableName;
-
-    try (AccumuloClient client = Accumulo.newClient().from(getClientProps()).build()) {
-      client.namespaceOperations().create(srcNs);
-      client.tableOperations().create(srcTableName);
-      client.namespaceOperations().create(destNs);
-      client.securityOperations().createLocalUser(newUserName, new PasswordToken(newUserName));
-      // User needs WRITE or ALTER_TABLE on the src table to flush it as part of the clone operation
-      client.securityOperations().grantTablePermission(newUserName, srcTableName,
-          TablePermission.ALTER_TABLE);
-      client.securityOperations().grantTablePermission(newUserName, srcTableName,
-          TablePermission.READ);
-      client.securityOperations().grantNamespacePermission(newUserName, destNs,
-          NamespacePermission.CREATE_TABLE);
-    }
-
-    try (AccumuloClient client =
-        Accumulo.newClient().to(getCluster().getInstanceName(), getCluster().getZooKeepers())
-            .as(newUserName, newUserName).build()) {
-      client.tableOperations().clone(srcTableName, dstTableName, CloneConfiguration.empty());
-    }
-  }
 }
