@@ -19,6 +19,7 @@
 package org.apache.accumulo.test.functional;
 
 import static java.util.concurrent.TimeUnit.SECONDS;
+import static org.apache.accumulo.core.util.LazySingletons.RANDOM;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
@@ -29,24 +30,18 @@ import static org.junit.jupiter.api.Assertions.fail;
 import java.io.IOException;
 import java.time.Duration;
 import java.util.ArrayList;
-import java.util.Arrays;
 import java.util.EnumSet;
-import java.util.HashMap;
+import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
 import java.util.NoSuchElementException;
 import java.util.Objects;
-import java.util.SortedSet;
-import java.util.TreeMap;
-import java.util.TreeSet;
-import java.util.concurrent.CountDownLatch;
+import java.util.Set;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicReference;
-import java.util.stream.Collectors;
-import java.util.stream.IntStream;
 
 import org.apache.accumulo.core.client.Accumulo;
 import org.apache.accumulo.core.client.AccumuloClient;
@@ -56,13 +51,10 @@ import org.apache.accumulo.core.client.BatchWriter;
 import org.apache.accumulo.core.client.IteratorSetting;
 import org.apache.accumulo.core.client.Scanner;
 import org.apache.accumulo.core.client.TableNotFoundException;
-import org.apache.accumulo.core.client.admin.ActiveCompaction;
-import org.apache.accumulo.core.client.admin.ActiveCompaction.CompactionHost;
 import org.apache.accumulo.core.client.admin.CompactionConfig;
 import org.apache.accumulo.core.client.admin.NewTableConfiguration;
 import org.apache.accumulo.core.client.admin.PluginConfig;
 import org.apache.accumulo.core.client.admin.compaction.CompactableFile;
-import org.apache.accumulo.core.client.admin.compaction.CompactionConfigurer;
 import org.apache.accumulo.core.client.admin.compaction.CompactionSelector;
 import org.apache.accumulo.core.client.admin.compaction.CompressionConfigurer;
 import org.apache.accumulo.core.clientImpl.ClientContext;
@@ -72,8 +64,6 @@ import org.apache.accumulo.core.data.Key;
 import org.apache.accumulo.core.data.Mutation;
 import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.data.Value;
-import org.apache.accumulo.core.file.FilePrefix;
-import org.apache.accumulo.core.file.rfile.RFile;
 import org.apache.accumulo.core.iterators.DevNull;
 import org.apache.accumulo.core.iterators.Filter;
 import org.apache.accumulo.core.iterators.IteratorEnvironment;
@@ -82,33 +72,25 @@ import org.apache.accumulo.core.iterators.SortedKeyValueIterator;
 import org.apache.accumulo.core.iterators.user.AgeOffFilter;
 import org.apache.accumulo.core.iterators.user.GrepIterator;
 import org.apache.accumulo.core.metadata.MetadataTable;
-import org.apache.accumulo.core.metadata.TabletFile;
 import org.apache.accumulo.core.metadata.schema.Ample;
-import org.apache.accumulo.core.metadata.schema.DataFileValue;
-import org.apache.accumulo.core.metadata.schema.MetadataSchema;
 import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection.DataFileColumnFamily;
 import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection.TabletColumnFamily;
 import org.apache.accumulo.core.metadata.schema.TabletMetadata;
 import org.apache.accumulo.core.metadata.schema.TabletMetadata.ColumnType;
 import org.apache.accumulo.core.metadata.schema.TabletsMetadata;
 import org.apache.accumulo.core.security.Authorizations;
-import org.apache.accumulo.core.spi.compaction.DefaultCompactionPlanner;
-import org.apache.accumulo.core.spi.compaction.SimpleCompactionDispatcher;
-import org.apache.accumulo.core.util.HostAndPort;
 import org.apache.accumulo.harness.AccumuloClusterHarness;
-import org.apache.accumulo.minicluster.ServerType;
-import org.apache.accumulo.miniclusterImpl.MiniAccumuloClusterImpl;
 import org.apache.accumulo.miniclusterImpl.MiniAccumuloConfigImpl;
 import org.apache.accumulo.test.VerifyIngest;
 import org.apache.accumulo.test.VerifyIngest.VerifyParams;
 import org.apache.accumulo.test.compaction.CompactionExecutorIT;
 import org.apache.accumulo.test.compaction.ExternalCompaction_1_IT.FSelector;
-import org.apache.accumulo.test.util.Wait;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.fs.RawLocalFileSystem;
 import org.apache.hadoop.io.Text;
+import org.bouncycastle.util.Arrays;
 import org.junit.jupiter.api.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -117,7 +99,6 @@ import com.google.common.base.Preconditions;
 import com.google.common.collect.Iterators;
 import com.google.common.collect.Lists;
 
-@SuppressWarnings("removal")
 public class CompactionIT extends AccumuloClusterHarness {
 
   public static class TestFilter extends Filter {
@@ -182,6 +163,22 @@ public class CompactionIT extends AccumuloClusterHarness {
 
   }
 
+  /**
+   * CompactionSelector that selects nothing for testing
+   */
+  public static class EmptyCompactionSelector implements CompactionSelector {
+
+    @Override
+    public void init(InitParameters iparams) {
+
+    }
+
+    @Override
+    public Selection select(SelectionParameters sparams) {
+      return new Selection(Set.of());
+    }
+  }
+
   private static final Logger log = LoggerFactory.getLogger(CompactionIT.class);
 
   private static final int MAX_DATA = 1000;
@@ -194,9 +191,7 @@ public class CompactionIT extends AccumuloClusterHarness {
   @Override
   public void configureMiniCluster(MiniAccumuloConfigImpl cfg, Configuration hadoopCoreSite) {
     cfg.setProperty(Property.INSTANCE_ZK_TIMEOUT, "15s");
-    cfg.setProperty(Property.TSERV_MAJC_THREAD_MAXOPEN, "4");
     cfg.setProperty(Property.TSERV_MAJC_DELAY, "1");
-    cfg.setProperty(Property.TSERV_MAJC_MAXCONCURRENT, "1");
     // use raw local file system so walogs sync and flush will work
     hadoopCoreSite.set("fs.file.impl", RawLocalFileSystem.class.getName());
   }
@@ -349,7 +344,6 @@ public class CompactionIT extends AccumuloClusterHarness {
     final String table1 = this.getUniqueNames(1)[0];
     try (AccumuloClient client = Accumulo.newClient().from(getClientProps()).build()) {
       client.tableOperations().create(table1);
-      client.tableOperations().setProperty(table1, Property.TABLE_FILE_MAX.getKey(), "1001");
       client.tableOperations().setProperty(table1, Property.TABLE_MAJC_RATIO.getKey(), "51");
       TableId tid = TableId.of(client.tableOperations().tableIdMap().get(table1));
 
@@ -489,45 +483,6 @@ public class CompactionIT extends AccumuloClusterHarness {
     }
   }
 
-  public static class FourConfigurer implements CompactionConfigurer {
-
-    @Override
-    public void init(InitParameters iparams) {}
-
-    @Override
-    public Overrides override(InputParameters params) {
-      if (new Text("4").equals(params.getTabletId().getEndRow())) {
-        return new Overrides(Map.of(Property.TABLE_FILE_COMPRESSION_TYPE.getKey(), "gz"));
-      } else {
-        return new Overrides(Map.of(Property.TABLE_FILE_COMPRESSION_TYPE.getKey(), "none"));
-      }
-    }
-  }
-
-  public static class UriConfigurer implements CompactionConfigurer {
-
-    @Override
-    public void init(InitParameters iparams) {}
-
-    @Override
-    public Overrides override(InputParameters params) {
-      // This will validate the paths looks like a tablet file path and throw an exception if it
-      // does not
-      var parts = TabletFile.parsePath(new Path(params.getOutputFile()));
-      // For this test should be producing A files
-      Preconditions.checkArgument(
-          parts.getFileName().startsWith(FilePrefix.FULL_COMPACTION.getPrefix() + ""));
-      Preconditions.checkArgument(parts.getFileName().endsWith(RFile.EXTENSION));
-
-      if (parts.getTabletDir()
-          .equals(MetadataSchema.TabletsSection.ServerColumnFamily.DEFAULT_TABLET_DIR_NAME)) {
-        return new Overrides(Map.of(Property.TABLE_FILE_COMPRESSION_TYPE.getKey(), "gz"));
-      } else {
-        return new Overrides(Map.of(Property.TABLE_FILE_COMPRESSION_TYPE.getKey(), "none"));
-      }
-    }
-  }
-
   @Test
   public void testConfigurer() throws Exception {
     String tableName = this.getUniqueNames(1)[0];
@@ -572,43 +527,6 @@ public class CompactionIT extends AccumuloClusterHarness {
       assertTrue(sizes > data.length * 10 && sizes < data.length * 11,
           "Unexpected files sizes : " + sizes);
 
-      // compact using a custom configurer that considers tablet end row
-      client.tableOperations().addSplits(tableName, new TreeSet<>(List.of(new Text("4"))));
-      client.tableOperations().compact(tableName, new CompactionConfig().setWait(true)
-          .setConfigurer(new PluginConfig(FourConfigurer.class.getName())));
-      var tabletSizes = getFilesSizesPerTablet(client, tableName);
-      assertTrue(tabletSizes.get("4") > 0 && tabletSizes.get("4") < 1000, tabletSizes.toString());
-      assertTrue(tabletSizes.get("null") > 500_000 && tabletSizes.get("4") < 510_000,
-          tabletSizes.toString());
-
-      // compact using a custom configurer that considers the output path, should invert which file
-      // is compressed
-      client.tableOperations().addSplits(tableName, new TreeSet<>(List.of(new Text("4"))));
-      client.tableOperations().compact(tableName, new CompactionConfig().setWait(true)
-          .setConfigurer(new PluginConfig(UriConfigurer.class.getName())));
-      tabletSizes = getFilesSizesPerTablet(client, tableName);
-      assertTrue(tabletSizes.get("4") > 500_000 && tabletSizes.get("4") < 510_000,
-          tabletSizes.toString());
-      assertTrue(tabletSizes.get("null") > 0 && tabletSizes.get("null") < 1000,
-          tabletSizes.toString());
-
-    }
-  }
-
-  private Map<String,Long> getFilesSizesPerTablet(AccumuloClient client, String table)
-      throws Exception {
-    var ctx = (ClientContext) client;
-    var ample = ctx.getAmple();
-    var id = ctx.getTableId(table);
-
-    try (var tablets = ample.readTablets().forTable(id).build()) {
-      Map<String,Long> sizes = new TreeMap<>();
-      for (var tablet : tablets) {
-        var tsize = tablet.getFilesMap().values().stream().mapToLong(DataFileValue::getSize).sum();
-        var endRow = tablet.getEndRow();
-        sizes.put(endRow == null ? "null" : endRow.toString(), tsize);
-      }
-      return sizes;
     }
   }
 
@@ -626,7 +544,7 @@ public class CompactionIT extends AccumuloClusterHarness {
       FunctionalTestUtils.createRFiles(c, fs, testrf.toString(), 500000, 59, 4);
 
       c.tableOperations().importDirectory(testrf.toString()).to(tableName).load();
-      int beforeCount = countFiles(c, tableName);
+      int beforeCount = countFiles(c);
 
       final AtomicBoolean fail = new AtomicBoolean(false);
       final int THREADS = 5;
@@ -656,7 +574,7 @@ public class CompactionIT extends AccumuloClusterHarness {
             "Failed to successfully run all threads, Check the test output for error");
       }
 
-      int finalCount = countFiles(c, tableName);
+      int finalCount = countFiles(c);
       assertTrue(finalCount < beforeCount);
       try {
         getClusterControl().adminStopAll();
@@ -680,10 +598,9 @@ public class CompactionIT extends AccumuloClusterHarness {
     try (AccumuloClient c = Accumulo.newClient().from(getClientProps()).build()) {
       final String tableName = getUniqueNames(1)[0];
       c.tableOperations().create(tableName);
-      c.tableOperations().setProperty(tableName, Property.TABLE_FILE_MAX.getKey(), "1001");
       c.tableOperations().setProperty(tableName, Property.TABLE_MAJC_RATIO.getKey(), "100.0");
 
-      var beforeCount = countFiles(c, tableName);
+      var beforeCount = countFiles(c);
 
       final int NUM_ENTRIES_AND_FILES = 60;
 
@@ -702,7 +619,7 @@ public class CompactionIT extends AccumuloClusterHarness {
         assertEquals(NUM_ENTRIES_AND_FILES, scanner.stream().count());
       }
 
-      var afterCount = countFiles(c, tableName);
+      var afterCount = countFiles(c);
 
       assertTrue(afterCount >= beforeCount + NUM_ENTRIES_AND_FILES);
 
@@ -718,287 +635,107 @@ public class CompactionIT extends AccumuloClusterHarness {
         assertEquals(0, scanner.stream().count());
       }
 
-      var finalCount = countFiles(c, tableName);
+      var finalCount = countFiles(c);
       assertTrue(finalCount <= beforeCount);
     }
   }
 
   @Test
-  public void testDeleteCompactionService() throws Exception {
+  public void testSelectNoFiles() throws Exception {
+
+    // Test a compaction selector that selects no files. In this case there is no work to,
+    // so we want to ensure it does not hang
+
     try (AccumuloClient c = Accumulo.newClient().from(getClientProps()).build()) {
-      var uniqueNames = getUniqueNames(2);
-      String table1 = uniqueNames[0];
-      String table2 = uniqueNames[1];
+      String tableName = getUniqueNames(1)[0];
+      c.tableOperations().create(tableName);
 
-      // create a compaction service named deleteme
-      c.instanceOperations().setProperty(
-          Property.TSERV_COMPACTION_SERVICE_PREFIX.getKey() + "deleteme.planner",
-          DefaultCompactionPlanner.class.getName());
-      c.instanceOperations().setProperty(
-          Property.TSERV_COMPACTION_SERVICE_PREFIX.getKey() + "deleteme.planner.opts.executors",
-          "[{'name':'all','type':'internal','numThreads':1}]".replaceAll("'", "\""));
+      writeFlush(c, tableName, "a");
+      writeFlush(c, tableName, "b");
 
-      // create a compaction service named keepme
-      c.instanceOperations().setProperty(
-          Property.TSERV_COMPACTION_SERVICE_PREFIX.getKey() + "keepme.planner",
-          DefaultCompactionPlanner.class.getName());
-      c.instanceOperations().setProperty(
-          Property.TSERV_COMPACTION_SERVICE_PREFIX.getKey() + "keepme.planner.opts.executors",
-          "[{'name':'all','type':'internal','numThreads':1}]".replaceAll("'", "\""));
+      CompactionConfig config = new CompactionConfig()
+          .setSelector(new PluginConfig(EmptyCompactionSelector.class.getName(), Map.of()))
+          .setWait(true);
+      c.tableOperations().compact(tableName, config);
 
-      // create a table that uses the compaction service deleteme
-      Map<String,String> props = new HashMap<>();
-      props.put(Property.TABLE_COMPACTION_DISPATCHER.getKey(),
-          SimpleCompactionDispatcher.class.getName());
-      props.put(Property.TABLE_COMPACTION_DISPATCHER_OPTS.getKey() + "service", "deleteme");
-      c.tableOperations().create(table1, new NewTableConfiguration().setProperties(props));
-
-      // create a table that uses the compaction service keepme
-      props.clear();
-      props.put(Property.TABLE_COMPACTION_DISPATCHER.getKey(),
-          SimpleCompactionDispatcher.class.getName());
-      props.put(Property.TABLE_COMPACTION_DISPATCHER_OPTS.getKey() + "service", "keepme");
-      c.tableOperations().create(table2, new NewTableConfiguration().setProperties(props));
-
-      try (var writer1 = c.createBatchWriter(table1); var writer2 = c.createBatchWriter(table2)) {
-        for (int i = 0; i < 10; i++) {
-          Mutation m = new Mutation("" + i);
-          m.put("f", "q", "" + i);
-          writer1.addMutation(m);
-          writer2.addMutation(m);
-        }
-      }
-
-      c.tableOperations().compact(table1, new CompactionConfig().setWait(true));
-      c.tableOperations().compact(table2, new CompactionConfig().setWait(true));
-
-      // delete the compaction service deleteme
-      c.instanceOperations()
-          .removeProperty(Property.TSERV_COMPACTION_SERVICE_PREFIX.getKey() + "deleteme.planner");
-      c.instanceOperations().removeProperty(
-          Property.TSERV_COMPACTION_SERVICE_PREFIX.getKey() + "deleteme.planner.opts.executors");
-
-      // add a new compaction service named newcs
-      c.instanceOperations().setProperty(
-          Property.TSERV_COMPACTION_SERVICE_PREFIX.getKey() + "newcs.planner",
-          DefaultCompactionPlanner.class.getName());
-      c.instanceOperations().setProperty(
-          Property.TSERV_COMPACTION_SERVICE_PREFIX.getKey() + "newcs.planner.opts.executors",
-          "[{'name':'all','type':'internal','numThreads':1}]".replaceAll("'", "\""));
-
-      // set table 1 to a compaction service newcs
-      c.tableOperations().setProperty(table1,
-          Property.TABLE_COMPACTION_DISPATCHER_OPTS.getKey() + "service", "newcs");
-
-      // ensure tables can still compact and are not impacted by the deleted compaction service
-      for (int i = 0; i < 10; i++) {
-        c.tableOperations().compact(table1, new CompactionConfig().setWait(true));
-        c.tableOperations().compact(table2, new CompactionConfig().setWait(true));
-
-        try (var scanner = c.createScanner(table1)) {
-          assertEquals(9 * 10 / 2, scanner.stream().map(Entry::getValue)
-              .mapToInt(v -> Integer.parseInt(v.toString())).sum());
-        }
-        try (var scanner = c.createScanner(table2)) {
-          assertEquals(9 * 10 / 2, scanner.stream().map(Entry::getValue)
-              .mapToInt(v -> Integer.parseInt(v.toString())).sum());
-        }
-
-        Thread.sleep(100);
-      }
+      assertEquals(Set.of("a", "b"), getRows(c, tableName));
     }
+
   }
 
   @Test
-  public void testGetActiveCompactions() throws Exception {
-    final String table1 = this.getUniqueNames(1)[0];
-    try (AccumuloClient client = Accumulo.newClient().from(getClientProps()).build()) {
-      client.tableOperations().create(table1);
-      try (BatchWriter bw = client.createBatchWriter(table1)) {
-        for (int i = 1; i <= MAX_DATA; i++) {
-          Mutation m = new Mutation(Integer.toString(i));
-          m.put("cf", "cq", new Value());
-          bw.addMutation(m);
-          bw.flush();
-          // flush often to create multiple files to compact
-          client.tableOperations().flush(table1, null, null, true);
+  public void testConcurrent() throws Exception {
+    // two compactions without iterators or strategy should be able to run concurrently
+
+    try (AccumuloClient c = Accumulo.newClient().from(getClientProps()).build()) {
+
+      String tableName = getUniqueNames(1)[0];
+      c.tableOperations().create(tableName);
+
+      // write random data because its very unlikely it will compress
+      writeRandomValue(c, tableName, 1 << 16);
+      writeRandomValue(c, tableName, 1 << 16);
+
+      c.tableOperations().compact(tableName, new CompactionConfig().setWait(false));
+      c.tableOperations().compact(tableName, new CompactionConfig().setWait(true));
+
+      assertEquals(1, FunctionalTestUtils.countRFiles(c, tableName));
+
+      writeRandomValue(c, tableName, 1 << 16);
+
+      IteratorSetting iterConfig = new IteratorSetting(30, SlowIterator.class);
+      SlowIterator.setSleepTime(iterConfig, 1000);
+
+      long t1 = System.currentTimeMillis();
+      c.tableOperations().compact(tableName,
+          new CompactionConfig().setWait(false).setIterators(java.util.Arrays.asList(iterConfig)));
+      try {
+        // this compaction should fail because previous one set iterators
+        c.tableOperations().compact(tableName, new CompactionConfig().setWait(true));
+        if (System.currentTimeMillis() - t1 < 2000) {
+          fail("Expected compaction to fail because another concurrent compaction set iterators");
         }
-      }
-
-      final AtomicReference<Exception> error = new AtomicReference<>();
-      final CountDownLatch started = new CountDownLatch(1);
-      Thread t = new Thread(() -> {
-        try {
-          IteratorSetting setting = new IteratorSetting(50, "sleepy", SlowIterator.class);
-          setting.addOption("sleepTime", "3000");
-          setting.addOption("seekSleepTime", "3000");
-          client.tableOperations().attachIterator(table1, setting, EnumSet.of(IteratorScope.majc));
-          started.countDown();
-          client.tableOperations().compact(table1, new CompactionConfig().setWait(true));
-        } catch (AccumuloSecurityException | TableNotFoundException | AccumuloException e) {
-          error.set(e);
-        }
-      });
-      t.start();
-
-      started.await();
-
-      List<ActiveCompaction> compactions = new ArrayList<>();
-      do {
-        client.instanceOperations().getActiveCompactions().forEach((ac) -> {
-          try {
-            if (ac.getTable().equals(table1)) {
-              compactions.add(ac);
-            }
-          } catch (TableNotFoundException e1) {
-            fail("Table was deleted during test, should not happen");
-          }
-        });
-        Thread.sleep(1000);
-      } while (compactions.isEmpty());
-
-      ActiveCompaction running1 = compactions.get(0);
-      CompactionHost host = running1.getHost();
-      assertTrue(host.getType() == CompactionHost.Type.TSERVER);
-
-      compactions.clear();
-      do {
-        HostAndPort hp = HostAndPort.fromParts(host.getAddress(), host.getPort());
-        client.instanceOperations().getActiveCompactions(hp.toString()).forEach((ac) -> {
-          try {
-            if (ac.getTable().equals(table1)) {
-              compactions.add(ac);
-            }
-          } catch (TableNotFoundException e1) {
-            fail("Table was deleted during test, should not happen");
-          }
-        });
-        Thread.sleep(1000);
-      } while (compactions.isEmpty());
-
-      ActiveCompaction running2 = compactions.get(0);
-      assertEquals(running1.getInputFiles(), running2.getInputFiles());
-      assertEquals(running1.getOutputFile(), running2.getOutputFile());
-      assertEquals(running1.getTablet(), running2.getTablet());
-
-      client.tableOperations().cancelCompaction(table1);
-      t.join();
+      } catch (AccumuloException e) {}
     }
   }
 
-  @Test
-  public void testMigrationCancelCompaction() throws Exception {
-
-    // This test creates 40 tablets w/ slow iterator, causes 40 compactions to start, and then
-    // starts a new tablet server. Some of the tablets should migrate to the new tserver and cancel
-    // their compaction. Because the test uses a slow iterator, if close blocks on compaction then
-    // the test should timeout. Two tables are used to have different iterator settings inorder to
-    // test the two different way compactions can be canceled. Compactions can be canceled by thread
-    // interrupt or by a check that is done after a compaction iterator returns a key value.
-
-    final String[] tables = this.getUniqueNames(2);
-    try (AccumuloClient client = Accumulo.newClient().from(getClientProps()).build()) {
-      client.instanceOperations().setProperty(
-          Property.TSERV_COMPACTION_SERVICE_DEFAULT_EXECUTORS.getKey(),
-          "[{'name':'any','numThreads':20}]".replaceAll("'", "\""));
-
-      SortedSet<Text> splits = IntStream.range(1, 20).mapToObj(i -> String.format("%06d", i * 1000))
-          .map(Text::new).collect(Collectors.toCollection(TreeSet::new));
-
-      // This iterator is intended to cover the case of a compaction being canceled by thread
-      // interrupt.
-      IteratorSetting setting1 = new IteratorSetting(50, "sleepy", SlowIterator.class);
-      setting1.addOption("sleepTime", "300000");
-      setting1.addOption("seekSleepTime", "3000");
-      SlowIterator.sleepUninterruptibly(setting1, false);
-
-      client.tableOperations().create(tables[0], new NewTableConfiguration().withSplits(splits)
-          .attachIterator(setting1, EnumSet.of(IteratorScope.majc)));
-
-      // This iterator is intended to cover the case of compaction being canceled by the check after
-      // a key value is returned. The iterator is configured to ignore interrupts.
-      IteratorSetting setting2 = new IteratorSetting(50, "sleepy", SlowIterator.class);
-      setting2.addOption("sleepTime", "2000");
-      setting2.addOption("seekSleepTime", "2000");
-      SlowIterator.sleepUninterruptibly(setting2, true);
-
-      client.tableOperations().create(tables[1], new NewTableConfiguration().withSplits(splits)
-          .attachIterator(setting2, EnumSet.of(IteratorScope.majc)));
-
-      // write files to each tablet, should cause compactions to start
-      for (var table : tables) {
-        for (int round = 0; round < 5; round++) {
-          try (var writer = client.createBatchWriter(table)) {
-            for (int i = 0; i < 20_000; i++) {
-              Mutation m = new Mutation(String.format("%06d", i));
-              m.put("f", "q", "v");
-              writer.addMutation(m);
-            }
-          }
-          client.tableOperations().flush(table, null, null, true);
-        }
-      }
-
-      assertEquals(2, client.instanceOperations().getTabletServers().size());
-
-      var tableId1 = ((ClientContext) client).getTableId(tables[0]);
-      var tableId2 = ((ClientContext) client).getTableId(tables[1]);
-
-      Wait.waitFor(() -> {
-        var runningCompactions = client.instanceOperations().getActiveCompactions().stream()
-            .map(ac -> ac.getTablet().getTable())
-            .filter(tid -> tid.equals(tableId1) || tid.equals(tableId2)).count();
-        log.debug("Running compactions {}", runningCompactions);
-        return runningCompactions == 40;
-      });
-
-      ((MiniAccumuloClusterImpl) getCluster()).getConfig().setNumTservers(3);
-      getCluster().getClusterControl().start(ServerType.TABLET_SERVER, "localhost");
-
-      Wait.waitFor(() -> {
-        var servers = client.instanceOperations().getTabletServers().size();
-        log.debug("Server count {}", servers);
-        return 3 == servers;
-      });
-
-      Wait.waitFor(() -> {
-        try (var tablets =
-            ((ClientContext) client).getAmple().readTablets().forLevel(Ample.DataLevel.USER)
-                .fetch(ColumnType.LOCATION, ColumnType.PREV_ROW).build()) {
-          Map<String,Long> counts = new HashMap<>();
-          for (var tablet : tablets) {
-            if (!tablet.getTableId().equals(tableId1) && !tablet.getTableId().equals(tableId2)) {
-              continue;
-            }
-
-            if (tablet.getLocation() != null
-                && tablet.getLocation().getType() == TabletMetadata.LocationType.CURRENT) {
-              counts.merge(tablet.getLocation().getHostPort(), 1L, Long::sum);
-            }
-          }
-
-          var total = counts.values().stream().mapToLong(l -> l).sum();
-          var min = counts.values().stream().mapToLong(l -> l).min().orElse(0);
-          var max = counts.values().stream().mapToLong(l -> l).max().orElse(100);
-          var serversSeen = counts.keySet();
-          log.debug("total:{} min:{} max:{} serversSeen:{}", total, min, max, serversSeen);
-          return total == 40 && min == 12 && max == 14 && serversSeen.size() == 3;
-        }
-      });
-    }
-  }
-
-  /**
-   * Counts the number of tablets and files in a table.
-   */
-  private int countFiles(AccumuloClient c, String tableName) throws Exception {
-    var tableId = getCluster().getServerContext().getTableId(tableName);
+  private int countFiles(AccumuloClient c) throws Exception {
     try (Scanner s = c.createScanner(MetadataTable.NAME, Authorizations.EMPTY)) {
-      s.setRange(MetadataSchema.TabletsSection.getRange(tableId));
-      TabletColumnFamily.PREV_ROW_COLUMN.fetch(s);
+      s.fetchColumnFamily(new Text(TabletColumnFamily.NAME));
       s.fetchColumnFamily(new Text(DataFileColumnFamily.NAME));
       return Iterators.size(s.iterator());
     }
   }
 
+  private void writeRandomValue(AccumuloClient c, String tableName, int size) throws Exception {
+    byte[] data1 = new byte[size];
+    RANDOM.get().nextBytes(data1);
+
+    try (BatchWriter bw = c.createBatchWriter(tableName)) {
+      Mutation m1 = new Mutation("r" + RANDOM.get().nextInt(909090));
+      m1.put("data", "bl0b", new Value(data1));
+      bw.addMutation(m1);
+    }
+    c.tableOperations().flush(tableName, null, null, true);
+  }
+
+  private Set<String> getRows(AccumuloClient c, String tableName) throws TableNotFoundException {
+    Set<String> rows = new HashSet<>();
+    try (Scanner scanner = c.createScanner(tableName, Authorizations.EMPTY)) {
+      for (Entry<Key,Value> entry : scanner) {
+        rows.add(entry.getKey().getRowData().toString());
+      }
+    }
+    return rows;
+  }
+
+  private void writeFlush(AccumuloClient client, String tablename, String row) throws Exception {
+    try (BatchWriter bw = client.createBatchWriter(tablename)) {
+      Mutation m = new Mutation(row);
+      m.put("", "", "");
+      bw.addMutation(m);
+    }
+    client.tableOperations().flush(tablename, null, null, true);
+  }
+
 }
