@@ -18,7 +18,6 @@
  */
 package org.apache.accumulo.test.functional;
 
-import static java.nio.charset.StandardCharsets.UTF_8;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.net.Socket;
@@ -28,13 +27,14 @@ import java.util.Properties;
 import org.apache.accumulo.core.client.Accumulo;
 import org.apache.accumulo.core.client.AccumuloClient;
 import org.apache.accumulo.core.conf.ClientProperty;
-import org.apache.accumulo.core.util.HostAndPort;
 import org.apache.accumulo.miniclusterImpl.MiniAccumuloConfigImpl;
 import org.apache.hadoop.conf.Configuration;
 import org.junit.jupiter.api.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import com.google.common.net.HostAndPort;
+
 import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
 
 // ACCUMULO-2757 - make sure we don't make too many more watchers
@@ -63,27 +63,29 @@ public class WatchTheWatchCountIT extends ConfigurableMacBase {
       }
       c.tableOperations().list();
       String zooKeepers = ClientProperty.INSTANCE_ZOOKEEPERS.getValue(props);
-      // base number of watchers 110 to 125, and 15 to 20 per table in a single-node instance.
-      final long MIN = 125L;
-      final long MAX = 250L;
+      // base number of watchers 90 to 125, and 15 to 25 per table in a single-node instance.
+      final long MIN = 135L;
+      final long MAX = 200L;
       long total = 0;
       final HostAndPort hostAndPort = HostAndPort.fromString(zooKeepers);
       for (int i = 0; i < 5; i++) {
         try (Socket socket = new Socket(hostAndPort.getHost(), hostAndPort.getPort())) {
-          socket.getOutputStream().write("wchs\n".getBytes(UTF_8), 0, 5);
+          socket.getOutputStream().write("wchs\n".getBytes(), 0, 5);
           byte[] buffer = new byte[1024];
           int n = socket.getInputStream().read(buffer);
-          String response = new String(buffer, 0, n, UTF_8);
+          String response = new String(buffer, 0, n);
           total = Long.parseLong(response.split(":")[1].trim());
           log.info("Total: {}", total);
           if (total > MIN && total < MAX) {
             break;
           }
-          log.debug("Expected number of watchers to be contained in ({}, {}), but"
-              + " actually was {}. Sleeping and retrying", MIN, MAX, total);
+          log.debug("Expected number of watchers to be contained in ({}, {}), currently have {}"
+              + ". Sleeping and retrying", MIN, MAX, total);
           Thread.sleep(5000);
         }
       }
+      log.info("Number of watchers to be expected in range: ({}, {}), currently have {}", MIN, MAX,
+          total);
 
       assertTrue(total > MIN && total < MAX, "Expected number of watchers to be contained in ("
           + MIN + ", " + MAX + "), but actually was " + total);
