@@ -19,6 +19,7 @@
 package org.apache.accumulo.test.manager;
 
 import static java.util.concurrent.TimeUnit.SECONDS;
+import static org.apache.accumulo.core.util.LazySingletons.RANDOM;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.junit.jupiter.api.Assertions.fail;
@@ -32,6 +33,7 @@ import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
+import java.util.Objects;
 import java.util.Set;
 import java.util.SortedSet;
 import java.util.TreeSet;
@@ -51,16 +53,14 @@ import org.apache.accumulo.core.clientImpl.TabletLocator;
 import org.apache.accumulo.core.conf.ClientProperty;
 import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.data.Range;
-import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.metadata.MetadataTable;
+import org.apache.accumulo.core.metadata.RootTable;
 import org.apache.accumulo.core.metadata.TServerInstance;
 import org.apache.accumulo.core.metadata.TabletLocationState;
-import org.apache.accumulo.core.metadata.schema.Ample.DataLevel;
 import org.apache.accumulo.core.rpc.clients.ThriftClientTypes;
 import org.apache.accumulo.core.spi.balancer.HostRegexTableLoadBalancer;
 import org.apache.accumulo.core.spi.balancer.data.TabletServerId;
-import org.apache.accumulo.core.util.HostAndPort;
 import org.apache.accumulo.minicluster.ServerType;
 import org.apache.accumulo.miniclusterImpl.MiniAccumuloConfigImpl;
 import org.apache.accumulo.miniclusterImpl.ProcessReference;
@@ -77,12 +77,14 @@ import org.slf4j.LoggerFactory;
 
 import com.google.common.collect.HashMultimap;
 import com.google.common.collect.SetMultimap;
+import com.google.common.net.HostAndPort;
 
 public class SuspendedTabletsIT extends ConfigurableMacBase {
   private static final Logger log = LoggerFactory.getLogger(SuspendedTabletsIT.class);
   private static ExecutorService THREAD_POOL;
 
   public static final int TSERVERS = 3;
+  public static final long SUSPEND_DURATION = 80;
   public static final int TABLETS = 30;
 
   private ProcessReference metadataTserverProcess;
@@ -94,6 +96,7 @@ public class SuspendedTabletsIT extends ConfigurableMacBase {
 
   @Override
   public void configure(MiniAccumuloConfigImpl cfg, Configuration fsConf) {
+    cfg.setProperty(Property.TABLE_SUSPEND_DURATION, SUSPEND_DURATION + "s");
     cfg.setClientProperty(ClientProperty.INSTANCE_ZOOKEEPERS_TIMEOUT, "5s");
     cfg.setProperty(Property.INSTANCE_ZK_TIMEOUT, "5s");
     // Start with 1 tserver, we'll increase that later
@@ -126,11 +129,11 @@ public class SuspendedTabletsIT extends ConfigurableMacBase {
 
       // Wait for the balancer to assign all metadata tablets to the chosen server.
       ClientContext ctx = (ClientContext) client;
-      TabletLocations tl = TabletLocations.retrieve(ctx, MetadataTable.NAME);
+      TabletLocations tl = TabletLocations.retrieve(ctx, MetadataTable.NAME, RootTable.NAME);
       while (tl.hosted.keySet().size() != 1 || !tl.hosted.containsKey(metadataServer)) {
         log.info("Metadata tablets are not hosted on the correct server. Waiting for balancer...");
         Thread.sleep(1000L);
-        tl = TabletLocations.retrieve(ctx, MetadataTable.NAME);
+        tl = TabletLocations.retrieve(ctx, MetadataTable.NAME, RootTable.NAME);
       }
       log.info("Metadata tablets are now hosted on {}", metadataServer);
     }
@@ -147,45 +150,91 @@ public class SuspendedTabletsIT extends ConfigurableMacBase {
     getCluster().start();
   }
 
-  enum AfterSuspendAction {
-    RESUME("80s"),
-    // Set a long suspend time for testing offline table, want the suspension to be cleared because
-    // the tablet went offline and not the because the suspension timed out.
-    OFFLINE("800s");
-
-    public final String suspendTime;
-
-    AfterSuspendAction(String suspendTime) {
-      this.suspendTime = suspendTime;
-    }
-  }
-
   @Test
   public void crashAndResumeTserver() throws Exception {
     // Run the test body. When we get to the point where we need a tserver to go away, get rid of it
     // via crashing
-    suspensionTestBody(new CrashTserverKiller(), AfterSuspendAction.RESUME);
-  }
+    suspensionTestBody((ctx, locs, count) -> {
+      // Exclude the tablet server hosting the metadata table from the list and only
+      // kill tablet servers that are not hosting the metadata table.
+      List<ProcessReference> procs = getCluster().getProcesses().get(ServerType.TABLET_SERVER)
+          .stream().filter(p -> !metadataTserverProcess.equals(p)).collect(Collectors.toList());
+      Collections.shuffle(procs, RANDOM.get());
+      assertEquals(TSERVERS - 1, procs.size(), "Not enough tservers exist");
+      assertTrue(procs.size() >= count, "Attempting to kill more tservers (" + count
+          + ") than exist in the cluster (" + procs.size() + ")");
 
-  @Test
-  public void crashAndOffline() throws Exception {
-    // Test to ensure that taking a table offline causes the suspension markers to be cleared.
-    // Suspension markers can prevent balancing and possibly cause other problems, so its good to
-    // clear them for offline tables.
-    suspensionTestBody(new CrashTserverKiller(), AfterSuspendAction.OFFLINE);
+      for (int i = 0; i < count; ++i) {
+        ProcessReference pr = procs.get(i);
+        log.info("Crashing {}", pr.getProcess());
+        getCluster().killProcess(ServerType.TABLET_SERVER, pr);
+      }
+    });
   }
 
   @Test
   public void shutdownAndResumeTserver() throws Exception {
     // Run the test body. When we get to the point where we need tservers to go away, stop them via
     // a clean shutdown.
-    suspensionTestBody(new ShutdownTserverKiller(), AfterSuspendAction.RESUME);
-  }
+    suspensionTestBody((ctx, locs, count) -> {
+      Set<TServerInstance> tserverSet = new HashSet<>();
+      Set<TServerInstance> metadataServerSet = new HashSet<>();
 
-  @Test
-  public void shutdownAndOffline() throws Exception {
-    // Test to ensure that taking a table offline causes the suspension markers to be cleared.
-    suspensionTestBody(new ShutdownTserverKiller(), AfterSuspendAction.OFFLINE);
+      TabletLocator tl = TabletLocator.getLocator(ctx, MetadataTable.ID);
+      for (TabletLocationState tls : locs.locationStates.values()) {
+        if (tls.current != null) {
+          // add to set of all servers
+          tserverSet.add(tls.current.getServerInstance());
+
+          // get server that the current tablets metadata is on
+          TabletLocator.TabletLocation tab =
+              tl.locateTablet(ctx, tls.extent.toMetaRow(), false, false);
+          // add it to the set of servers with metadata
+          metadataServerSet.add(new TServerInstance(tab.getTserverLocation(),
+              Long.valueOf(tab.getTserverSession(), 16)));
+        }
+      }
+
+      // remove servers with metadata on them from the list of servers to be shutdown
+      assertEquals(1, metadataServerSet.size(), "Expecting a single tServer in metadataServerSet");
+      tserverSet.removeAll(metadataServerSet);
+
+      assertEquals(TSERVERS - 1, tserverSet.size(),
+          "Expecting " + (TSERVERS - 1) + " tServers in shutdown-list");
+
+      List<TServerInstance> tserversList = new ArrayList<>(tserverSet);
+      Collections.shuffle(tserversList, RANDOM.get());
+
+      for (int i1 = 0; i1 < count; ++i1) {
+        final String tserverName = tserversList.get(i1).getHostPortSession();
+        ThriftClientTypes.MANAGER.executeVoid(ctx, client -> {
+          log.info("Sending shutdown command to {} via ManagerClientService", tserverName);
+          client.shutdownTabletServer(null, ctx.rpcCreds(), tserverName, false);
+        });
+      }
+
+      log.info("Waiting for tserver process{} to die", count == 1 ? "" : "es");
+      for (int i2 = 0; i2 < 10; ++i2) {
+        List<ProcessReference> deadProcs = new ArrayList<>();
+        for (ProcessReference pr1 : getCluster().getProcesses().get(ServerType.TABLET_SERVER)) {
+          Process p = pr1.getProcess();
+          if (!p.isAlive()) {
+            deadProcs.add(pr1);
+          }
+        }
+        for (ProcessReference pr2 : deadProcs) {
+          log.info("Process {} is dead, informing cluster control about this", pr2.getProcess());
+          getCluster().getClusterControl().killProcess(ServerType.TABLET_SERVER, pr2);
+          --count;
+        }
+        if (count == 0) {
+          return;
+        } else {
+          Thread.sleep(SECONDS.toMillis(2));
+        }
+      }
+      throw new IllegalStateException("Tablet servers didn't die!");
+    });
   }
 
   /**
@@ -193,8 +242,7 @@ public class SuspendedTabletsIT extends ConfigurableMacBase {
    *
    * @param serverStopper callback which shuts down some tablet servers.
    */
-  private void suspensionTestBody(TServerKiller serverStopper, AfterSuspendAction action)
-      throws Exception {
+  private void suspensionTestBody(TServerKiller serverStopper) throws Exception {
     try (AccumuloClient client = Accumulo.newClient().from(getClientProperties()).build()) {
       ClientContext ctx = (ClientContext) client;
 
@@ -206,7 +254,6 @@ public class SuspendedTabletsIT extends ConfigurableMacBase {
       }
       log.info("Creating table " + tableName);
       NewTableConfiguration ntc = new NewTableConfiguration().withSplits(splitPoints);
-      ntc.setProperties(Map.of(Property.TABLE_SUSPEND_DURATION.getKey(), action.suspendTime));
       ctx.tableOperations().create(tableName, ntc);
 
       // Wait for all of the tablets to hosted ...
@@ -254,43 +301,27 @@ public class SuspendedTabletsIT extends ConfigurableMacBase {
         assertEquals(beforeDeathState.hosted.get(server), deadTabletsByServer.get(server));
       }
       assertEquals(TABLETS, ds.hostedCount + ds.suspendedCount);
+      // Restart the first tablet server, making sure it ends up on the same port
+      HostAndPort restartedServer = deadTabletsByServer.keySet().iterator().next();
+      log.info("Restarting " + restartedServer);
+      getCluster().getClusterControl().start(ServerType.TABLET_SERVER,
+          Map.of(Property.TSERV_CLIENTPORT.getKey(), "" + restartedServer.getPort(),
+              Property.TSERV_PORTSEARCH.getKey(), "false"),
+          1);
 
-      assertTrue(ds.suspendedCount > 0);
+      // Eventually, the suspended tablets should be reassigned to the newly alive tserver.
+      log.info("Awaiting tablet unsuspension for tablets belonging to " + restartedServer);
+      while (ds.suspended.containsKey(restartedServer) || ds.assignedCount != 0) {
+        Thread.sleep(1000);
+        ds = TabletLocations.retrieve(ctx, tableName);
+      }
+      assertEquals(deadTabletsByServer.get(restartedServer), ds.hosted.get(restartedServer));
 
-      if (action == AfterSuspendAction.OFFLINE) {
-        client.tableOperations().offline(tableName, true);
-
-        while (ds.suspendedCount > 0) {
-          Thread.sleep(1000);
-          ds = TabletLocations.retrieve(ctx, tableName);
-          log.info("Waiting for suspended {}", ds.suspended);
-        }
-      } else if (action == AfterSuspendAction.RESUME) {
-        // Restart the first tablet server, making sure it ends up on the same port
-        HostAndPort restartedServer = deadTabletsByServer.keySet().iterator().next();
-        log.info("Restarting " + restartedServer);
-        getCluster().getClusterControl()
-            .start(
-                ServerType.TABLET_SERVER, Map.of(Property.TSERV_CLIENTPORT.getKey(),
-                    "" + restartedServer.getPort(), Property.TSERV_PORTSEARCH.getKey(), "false"),
-                1);
-
-        // Eventually, the suspended tablets should be reassigned to the newly alive tserver.
-        log.info("Awaiting tablet unsuspension for tablets belonging to " + restartedServer);
-        while (ds.suspended.containsKey(restartedServer) || ds.assignedCount != 0) {
-          Thread.sleep(1000);
-          ds = TabletLocations.retrieve(ctx, tableName);
-        }
-        assertEquals(deadTabletsByServer.get(restartedServer), ds.hosted.get(restartedServer));
-
-        // Finally, after much longer, remaining suspended tablets should be reassigned.
-        log.info("Awaiting tablet reassignment for remaining tablets");
-        while (ds.hostedCount != TABLETS) {
-          Thread.sleep(1000);
-          ds = TabletLocations.retrieve(ctx, tableName);
-        }
-      } else {
-        throw new IllegalStateException("Unknown action " + action);
+      // Finally, after much longer, remaining suspended tablets should be reassigned.
+      log.info("Awaiting tablet reassignment for remaining tablets");
+      while (ds.hostedCount != TABLETS) {
+        Thread.sleep(1000);
+        ds = TabletLocations.retrieve(ctx, tableName);
       }
     }
   }
@@ -300,95 +331,6 @@ public class SuspendedTabletsIT extends ConfigurableMacBase {
         throws Exception;
   }
 
-  private class ShutdownTserverKiller implements TServerKiller {
-
-    @Override
-    public void eliminateTabletServers(ClientContext ctx, TabletLocations locs, int count)
-        throws Exception {
-
-      Set<TServerInstance> tserverSet = new HashSet<>();
-      Set<TServerInstance> metadataServerSet = new HashSet<>();
-
-      TabletLocator tl = TabletLocator.getLocator(ctx, MetadataTable.ID);
-      for (TabletLocationState tls : locs.locationStates.values()) {
-        if (tls.current != null) {
-          // add to set of all servers
-          tserverSet.add(tls.current.getServerInstance());
-
-          // get server that the current tablets metadata is on
-          TabletLocator.TabletLocation tab =
-              tl.locateTablet(ctx, tls.extent.toMetaRow(), false, false);
-          // add it to the set of servers with metadata
-          metadataServerSet
-              .add(new TServerInstance(tab.tablet_location, Long.valueOf(tab.tablet_session, 16)));
-        }
-      }
-
-      // remove servers with metadata on them from the list of servers to be shutdown
-      assertEquals(1, metadataServerSet.size(), "Expecting a single tServer in metadataServerSet");
-      tserverSet.removeAll(metadataServerSet);
-
-      assertEquals(TSERVERS - 1, tserverSet.size(),
-          "Expecting " + (TSERVERS - 1) + " tServers in shutdown-list");
-
-      List<TServerInstance> tserversList = new ArrayList<>(tserverSet);
-      Collections.shuffle(tserversList, random);
-
-      for (int i1 = 0; i1 < count; ++i1) {
-        final String tserverName = tserversList.get(i1).getHostPortSession();
-        ThriftClientTypes.MANAGER.executeVoid(ctx, client -> {
-          log.info("Sending shutdown command to {} via ManagerClientService", tserverName);
-          client.shutdownTabletServer(null, ctx.rpcCreds(), tserverName, false);
-        });
-      }
-
-      log.info("Waiting for tserver process{} to die", count == 1 ? "" : "es");
-      for (int i2 = 0; i2 < 10; ++i2) {
-        List<ProcessReference> deadProcs = new ArrayList<>();
-        for (ProcessReference pr1 : getCluster().getProcesses().get(ServerType.TABLET_SERVER)) {
-          Process p = pr1.getProcess();
-          if (!p.isAlive()) {
-            deadProcs.add(pr1);
-          }
-        }
-        for (ProcessReference pr2 : deadProcs) {
-          log.info("Process {} is dead, informing cluster control about this", pr2.getProcess());
-          getCluster().getClusterControl().killProcess(ServerType.TABLET_SERVER, pr2);
-          --count;
-        }
-        if (count == 0) {
-          return;
-        } else {
-          Thread.sleep(SECONDS.toMillis(2));
-        }
-      }
-      throw new IllegalStateException("Tablet servers didn't die!");
-
-    }
-  }
-
-  private class CrashTserverKiller implements TServerKiller {
-
-    @Override
-    public void eliminateTabletServers(ClientContext ctx, TabletLocations locs, int count)
-        throws Exception {
-      // Exclude the tablet server hosting the metadata table from the list and only
-      // kill tablet servers that are not hosting the metadata table.
-      List<ProcessReference> procs = getCluster().getProcesses().get(ServerType.TABLET_SERVER)
-          .stream().filter(p -> !metadataTserverProcess.equals(p)).collect(Collectors.toList());
-      Collections.shuffle(procs, random);
-      assertEquals(TSERVERS - 1, procs.size(), "Not enough tservers exist");
-      assertTrue(procs.size() >= count, "Attempting to kill more tservers (" + count
-          + ") than exist in the cluster (" + procs.size() + ")");
-
-      for (int i = 0; i < count; ++i) {
-        ProcessReference pr = procs.get(i);
-        log.info("Crashing {}", pr.getProcess());
-        getCluster().killProcess(ServerType.TABLET_SERVER, pr);
-      }
-    }
-  }
-
   private static final AtomicInteger threadCounter = new AtomicInteger(0);
 
   @BeforeAll
@@ -454,6 +396,11 @@ public class SuspendedTabletsIT extends ConfigurableMacBase {
 
     public static TabletLocations retrieve(final ClientContext ctx, final String tableName)
         throws Exception {
+      return retrieve(ctx, tableName, MetadataTable.NAME);
+    }
+
+    public static TabletLocations retrieve(final ClientContext ctx, final String tableName,
+        final String metaName) throws Exception {
       int sleepTime = 200;
       int remainingAttempts = 30;
 
@@ -461,7 +408,7 @@ public class SuspendedTabletsIT extends ConfigurableMacBase {
         try {
           FutureTask<TabletLocations> tlsFuture = new FutureTask<>(() -> {
             TabletLocations answer = new TabletLocations();
-            answer.scan(ctx, tableName);
+            answer.scan(ctx, tableName, metaName);
             return answer;
           });
           THREAD_POOL.execute(tlsFuture);
@@ -480,14 +427,14 @@ public class SuspendedTabletsIT extends ConfigurableMacBase {
       }
     }
 
-    private void scan(ClientContext ctx, String tableName) {
+    private void scan(ClientContext ctx, String tableName, String metaName) {
       Map<String,String> idMap = ctx.tableOperations().tableIdMap();
-      TableId tableId = TableId.of(idMap.get(tableName));
-      try (var scanner = new MetaDataTableScanner(ctx, new Range(), DataLevel.of(tableId))) {
+      String tableId = Objects.requireNonNull(idMap.get(tableName));
+      try (var scanner = new MetaDataTableScanner(ctx, new Range(), metaName)) {
         while (scanner.hasNext()) {
           TabletLocationState tls = scanner.next();
 
-          if (!tls.extent.tableId().equals(tableId)) {
+          if (!tls.extent.tableId().canonical().equals(tableId)) {
             continue;
           }
           locationStates.put(tls.extent, tls);
