@@ -20,7 +20,6 @@ package org.apache.accumulo.test.metrics;
 
 import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertNotEquals;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.junit.jupiter.api.Assertions.fail;
 
@@ -43,9 +42,7 @@ import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.data.Mutation;
 import org.apache.accumulo.core.data.Value;
 import org.apache.accumulo.core.metrics.MetricsProducer;
-import org.apache.accumulo.core.spi.metrics.LoggingMeterRegistryFactory;
 import org.apache.accumulo.miniclusterImpl.MiniAccumuloConfigImpl;
-import org.apache.accumulo.server.ServerOpts;
 import org.apache.accumulo.test.functional.ConfigurableMacBase;
 import org.apache.accumulo.test.metrics.TestStatsDSink.Metric;
 import org.apache.hadoop.conf.Configuration;
@@ -81,14 +78,11 @@ public class MetricsIT extends ConfigurableMacBase implements MetricsProducer {
     cfg.setProperty(Property.GC_CYCLE_START, "1s");
     cfg.setProperty(Property.GC_CYCLE_DELAY, "1s");
     cfg.setProperty(Property.MANAGER_FATE_METRICS_MIN_UPDATE_INTERVAL, "1s");
-    // Tell the server processes to use a StatsDMeterRegistry and the simple logging registry
-    // that will be configured to push all metrics to the sink we started.
+
+    // Tell the server processes to use a StatsDMeterRegistry that will be configured
+    // to push all metrics to the sink we started.
     cfg.setProperty(Property.GENERAL_MICROMETER_ENABLED, "true");
-    cfg.setProperty(Property.GENERAL_MICROMETER_JVM_METRICS_ENABLED, "true");
-    cfg.setProperty("general.custom.metrics.opts.logging.step", "1s");
-    String clazzList = LoggingMeterRegistryFactory.class.getName() + ","
-        + TestStatsDRegistryFactory.class.getName();
-    cfg.setProperty(Property.GENERAL_MICROMETER_FACTORY, clazzList);
+    cfg.setProperty(Property.GENERAL_MICROMETER_FACTORY, TestStatsDRegistryFactory.class.getName());
     Map<String,String> sysProps = Map.of(TestStatsDRegistryFactory.SERVER_HOST, "127.0.0.1",
         TestStatsDRegistryFactory.SERVER_PORT, Integer.toString(sink.getPort()));
     cfg.setSystemProperties(sysProps);
@@ -99,29 +93,13 @@ public class MetricsIT extends ConfigurableMacBase implements MetricsProducer {
 
     doWorkToGenerateMetrics();
     cluster.stop();
-    // meter names sorted and formatting disabled to make it easier to diff changes
-    // @formatter:off
-    Set<String> unexpectedMetrics =
-            Set.of(METRICS_COMPACTOR_MAJC_STUCK,
-                    METRICS_COMPACTOR_COMPACTIONS_CANCELLED,
-                    METRICS_COMPACTOR_COMPACTIONS_COMPLETED,
-                    METRICS_COMPACTOR_COMPACTIONS_FAILED,
-                    METRICS_COMPACTOR_FAILURES_CONSECUTIVE,
-                    METRICS_COMPACTOR_FAILURES_TERMINATION,
-                    METRICS_REPLICATION_QUEUE,
-                    METRICS_SCAN_YIELDS,
-                    METRICS_UPDATE_ERRORS);
 
-    // add sserver as flaky until scan server included in mini tests.
-    Set<String> flakyMetrics = Set.of(METRICS_FATE_TYPE_IN_PROGRESS,
-            METRICS_MANAGER_BALANCER_MIGRATIONS_NEEDED,
-            METRICS_SCAN_BUSY_TIMEOUT_COUNTER,
-            METRICS_SCAN_RESERVATION_CONFLICT_COUNTER,
-            METRICS_SCAN_RESERVATION_TOTAL_TIMER,
-            METRICS_SCAN_RESERVATION_WRITEOUT_TIMER,
-            METRICS_SCAN_TABLET_METADATA_CACHE,
-            METRICS_SERVER_IDLE);
-    // @formatter:on
+    Set<String> unexpectedMetrics = Set.of(METRICS_SCAN_YIELDS, METRICS_UPDATE_ERRORS,
+        METRICS_COMPACTOR_MAJC_STUCK, METRICS_SCAN_BUSY_TIMEOUT, METRICS_SCAN_PAUSED_FOR_MEM,
+        METRICS_SCAN_RETURN_FOR_MEM, METRICS_MINC_PAUSED, METRICS_MAJC_PAUSED);
+    Set<String> flakyMetrics = Set.of(METRICS_GC_WAL_ERRORS, METRICS_FATE_TYPE_IN_PROGRESS,
+        METRICS_PROPSTORE_EVICTION_COUNT, METRICS_PROPSTORE_REFRESH_COUNT,
+        METRICS_PROPSTORE_REFRESH_LOAD_COUNT, METRICS_PROPSTORE_ZK_ERROR_COUNT);
 
     Map<String,String> expectedMetricNames = this.getMetricFields();
     flakyMetrics.forEach(expectedMetricNames::remove); // might not see these
@@ -212,8 +190,7 @@ public class MetricsIT extends ConfigurableMacBase implements MetricsProducer {
             var t = a.getTags();
             log.trace("METRICS, name: '{}' num tags: {}, tags: {}", a.getName(), t.size(), t);
             // check hostname is always set and is valid
-            assertNotEquals(ServerOpts.BIND_ALL_ADDRESSES, a.getTags().get("host"));
-            assertNotNull(a.getTags().get("instance.name"));
+            assertNotEquals("0.0.0.0", a.getTags().get("host"));
 
             // check the length of the tag value is sane
             final int MAX_EXPECTED_TAG_LEN = 128;
