@@ -18,7 +18,7 @@
  */
 package org.apache.accumulo.test.performance.scan;
 
-import static org.apache.accumulo.harness.AccumuloITBase.random;
+import static org.apache.accumulo.core.util.LazySingletons.RANDOM;
 
 import java.io.IOException;
 import java.net.InetAddress;
@@ -64,26 +64,25 @@ import org.apache.accumulo.core.iteratorsImpl.system.MultiIterator;
 import org.apache.accumulo.core.iteratorsImpl.system.SortedMapIterator;
 import org.apache.accumulo.core.iteratorsImpl.system.VisibilityFilter;
 import org.apache.accumulo.core.metadata.MetadataServicer;
+import org.apache.accumulo.core.metadata.StoredTabletFile;
 import org.apache.accumulo.core.metadata.TabletFile;
 import org.apache.accumulo.core.security.Authorizations;
 import org.apache.accumulo.core.spi.crypto.NoCryptoServiceFactory;
-import org.apache.accumulo.core.util.HostAndPort;
 import org.apache.accumulo.core.util.Stat;
 import org.apache.accumulo.server.ServerContext;
 import org.apache.accumulo.server.cli.ServerUtilOpts;
 import org.apache.accumulo.server.conf.TableConfiguration;
 import org.apache.accumulo.server.fs.VolumeManager;
-import org.apache.accumulo.server.iterators.SystemIteratorEnvironmentImpl;
 import org.apache.accumulo.server.util.MetadataTableUtil;
 import org.apache.hadoop.fs.BlockLocation;
 import org.apache.hadoop.fs.FileStatus;
 import org.apache.hadoop.fs.FileSystem;
-import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.io.Text;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import com.beust.jcommander.Parameter;
+import com.google.common.net.HostAndPort;
 
 import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
 
@@ -104,6 +103,8 @@ public class CollectTabletStats {
     String columns;
   }
 
+  static class TestEnvironment implements IteratorEnvironment {}
+
   public static void main(String[] args) throws Exception {
 
     final CollectOptions opts = new CollectOptions();
@@ -136,10 +137,10 @@ public class CollectTabletStats {
 
     List<KeyExtent> tabletsToTest = selectRandomTablets(opts.numThreads, candidates);
 
-    Map<KeyExtent,List<TabletFile>> tabletFiles = new HashMap<>();
+    Map<KeyExtent,List<StoredTabletFile>> tabletFiles = new HashMap<>();
 
     for (KeyExtent ke : tabletsToTest) {
-      List<TabletFile> files = getTabletFiles(context, ke);
+      List<StoredTabletFile> files = getTabletFiles(context, ke);
       tabletFiles.put(ke, files);
     }
 
@@ -166,7 +167,7 @@ public class CollectTabletStats {
       ArrayList<Test> tests = new ArrayList<>();
 
       for (final KeyExtent ke : tabletsToTest) {
-        final List<TabletFile> files = tabletFiles.get(ke);
+        final List<StoredTabletFile> files = tabletFiles.get(ke);
         Test test = new Test(ke) {
           @Override
           public int runTest() throws Exception {
@@ -186,7 +187,7 @@ public class CollectTabletStats {
       ArrayList<Test> tests = new ArrayList<>();
 
       for (final KeyExtent ke : tabletsToTest) {
-        final List<TabletFile> files = tabletFiles.get(ke);
+        final List<StoredTabletFile> files = tabletFiles.get(ke);
         Test test = new Test(ke) {
           @Override
           public int runTest() throws Exception {
@@ -204,7 +205,7 @@ public class CollectTabletStats {
       ArrayList<Test> tests = new ArrayList<>();
 
       for (final KeyExtent ke : tabletsToTest) {
-        final List<TabletFile> files = tabletFiles.get(ke);
+        final List<StoredTabletFile> files = tabletFiles.get(ke);
         Test test = new Test(ke) {
           @Override
           public int runTest() throws Exception {
@@ -381,7 +382,7 @@ public class CollectTabletStats {
     List<KeyExtent> tabletsToTest = new ArrayList<>();
 
     for (int i = 0; i < numThreads; i++) {
-      int rindex = random.nextInt(candidates.size());
+      int rindex = RANDOM.get().nextInt(candidates.size());
       tabletsToTest.add(candidates.get(rindex));
       Collections.swap(candidates, rindex, candidates.size() - 1);
       candidates = candidates.subList(0, candidates.size() - 1);
@@ -389,14 +390,14 @@ public class CollectTabletStats {
     return tabletsToTest;
   }
 
-  private static List<TabletFile> getTabletFiles(ServerContext context, KeyExtent ke)
+  private static List<StoredTabletFile> getTabletFiles(ServerContext context, KeyExtent ke)
       throws IOException {
     return new ArrayList<>(
         MetadataTableUtil.getFileAndLogEntries(context, ke).getSecond().keySet());
   }
 
-  private static void reportHdfsBlockLocations(ServerContext context, List<TabletFile> files)
-      throws Exception {
+  private static void reportHdfsBlockLocations(ServerContext context,
+      List<? extends TabletFile> files) throws Exception {
     VolumeManager fs = context.getVolumeManager();
 
     System.out.println("\t\tFile block report : ");
@@ -404,8 +405,8 @@ public class CollectTabletStats {
       FileStatus status = fs.getFileStatus(file.getPath());
 
       if (status.isDirectory()) {
-        // assume it is a map file
-        status = fs.getFileStatus(new Path(file + "/data"));
+        log.warn("Saw unexpected directory at {} while getting block locations", file);
+        continue;
       }
       FileSystem ns = fs.getFileSystemByPath(file.getPath());
       BlockLocation[] locs = ns.getFileBlockLocations(status, 0, status.getLen());
@@ -426,16 +427,16 @@ public class CollectTabletStats {
   }
 
   private static SortedKeyValueIterator<Key,Value> createScanIterator(KeyExtent ke,
-      Collection<SortedKeyValueIterator<Key,Value>> mapfiles, Authorizations authorizations,
+      Collection<SortedKeyValueIterator<Key,Value>> dataFiles, Authorizations authorizations,
       byte[] defaultLabels, HashSet<Column> columnSet, List<IterInfo> ssiList,
-      Map<String,Map<String,String>> ssio, boolean useTableIterators, TableConfiguration conf,
-      ServerContext context) throws IOException, ReflectiveOperationException {
+      Map<String,Map<String,String>> ssio, boolean useTableIterators, TableConfiguration conf)
+      throws IOException {
 
     SortedMapIterator smi = new SortedMapIterator(new TreeMap<>());
 
-    List<SortedKeyValueIterator<Key,Value>> iters = new ArrayList<>(mapfiles.size() + 1);
+    List<SortedKeyValueIterator<Key,Value>> iters = new ArrayList<>(dataFiles.size() + 1);
 
-    iters.addAll(mapfiles);
+    iters.addAll(dataFiles);
     iters.add(smi);
 
     MultiIterator multiIter = new MultiIterator(iters, ke);
@@ -448,25 +449,23 @@ public class CollectTabletStats {
 
     if (useTableIterators) {
       var ibEnv = IteratorConfigUtil.loadIterConf(IteratorScope.scan, ssiList, ssio, conf);
-      IteratorEnvironment iterEnv = new SystemIteratorEnvironmentImpl.Builder(context)
-          .withScope(IteratorScope.scan).withTableId(ke.tableId()).build();
-      var iteratorBuilder = ibEnv.env(iterEnv).useClassLoader("test").build();
+      var iteratorBuilder = ibEnv.env(new TestEnvironment()).useClassLoader("test").build();
       return IteratorConfigUtil.loadIterators(visFilter, iteratorBuilder);
     }
     return visFilter;
   }
 
   private static int readFiles(VolumeManager fs, AccumuloConfiguration aconf,
-      List<TabletFile> files, KeyExtent ke, String[] columns) throws Exception {
+      List<StoredTabletFile> files, KeyExtent ke, String[] columns) throws Exception {
 
     int count = 0;
 
     HashSet<ByteSequence> columnSet = createColumnBSS(columns);
 
-    for (TabletFile file : files) {
+    for (StoredTabletFile file : files) {
       FileSystem ns = fs.getFileSystemByPath(file.getPath());
       FileSKVIterator reader = FileOperations.getInstance().newReaderBuilder()
-          .forFile(file.getPathStr(), ns, ns.getConf(), NoCryptoServiceFactory.NONE)
+          .forFile(file, ns, ns.getConf(), NoCryptoServiceFactory.NONE)
           .withTableConfiguration(aconf).build();
       Range range = new Range(ke.prevEndRow(), false, ke.endRow(), true);
       reader.seek(range, columnSet, !columnSet.isEmpty());
@@ -489,17 +488,17 @@ public class CollectTabletStats {
   }
 
   private static int readFilesUsingIterStack(VolumeManager fs, ServerContext context,
-      List<TabletFile> files, Authorizations auths, KeyExtent ke, String[] columns,
+      List<StoredTabletFile> files, Authorizations auths, KeyExtent ke, String[] columns,
       boolean useTableIterators) throws Exception {
 
     SortedKeyValueIterator<Key,Value> reader;
 
     List<SortedKeyValueIterator<Key,Value>> readers = new ArrayList<>(files.size());
 
-    for (TabletFile file : files) {
+    for (StoredTabletFile file : files) {
       FileSystem ns = fs.getFileSystemByPath(file.getPath());
       readers.add(FileOperations.getInstance().newReaderBuilder()
-          .forFile(file.getPathStr(), ns, ns.getConf(), NoCryptoServiceFactory.NONE)
+          .forFile(file, ns, ns.getConf(), NoCryptoServiceFactory.NONE)
           .withTableConfiguration(context.getConfiguration()).build());
     }
 
@@ -507,7 +506,7 @@ public class CollectTabletStats {
     Map<String,Map<String,String>> emptySsio = Collections.emptyMap();
     TableConfiguration tconf = context.getTableConfiguration(ke.tableId());
     reader = createScanIterator(ke, readers, auths, new byte[] {}, new HashSet<>(), emptyIterinfo,
-        emptySsio, useTableIterators, tconf, context);
+        emptySsio, useTableIterators, tconf);
 
     HashSet<ByteSequence> columnSet = createColumnBSS(columns);
 
