@@ -45,11 +45,6 @@ public class SimpleThriftServiceHandler implements SimpleThriftService.Iface {
     return value;
   }
 
-  @Override
-  public void echoPassVoid(String value) throws TException {
-    setProp("echoPassVoid", value);
-  }
-
   @Override
   public void onewayFail(String value) throws TException {
     setProp("onewayFail", value);
