@@ -107,16 +107,6 @@ public class ThriftBehaviorIT extends WithTestNames {
     assertEquals(KITTY_MSG, client.echoPass(KITTY_MSG));
   }
 
-  @Test
-  public void echoPassVoidHandler() throws TException {
-    handler.echoPassVoid(KITTY_MSG);
-  }
-
-  @Test
-  public void echoPassVoid() throws TException {
-    client.echoPassVoid(KITTY_MSG);
-  }
-
   @Test
   public void onewayFailHandler() throws TException {
     var e = assertThrows(TException.class, () -> handler.onewayFail(KITTY_MSG));
